@@ -15,6 +15,7 @@
  * Copyright (c) 2011      Oak Ridge National Labs.  All rights reserved.
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Mellanox Technologies, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -24,11 +25,11 @@
  */
 
 #define _GNU_SOURCE
+#include <pthread.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <time.h>
-#include <pthread.h>
+#include <unistd.h>
 
 #include <pmix_tool.h>
 
@@ -39,36 +40,36 @@ typedef struct {
     pmix_status_t status;
 } mylock_t;
 
-#define DEBUG_CONSTRUCT_LOCK(l)                     \
-    do {                                            \
-        pthread_mutex_init(&(l)->mutex, NULL);      \
-        pthread_cond_init(&(l)->cond, NULL);        \
-        (l)->active = true;                         \
-        (l)->status = PMIX_SUCCESS;                 \
-    } while(0)
+#define DEBUG_CONSTRUCT_LOCK(l)                \
+    do {                                       \
+        pthread_mutex_init(&(l)->mutex, NULL); \
+        pthread_cond_init(&(l)->cond, NULL);   \
+        (l)->active = true;                    \
+        (l)->status = PMIX_SUCCESS;            \
+    } while (0)
 
 #define DEBUG_DESTRUCT_LOCK(l)              \
     do {                                    \
         pthread_mutex_destroy(&(l)->mutex); \
         pthread_cond_destroy(&(l)->cond);   \
-    } while(0)
+    } while (0)
 
-#define DEBUG_WAIT_THREAD(lck)                                      \
-    do {                                                            \
-        pthread_mutex_lock(&(lck)->mutex);                          \
-        while ((lck)->active) {                                     \
-            pthread_cond_wait(&(lck)->cond, &(lck)->mutex);         \
-        }                                                           \
-        pthread_mutex_unlock(&(lck)->mutex);                        \
-    } while(0)
+#define DEBUG_WAIT_THREAD(lck)                              \
+    do {                                                    \
+        pthread_mutex_lock(&(lck)->mutex);                  \
+        while ((lck)->active) {                             \
+            pthread_cond_wait(&(lck)->cond, &(lck)->mutex); \
+        }                                                   \
+        pthread_mutex_unlock(&(lck)->mutex);                \
+    } while (0)
 
-#define DEBUG_WAKEUP_THREAD(lck)                        \
-    do {                                                \
-        pthread_mutex_lock(&(lck)->mutex);              \
-        (lck)->active = false;                          \
-        pthread_cond_broadcast(&(lck)->cond);           \
-        pthread_mutex_unlock(&(lck)->mutex);            \
-    } while(0)
+#define DEBUG_WAKEUP_THREAD(lck)              \
+    do {                                      \
+        pthread_mutex_lock(&(lck)->mutex);    \
+        (lck)->active = false;                \
+        pthread_cond_broadcast(&(lck)->cond); \
+        pthread_mutex_unlock(&(lck)->mutex);  \
+    } while (0)
 
 /* define a structure for collecting returned
  * info from a query */
@@ -94,13 +95,10 @@ static pmix_proc_t myproc;
  * Once we have dealt with the returned data, we must
  * call the release_fn so that the PMIx library can
  * cleanup */
-static void cbfunc(pmix_status_t status,
-                   pmix_info_t *info, size_t ninfo,
-                   void *cbdata,
-                   pmix_release_cbfunc_t release_fn,
-                   void *release_cbdata)
+static void querycbfunc(pmix_status_t status, pmix_info_t *info, size_t ninfo, void *cbdata,
+                        pmix_release_cbfunc_t release_fn, void *release_cbdata)
 {
-    myquery_data_t *mq = (myquery_data_t*)cbdata;
+    myquery_data_t *mq = (myquery_data_t *) cbdata;
     size_t n;
 
     /* save the returned info - the PMIx library "owns" it
@@ -109,7 +107,7 @@ static void cbfunc(pmix_status_t status,
     if (0 < ninfo) {
         PMIX_INFO_CREATE(mq->info, ninfo);
         mq->ninfo = ninfo;
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             fprintf(stderr, "Transferring %s\n", info[n].key);
             PMIX_INFO_XFER(&mq->info[n], &info[n]);
         }
@@ -129,13 +127,10 @@ static void cbfunc(pmix_status_t status,
  * when registering for general events - i.e.,, the default
  * handler. We don't technically need to register one, but it
  * is usually good practice to catch any events that occur */
-static void notification_fn(size_t evhdlr_registration_id,
-                            pmix_status_t status,
-                            const pmix_proc_t *source,
-                            pmix_info_t info[], size_t ninfo,
+static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
+                            const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                             pmix_info_t results[], size_t nresults,
-                            pmix_event_notification_cbfunc_fn_t cbfunc,
-                            void *cbdata)
+                            pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
     /* this example doesn't do anything with default events */
     if (NULL != cbfunc) {
@@ -150,13 +145,10 @@ static void notification_fn(size_t evhdlr_registration_id,
  * to declare a use-specific notification callback point. In this case,
  * we are asking to know whenever a job terminates, and we will then
  * know we can exit */
-static void release_fn(size_t evhdlr_registration_id,
-                       pmix_status_t status,
-                       const pmix_proc_t *source,
-                       pmix_info_t info[], size_t ninfo,
+static void release_fn(size_t evhdlr_registration_id, pmix_status_t status,
+                       const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                        pmix_info_t results[], size_t nresults,
-                       pmix_event_notification_cbfunc_fn_t cbfunc,
-                       void *cbdata)
+                       pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
     /* tell the event handler state machine that we are the last step */
     if (NULL != cbfunc) {
@@ -173,15 +165,13 @@ static void release_fn(size_t evhdlr_registration_id,
  * to the registered event. The index is used later on to deregister
  * an event handler - if we don't explicitly deregister it, then the
  * PMIx server will do so when it see us exit */
-static void evhandler_reg_callbk(pmix_status_t status,
-                                 size_t evhandler_ref,
-                                 void *cbdata)
+static void evhandler_reg_callbk(pmix_status_t status, size_t evhandler_ref, void *cbdata)
 {
-    mylock_t *lock = (mylock_t*)cbdata;
+    mylock_t *lock = (mylock_t *) cbdata;
 
     if (PMIX_SUCCESS != status) {
         fprintf(stderr, "Client %s:%d EVENT HANDLER REGISTRATION FAILED WITH STATUS %d, ref=%lu\n",
-                   myproc.nspace, myproc.rank, status, (unsigned long)evhandler_ref);
+                myproc.nspace, myproc.rank, status, (unsigned long) evhandler_ref);
     }
     lock->status = status;
     DEBUG_WAKEUP_THREAD(lock);
@@ -194,26 +184,30 @@ static pmix_status_t spawn_debugger(char *appspace)
     pmix_app_t *debugger;
     size_t dninfo;
     char cwd[1024];
-    char dspace[PMIX_MAX_NSLEN+1];
+    char dspace[PMIX_MAX_NSLEN + 1];
 
     /* setup the debugger */
     PMIX_APP_CREATE(debugger, 1);
     debugger[0].cmd = strdup("./debuggerd");
     PMIX_ARGV_APPEND(rc, debugger[0].argv, "./debuggerd");
-    getcwd(cwd, 1024);  // point us to our current directory
+    getcwd(cwd, 1024); // point us to our current directory
     debugger[0].cwd = strdup(cwd);
     /* provide directives so the daemons go where we want, and
      * let the RM know these are debugger daemons */
     dninfo = 4;
     PMIX_INFO_CREATE(dinfo, dninfo);
-    PMIX_INFO_LOAD(&dinfo[0], PMIX_MAPBY, "ppr:1:node", PMIX_STRING);  // instruct the RM to launch one copy of the executable on each node
+    PMIX_INFO_LOAD(&dinfo[0], PMIX_MAPBY, "ppr:1:node",
+                   PMIX_STRING); // instruct the RM to launch one copy of the executable on each
+                                 // node
     PMIX_INFO_LOAD(&dinfo[1], PMIX_DEBUGGER_DAEMONS, NULL, PMIX_BOOL); // these are debugger daemons
-    PMIX_INFO_LOAD(&dinfo[2], PMIX_DEBUG_JOB, appspace, PMIX_STRING); // the nspace being debugged
-    PMIX_INFO_LOAD(&dinfo[3], PMIX_NOTIFY_COMPLETION, NULL, PMIX_BOOL); // notify us when the debugger job completes
+    PMIX_INFO_LOAD(&dinfo[2], PMIX_DEBUG_JOB, appspace, PMIX_STRING);  // the nspace being debugged
+    PMIX_INFO_LOAD(&dinfo[3], PMIX_NOTIFY_COMPLETION, NULL,
+                   PMIX_BOOL); // notify us when the debugger job completes
     /* spawn the daemons */
     fprintf(stderr, "Debugger: spawning %s\n", debugger[0].cmd);
     if (PMIX_SUCCESS != (rc = PMIx_Spawn(dinfo, dninfo, debugger, 1, dspace))) {
-        fprintf(stderr, "Debugger daemons failed to launch with error: %s\n", PMIx_Error_string(rc));
+        fprintf(stderr, "Debugger daemons failed to launch with error: %s\n",
+                PMIx_Error_string(rc));
     }
     fprintf(stderr, "SPAWNED DEBUGGERD\n");
     /* cleanup */
@@ -223,7 +217,7 @@ static pmix_status_t spawn_debugger(char *appspace)
     return rc;
 }
 
-#define DBGR_LOOP_LIMIT  10
+#define DBGR_LOOP_LIMIT 10
 
 int main(int argc, char **argv)
 {
@@ -232,7 +226,7 @@ int main(int argc, char **argv)
     pmix_app_t *app;
     size_t ninfo, napps;
     char *nspace = NULL;
-    char appspace[PMIX_MAX_NSLEN+1];
+    char appspace[PMIX_MAX_NSLEN + 1];
     int i;
     pmix_query_t *query;
     size_t nq, n;
@@ -243,14 +237,11 @@ int main(int argc, char **argv)
     mylock_t mylock;
 
     /* Process any arguments we were given */
-    for (i=1; i < argc; i++) {
-        if (0 == strcmp(argv[i], "-h") ||
-            0 == strcmp(argv[i], "--help")) {
+    for (i = 1; i < argc; i++) {
+        if (0 == strcmp(argv[i], "-h") || 0 == strcmp(argv[i], "--help")) {
             /* print the usage message and exit */
-
         }
-        if (0 == strcmp(argv[i], "-a") ||
-            0 == strcmp(argv[i], "--attach")) {
+        if (0 == strcmp(argv[i], "-a") || 0 == strcmp(argv[i], "--attach")) {
             if (NULL != nspace) {
                 /* can only support one */
                 fprintf(stderr, "Cannot attach to more than one nspace\n");
@@ -288,24 +279,23 @@ int main(int argc, char **argv)
 
     /* register a default event handler */
     DEBUG_CONSTRUCT_LOCK(&mylock);
-    PMIx_Register_event_handler(NULL, 0, NULL, 0,
-                                notification_fn, evhandler_reg_callbk, (void*)&mylock);
+    PMIx_Register_event_handler(NULL, 0, NULL, 0, notification_fn, evhandler_reg_callbk,
+                                (void *) &mylock);
     DEBUG_WAIT_THREAD(&mylock);
     DEBUG_DESTRUCT_LOCK(&mylock);
 
     /* register another handler specifically for when the debugger
      * job completes */
     DEBUG_CONSTRUCT_LOCK(&mylock);
-    PMIx_Register_event_handler(&code, 1, NULL, 0,
-                                release_fn, evhandler_reg_callbk, (void*)&mylock);
+    PMIx_Register_event_handler(&code, 1, NULL, 0, release_fn, evhandler_reg_callbk,
+                                (void *) &mylock);
     DEBUG_WAIT_THREAD(&mylock);
     DEBUG_DESTRUCT_LOCK(&mylock);
 
     /* if we are attaching to a running job, then attach to it */
     if (NULL != nspace) {
         if (PMIX_SUCCESS != (rc = attach_to_running_job(nspace))) {
-            fprintf(stderr, "Failed to attach to nspace %s: error code %d\n",
-                    nspace, rc);
+            fprintf(stderr, "Failed to attach to nspace %s: error code %d\n", nspace, rc);
             goto done;
         }
     } else {
@@ -327,7 +317,8 @@ int main(int argc, char **argv)
         myquery_data.ninfo = 0;
         /* execute the query */
         fprintf(stderr, "Debugger: querying capabilities\n");
-        if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(query, nq, cbfunc, (void*)&myquery_data))) {
+        if (PMIX_SUCCESS
+            != (rc = PMIx_Query_info_nb(query, nq, querycbfunc, (void *) &myquery_data))) {
             fprintf(stderr, "PMIx_Query_info failed: %d\n", rc);
             goto done;
         }
@@ -340,7 +331,8 @@ int main(int argc, char **argv)
          * attributes it supports */
         if (2 != myquery_data.ninfo) {
             /* this is an error */
-            fprintf(stderr, "PMIx Query returned an incorrect number of results: %lu\n", myquery_data.ninfo);
+            fprintf(stderr, "PMIx Query returned an incorrect number of results: %lu\n",
+                    myquery_data.ninfo);
             PMIX_INFO_FREE(myquery_data.info, myquery_data.ninfo);
             goto done;
         }
@@ -357,7 +349,7 @@ int main(int argc, char **argv)
          * in the same order as the query keys. However, this is not guaranteed,
          * so we should search the returned info structures to find the desired key
          */
-        for (n=0; n < myquery_data.ninfo; n++) {
+        for (n = 0; n < myquery_data.ninfo; n++) {
             if (0 == strcmp(myquery_data.info[n].key, PMIX_QUERY_SPAWN_SUPPORT)) {
                 /* see if the cospawn attribute is included */
                 if (NULL != strstr(myquery_data.info[n].value.data.string, PMIX_COSPAWN_APP)) {
@@ -366,7 +358,8 @@ int main(int argc, char **argv)
                     cospawn = false;
                 }
             } else if (0 == strcmp(myquery_data.info[n].key, PMIX_QUERY_DEBUG_SUPPORT)) {
-                if (NULL != strstr(myquery_data.info[n].value.data.string, PMIX_DEBUG_STOP_ON_EXEC)) {
+                if (NULL
+                    != strstr(myquery_data.info[n].value.data.string, PMIX_DEBUG_STOP_ON_EXEC)) {
                     stop_on_exec = true;
                 } else {
                     stop_on_exec = false;
@@ -385,26 +378,29 @@ int main(int argc, char **argv)
             /* setup the executable */
             app[0].cmd = strdup("client");
             PMIX_ARGV_APPEND(rc, app[0].argv, "./client");
-            getcwd(cwd, 1024);  // point us to our current directory
+            getcwd(cwd, 1024); // point us to our current directory
             app[0].cwd = strdup(cwd);
             app[0].maxprocs = 2;
             /* provide job-level directives so the apps do what the user requested */
             ninfo = 4;
             PMIX_INFO_CREATE(info, ninfo);
-            PMIX_INFO_LOAD(&info[0], PMIX_MAPBY, "slot", PMIX_STRING);  // map by slot
+            PMIX_INFO_LOAD(&info[0], PMIX_MAPBY, "slot", PMIX_STRING); // map by slot
             if (stop_on_exec) {
-                PMIX_INFO_LOAD(&info[1], PMIX_DEBUG_STOP_ON_EXEC, NULL, PMIX_BOOL);  // procs are to stop on first instruction
+                PMIX_INFO_LOAD(&info[1], PMIX_DEBUG_STOP_ON_EXEC, NULL,
+                               PMIX_BOOL); // procs are to stop on first instruction
             } else {
-                PMIX_INFO_LOAD(&info[1], PMIX_DEBUG_STOP_IN_INIT, NULL, PMIX_BOOL);  // procs are to pause in PMIx_Init for debugger attach
+                PMIX_INFO_LOAD(&info[1], PMIX_DEBUG_STOP_IN_INIT, NULL,
+                               PMIX_BOOL); // procs are to pause in PMIx_Init for debugger attach
             }
-            PMIX_INFO_LOAD(&info[2], PMIX_FWD_STDOUT, NULL, PMIX_BOOL);  // forward stdout to me
-            PMIX_INFO_LOAD(&info[3], PMIX_FWD_STDERR, NULL, PMIX_BOOL);  // forward stderr to me
+            PMIX_INFO_LOAD(&info[2], PMIX_FWD_STDOUT, NULL, PMIX_BOOL); // forward stdout to me
+            PMIX_INFO_LOAD(&info[3], PMIX_FWD_STDERR, NULL, PMIX_BOOL); // forward stderr to me
 
             /* spawn the job - the function will return when the app
              * has been launched */
             fprintf(stderr, "Debugger: spawning %s\n", app[0].cmd);
             if (PMIX_SUCCESS != (rc = PMIx_Spawn(info, ninfo, app, napps, appspace))) {
-                fprintf(stderr, "Application failed to launch with error: %s(%d)\n", PMIx_Error_string(rc), rc);
+                fprintf(stderr, "Application failed to launch with error: %s(%d)\n",
+                        PMIx_Error_string(rc), rc);
                 goto done;
             }
             PMIX_INFO_FREE(info, ninfo);
@@ -416,22 +412,20 @@ int main(int argc, char **argv)
             }
         }
 
-
         /* this is where a debugger tool would wait until the debug operation is complete */
         DEBUG_WAIT_THREAD(&waiting_for_debugger);
     }
 
-  done:
+done:
     DEBUG_DESTRUCT_LOCK(&waiting_for_debugger);
     PMIx_tool_finalize();
 
-    return(rc);
+    return (rc);
 }
 
 static int attach_to_running_job(char *nspace)
 {
     pmix_status_t rc;
-    pmix_proc_t myproc;
     pmix_query_t *query;
     size_t nq;
     myquery_data_t *q;
@@ -442,10 +436,11 @@ static int attach_to_running_job(char *nspace)
     PMIX_QUERY_CREATE(query, nq);
     PMIX_ARGV_APPEND(rc, query[0].keys, PMIX_QUERY_NAMESPACES);
 
-    q = (myquery_data_t*)malloc(sizeof(myquery_data_t));
+    q = (myquery_data_t *) malloc(sizeof(myquery_data_t));
     DEBUG_CONSTRUCT_LOCK(&q->lock);
-    if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(query, nq, cbfunc, (void*)q))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Query_info failed: %d\n", myproc.nspace, myproc.rank, rc);
+    if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(query, nq, querycbfunc, (void *) q))) {
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Query_info failed: %d\n", myproc.nspace,
+                myproc.rank, rc);
         return -1;
     }
     DEBUG_WAIT_THREAD(&q->lock);
