@@ -17,6 +17,7 @@
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -27,117 +28,99 @@
 
 #include "src/include/pmix_config.h"
 #include "../include/pmix_server.h"
-#include "src/include/types.h"
 #include "src/include/pmix_globals.h"
+#include "src/include/types.h"
 
+#include <dirent.h>
+#include <errno.h>
+#include <pwd.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
-#include <time.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#include <errno.h>
-#include <signal.h>
-#include <pwd.h>
-#include <sys/stat.h>
-#include <dirent.h>
+#include <time.h>
+#include <unistd.h>
 
 #include "src/class/pmix_list.h"
-#include "src/util/pmix_environ.h"
-#include "src/util/output.h"
-#include "src/util/printf.h"
 #include "src/util/argv.h"
+#include "src/util/output.h"
+#include "src/util/pmix_environ.h"
+#include "src/util/printf.h"
 
 static pmix_status_t connected(const pmix_proc_t *proc, void *server_object,
                                pmix_op_cbfunc_t cbfunc, void *cbdata);
 static pmix_status_t finalized(const pmix_proc_t *proc, void *server_object,
                                pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t abort_fn(const pmix_proc_t *proc, void *server_object,
-                              int status, const char msg[],
-                              pmix_proc_t procs[], size_t nprocs,
+static pmix_status_t abort_fn(const pmix_proc_t *proc, void *server_object, int status,
+                              const char msg[], pmix_proc_t procs[], size_t nprocs,
                               pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs,
-                                const pmix_info_t info[], size_t ninfo,
-                                char *data, size_t ndata,
-                                pmix_modex_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t dmodex_fn(const pmix_proc_t *proc,
-                               const pmix_info_t info[], size_t ninfo,
+static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
+                                size_t ninfo, char *data, size_t ndata, pmix_modex_cbfunc_t cbfunc,
+                                void *cbdata);
+static pmix_status_t dmodex_fn(const pmix_proc_t *proc, const pmix_info_t info[], size_t ninfo,
                                pmix_modex_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t publish_fn(const pmix_proc_t *proc,
-                                const pmix_info_t info[], size_t ninfo,
-                                pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys,
-                               const pmix_info_t info[], size_t ninfo,
-                               pmix_lookup_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys,
-                                  const pmix_info_t info[], size_t ninfo,
-                                  pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t spawn_fn(const pmix_proc_t *proc,
-                              const pmix_info_t job_info[], size_t ninfo,
-                              const pmix_app_t apps[], size_t napps,
-                              pmix_spawn_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs,
-                                const pmix_info_t info[], size_t ninfo,
+static pmix_status_t publish_fn(const pmix_proc_t *proc, const pmix_info_t info[], size_t ninfo,
                                 pmix_op_cbfunc_t cbfunc, void *cbdata);
+static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys, const pmix_info_t info[],
+                               size_t ninfo, pmix_lookup_cbfunc_t cbfunc, void *cbdata);
+static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys, const pmix_info_t info[],
+                                  size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata);
+static pmix_status_t spawn_fn(const pmix_proc_t *proc, const pmix_info_t job_info[], size_t ninfo,
+                              const pmix_app_t apps[], size_t napps, pmix_spawn_cbfunc_t cbfunc,
+                              void *cbdata);
+static pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
+                                size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata);
 static pmix_status_t disconnect_fn(const pmix_proc_t procs[], size_t nprocs,
-                                   const pmix_info_t info[], size_t ninfo,
-                                   pmix_op_cbfunc_t cbfunc, void *cbdata);
+                                   const pmix_info_t info[], size_t ninfo, pmix_op_cbfunc_t cbfunc,
+                                   void *cbdata);
 static pmix_status_t register_event_fn(pmix_status_t *codes, size_t ncodes,
                                        const pmix_info_t info[], size_t ninfo,
                                        pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t deregister_events(pmix_status_t *codes, size_t ncodes,
-                                       pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t notify_event(pmix_status_t code,
-                                  const pmix_proc_t *source,
-                                  pmix_data_range_t range,
-                                  pmix_info_t info[], size_t ninfo,
+static pmix_status_t deregister_events(pmix_status_t *codes, size_t ncodes, pmix_op_cbfunc_t cbfunc,
+                                       void *cbdata);
+static pmix_status_t notify_event(pmix_status_t code, const pmix_proc_t *source,
+                                  pmix_data_range_t range, pmix_info_t info[], size_t ninfo,
                                   pmix_op_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t query_fn(pmix_proc_t *proct,
-                              pmix_query_t *queries, size_t nqueries,
-                              pmix_info_cbfunc_t cbfunc,
-                              void *cbdata);
-static void tool_connect_fn(pmix_info_t *info, size_t ninfo,
-                            pmix_tool_connection_cbfunc_t cbfunc,
+static pmix_status_t query_fn(pmix_proc_t *proct, pmix_query_t *queries, size_t nqueries,
+                              pmix_info_cbfunc_t cbfunc, void *cbdata);
+static void tool_connect_fn(pmix_info_t *info, size_t ninfo, pmix_tool_connection_cbfunc_t cbfunc,
                             void *cbdata);
-static void log_fn(const pmix_proc_t *client,
-                   const pmix_info_t data[], size_t ndata,
-                   const pmix_info_t directives[], size_t ndirs,
-                   pmix_op_cbfunc_t cbfunc, void *cbdata);
+static void log_fn(const pmix_proc_t *client, const pmix_info_t data[], size_t ndata,
+                   const pmix_info_t directives[], size_t ndirs, pmix_op_cbfunc_t cbfunc,
+                   void *cbdata);
 
-static pmix_server_module_t mymodule = {
-    .client_connected = connected,
-    .client_finalized = finalized,
-    .abort = abort_fn,
-    .fence_nb = fencenb_fn,
-    .direct_modex = dmodex_fn,
-    .publish = publish_fn,
-    .lookup = lookup_fn,
-    .unpublish = unpublish_fn,
-    .spawn = spawn_fn,
-    .connect = connect_fn,
-    .disconnect = disconnect_fn,
-    .register_events = register_event_fn,
-    .deregister_events = deregister_events,
-    .notify_event = notify_event,
-    .query = query_fn,
-    .tool_connected = tool_connect_fn,
-    .log = log_fn
-};
+static pmix_server_module_t mymodule = {.client_connected = connected,
+                                        .client_finalized = finalized,
+                                        .abort = abort_fn,
+                                        .fence_nb = fencenb_fn,
+                                        .direct_modex = dmodex_fn,
+                                        .publish = publish_fn,
+                                        .lookup = lookup_fn,
+                                        .unpublish = unpublish_fn,
+                                        .spawn = spawn_fn,
+                                        .connect = connect_fn,
+                                        .disconnect = disconnect_fn,
+                                        .register_events = register_event_fn,
+                                        .deregister_events = deregister_events,
+                                        .notify_event = notify_event,
+                                        .query = query_fn,
+                                        .tool_connected = tool_connect_fn,
+                                        .log = log_fn};
 
 typedef struct {
     pmix_list_item_t super;
     pmix_pdata_t pdata;
 } pmix_locdat_t;
-PMIX_CLASS_INSTANCE(pmix_locdat_t,
-                    pmix_list_item_t,
-                    NULL, NULL);
+PMIX_CLASS_INSTANCE(pmix_locdat_t, pmix_list_item_t, NULL, NULL);
 
-#define PMIX_WAIT_FOR_COMPLETION(a)             \
-    do {                                        \
-        while ((a)) {                           \
-            usleep(10);                         \
-        }                                       \
-        PMIX_ACQUIRE_OBJECT((a));               \
+#define PMIX_WAIT_FOR_COMPLETION(a) \
+    do {                            \
+        while ((a)) {               \
+            usleep(10);             \
+        }                           \
+        PMIX_ACQUIRE_OBJECT((a));   \
     } while (0)
 
 typedef struct {
@@ -165,40 +148,31 @@ static void xfdes(myxfer_t *p)
         PMIX_INFO_FREE(p->info, p->ninfo);
     }
 }
-PMIX_CLASS_INSTANCE(myxfer_t,
-                    pmix_object_t,
-                    xfcon, xfdes);
+PMIX_CLASS_INSTANCE(myxfer_t, pmix_object_t, xfcon, xfdes);
 
 typedef struct {
     pmix_list_item_t super;
     pid_t pid;
 } wait_tracker_t;
-PMIX_CLASS_INSTANCE(wait_tracker_t,
-                    pmix_list_item_t,
-                    NULL, NULL);
+PMIX_CLASS_INSTANCE(wait_tracker_t, pmix_list_item_t, NULL, NULL);
 
 static volatile int wakeup;
 static pmix_list_t pubdata;
 static pmix_event_t handler;
 static pmix_list_t children;
 
-static void set_namespace(int nprocs, char *ranks, char *nspace,
-                          pmix_op_cbfunc_t cbfunc, myxfer_t *x);
-static void errhandler(size_t evhdlr_registration_id,
-                       pmix_status_t status,
-                       const pmix_proc_t *source,
-                       pmix_info_t info[], size_t ninfo,
+static void set_namespace(int nprocs, char *ranks, char *nspace, pmix_op_cbfunc_t cbfunc,
+                          myxfer_t *x);
+static void errhandler(size_t evhdlr_registration_id, pmix_status_t status,
+                       const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                        pmix_info_t results[], size_t nresults,
-                       pmix_event_notification_cbfunc_fn_t cbfunc,
-                       void *cbdata);
+                       pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata);
 static void wait_signal_callback(int fd, short event, void *arg);
-static void errhandler_reg_callbk (pmix_status_t status,
-                                   size_t errhandler_ref,
-                                   void *cbdata);
+static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, void *cbdata);
 
 static void opcbfunc(pmix_status_t status, void *cbdata)
 {
-    myxfer_t *x = (myxfer_t*)cbdata;
+    myxfer_t *x = (myxfer_t *) cbdata;
 
     /* release the caller, if necessary */
     if (NULL != x->cbfunc) {
@@ -209,10 +183,10 @@ static void opcbfunc(pmix_status_t status, void *cbdata)
 
 int main(int argc, char **argv)
 {
-    char **client_env=NULL;
-    char **client_argv=NULL;
-    char *tmp, **atmp, *executable=NULL, *tmpdir, *cleanup;
-    int rc, nprocs=1, n, k;
+    char **client_env = NULL;
+    char **client_argv = NULL;
+    char *tmp, **atmp, *executable = NULL, *tmpdir, *cleanup;
+    int rc, nprocs = 1, n, k;
     uid_t myuid;
     gid_t mygid;
     pid_t pid;
@@ -232,7 +206,7 @@ int main(int argc, char **argv)
             }
         }
     }
-    if (0 > asprintf(&tmpdir, "%s/pmix.%lu", tdir, (long unsigned)uid)) {
+    if (0 > asprintf(&tmpdir, "%s/pmix.%lu", tdir, (long unsigned) uid)) {
         fprintf(stderr, "Out of memory\n");
         exit(1);
     }
@@ -256,29 +230,26 @@ int main(int argc, char **argv)
     PMIX_INFO_FREE(info, 1);
 
     /* register the errhandler */
-    PMIx_Register_event_handler(NULL, 0, NULL, 0,
-                                errhandler, errhandler_reg_callbk, NULL);
+    PMIx_Register_event_handler(NULL, 0, NULL, 0, errhandler, errhandler_reg_callbk, NULL);
 
     /* setup the pub data, in case it is used */
     PMIX_CONSTRUCT(&pubdata, pmix_list_t);
 
     /* setup to see sigchld on the forked tests */
     PMIX_CONSTRUCT(&children, pmix_list_t);
-    pmix_event_assign(&handler, pmix_globals.evbase, SIGCHLD,
-                      EV_SIGNAL|EV_PERSIST,wait_signal_callback, &handler);
+    pmix_event_assign(&handler, pmix_globals.evbase, SIGCHLD, EV_SIGNAL | EV_PERSIST,
+                      wait_signal_callback, &handler);
     pmix_event_add(&handler, NULL);
 
     /* see if we were passed the number of procs to run or
      * the executable to use */
-    for (n=1; n < (argc-1); n++) {
-        if (0 == strcmp("-n", argv[n]) &&
-            NULL != argv[n+1]) {
-            nprocs = strtol(argv[n+1], NULL, 10);
-            ++n;  // step over the argument
-        } else if (0 == strcmp("-e", argv[n]) &&
-                   NULL != argv[n+1]) {
-            executable = strdup(argv[n+1]);
-            for (k=n+2; NULL != argv[k]; k++) {
+    for (n = 1; n < (argc - 1); n++) {
+        if (0 == strcmp("-n", argv[n]) && NULL != argv[n + 1]) {
+            nprocs = strtol(argv[n + 1], NULL, 10);
+            ++n; // step over the argument
+        } else if (0 == strcmp("-e", argv[n]) && NULL != argv[n + 1]) {
+            executable = strdup(argv[n + 1]);
+            for (k = n + 2; NULL != argv[k]; k++) {
                 pmix_argv_append_nosize(&client_argv, argv[k]);
             }
             n += k;
@@ -290,7 +261,7 @@ int main(int argc, char **argv)
 
     /* we have a single namespace for all clients */
     atmp = NULL;
-    for (n=0; n < nprocs; n++) {
+    for (n = 0; n < nprocs; n++) {
         asprintf(&tmp, "%d", n);
         pmix_argv_append_nosize(&atmp, tmp);
         free(tmp);
@@ -327,18 +298,18 @@ int main(int argc, char **argv)
     PMIX_RELEASE(x);
 
     /* fork/exec the test */
-    (void)strncpy(proc.nspace, "foobar", PMIX_MAX_NSLEN);
+    (void) strncpy(proc.nspace, "foobar", PMIX_MAX_NSLEN);
     for (n = 0; n < nprocs; n++) {
         proc.rank = n;
-        if (PMIX_SUCCESS != (rc = PMIx_server_setup_fork(&proc, &client_env))) {//n
+        if (PMIX_SUCCESS != (rc = PMIx_server_setup_fork(&proc, &client_env))) { // n
             fprintf(stderr, "Server fork setup failed with error %d\n", rc);
             PMIx_server_finalize();
             system(cleanup);
             return rc;
         }
         x = PMIX_NEW(myxfer_t);
-        if (PMIX_SUCCESS != (rc = PMIx_server_register_client(&proc, myuid, mygid,
-                                                              NULL, opcbfunc, x))) {
+        if (PMIX_SUCCESS
+            != (rc = PMIx_server_register_client(&proc, myuid, mygid, NULL, opcbfunc, x))) {
             fprintf(stderr, "Server fork setup failed with error %d\n", rc);
             PMIx_server_finalize();
             system(cleanup);
@@ -394,18 +365,16 @@ int main(int argc, char **argv)
     return rc;
 }
 
-static void setup_cbfunc(pmix_status_t status,
-                         pmix_info_t info[], size_t ninfo,
-                         void *provided_cbdata,
-                         pmix_op_cbfunc_t cbfunc, void *cbdata)
+static void setup_cbfunc(pmix_status_t status, pmix_info_t info[], size_t ninfo,
+                         void *provided_cbdata, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
-    myxfer_t *myxfer = (myxfer_t*)provided_cbdata;
+    myxfer_t *myxfer = (myxfer_t *) provided_cbdata;
     size_t i;
 
     if (PMIX_SUCCESS == status && 0 < ninfo) {
         myxfer->ninfo = ninfo;
         PMIX_INFO_CREATE(myxfer->info, ninfo);
-        for (i=0; i < ninfo; i++) {
+        for (i = 0; i < ninfo; i++) {
             PMIX_INFO_XFER(&myxfer->info[i], &info[i]);
         }
     }
@@ -415,8 +384,8 @@ static void setup_cbfunc(pmix_status_t status,
     myxfer->active = false;
 }
 
-static void set_namespace(int nprocs, char *ranks, char *nspace,
-                          pmix_op_cbfunc_t cbfunc, myxfer_t *x)
+static void set_namespace(int nprocs, char *ranks, char *nspace, pmix_op_cbfunc_t cbfunc,
+                          myxfer_t *x)
 {
     char *regex, *ppn;
     char hostname[PMIX_MAXHOSTNAMELEN];
@@ -430,7 +399,8 @@ static void set_namespace(int nprocs, char *ranks, char *nspace,
      * security keys or endpoint info */
     PMIX_CONSTRUCT(&myxfer, myxfer_t);
     myxfer.active = true;
-    if (PMIX_SUCCESS != (rc = PMIx_server_setup_application(nspace, NULL, 0, setup_cbfunc, &myxfer))) {
+    if (PMIX_SUCCESS
+        != (rc = PMIx_server_setup_application(nspace, NULL, 0, setup_cbfunc, &myxfer))) {
         PMIX_DESTRUCT(&myxfer);
         fprintf(stderr, "Failed to setup application: %d\n", rc);
         exit(1);
@@ -440,67 +410,60 @@ static void set_namespace(int nprocs, char *ranks, char *nspace,
 
     PMIX_INFO_CREATE(x->info, x->ninfo);
     if (0 < myxfer.ninfo) {
-        for (i=0; i < myxfer.ninfo; i++) {
+        for (i = 0; i < myxfer.ninfo; i++) {
             PMIX_INFO_XFER(&x->info[i], &myxfer.info[i]);
         }
     }
     PMIX_DESTRUCT(&myxfer);
 
-    (void)strncpy(x->info[i].key, PMIX_UNIV_SIZE, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_UNIV_SIZE, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_UINT32;
     x->info[i].value.data.uint32 = nprocs;
 
     ++i;
-    (void)strncpy(x->info[i].key, PMIX_SPAWNED, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_SPAWNED, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_UINT32;
     x->info[i].value.data.uint32 = 0;
 
     ++i;
-    (void)strncpy(x->info[i].key, PMIX_LOCAL_SIZE, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_LOCAL_SIZE, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_UINT32;
     x->info[i].value.data.uint32 = nprocs;
 
     ++i;
-    (void)strncpy(x->info[i].key, PMIX_LOCAL_PEERS, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_LOCAL_PEERS, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_STRING;
     x->info[i].value.data.string = strdup(ranks);
 
     ++i;
     PMIx_generate_regex(hostname, &regex);
-    (void)strncpy(x->info[i].key, PMIX_NODE_MAP, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_NODE_MAP, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_STRING;
     x->info[i].value.data.string = regex;
 
     ++i;
     PMIx_generate_ppn(ranks, &ppn);
-    (void)strncpy(x->info[i].key, PMIX_PROC_MAP, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_PROC_MAP, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_STRING;
     x->info[i].value.data.string = ppn;
 
     ++i;
-    (void)strncpy(x->info[i].key, PMIX_JOB_SIZE, PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[i].key, PMIX_JOB_SIZE, PMIX_MAX_KEYLEN);
     x->info[i].value.type = PMIX_UINT32;
     x->info[i].value.data.uint32 = nprocs;
 
-    PMIx_server_register_nspace(nspace, nprocs, x->info, x->ninfo,
-                                cbfunc, x);
-
+    PMIx_server_register_nspace(nspace, nprocs, x->info, x->ninfo, cbfunc, x);
 }
 
-static void errhandler(size_t evhdlr_registration_id,
-                       pmix_status_t status,
-                       const pmix_proc_t *source,
-                       pmix_info_t info[], size_t ninfo,
+static void errhandler(size_t evhdlr_registration_id, pmix_status_t status,
+                       const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                        pmix_info_t results[], size_t nresults,
-                       pmix_event_notification_cbfunc_fn_t cbfunc,
-                       void *cbdata)
+                       pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
     pmix_output(0, "SERVER: ERRHANDLER CALLED WITH STATUS %d", status);
 }
 
-static void errhandler_reg_callbk (pmix_status_t status,
-                                   size_t errhandler_ref,
-                                   void *cbdata)
+static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, void *cbdata)
 {
     return;
 }
@@ -514,10 +477,9 @@ static pmix_status_t connected(const pmix_proc_t *proc, void *server_object,
     return PMIX_SUCCESS;
 }
 static pmix_status_t finalized(const pmix_proc_t *proc, void *server_object,
-                     pmix_op_cbfunc_t cbfunc, void *cbdata)
+                               pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
-    pmix_output(0, "SERVER: FINALIZED %s:%d",
-                proc->nspace, proc->rank);
+    pmix_output(0, "SERVER: FINALIZED %s:%d", proc->nspace, proc->rank);
     --wakeup;
     /* ensure we call the cbfunc so the proc can exit! */
     if (NULL != cbfunc) {
@@ -528,7 +490,7 @@ static pmix_status_t finalized(const pmix_proc_t *proc, void *server_object,
 
 static void abcbfunc(pmix_status_t status, void *cbdata)
 {
-    myxfer_t *x = (myxfer_t*)cbdata;
+    myxfer_t *x = (myxfer_t *) cbdata;
 
     /* be sure to release the caller */
     if (NULL != x->cbfunc) {
@@ -537,10 +499,8 @@ static void abcbfunc(pmix_status_t status, void *cbdata)
     PMIX_RELEASE(x);
 }
 
-static pmix_status_t abort_fn(const pmix_proc_t *proc,
-                              void *server_object,
-                              int status, const char msg[],
-                              pmix_proc_t procs[], size_t nprocs,
+static pmix_status_t abort_fn(const pmix_proc_t *proc, void *server_object, int status,
+                              const char msg[], pmix_proc_t procs[], size_t nprocs,
                               pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_status_t rc;
@@ -558,34 +518,31 @@ static pmix_status_t abort_fn(const pmix_proc_t *proc,
     /* use the myxfer_t object to ensure we release
      * the caller when notification has been queued */
     x = PMIX_NEW(myxfer_t);
-    (void)strncpy(x->caller.nspace, proc->nspace, PMIX_MAX_NSLEN);
+    (void) strncpy(x->caller.nspace, proc->nspace, PMIX_MAX_NSLEN);
     x->caller.rank = proc->rank;
 
     PMIX_INFO_CREATE(x->info, 2);
-    (void)strncpy(x->info[0].key, "DARTH", PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[0].key, "DARTH", PMIX_MAX_KEYLEN);
     x->info[0].value.type = PMIX_INT8;
     x->info[0].value.data.int8 = 12;
-    (void)strncpy(x->info[1].key, "VADER", PMIX_MAX_KEYLEN);
+    (void) strncpy(x->info[1].key, "VADER", PMIX_MAX_KEYLEN);
     x->info[1].value.type = PMIX_DOUBLE;
     x->info[1].value.data.dval = 12.34;
     x->cbfunc = cbfunc;
     x->cbdata = cbdata;
 
-    if (PMIX_SUCCESS != (rc = PMIx_Notify_event(status, &x->caller,
-                                                PMIX_RANGE_NAMESPACE,
-                                                x->info, 2,
-                                                abcbfunc, x))) {
-        pmix_output(0, "SERVER: FAILED NOTIFY ERROR %d", (int)rc);
+    if (PMIX_SUCCESS
+        != (rc = PMIx_Notify_event(status, &x->caller, PMIX_RANGE_NAMESPACE, x->info, 2, abcbfunc,
+                                   x))) {
+        pmix_output(0, "SERVER: FAILED NOTIFY ERROR %d", (int) rc);
     }
 
     return PMIX_SUCCESS;
 }
 
-
-static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs,
-                      const pmix_info_t info[], size_t ninfo,
-                      char *data, size_t ndata,
-                      pmix_modex_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
+                                size_t ninfo, char *data, size_t ndata, pmix_modex_cbfunc_t cbfunc,
+                                void *cbdata)
 {
     pmix_output(0, "SERVER: FENCENB");
     /* pass the provided data back to each participating proc */
@@ -595,10 +552,8 @@ static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs,
     return PMIX_SUCCESS;
 }
 
-
-static pmix_status_t dmodex_fn(const pmix_proc_t *proc,
-                     const pmix_info_t info[], size_t ninfo,
-                     pmix_modex_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t dmodex_fn(const pmix_proc_t *proc, const pmix_info_t info[], size_t ninfo,
+                               pmix_modex_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_output(0, "SERVER: DMODEX");
 
@@ -610,22 +565,20 @@ static pmix_status_t dmodex_fn(const pmix_proc_t *proc,
     return PMIX_SUCCESS;
 }
 
-
-static pmix_status_t publish_fn(const pmix_proc_t *proc,
-                      const pmix_info_t info[], size_t ninfo,
-                      pmix_op_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t publish_fn(const pmix_proc_t *proc, const pmix_info_t info[], size_t ninfo,
+                                pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_locdat_t *p;
     size_t n;
 
     pmix_output(0, "SERVER: PUBLISH");
 
-    for (n=0; n < ninfo; n++) {
+    for (n = 0; n < ninfo; n++) {
         p = PMIX_NEW(pmix_locdat_t);
-        (void)strncpy(p->pdata.proc.nspace, proc->nspace, PMIX_MAX_NSLEN);
+        (void) strncpy(p->pdata.proc.nspace, proc->nspace, PMIX_MAX_NSLEN);
         p->pdata.proc.rank = proc->rank;
-        (void)strncpy(p->pdata.key, info[n].key, PMIX_MAX_KEYLEN);
-        pmix_value_xfer(&p->pdata.value, (pmix_value_t*)&info[n].value);
+        (void) strncpy(p->pdata.key, info[n].key, PMIX_MAX_KEYLEN);
+        pmix_value_xfer(&p->pdata.value, (pmix_value_t *) &info[n].value);
         pmix_list_append(&pubdata, &p->super);
     }
     if (NULL != cbfunc) {
@@ -634,10 +587,8 @@ static pmix_status_t publish_fn(const pmix_proc_t *proc,
     return PMIX_SUCCESS;
 }
 
-
-static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys,
-                     const pmix_info_t info[], size_t ninfo,
-                     pmix_lookup_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys, const pmix_info_t info[],
+                               size_t ninfo, pmix_lookup_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_locdat_t *p, *p2;
     pmix_list_t results;
@@ -649,13 +600,13 @@ static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys,
 
     PMIX_CONSTRUCT(&results, pmix_list_t);
 
-    for (n=0; NULL != keys[n]; n++) {
-        PMIX_LIST_FOREACH(p, &pubdata, pmix_locdat_t) {
+    for (n = 0; NULL != keys[n]; n++) {
+        PMIX_LIST_FOREACH (p, &pubdata, pmix_locdat_t) {
             if (0 == strncmp(keys[n], p->pdata.key, PMIX_MAX_KEYLEN)) {
                 p2 = PMIX_NEW(pmix_locdat_t);
-                (void)strncpy(p2->pdata.proc.nspace, p->pdata.proc.nspace, PMIX_MAX_NSLEN);
+                (void) strncpy(p2->pdata.proc.nspace, p->pdata.proc.nspace, PMIX_MAX_NSLEN);
                 p2->pdata.proc.rank = p->pdata.proc.rank;
-                (void)strncpy(p2->pdata.key, p->pdata.key, PMIX_MAX_KEYLEN);
+                (void) strncpy(p2->pdata.key, p->pdata.key, PMIX_MAX_KEYLEN);
                 pmix_value_xfer(&p2->pdata.value, &p->pdata.value);
                 pmix_list_append(&results, &p2->super);
                 break;
@@ -665,12 +616,12 @@ static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys,
     if (0 < (n = pmix_list_get_size(&results))) {
         ret = PMIX_SUCCESS;
         PMIX_PDATA_CREATE(pd, n);
-        for (i=0; i < n; i++) {
-            p = (pmix_locdat_t*)pmix_list_remove_first(&results);
+        for (i = 0; i < n; i++) {
+            p = (pmix_locdat_t *) pmix_list_remove_first(&results);
             if (p) {
-                (void)strncpy(pd[i].proc.nspace, p->pdata.proc.nspace, PMIX_MAX_NSLEN);
+                (void) strncpy(pd[i].proc.nspace, p->pdata.proc.nspace, PMIX_MAX_NSLEN);
                 pd[i].proc.rank = p->pdata.proc.rank;
-                (void)strncpy(pd[i].key, p->pdata.key, PMIX_MAX_KEYLEN);
+                (void) strncpy(pd[i].key, p->pdata.key, PMIX_MAX_KEYLEN);
                 pmix_value_xfer(&pd[i].value, &p->pdata.value);
             }
         }
@@ -685,18 +636,16 @@ static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys,
     return PMIX_SUCCESS;
 }
 
-
-static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys,
-                        const pmix_info_t info[], size_t ninfo,
-                        pmix_op_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys, const pmix_info_t info[],
+                                  size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_locdat_t *p, *p2;
     size_t n;
 
     pmix_output(0, "SERVER: UNPUBLISH");
 
-    for (n=0; NULL != keys[n]; n++) {
-        PMIX_LIST_FOREACH_SAFE(p, p2, &pubdata, pmix_locdat_t) {
+    for (n = 0; NULL != keys[n]; n++) {
+        PMIX_LIST_FOREACH_SAFE (p, p2, &pubdata, pmix_locdat_t) {
             if (0 == strncmp(keys[n], p->pdata.key, PMIX_MAX_KEYLEN)) {
                 pmix_list_remove_item(&pubdata, &p->super);
                 PMIX_RELEASE(p);
@@ -712,17 +661,16 @@ static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys,
 
 static void spcbfunc(pmix_status_t status, void *cbdata)
 {
-    myxfer_t *x = (myxfer_t*)cbdata;
+    myxfer_t *x = (myxfer_t *) cbdata;
 
     if (NULL != x->spcbfunc) {
         x->spcbfunc(PMIX_SUCCESS, "DYNSPACE", x->cbdata);
     }
 }
 
-static pmix_status_t spawn_fn(const pmix_proc_t *proc,
-                    const pmix_info_t job_info[], size_t ninfo,
-                    const pmix_app_t apps[], size_t napps,
-                    pmix_spawn_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t spawn_fn(const pmix_proc_t *proc, const pmix_info_t job_info[], size_t ninfo,
+                              const pmix_app_t apps[], size_t napps, pmix_spawn_cbfunc_t cbfunc,
+                              void *cbdata)
 {
     myxfer_t *x;
 
@@ -744,10 +692,8 @@ static pmix_status_t spawn_fn(const pmix_proc_t *proc,
     return PMIX_SUCCESS;
 }
 
-
-static pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs,
-                                const pmix_info_t info[], size_t ninfo,
-                                pmix_op_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
+                                size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_output(0, "SERVER: CONNECT");
 
@@ -761,10 +707,9 @@ static pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs,
     return PMIX_SUCCESS;
 }
 
-
 static pmix_status_t disconnect_fn(const pmix_proc_t procs[], size_t nprocs,
-                                   const pmix_info_t info[], size_t ninfo,
-                                   pmix_op_cbfunc_t cbfunc, void *cbdata)
+                                   const pmix_info_t info[], size_t ninfo, pmix_op_cbfunc_t cbfunc,
+                                   void *cbdata)
 {
     pmix_output(0, "SERVER: DISCONNECT");
 
@@ -788,16 +733,14 @@ static pmix_status_t register_event_fn(pmix_status_t *codes, size_t ncodes,
     return PMIX_SUCCESS;
 }
 
-static pmix_status_t deregister_events(pmix_status_t *codes, size_t ncodes,
-                                       pmix_op_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t deregister_events(pmix_status_t *codes, size_t ncodes, pmix_op_cbfunc_t cbfunc,
+                                       void *cbdata)
 {
     return PMIX_SUCCESS;
 }
 
-static pmix_status_t notify_event(pmix_status_t code,
-                                  const pmix_proc_t *source,
-                                  pmix_data_range_t range,
-                                  pmix_info_t info[], size_t ninfo,
+static pmix_status_t notify_event(pmix_status_t code, const pmix_proc_t *source,
+                                  pmix_data_range_t range, pmix_info_t info[], size_t ninfo,
                                   pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
     return PMIX_SUCCESS;
@@ -808,10 +751,8 @@ typedef struct query_data_t {
     size_t ndata;
 } query_data_t;
 
-static pmix_status_t query_fn(pmix_proc_t *proct,
-                              pmix_query_t *queries, size_t nqueries,
-                              pmix_info_cbfunc_t cbfunc,
-                              void *cbdata)
+static pmix_status_t query_fn(pmix_proc_t *proct, pmix_query_t *queries, size_t nqueries,
+                              pmix_info_cbfunc_t cbfunc, void *cbdata)
 {
     size_t n;
     pmix_info_t *info;
@@ -823,10 +764,10 @@ static pmix_status_t query_fn(pmix_proc_t *proct,
     }
     /* keep this simple */
     PMIX_INFO_CREATE(info, nqueries);
-    for (n=0; n < nqueries; n++) {
-        (void)strncpy(info[n].key, queries[n].keys[0], PMIX_MAX_KEYLEN);
+    for (n = 0; n < nqueries; n++) {
+        (void) strncpy(info[n].key, queries[n].keys[0], PMIX_MAX_KEYLEN);
         info[n].value.type = PMIX_STRING;
-        if (0 > asprintf(&info[n].value.data.string, "%d", (int)n)) {
+        if (0 > asprintf(&info[n].value.data.string, "%d", (int) n)) {
             return PMIX_ERROR;
         }
     }
@@ -834,8 +775,7 @@ static pmix_status_t query_fn(pmix_proc_t *proct,
     return PMIX_SUCCESS;
 }
 
-static void tool_connect_fn(pmix_info_t *info, size_t ninfo,
-                            pmix_tool_connection_cbfunc_t cbfunc,
+static void tool_connect_fn(pmix_info_t *info, size_t ninfo, pmix_tool_connection_cbfunc_t cbfunc,
                             void *cbdata)
 {
     pmix_proc_t proc;
@@ -843,7 +783,7 @@ static void tool_connect_fn(pmix_info_t *info, size_t ninfo,
     pmix_output(0, "SERVER: TOOL CONNECT");
 
     /* just pass back an arbitrary nspace */
-    (void)strncpy(proc.nspace, "TOOL", PMIX_MAX_NSLEN);
+    (void) strncpy(proc.nspace, "TOOL", PMIX_MAX_NSLEN);
     proc.rank = 0;
 
     if (NULL != cbfunc) {
@@ -851,10 +791,9 @@ static void tool_connect_fn(pmix_info_t *info, size_t ninfo,
     }
 }
 
-static void log_fn(const pmix_proc_t *client,
-                   const pmix_info_t data[], size_t ndata,
-                   const pmix_info_t directives[], size_t ndirs,
-                   pmix_op_cbfunc_t cbfunc, void *cbdata)
+static void log_fn(const pmix_proc_t *client, const pmix_info_t data[], size_t ndata,
+                   const pmix_info_t directives[], size_t ndirs, pmix_op_cbfunc_t cbfunc,
+                   void *cbdata)
 {
     pmix_output(0, "SERVER: LOG");
 
@@ -865,7 +804,7 @@ static void log_fn(const pmix_proc_t *client,
 
 static void wait_signal_callback(int fd, short event, void *arg)
 {
-    pmix_event_t *sig = (pmix_event_t*) arg;
+    pmix_event_t *sig = (pmix_event_t *) arg;
     int status;
     pid_t pid;
     wait_tracker_t *t2;
@@ -889,7 +828,7 @@ static void wait_signal_callback(int fd, short event, void *arg)
         }
 
         /* we are already in an event, so it is safe to access the list */
-        PMIX_LIST_FOREACH(t2, &children, wait_tracker_t) {
+        PMIX_LIST_FOREACH (t2, &children, wait_tracker_t) {
             if (pid == t2->pid) {
                 /* found it! */
                 --wakeup;
