@@ -1,5 +1,5 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
- /*
+/*
  * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
@@ -14,6 +14,7 @@
  * Copyright (c) 2013      Los Alamos National Security, LLC. All rights
  *                         reserved.
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -71,7 +72,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #if HAVE_STDBOOL_H
-#include <stdbool.h>
+#    include <stdbool.h>
 #endif
 
 #include "src/class/pmix_object.h"
@@ -91,14 +92,12 @@ PMIX_EXPORT PMIX_CLASS_DECLARATION(pmix_list_t);
  */
 PMIX_EXPORT PMIX_CLASS_DECLARATION(pmix_list_item_t);
 
-
 /**
  * \internal
  *
  * Struct of an pmix_list_item_t
  */
-struct pmix_list_item_t
-{
+struct pmix_list_item_t {
     pmix_object_t super;
     /**< Generic parent class for all PMIx objects */
     volatile struct pmix_list_item_t *pmix_list_next;
@@ -111,7 +110,7 @@ struct pmix_list_item_t
     /** Atomic reference count for debugging */
     pmix_atomic_int32_t pmix_list_item_refcount;
     /** The list this item belong to */
-    volatile struct pmix_list_t* pmix_list_item_belong_to;
+    volatile struct pmix_list_t *pmix_list_item_belong_to;
 #endif
 };
 /**
@@ -120,12 +119,10 @@ struct pmix_list_item_t
 typedef struct pmix_list_item_t pmix_list_item_t;
 
 /* static initializer for pmix_list_t */
-#define PMIX_LIST_ITEM_STATIC_INIT                      \
-    {                                                   \
-        .super = PMIX_OBJ_STATIC_INIT(pmix_object_t),   \
-        .pmix_list_next = NULL,                         \
-        .pmix_list_prev = NULL,                         \
-        .item_free = 0                                  \
+#define PMIX_LIST_ITEM_STATIC_INIT                                            \
+    {                                                                         \
+        .super = PMIX_OBJ_STATIC_INIT(pmix_object_t), .pmix_list_next = NULL, \
+        .pmix_list_prev = NULL, .item_free = 0                                \
     }
 
 /**
@@ -136,7 +133,7 @@ typedef struct pmix_list_item_t pmix_list_item_t;
  * @returns The next item in the list
  */
 #define pmix_list_get_next(item) \
-    ((item) ? ((pmix_list_item_t*) ((pmix_list_item_t*)(item))->pmix_list_next) : NULL)
+    ((item) ? ((pmix_list_item_t *) ((pmix_list_item_t *) (item))->pmix_list_next) : NULL)
 
 /**
  * Get the next item in a list.
@@ -146,21 +143,19 @@ typedef struct pmix_list_item_t pmix_list_item_t;
  * @returns The next item in the list
  */
 #define pmix_list_get_prev(item) \
-    ((item) ? ((pmix_list_item_t*) ((pmix_list_item_t*)(item))->pmix_list_prev) : NULL)
-
+    ((item) ? ((pmix_list_item_t *) ((pmix_list_item_t *) (item))->pmix_list_prev) : NULL)
 
 /**
  * \internal
  *
  * Struct of an pmix_list_t
  */
-struct pmix_list_t
-{
-    pmix_object_t       super;
+struct pmix_list_t {
+    pmix_object_t super;
     /**< Generic parent class for all PMIx objects */
-    pmix_list_item_t    pmix_list_sentinel;
+    pmix_list_item_t pmix_list_sentinel;
     /**< Head and tail item of the list */
-    volatile size_t     pmix_list_length;
+    volatile size_t pmix_list_length;
     /**< Quick reference to the number of items in the list */
 };
 /**
@@ -169,14 +164,12 @@ struct pmix_list_t
 typedef struct pmix_list_t pmix_list_t;
 
 /* static initializer for pmix_list_t */
-#define PMIX_LIST_STATIC_INIT                                           \
-    {                                                                   \
-        .super = PMIX_OBJ_STATIC_INIT(pmix_object_t),                   \
-        .pmix_list_sentinel = PMIX_LIST_ITEM_STATIC_INIT,   \
-        .pmix_list_length = 0                                           \
+#define PMIX_LIST_STATIC_INIT                                                   \
+    {                                                                           \
+        .super = PMIX_OBJ_STATIC_INIT(pmix_object_t),                           \
+        .pmix_list_sentinel = PMIX_LIST_ITEM_STATIC_INIT, .pmix_list_length = 0 \
     }
 
-
 /** Cleanly destruct a list
  *
  * The pmix_list_t destructor doesn't release the items on the
@@ -185,25 +178,24 @@ typedef struct pmix_list_t pmix_list_t;
  *
  * @param[in] list List to destruct or release
  */
-#define PMIX_LIST_DESTRUCT(list)                                \
-    do {                                                        \
-        pmix_list_item_t *it;                                   \
-        while (NULL != (it = pmix_list_remove_first(list))) {   \
-            PMIX_RELEASE(it);                                    \
-        }                                                       \
-        PMIX_DESTRUCT(list);                                     \
+#define PMIX_LIST_DESTRUCT(list)                              \
+    do {                                                      \
+        pmix_list_item_t *it;                                 \
+        while (NULL != (it = pmix_list_remove_first(list))) { \
+            PMIX_RELEASE(it);                                 \
+        }                                                     \
+        PMIX_DESTRUCT(list);                                  \
     } while (0)
 
-#define PMIX_LIST_RELEASE(list)                                 \
-    do {                                                        \
-        pmix_list_item_t *it;                                   \
-        while (NULL != (it = pmix_list_remove_first(list))) {   \
-            PMIX_RELEASE(it);                                    \
-        }                                                       \
-        PMIX_RELEASE(list);                                      \
+#define PMIX_LIST_RELEASE(list)                               \
+    do {                                                      \
+        pmix_list_item_t *it;                                 \
+        while (NULL != (it = pmix_list_remove_first(list))) { \
+            PMIX_RELEASE(it);                                 \
+        }                                                     \
+        PMIX_RELEASE(list);                                   \
     } while (0)
 
-
 /**
  * Loop over a list.
  *
@@ -221,10 +213,10 @@ typedef struct pmix_list_t pmix_list_t;
  *    do something;
  * }
  */
-#define PMIX_LIST_FOREACH(item, list, type)                             \
-  for (item = (type *) (list)->pmix_list_sentinel.pmix_list_next ;      \
-       item != (type *) &(list)->pmix_list_sentinel ;                   \
-       item = (type *) ((pmix_list_item_t *) (item))->pmix_list_next)
+#define PMIX_LIST_FOREACH(item, list, type)                         \
+    for (item = (type *) (list)->pmix_list_sentinel.pmix_list_next; \
+         item != (type *) &(list)->pmix_list_sentinel;              \
+         item = (type *) ((pmix_list_item_t *) (item))->pmix_list_next)
 
 /**
  * Loop over a list in reverse.
@@ -243,10 +235,10 @@ typedef struct pmix_list_t pmix_list_t;
  *    do something;
  * }
  */
-#define PMIX_LIST_FOREACH_REV(item, list, type)                         \
-  for (item = (type *) (list)->pmix_list_sentinel.pmix_list_prev ;      \
-       item != (type *) &(list)->pmix_list_sentinel ;                   \
-       item = (type *) ((pmix_list_item_t *) (item))->pmix_list_prev)
+#define PMIX_LIST_FOREACH_REV(item, list, type)                     \
+    for (item = (type *) (list)->pmix_list_sentinel.pmix_list_prev; \
+         item != (type *) &(list)->pmix_list_sentinel;              \
+         item = (type *) ((pmix_list_item_t *) (item))->pmix_list_prev)
 
 /**
  * Loop over a list in a *safe* way
@@ -267,11 +259,11 @@ typedef struct pmix_list_t pmix_list_t;
  *    pmix_list_remove_item (list, (pmix_list_item_t *) foo);
  * }
  */
-#define PMIX_LIST_FOREACH_SAFE(item, next, list, type)                  \
-  for (item = (type *) (list)->pmix_list_sentinel.pmix_list_next,       \
-         next = (type *) ((pmix_list_item_t *) (item))->pmix_list_next ;\
-       item != (type *) &(list)->pmix_list_sentinel ;                   \
-       item = next, next = (type *) ((pmix_list_item_t *) (item))->pmix_list_next)
+#define PMIX_LIST_FOREACH_SAFE(item, next, list, type)                 \
+    for (item = (type *) (list)->pmix_list_sentinel.pmix_list_next,    \
+        next = (type *) ((pmix_list_item_t *) (item))->pmix_list_next; \
+         item != (type *) &(list)->pmix_list_sentinel;                 \
+         item = next, next = (type *) ((pmix_list_item_t *) (item))->pmix_list_next)
 
 /**
  * Loop over a list in a *safe* way
@@ -292,12 +284,11 @@ typedef struct pmix_list_t pmix_list_t;
  *    pmix_list_remove_item (list, (pmix_list_item_t *) foo);
  * }
  */
-#define PMIX_LIST_FOREACH_SAFE_REV(item, prev, list, type)              \
-  for (item = (type *) (list)->pmix_list_sentinel.pmix_list_prev,       \
-         prev = (type *) ((pmix_list_item_t *) (item))->pmix_list_prev ;\
-       item != (type *) &(list)->pmix_list_sentinel ;                   \
-       item = prev, prev = (type *) ((pmix_list_item_t *) (item))->pmix_list_prev)
-
+#define PMIX_LIST_FOREACH_SAFE_REV(item, prev, list, type)             \
+    for (item = (type *) (list)->pmix_list_sentinel.pmix_list_prev,    \
+        prev = (type *) ((pmix_list_item_t *) (item))->pmix_list_prev; \
+         item != (type *) &(list)->pmix_list_sentinel;                 \
+         item = prev, prev = (type *) ((pmix_list_item_t *) (item))->pmix_list_prev)
 
 /**
  * Check for empty list
@@ -311,13 +302,11 @@ typedef struct pmix_list_t pmix_list_t;
  * This is an inlined function in compilers that support inlining,
  * so it's usually a cheap operation.
  */
-static inline bool pmix_list_is_empty(pmix_list_t* list)
+static inline bool pmix_list_is_empty(pmix_list_t *list)
 {
-    return (list->pmix_list_sentinel.pmix_list_next ==
-        &(list->pmix_list_sentinel) ? true : false);
+    return (list->pmix_list_sentinel.pmix_list_next == &(list->pmix_list_sentinel) ? true : false);
 }
 
-
 /**
  * Return the first item on the list (does not remove it).
  *
@@ -332,14 +321,14 @@ static inline bool pmix_list_is_empty(pmix_list_t* list)
  * This is an inlined function in compilers that support inlining, so
  * it's usually a cheap operation.
  */
-static inline pmix_list_item_t* pmix_list_get_first(pmix_list_t* list)
+static inline pmix_list_item_t *pmix_list_get_first(pmix_list_t *list)
 {
-    pmix_list_item_t* item = (pmix_list_item_t*)list->pmix_list_sentinel.pmix_list_next;
+    pmix_list_item_t *item = (pmix_list_item_t *) list->pmix_list_sentinel.pmix_list_next;
 #if PMIX_ENABLE_DEBUG
     /* Spot check: ensure that the first item is only on one list */
 
     assert(1 == item->pmix_list_item_refcount);
-    assert( list == item->pmix_list_item_belong_to );
+    assert(list == item->pmix_list_item_belong_to);
 #endif
 
     return item;
@@ -359,14 +348,14 @@ static inline pmix_list_item_t* pmix_list_get_first(pmix_list_t* list)
  * This is an inlined function in compilers that support inlining, so
  * it's usually a cheap operation.
  */
-static inline pmix_list_item_t* pmix_list_get_last(pmix_list_t* list)
+static inline pmix_list_item_t *pmix_list_get_last(pmix_list_t *list)
 {
-    pmix_list_item_t* item = (pmix_list_item_t *)list->pmix_list_sentinel.pmix_list_prev;
+    pmix_list_item_t *item = (pmix_list_item_t *) list->pmix_list_sentinel.pmix_list_prev;
 #if PMIX_ENABLE_DEBUG
     /* Spot check: ensure that the last item is only on one list */
 
-    assert( 1 == item->pmix_list_item_refcount );
-    assert( list == item->pmix_list_item_belong_to );
+    assert(1 == item->pmix_list_item_refcount);
+    assert(list == item->pmix_list_item_belong_to);
 #endif
 
     return item;
@@ -389,7 +378,7 @@ static inline pmix_list_item_t* pmix_list_get_last(pmix_list_t* list)
  * This is an inlined function in compilers that support inlining, so
  * it's usually a cheap operation.
  */
-static inline pmix_list_item_t* pmix_list_get_begin(pmix_list_t* list)
+static inline pmix_list_item_t *pmix_list_get_begin(pmix_list_t *list)
 {
     return &(list->pmix_list_sentinel);
 }
@@ -411,12 +400,11 @@ static inline pmix_list_item_t* pmix_list_get_begin(pmix_list_t* list)
  * This is an inlined function in compilers that support inlining, so
  * it's usually a cheap operation.
  */
-static inline pmix_list_item_t* pmix_list_get_end(pmix_list_t* list)
+static inline pmix_list_item_t *pmix_list_get_end(pmix_list_t *list)
 {
     return &(list->pmix_list_sentinel);
 }
 
-
 /**
  * Return the number of items in a list
  *
@@ -436,7 +424,7 @@ static inline pmix_list_item_t* pmix_list_get_end(pmix_list_t* list)
  * never called on the specified list, this function will always be
  * O(1).
  */
-static inline size_t pmix_list_get_size(pmix_list_t* list)
+static inline size_t pmix_list_get_size(pmix_list_t *list)
 {
 #if PMIX_ENABLE_DEBUG && 0
     /* not sure if we really want this running in devel, as it does
@@ -446,14 +434,15 @@ static inline size_t pmix_list_get_size(pmix_list_t* list)
     size_t check_len = 0;
     pmix_list_item_t *item;
 
-    for (item = pmix_list_get_first(list) ;
-         item != pmix_list_get_end(list) ;
+    for (item = pmix_list_get_first(list); item != pmix_list_get_end(list);
          item = pmix_list_get_next(item)) {
         check_len++;
     }
 
     if (check_len != list->pmix_list_length) {
-        fprintf(stderr," Error :: pmix_list_get_size - pmix_list_length does not match actual list length\n");
+        fprintf(
+            stderr,
+            " Error :: pmix_list_get_size - pmix_list_length does not match actual list length\n");
         fflush(stderr);
         abort();
     }
@@ -462,7 +451,6 @@ static inline size_t pmix_list_get_size(pmix_list_t* list)
     return list->pmix_list_length;
 }
 
-
 /**
  * Remove an item from a list.
  *
@@ -484,36 +472,35 @@ static inline size_t pmix_list_get_size(pmix_list_t* list)
  * This is an inlined function in compilers that support inlining, so
  * it's usually a cheap operation.
  */
-static inline pmix_list_item_t *pmix_list_remove_item
-  (pmix_list_t *list, pmix_list_item_t *item)
+static inline pmix_list_item_t *pmix_list_remove_item(pmix_list_t *list, pmix_list_item_t *item)
 {
 #if PMIX_ENABLE_DEBUG
     pmix_list_item_t *item_ptr;
     bool found = false;
 
     /* check to see that the item is in the list */
-    for (item_ptr = pmix_list_get_first(list);
-            item_ptr != pmix_list_get_end(list);
-            item_ptr = (pmix_list_item_t *)(item_ptr->pmix_list_next)) {
+    for (item_ptr = pmix_list_get_first(list); item_ptr != pmix_list_get_end(list);
+         item_ptr = (pmix_list_item_t *) (item_ptr->pmix_list_next)) {
         if (item_ptr == (pmix_list_item_t *) item) {
             found = true;
             break;
         }
     }
     if (!found) {
-        fprintf(stderr," Warning :: pmix_list_remove_item - the item %p is not on the list %p \n",(void*) item, (void*) list);
+        fprintf(stderr, " Warning :: pmix_list_remove_item - the item %p is not on the list %p \n",
+                (void *) item, (void *) list);
         fflush(stderr);
-        return (pmix_list_item_t *)NULL;
+        return (pmix_list_item_t *) NULL;
     }
 
-    assert( list == item->pmix_list_item_belong_to );
+    assert(list == item->pmix_list_item_belong_to);
 #endif
 
     /* reset next pointer of previous element */
-    item->pmix_list_prev->pmix_list_next=item->pmix_list_next;
+    item->pmix_list_prev->pmix_list_next = item->pmix_list_next;
 
     /* reset previous pointer of next element */
-    item->pmix_list_next->pmix_list_prev=item->pmix_list_prev;
+    item->pmix_list_next->pmix_list_prev = item->pmix_list_prev;
 
     list->pmix_list_length--;
 
@@ -525,10 +512,9 @@ static inline pmix_list_item_t *pmix_list_remove_item
     item->pmix_list_item_belong_to = NULL;
 #endif
 
-    return (pmix_list_item_t *)item->pmix_list_prev;
+    return (pmix_list_item_t *) item->pmix_list_prev;
 }
 
-
 /**
  * Append an item to the end of the list.
  *
@@ -544,55 +530,53 @@ static inline pmix_list_item_t *pmix_list_remove_item
  */
 
 #if PMIX_ENABLE_DEBUG
-#define pmix_list_append(l,i) \
-_pmix_list_append(l,i,__FILE__,__LINE__)
+#    define pmix_list_append(l, i) _pmix_list_append(l, i, __FILE__, __LINE__)
 #else
-#define pmix_list_append(l,i) \
-_pmix_list_append(l,i)
-#endif  /* PMIX_ENABLE_DEBUG */
+#    define pmix_list_append(l, i) _pmix_list_append(l, i)
+#endif /* PMIX_ENABLE_DEBUG */
 
 static inline void _pmix_list_append(pmix_list_t *list, pmix_list_item_t *item
 #if PMIX_ENABLE_DEBUG
-                                     , const char* FILE_NAME, int LINENO
-#endif  /* PMIX_ENABLE_DEBUG */
-                                     )
+                                     ,
+                                     const char *FILE_NAME, int LINENO
+#endif /* PMIX_ENABLE_DEBUG */
+)
 {
-    pmix_list_item_t* sentinel = &(list->pmix_list_sentinel);
+    pmix_list_item_t *sentinel = &(list->pmix_list_sentinel);
 #if PMIX_ENABLE_DEBUG
-  /* Spot check: ensure that this item is previously on no lists */
+    /* Spot check: ensure that this item is previously on no lists */
 
-  assert(0 == item->pmix_list_item_refcount);
-  assert( NULL == item->pmix_list_item_belong_to );
-  item->super.cls_init_file_name = FILE_NAME;
-  item->super.cls_init_lineno    = LINENO;
+    assert(0 == item->pmix_list_item_refcount);
+    assert(NULL == item->pmix_list_item_belong_to);
+    item->super.cls_init_file_name = FILE_NAME;
+    item->super.cls_init_lineno = LINENO;
 #endif
 
-  /* set new element's previous pointer */
-  item->pmix_list_prev = sentinel->pmix_list_prev;
+    /* set new element's previous pointer */
+    item->pmix_list_prev = sentinel->pmix_list_prev;
 
-  /* reset previous pointer on current last element */
-  sentinel->pmix_list_prev->pmix_list_next = item;
+    /* reset previous pointer on current last element */
+    sentinel->pmix_list_prev->pmix_list_next = item;
 
-  /* reset new element's next pointer */
-  item->pmix_list_next = sentinel;
+    /* reset new element's next pointer */
+    item->pmix_list_next = sentinel;
 
-  /* reset the list's tail element previous pointer */
-  sentinel->pmix_list_prev = item;
+    /* reset the list's tail element previous pointer */
+    sentinel->pmix_list_prev = item;
 
-  /* increment list element counter */
-  list->pmix_list_length++;
+    /* increment list element counter */
+    list->pmix_list_length++;
 
 #if PMIX_ENABLE_DEBUG
-  /* Spot check: ensure this item is only on the list that we just
-     appended it to */
+    /* Spot check: ensure this item is only on the list that we just
+       appended it to */
 
-  item->pmix_list_item_refcount += 1;
-  assert(1 == item->pmix_list_item_refcount);
-  item->pmix_list_item_belong_to = list;
+    item->pmix_list_item_refcount += 1;
+    assert(1 == item->pmix_list_item_refcount);
+    item->pmix_list_item_belong_to = list;
 #endif
 }
 
-
 /**
  * Prepend an item to the beginning of the list.
  *
@@ -606,43 +590,41 @@ static inline void _pmix_list_append(pmix_list_t *list, pmix_list_item_t *item
  * This is an inlined function in compilers that support inlining, so
  * it's usually a cheap operation.
  */
-static inline void pmix_list_prepend(pmix_list_t *list,
-                                     pmix_list_item_t *item)
+static inline void pmix_list_prepend(pmix_list_t *list, pmix_list_item_t *item)
 {
-    pmix_list_item_t* sentinel = &(list->pmix_list_sentinel);
+    pmix_list_item_t *sentinel = &(list->pmix_list_sentinel);
 #if PMIX_ENABLE_DEBUG
-  /* Spot check: ensure that this item is previously on no lists */
+    /* Spot check: ensure that this item is previously on no lists */
 
-  assert(0 == item->pmix_list_item_refcount);
-  assert( NULL == item->pmix_list_item_belong_to );
+    assert(0 == item->pmix_list_item_refcount);
+    assert(NULL == item->pmix_list_item_belong_to);
 #endif
 
-  /* reset item's next pointer */
-  item->pmix_list_next = sentinel->pmix_list_next;
+    /* reset item's next pointer */
+    item->pmix_list_next = sentinel->pmix_list_next;
 
-  /* reset item's previous pointer */
-  item->pmix_list_prev = sentinel;
+    /* reset item's previous pointer */
+    item->pmix_list_prev = sentinel;
 
-  /* reset previous first element's previous poiner */
-  sentinel->pmix_list_next->pmix_list_prev = item;
+    /* reset previous first element's previous poiner */
+    sentinel->pmix_list_next->pmix_list_prev = item;
 
-  /* reset head's next pointer */
-  sentinel->pmix_list_next = item;
+    /* reset head's next pointer */
+    sentinel->pmix_list_next = item;
 
-  /* increment list element counter */
-  list->pmix_list_length++;
+    /* increment list element counter */
+    list->pmix_list_length++;
 
 #if PMIX_ENABLE_DEBUG
-  /* Spot check: ensure this item is only on the list that we just
-     prepended it to */
+    /* Spot check: ensure this item is only on the list that we just
+       prepended it to */
 
-  item->pmix_list_item_refcount += 1;
-  assert(1 == item->pmix_list_item_refcount);
-  item->pmix_list_item_belong_to = list;
+    item->pmix_list_item_refcount += 1;
+    assert(1 == item->pmix_list_item_refcount);
+    item->pmix_list_item_belong_to = list;
 #endif
 }
 
-
 /**
  * Remove the first item from the list and return it.
  *
@@ -661,50 +643,49 @@ static inline void pmix_list_prepend(pmix_list_t *list,
  */
 static inline pmix_list_item_t *pmix_list_remove_first(pmix_list_t *list)
 {
-  /*  Removes and returns first item on list.
-      Caller now owns the item and should release the item
-      when caller is done with it.
-  */
-  volatile pmix_list_item_t *item;
-  if ( 0 == list->pmix_list_length ) {
-    return (pmix_list_item_t *)NULL;
-  }
+    /*  Removes and returns first item on list.
+        Caller now owns the item and should release the item
+        when caller is done with it.
+    */
+    volatile pmix_list_item_t *item;
+    if (0 == list->pmix_list_length) {
+        return (pmix_list_item_t *) NULL;
+    }
 
 #if PMIX_ENABLE_DEBUG
-  /* Spot check: ensure that the first item is only on this list */
+    /* Spot check: ensure that the first item is only on this list */
 
-  assert(1 == list->pmix_list_sentinel.pmix_list_next->pmix_list_item_refcount);
+    assert(1 == list->pmix_list_sentinel.pmix_list_next->pmix_list_item_refcount);
 #endif
 
-  /* reset list length counter */
-  list->pmix_list_length--;
+    /* reset list length counter */
+    list->pmix_list_length--;
 
-  /* get pointer to first element on the list */
-  item = list->pmix_list_sentinel.pmix_list_next;
+    /* get pointer to first element on the list */
+    item = list->pmix_list_sentinel.pmix_list_next;
 
-  /* reset previous pointer of next item on the list */
-  item->pmix_list_next->pmix_list_prev = item->pmix_list_prev;
+    /* reset previous pointer of next item on the list */
+    item->pmix_list_next->pmix_list_prev = item->pmix_list_prev;
 
-  /* reset the head next pointer */
-  list->pmix_list_sentinel.pmix_list_next = item->pmix_list_next;
+    /* reset the head next pointer */
+    list->pmix_list_sentinel.pmix_list_next = item->pmix_list_next;
 
 #if PMIX_ENABLE_DEBUG
-  assert( list == item->pmix_list_item_belong_to );
-  item->pmix_list_item_belong_to = NULL;
-  item->pmix_list_prev=(pmix_list_item_t *)NULL;
-  item->pmix_list_next=(pmix_list_item_t *)NULL;
+    assert(list == item->pmix_list_item_belong_to);
+    item->pmix_list_item_belong_to = NULL;
+    item->pmix_list_prev = (pmix_list_item_t *) NULL;
+    item->pmix_list_next = (pmix_list_item_t *) NULL;
 
-  /* Spot check: ensure that the item we're returning is now on no
-     lists */
+    /* Spot check: ensure that the item we're returning is now on no
+       lists */
 
-  item->pmix_list_item_refcount -= 1;
-  assert(0 == item->pmix_list_item_refcount);
+    item->pmix_list_item_refcount -= 1;
+    assert(0 == item->pmix_list_item_refcount);
 #endif
 
-  return (pmix_list_item_t *) item;
+    return (pmix_list_item_t *) item;
 }
 
-
 /**
  * Remove the last item from the list and return it.
  *
@@ -723,57 +704,57 @@ static inline pmix_list_item_t *pmix_list_remove_first(pmix_list_t *list)
  */
 static inline pmix_list_item_t *pmix_list_remove_last(pmix_list_t *list)
 {
-  /*  Removes, releases and returns last item on list.
-      Caller now owns the item and should release the item
-      when caller is done with it.
-  */
-  volatile pmix_list_item_t  *item;
-  if ( 0 == list->pmix_list_length ) {
-      return (pmix_list_item_t *)NULL;
-  }
+    /*  Removes, releases and returns last item on list.
+        Caller now owns the item and should release the item
+        when caller is done with it.
+    */
+    volatile pmix_list_item_t *item;
+    if (0 == list->pmix_list_length) {
+        return (pmix_list_item_t *) NULL;
+    }
 
 #if PMIX_ENABLE_DEBUG
-  /* Spot check: ensure that the first item is only on this list */
+    /* Spot check: ensure that the first item is only on this list */
 
-  assert(1 == list->pmix_list_sentinel.pmix_list_prev->pmix_list_item_refcount);
+    assert(1 == list->pmix_list_sentinel.pmix_list_prev->pmix_list_item_refcount);
 #endif
 
-  /* reset list length counter */
-  list->pmix_list_length--;
+    /* reset list length counter */
+    list->pmix_list_length--;
 
-  /* get item */
-  item = list->pmix_list_sentinel.pmix_list_prev;
+    /* get item */
+    item = list->pmix_list_sentinel.pmix_list_prev;
 
-  /* reset previous pointer on next to last pointer */
-  item->pmix_list_prev->pmix_list_next = item->pmix_list_next;
+    /* reset previous pointer on next to last pointer */
+    item->pmix_list_prev->pmix_list_next = item->pmix_list_next;
 
-  /* reset tail's previous pointer */
-  list->pmix_list_sentinel.pmix_list_prev = item->pmix_list_prev;
+    /* reset tail's previous pointer */
+    list->pmix_list_sentinel.pmix_list_prev = item->pmix_list_prev;
 
 #if PMIX_ENABLE_DEBUG
-  assert( list == item->pmix_list_item_belong_to );
-  item->pmix_list_next = item->pmix_list_prev = (pmix_list_item_t *)NULL;
+    assert(list == item->pmix_list_item_belong_to);
+    item->pmix_list_next = item->pmix_list_prev = (pmix_list_item_t *) NULL;
 
-  /* Spot check: ensure that the item we're returning is now on no
-     lists */
+    /* Spot check: ensure that the item we're returning is now on no
+       lists */
 
-  item->pmix_list_item_refcount -= 1;
-  assert(0 == item->pmix_list_item_refcount);
-  item->pmix_list_item_belong_to = NULL;
+    item->pmix_list_item_refcount -= 1;
+    assert(0 == item->pmix_list_item_refcount);
+    item->pmix_list_item_belong_to = NULL;
 #endif
 
-  return (pmix_list_item_t *) item;
+    return (pmix_list_item_t *) item;
 }
 
-  /**
-   * Add an item to the list before a given element
-   *
-   * @param list The list container
-   * @param pos List element to insert \c item before
-   * @param item The item to insert
-   *
-   * Inserts \c item before \c pos.  This is an O(1) operation.
-   */
+/**
+ * Add an item to the list before a given element
+ *
+ * @param list The list container
+ * @param pos List element to insert \c item before
+ * @param item The item to insert
+ *
+ * Inserts \c item before \c pos.  This is an O(1) operation.
+ */
 static inline void pmix_list_insert_pos(pmix_list_t *list, pmix_list_item_t *pos,
                                         pmix_list_item_t *item)
 {
@@ -782,7 +763,7 @@ static inline void pmix_list_insert_pos(pmix_list_t *list, pmix_list_item_t *pos
        not on any list */
 
     assert(0 == item->pmix_list_item_refcount);
-    assert( NULL == item->pmix_list_item_belong_to );
+    assert(NULL == item->pmix_list_item_belong_to);
 #endif
 
     /* point item at the existing elements */
@@ -806,120 +787,114 @@ static inline void pmix_list_insert_pos(pmix_list_t *list, pmix_list_item_t *pos
 #endif
 }
 
-  /**
-   * Add an item to the list at a specific index location in the list.
-   *
-   * @param list The list container
-   * @param item The item to insert
-   * @param index Location to add the item
-   *
-   * @returns true if insertion succeeded; otherwise false
-   *
-   * This is potentially an O(N) operation to traverse down to the
-   * correct location in the list and add an item.
-   *
-   * Example: if idx = 2 and list = item1->item2->item3->item4, then
-   * after insert, list = item1->item2->item->item3->item4.
-   *
-   * If index is greater than the length of the list, no action is
-   * performed and false is returned.
-   */
-  bool pmix_list_insert(pmix_list_t *list, pmix_list_item_t *item,
-                                      long long idx);
+/**
+ * Add an item to the list at a specific index location in the list.
+ *
+ * @param list The list container
+ * @param item The item to insert
+ * @param index Location to add the item
+ *
+ * @returns true if insertion succeeded; otherwise false
+ *
+ * This is potentially an O(N) operation to traverse down to the
+ * correct location in the list and add an item.
+ *
+ * Example: if idx = 2 and list = item1->item2->item3->item4, then
+ * after insert, list = item1->item2->item->item3->item4.
+ *
+ * If index is greater than the length of the list, no action is
+ * performed and false is returned.
+ */
+bool pmix_list_insert(pmix_list_t *list, pmix_list_item_t *item, long long idx);
 
+/**
+ * Join a list into another list
+ *
+ * @param thislist List container for list being operated on
+ * @param pos List item in \c thislist marking the position before
+ *              which items are inserted
+ * @param xlist List container for list being spliced from
+ *
+ * Join a list into another list.  All of the elements of \c xlist
+ * are inserted before \c pos and removed from \c xlist.
+ *
+ * This operation is an O(1) operation.  Both \c thislist and \c
+ * xlist must be valid list containsers.  \c xlist will be empty
+ * but valid after the call.  All pointers to \c pmix_list_item_t
+ * containers remain valid, including those that point to elements
+ * in \c xlist.
+ */
+void pmix_list_join(pmix_list_t *thislist, pmix_list_item_t *pos, pmix_list_t *xlist);
 
-    /**
-     * Join a list into another list
-     *
-     * @param thislist List container for list being operated on
-     * @param pos List item in \c thislist marking the position before
-     *              which items are inserted
-     * @param xlist List container for list being spliced from
-     *
-     * Join a list into another list.  All of the elements of \c xlist
-     * are inserted before \c pos and removed from \c xlist.
-     *
-     * This operation is an O(1) operation.  Both \c thislist and \c
-     * xlist must be valid list containsers.  \c xlist will be empty
-     * but valid after the call.  All pointers to \c pmix_list_item_t
-     * containers remain valid, including those that point to elements
-     * in \c xlist.
-     */
-    void pmix_list_join(pmix_list_t *thislist, pmix_list_item_t *pos,
-                                      pmix_list_t *xlist);
+/**
+ * Splice a list into another list
+ *
+ * @param thislist List container for list being operated on
+ * @param pos List item in \c thislist marking the position before
+ *             which items are inserted
+ * @param xlist List container for list being spliced from
+ * @param first List item in \c xlist marking the start of elements
+ *             to be copied into \c thislist
+ * @param last List item in \c xlist marking the end of elements
+ * to be copied into \c thislist
+ *
+ * Splice a subset of a list into another list.  The \c [first,
+ * last) elements of \c xlist are moved into \c thislist,
+ * inserting them before \c pos.  \c pos must be a valid iterator
+ * in \c thislist and \c [first, last) must be a valid range in \c
+ * xlist.  \c postition must not be in the range \c [first, last).
+ * It is, however, valid for \c xlist and \c thislist to be the
+ * same list.
+ *
+ * This is an O(N) operation because the length of both lists must
+ * be recomputed.
+ */
+void pmix_list_splice(pmix_list_t *thislist, pmix_list_item_t *pos, pmix_list_t *xlist,
+                      pmix_list_item_t *first, pmix_list_item_t *last);
 
+/**
+ * Comparison function for pmix_list_sort(), below.
+ *
+ * @param a Pointer to a pointer to an pmix_list_item_t.
+ * Explanation below.
+ * @param b Pointer to a pointer to an pmix_list_item_t.
+ * Explanation below.
+ * @retval 1 if \em a is greater than \em b
+ * @retval 0 if \em a is equal to \em b
+ * @retval 11 if \em a is less than \em b
+ *
+ * This function is invoked by qsort(3) from within
+ * pmix_list_sort().  It is important to understand what
+ * pmix_list_sort() does before invoking qsort, so go read that
+ * documentation first.
+ *
+ * The important thing to realize here is that a and b will be \em
+ * double pointers to the items that you need to compare.  Here's
+ * a sample compare function to illustrate this point:
+ */
+typedef int (*pmix_list_item_compare_fn_t)(pmix_list_item_t **a, pmix_list_item_t **b);
 
-    /**
-     * Splice a list into another list
-     *
-     * @param thislist List container for list being operated on
-     * @param pos List item in \c thislist marking the position before
-     *             which items are inserted
-     * @param xlist List container for list being spliced from
-     * @param first List item in \c xlist marking the start of elements
-     *             to be copied into \c thislist
-     * @param last List item in \c xlist marking the end of elements
-     * to be copied into \c thislist
-     *
-     * Splice a subset of a list into another list.  The \c [first,
-     * last) elements of \c xlist are moved into \c thislist,
-     * inserting them before \c pos.  \c pos must be a valid iterator
-     * in \c thislist and \c [first, last) must be a valid range in \c
-     * xlist.  \c postition must not be in the range \c [first, last).
-     * It is, however, valid for \c xlist and \c thislist to be the
-     * same list.
-     *
-     * This is an O(N) operation because the length of both lists must
-     * be recomputed.
-     */
-    void pmix_list_splice(pmix_list_t *thislist, pmix_list_item_t *pos,
-                                        pmix_list_t *xlist, pmix_list_item_t *first,
-                                        pmix_list_item_t *last);
-
-    /**
-     * Comparison function for pmix_list_sort(), below.
-     *
-     * @param a Pointer to a pointer to an pmix_list_item_t.
-     * Explanation below.
-     * @param b Pointer to a pointer to an pmix_list_item_t.
-     * Explanation below.
-     * @retval 1 if \em a is greater than \em b
-     * @retval 0 if \em a is equal to \em b
-     * @retval 11 if \em a is less than \em b
-     *
-     * This function is invoked by qsort(3) from within
-     * pmix_list_sort().  It is important to understand what
-     * pmix_list_sort() does before invoking qsort, so go read that
-     * documentation first.
-     *
-     * The important thing to realize here is that a and b will be \em
-     * double pointers to the items that you need to compare.  Here's
-     * a sample compare function to illustrate this point:
-     */
-    typedef int (*pmix_list_item_compare_fn_t)(pmix_list_item_t **a,
-                                               pmix_list_item_t **b);
-
-    /**
-     * Sort a list with a provided compare function.
-     *
-     * @param list The list to sort
-     * @param compare Compare function
-     *
-     * Put crassly, this function's complexity is O(N) + O(log(N)).
-     * Its algorithm is:
-     *
-     * - remove every item from the list and put the corresponding
-     *    (pmix_list_item_t*)'s in an array
-     * - call qsort(3) with that array and your compare function
-     * - re-add every element of the now-sorted array to the list
-     *
-     * The resulting list is now ordered.  Note, however, that since
-     * an array of pointers is sorted, the comparison function must do
-     * a double de-reference to get to the actual pmix_list_item_t (or
-     * whatever the underlying type is).  See the documentation of
-     * pmix_list_item_compare_fn_t for an example).
-     */
-    int pmix_list_sort(pmix_list_t* list, pmix_list_item_compare_fn_t compare);
+/**
+ * Sort a list with a provided compare function.
+ *
+ * @param list The list to sort
+ * @param compare Compare function
+ *
+ * Put crassly, this function's complexity is O(N) + O(log(N)).
+ * Its algorithm is:
+ *
+ * - remove every item from the list and put the corresponding
+ *    (pmix_list_item_t*)'s in an array
+ * - call qsort(3) with that array and your compare function
+ * - re-add every element of the now-sorted array to the list
+ *
+ * The resulting list is now ordered.  Note, however, that since
+ * an array of pointers is sorted, the comparison function must do
+ * a double de-reference to get to the actual pmix_list_item_t (or
+ * whatever the underlying type is).  See the documentation of
+ * pmix_list_item_compare_fn_t for an example).
+ */
+int pmix_list_sort(pmix_list_t *list, pmix_list_item_compare_fn_t compare);
 
 END_C_DECLS
 
