@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
 /*
- * Copyright (c) 2014-2019 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2014-2019 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
  * Copyright (c) 2014      Artem Y. Polyakov <artpol84@gmail.com>.
@@ -8,6 +8,7 @@
  * Copyright (c) 2016      Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -15,67 +16,60 @@
  * $HEADER$
  */
 
-#include <src/include/pmix_config.h>
+#include "src/include/pmix_config.h"
 
-#include <src/include/types.h>
-#include <src/include/pmix_stdint.h>
+#include "src/include/pmix_stdint.h"
 
-#include <pmix.h>
-#include <pmix_rename.h>
+#include "include/pmix.h"
 
 #include "src/include/pmix_globals.h"
 
 #ifdef HAVE_STRING_H
-#include <string.h>
+#    include <string.h>
 #endif
 #include <fcntl.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
+#    include <sys/socket.h>
 #endif
 #ifdef HAVE_SYS_UN_H
-#include <sys/un.h>
+#    include <sys/un.h>
 #endif
 #ifdef HAVE_SYS_UIO_H
-#include <sys/uio.h>
+#    include <sys/uio.h>
 #endif
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#    include <sys/types.h>
 #endif
 #include PMIX_EVENT_HEADER
 
 #include "src/class/pmix_list.h"
-#include "src/threads/threads.h"
 #include "src/mca/bfrops/bfrops.h"
+#include "src/mca/ptl/ptl.h"
+#include "src/threads/threads.h"
 #include "src/util/argv.h"
 #include "src/util/error.h"
 #include "src/util/output.h"
-#include "src/mca/ptl/ptl.h"
 
 #include "pmix_client_ops.h"
 
-static void wait_cbfunc(struct pmix_peer_t *pr,
-                        pmix_ptl_hdr_t *hdr,
-                        pmix_buffer_t *buf, void *cbdata);
+static void wait_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                        void *cbdata);
 static void op_cbfunc(pmix_status_t status, void *cbdata);
-static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
-                               pmix_ptl_hdr_t *hdr,
-                               pmix_buffer_t *buf, void *cbdata);
-static void lookup_cbfunc(pmix_status_t status, pmix_pdata_t pdata[], size_t ndata,
-                          void *cbdata);
+static void wait_lookup_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                               void *cbdata);
+static void lookup_cbfunc(pmix_status_t status, pmix_pdata_t pdata[], size_t ndata, void *cbdata);
 
-PMIX_EXPORT pmix_status_t PMIx_Publish(const pmix_info_t info[],
-                                       size_t ninfo)
+PMIX_EXPORT pmix_status_t PMIx_Publish(const pmix_info_t info[], size_t ninfo)
 {
     pmix_status_t rc;
     pmix_cb_t *cb;
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: publish called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: publish called");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -100,7 +94,7 @@ PMIX_EXPORT pmix_status_t PMIx_Publish(const pmix_info_t info[],
 
     /* wait for the server to ack our request */
     PMIX_WAIT_THREAD(&cb->lock);
-    rc = (pmix_status_t)cb->status;
+    rc = (pmix_status_t) cb->status;
     PMIX_RELEASE(cb);
 
     return rc;
@@ -116,8 +110,7 @@ PMIX_EXPORT pmix_status_t PMIx_Publish_nb(const pmix_info_t info[], size_t ninfo
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: publish called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: publish called");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -141,16 +134,14 @@ PMIX_EXPORT pmix_status_t PMIx_Publish_nb(const pmix_info_t info[], size_t ninfo
     /* create the publish cmd */
     msg = PMIX_NEW(pmix_buffer_t);
     /* pack the cmd */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &cmd, 1, PMIX_COMMAND);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &cmd, 1, PMIX_COMMAND);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     /* pack our effective userid - will be used to constrain lookup */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &pmix_globals.uid, 1, PMIX_UINT32);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &pmix_globals.uid, 1, PMIX_UINT32);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -158,8 +149,7 @@ PMIX_EXPORT pmix_status_t PMIx_Publish_nb(const pmix_info_t info[], size_t ninfo
     }
     /* pass the number of info structs - needed on remote end so
      * space can be malloc'd for the values */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &ninfo, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &ninfo, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -167,8 +157,7 @@ PMIX_EXPORT pmix_status_t PMIx_Publish_nb(const pmix_info_t info[], size_t ninfo
     }
     if (0 < ninfo) {
         /* pack the info structs */
-        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, info, ninfo, PMIX_INFO);
+        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, info, ninfo, PMIX_INFO);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -184,8 +173,7 @@ PMIX_EXPORT pmix_status_t PMIx_Publish_nb(const pmix_info_t info[], size_t ninfo
     cb->cbdata = cbdata;
 
     /* push the message into our event base to send to the server */
-    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver,
-                       msg, wait_cbfunc, (void*)cb);
+    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver, msg, wait_cbfunc, (void *) cb);
     if (PMIX_SUCCESS != rc) {
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cb);
@@ -194,8 +182,8 @@ PMIX_EXPORT pmix_status_t PMIx_Publish_nb(const pmix_info_t info[], size_t ninfo
     return rc;
 }
 
-PMIX_EXPORT pmix_status_t PMIx_Lookup(pmix_pdata_t pdata[], size_t ndata,
-                                      const pmix_info_t info[], size_t ninfo)
+PMIX_EXPORT pmix_status_t PMIx_Lookup(pmix_pdata_t pdata[], size_t ndata, const pmix_info_t info[],
+                                      size_t ninfo)
 {
     pmix_status_t rc;
     pmix_cb_t *cb;
@@ -204,8 +192,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup(pmix_pdata_t pdata[], size_t ndata,
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: lookup called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: lookup called");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -225,7 +212,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup(pmix_pdata_t pdata[], size_t ndata,
     }
 
     /* transfer the pdata keys to the keys argv array */
-    for (i=0; i < ndata; i++) {
+    for (i = 0; i < ndata; i++) {
         if ('\0' != pdata[i].key[0]) {
             pmix_argv_append_nosize(&keys, pdata[i].key);
         }
@@ -235,11 +222,10 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup(pmix_pdata_t pdata[], size_t ndata,
      * recv routine so we know which callback to use when
      * the return message is recvd */
     cb = PMIX_NEW(pmix_cb_t);
-    cb->cbdata = (void*)pdata;
+    cb->cbdata = (void *) pdata;
     cb->nvals = ndata;
 
-    if (PMIX_SUCCESS != (rc = PMIx_Lookup_nb(keys, info, ninfo,
-                                             lookup_cbfunc, cb))) {
+    if (PMIX_SUCCESS != (rc = PMIx_Lookup_nb(keys, info, ninfo, lookup_cbfunc, cb))) {
         PMIX_RELEASE(cb);
         pmix_argv_free(keys);
         return rc;
@@ -255,8 +241,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup(pmix_pdata_t pdata[], size_t ndata,
     return rc;
 }
 
-PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
-                                         const pmix_info_t info[], size_t ninfo,
+PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys, const pmix_info_t info[], size_t ninfo,
                                          pmix_lookup_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_buffer_t *msg;
@@ -267,8 +252,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: lookup_nb called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: lookup_nb called");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -290,16 +274,14 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
     /* create the lookup cmd */
     msg = PMIX_NEW(pmix_buffer_t);
     /* pack the cmd */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &cmd, 1, PMIX_COMMAND);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &cmd, 1, PMIX_COMMAND);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     /* pack our effective userid - will be used to constrain lookup */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &pmix_globals.uid, 1, PMIX_UINT32);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &pmix_globals.uid, 1, PMIX_UINT32);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -307,17 +289,15 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
     }
     /* pack the keys */
     nkeys = pmix_argv_count(keys);
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &nkeys, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &nkeys, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     if (0 < nkeys) {
-        for (n=0; n < nkeys; n++) {
-            PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                             msg, &keys[n], 1, PMIX_STRING);
+        for (n = 0; n < nkeys; n++) {
+            PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &keys[n], 1, PMIX_STRING);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
                 PMIX_RELEASE(msg);
@@ -327,8 +307,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
     }
     /* pass the number of info structs - needed on remote end so
      * space can be malloc'd for the values */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &ninfo, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &ninfo, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -336,8 +315,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
     }
     if (0 < ninfo) {
         /* pack the info structs */
-        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, info, ninfo, PMIX_INFO);
+        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, info, ninfo, PMIX_INFO);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -353,8 +331,7 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
     cb->cbdata = cbdata;
 
     /* send to the server */
-    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver,
-                       msg, wait_lookup_cbfunc, (void*)cb);
+    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver, msg, wait_lookup_cbfunc, (void *) cb);
     if (PMIX_SUCCESS != rc) {
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cb);
@@ -363,17 +340,14 @@ PMIX_EXPORT pmix_status_t PMIx_Lookup_nb(char **keys,
     return rc;
 }
 
-PMIX_EXPORT pmix_status_t PMIx_Unpublish(char **keys,
-                                         const pmix_info_t info[],
-                                         size_t ninfo)
+PMIX_EXPORT pmix_status_t PMIx_Unpublish(char **keys, const pmix_info_t info[], size_t ninfo)
 {
     pmix_status_t rc;
     pmix_cb_t *cb;
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: unpublish called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: unpublish called");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -406,8 +380,7 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish(char **keys,
     return rc;
 }
 
-PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
-                                            const pmix_info_t info[], size_t ninfo,
+PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys, const pmix_info_t info[], size_t ninfo,
                                             pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_buffer_t *msg;
@@ -418,8 +391,7 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: unpublish called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: unpublish called");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -436,16 +408,14 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
     /* create the unpublish cmd */
     msg = PMIX_NEW(pmix_buffer_t);
     /* pack the cmd */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &cmd, 1, PMIX_COMMAND);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &cmd, 1, PMIX_COMMAND);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     /* pack our effective userid - will be used to constrain lookup */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &pmix_globals.uid, 1, PMIX_UINT32);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &pmix_globals.uid, 1, PMIX_UINT32);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -453,17 +423,15 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
     }
     /* pack the number of keys */
     i = pmix_argv_count(keys);
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &i, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &i, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     if (0 < i) {
-        for (j=0; j < i; j++) {
-            PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                             msg, &keys[j], 1, PMIX_STRING);
+        for (j = 0; j < i; j++) {
+            PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &keys[j], 1, PMIX_STRING);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
                 PMIX_RELEASE(msg);
@@ -473,8 +441,7 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
     }
     /* pass the number of info structs - needed on remote end so
      * space can be malloc'd for the values */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &ninfo, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &ninfo, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -482,8 +449,7 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
     }
     if (0 < ninfo) {
         /* pack the info structs */
-        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, info, ninfo, PMIX_INFO);
+        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, info, ninfo, PMIX_INFO);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -497,8 +463,7 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
     cb->cbdata = cbdata;
 
     /* send to the server */
-    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver,
-                       msg, wait_cbfunc, (void*)cb);
+    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver, msg, wait_cbfunc, (void *) cb);
     if (PMIX_SUCCESS != rc) {
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cb);
@@ -507,11 +472,10 @@ PMIX_EXPORT pmix_status_t PMIx_Unpublish_nb(char **keys,
     return rc;
 }
 
-static void wait_cbfunc(struct pmix_peer_t *pr,
-                        pmix_ptl_hdr_t *hdr,
-                        pmix_buffer_t *buf, void *cbdata)
+static void wait_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                        void *cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
     pmix_status_t rc;
     int ret;
     int32_t cnt;
@@ -520,7 +484,7 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
 
     pmix_output_verbose(2, pmix_globals.debug_output,
                         "pmix:client recv callback activated with %d bytes",
-                        (NULL == buf) ? -1 : (int)buf->bytes_used);
+                        (NULL == buf) ? -1 : (int) buf->bytes_used);
 
     if (NULL == buf) {
         ret = PMIX_ERR_BAD_PARAM;
@@ -535,14 +499,13 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
 
     /* unpack the returned status */
     cnt = 1;
-    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver,
-                       buf, &ret, &cnt, PMIX_STATUS);
+    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver, buf, &ret, &cnt, PMIX_STATUS);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         ret = rc;
     }
 
-  report:
+report:
     if (NULL != cb->cbfunc.opfn) {
         cb->cbfunc.opfn(ret, cb->cbdata);
     }
@@ -551,18 +514,17 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
 
 static void op_cbfunc(pmix_status_t status, void *cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
 
     cb->status = status;
     PMIX_POST_OBJECT(cb);
     PMIX_WAKEUP_THREAD(&cb->lock);
 }
 
-static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
-                               pmix_ptl_hdr_t *hdr,
-                               pmix_buffer_t *buf, void *cbdata)
+static void wait_lookup_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                               void *cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
     pmix_status_t rc, ret;
     int32_t cnt;
     pmix_pdata_t *pdata;
@@ -572,7 +534,7 @@ static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
 
     pmix_output_verbose(2, pmix_globals.debug_output,
                         "pmix:client recv callback activated with %d bytes",
-                        (NULL == buf) ? -1 : (int)buf->bytes_used);
+                        (NULL == buf) ? -1 : (int) buf->bytes_used);
 
     /* set the defaults */
     pdata = NULL;
@@ -596,8 +558,7 @@ static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
 
     /* unpack the returned status */
     cnt = 1;
-    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver,
-                       buf, &ret, &cnt, PMIX_STATUS);
+    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver, buf, &ret, &cnt, PMIX_STATUS);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         ret = rc;
@@ -612,8 +573,7 @@ static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
 
     /* unpack the number of returned values */
     cnt = 1;
-    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver,
-                       buf, &ndata, &cnt, PMIX_SIZE);
+    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver, buf, &ndata, &cnt, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(cb);
@@ -624,20 +584,19 @@ static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
         PMIX_PDATA_CREATE(pdata, ndata);
         cnt = ndata;
         /* unpack the returned values into the pdata array */
-        PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver,
-                           buf, pdata, &cnt, PMIX_PDATA);
+        PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver, buf, pdata, &cnt, PMIX_PDATA);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             goto cleanup;
         }
     }
 
-  report:
+report:
     if (NULL != cb->cbfunc.lookupfn) {
         cb->cbfunc.lookupfn(rc, pdata, ndata, cb->cbdata);
     }
 
- cleanup:
+cleanup:
     /* cleanup */
     if (NULL != pdata) {
         PMIX_PDATA_FREE(pdata, ndata);
@@ -646,25 +605,25 @@ static void wait_lookup_cbfunc(struct pmix_peer_t *pr,
     PMIX_RELEASE(cb);
 }
 
-static void lookup_cbfunc(pmix_status_t status, pmix_pdata_t pdata[], size_t ndata,
-                          void *cbdata)
+static void lookup_cbfunc(pmix_status_t status, pmix_pdata_t pdata[], size_t ndata, void *cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
-    pmix_pdata_t *tgt = (pmix_pdata_t*)cb->cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
+    pmix_pdata_t *tgt = (pmix_pdata_t *) cb->cbdata;
     size_t i, j;
 
     PMIX_ACQUIRE_OBJECT(cb);
     cb->status = status;
     if (PMIX_SUCCESS == status) {
         /* find the matching key in the provided info array - error if not found */
-        for (i=0; i < ndata; i++) {
-            for (j=0; j < cb->nvals; j++) {
+        for (i = 0; i < ndata; i++) {
+            for (j = 0; j < cb->nvals; j++) {
                 if (0 == strcmp(pdata[i].key, tgt[j].key)) {
                     /* transfer the publishing proc id */
                     pmix_strncpy(tgt[j].proc.nspace, pdata[i].proc.nspace, PMIX_MAX_NSLEN);
                     tgt[j].proc.rank = pdata[i].proc.rank;
                     /* transfer the value to the pmix_info_t */
-                    PMIX_BFROPS_VALUE_XFER(cb->status, pmix_client_globals.myserver, &tgt[j].value, &pdata[i].value);
+                    PMIX_BFROPS_VALUE_XFER(cb->status, pmix_client_globals.myserver, &tgt[j].value,
+                                           &pdata[i].value);
                     break;
                 }
             }
