@@ -8,6 +8,7 @@
  * Copyright (c) 2016      Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -24,58 +25,58 @@
 #include "src/include/pmix_globals.h"
 
 #ifdef HAVE_STRING_H
-#include <string.h>
+#    include <string.h>
 #endif
 #include <fcntl.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
+#    include <sys/socket.h>
 #endif
 #ifdef HAVE_SYS_UN_H
-#include <sys/un.h>
+#    include <sys/un.h>
 #endif
 #ifdef HAVE_SYS_UIO_H
-#include <sys/uio.h>
+#    include <sys/uio.h>
 #endif
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#    include <sys/types.h>
 #endif
 #include PMIX_EVENT_HEADER
 
 #include "src/class/pmix_list.h"
-#include "src/threads/threads.h"
 #include "src/mca/bfrops/bfrops.h"
+#include "src/mca/gds/gds.h"
+#include "src/mca/pfexec/pfexec.h"
+#include "src/mca/pmdl/pmdl.h"
 #include "src/mca/pnet/base/base.h"
+#include "src/mca/ptl/ptl.h"
+#include "src/threads/threads.h"
 #include "src/util/argv.h"
+#include "src/util/basename.h"
 #include "src/util/error.h"
 #include "src/util/name_fns.h"
 #include "src/util/output.h"
 #include "src/util/pmix_environ.h"
-#include "src/mca/gds/gds.h"
-#include "src/mca/pfexec/pfexec.h"
-#include "src/mca/pmdl/pmdl.h"
-#include "src/mca/ptl/ptl.h"
+#include "src/util/pmix_getcwd.h"
 
+#include "src/server/pmix_server_ops.h"
 #include "pmix_client_ops.h"
 
-static void wait_cbfunc(struct pmix_peer_t *pr,
-                        pmix_ptl_hdr_t *hdr,
-                        pmix_buffer_t *buf, void *cbdata);
+static void wait_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                        void *cbdata);
 static void spawn_cbfunc(pmix_status_t status, char nspace[], void *cbdata);
 
 PMIX_EXPORT pmix_status_t PMIx_Spawn(const pmix_info_t job_info[], size_t ninfo,
-                                     const pmix_app_t apps[], size_t napps,
-                                     pmix_nspace_t nspace)
+                                     const pmix_app_t apps[], size_t napps, pmix_nspace_t nspace)
 {
     pmix_status_t rc;
     pmix_cb_t *cb;
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_client_globals.spawn_output,
-                        "%s pmix: spawn called",
+    pmix_output_verbose(2, pmix_client_globals.spawn_output, "%s pmix: spawn called",
                         PMIX_NAME_PRINT(&pmix_globals.myid));
 
     if (pmix_globals.init_cntr <= 0) {
@@ -84,16 +85,17 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn(const pmix_info_t job_info[], size_t ninfo,
     }
 
     /* if we aren't connected, don't attempt to send */
-    if (!pmix_globals.connected && !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+    if (!PMIX_PEER_IS_SERVER(pmix_globals.mypeer) &&
+        !pmix_globals.connected &&
+        !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
         return PMIX_ERR_UNREACH;
     }
     PMIX_RELEASE_THREAD(&pmix_global_lock);
 
-
     /* ensure the nspace (if provided) is initialized */
     if (NULL != nspace) {
-        memset(nspace, 0, PMIX_MAX_NSLEN+1);
+        memset(nspace, 0, PMIX_MAX_NSLEN + 1);
     }
 
     /* create a callback object */
@@ -135,11 +137,15 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
     bool forkexec = false;
     pmix_kval_t *kv;
     pmix_list_t ilist;
+    char cwd[PMIX_PATH_MAX];
+    char *tmp, *t2;
+    pmix_setup_caddy_t *cd;
+    bool proxy = false;
+    pmix_proc_t parent;
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_client_globals.spawn_output,
-                        "%s pmix: spawn_nb called",
+    pmix_output_verbose(2, pmix_client_globals.spawn_output, "%s pmix: spawn_nb called",
                         PMIX_NAME_PRINT(&pmix_globals.myid));
 
     if (pmix_globals.init_cntr <= 0) {
@@ -152,7 +158,7 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
         /* if I am a launcher, we default to local fork/exec */
         if (PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
             forkexec = true;
-        } else {
+        } else if (!PMIX_PEER_IS_SERVER(pmix_globals.mypeer)) {
             PMIX_RELEASE_THREAD(&pmix_global_lock);
             return PMIX_ERR_UNREACH;
         }
@@ -161,7 +167,7 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
 
     /* check job info for directives */
     if (NULL != job_info) {
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             if (PMIX_CHECK_KEY(&job_info[n], PMIX_SETUP_APP_ENVARS)) {
                 PMIX_CONSTRUCT(&ilist, pmix_list_t);
                 rc = pmix_pmdl.harvest_envars(NULL, job_info, ninfo, &ilist);
@@ -169,26 +175,56 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
                     PMIX_LIST_DESTRUCT(&ilist);
                     return rc;
                 }
-                PMIX_LIST_FOREACH(kv, &ilist, pmix_kval_t) {
+                PMIX_LIST_FOREACH (kv, &ilist, pmix_kval_t) {
                     /* cycle across all the apps and set this envar */
-                    for (m=0; m < napps; m++) {
-                        aptr = (pmix_app_t*)&apps[m];
-                        pmix_setenv(kv->value->data.envar.envar,
-                                    kv->value->data.envar.value,
-                                    true, &aptr->env);
+                    for (m = 0; m < napps; m++) {
+                        aptr = (pmix_app_t *) &apps[m];
+                        pmix_setenv(kv->value->data.envar.envar, kv->value->data.envar.value, true,
+                                    &aptr->env);
                     }
                 }
                 jobenvars = true;
                 PMIX_LIST_DESTRUCT(&ilist);
-                break;
+            } else if (PMIX_CHECK_KEY(&job_info[n], PMIX_PARENT_ID)) {
+                PMIX_XFER_PROCID(&parent, job_info[n].value.data.proc);
+                proxy = true;
             }
         }
     }
 
-    for (n=0; n < napps; n++) {
+    for (n = 0; n < napps; n++) {
+        aptr = (pmix_app_t *) &apps[n];
+        /* protect against idiot case (yes, they exist) */
+        if (NULL == aptr->cmd && NULL == aptr->argv) {
+            /* they gave us nothing to spawn! */
+            return PMIX_ERR_BAD_PARAM;
+        }
+        /* if they didn't give us a desired working directory, then
+         * take the one we are in */
+        if (NULL == aptr->cwd) {
+            rc = pmix_getcwd(cwd, sizeof(cwd));
+            if (PMIX_SUCCESS != rc) {
+                return rc;
+            }
+            aptr->cwd = strdup(cwd);
+        }
+        /* if they didn't give us the cmd as the first argv, fix it */
+        if (NULL == aptr->argv) {
+            tmp = pmix_basename(aptr->cmd);
+            aptr->argv = (char **) malloc(2 * sizeof(char *));
+            aptr->argv[0] = tmp;
+            aptr->argv[1] = NULL;
+        } else {
+            tmp = pmix_basename(aptr->cmd);
+            t2 = pmix_basename(aptr->argv[0]);
+            if (0 != strcmp(tmp, t2)) {
+                pmix_argv_prepend_nosize(&aptr->argv, tmp);
+            }
+            free(tmp);
+            free(t2);
+        }
         /* do a quick check of the apps directive array to ensure
          * the ninfo field has been set */
-        aptr = (pmix_app_t*)&apps[n];
         if (NULL != aptr->info && 0 == aptr->ninfo) {
             /* look for the info marked as "end" */
             m = 0;
@@ -202,7 +238,7 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
             aptr->ninfo = m;
         }
         if (!jobenvars) {
-            for (m=0; m < aptr->ninfo; m++) {
+            for (m = 0; m < aptr->ninfo; m++) {
                 if (PMIX_CHECK_KEY(&aptr->info[m], PMIX_SETUP_APP_ENVARS)) {
                     PMIX_CONSTRUCT(&ilist, pmix_list_t);
                     rc = pmix_pmdl.harvest_envars(NULL, aptr->info, aptr->ninfo, &ilist);
@@ -210,10 +246,9 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
                         PMIX_LIST_DESTRUCT(&ilist);
                         return rc;
                     }
-                    PMIX_LIST_FOREACH(kv, &ilist, pmix_kval_t) {
-                        pmix_setenv(kv->value->data.envar.envar,
-                                    kv->value->data.envar.value,
-                                    true, &aptr->env);
+                    PMIX_LIST_FOREACH (kv, &ilist, pmix_kval_t) {
+                        pmix_setenv(kv->value->data.envar.envar, kv->value->data.envar.value, true,
+                                    &aptr->env);
                     }
                     jobenvars = true;
                     PMIX_LIST_DESTRUCT(&ilist);
@@ -223,19 +258,59 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
         }
     }
 
-    /* if I am a tool and not connected, then just fork/exec
+    /* if we are a server, then process this ourselves */
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) &&
+        !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+        cd = PMIX_NEW(pmix_setup_caddy_t);
+        if (NULL == cd) {
+            return PMIX_ERR_NOMEM;
+        }
+        /* if I am spawning on behalf of someone else, then
+         * that peer is the "spawner" */
+        if (proxy) {
+            /* find the parent's peer object */
+            cd->peer = pmix_get_peer_object(&parent);
+            if (NULL == cd->peer) {
+                PMIX_RELEASE(cd);
+                return PMIX_ERR_NOT_FOUND;
+            }
+        } else {
+            cd->peer = pmix_globals.mypeer;
+        }
+        PMIX_RETAIN(cd->peer);
+        cd->info = (pmix_info_t*)job_info;
+        cd->ninfo = ninfo;
+        cd->apps = (pmix_app_t*)apps;
+        cd->napps = napps;
+        cd->spcbfunc = cbfunc;
+        cd->cbdata = cbdata;
+        // mark that we are using the input data
+        cd->copied = false;
+        /* run a quick check of the directives to see if any IOF
+         * requests were included so we can set that up now - helps
+         * to catch any early output - and a request for notification
+         * of job termination so we can setup the event registration */
+        pmix_server_spawn_parser(pmix_globals.mypeer, cd);
+        /* call the local host */
+        rc = pmix_host_server.spawn(&pmix_globals.myid, cd->info, cd->ninfo,
+                                    cd->apps, cd->napps,
+                                    pmix_server_spcbfunc, cd);
+        if (PMIX_SUCCESS != rc) {
+            PMIX_RELEASE(cd);
+        }
+        return rc;
+    }
+
+    /* if we are not connected, then just fork/exec
      * the specified application */
     if (forkexec) {
-        rc = pmix_pfexec.spawn_job(job_info, ninfo,
-                                   apps, napps,
-                                   cbfunc, cbdata);
+        rc = pmix_pfexec.spawn_job(job_info, ninfo, apps, napps, cbfunc, cbdata);
         return rc;
     }
 
     msg = PMIX_NEW(pmix_buffer_t);
     /* pack the cmd */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &cmd, 1, PMIX_COMMAND);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &cmd, 1, PMIX_COMMAND);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -243,16 +318,14 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
     }
 
     /* pack the job-level directives */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &ninfo, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &ninfo, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     if (0 < ninfo) {
-        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, job_info, ninfo, PMIX_INFO);
+        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, job_info, ninfo, PMIX_INFO);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -261,16 +334,14 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
     }
 
     /* pack the apps */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &napps, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &napps, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     if (0 < napps) {
-        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, apps, napps, PMIX_APP);
+        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, apps, napps, PMIX_APP);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -286,8 +357,7 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
     cb->cbdata = cbdata;
 
     /* push the message into our event base to send to the server */
-    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver,
-                       msg, wait_cbfunc, (void*)cb);
+    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver, msg, wait_cbfunc, (void *) cb);
     if (PMIX_SUCCESS != rc) {
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cb);
@@ -297,12 +367,11 @@ PMIX_EXPORT pmix_status_t PMIx_Spawn_nb(const pmix_info_t job_info[], size_t nin
 }
 
 /* callback for wait completion */
-static void wait_cbfunc(struct pmix_peer_t *pr,
-                        pmix_ptl_hdr_t *hdr,
-                        pmix_buffer_t *buf, void *cbdata)
+static void wait_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                        void *cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
-    char nspace[PMIX_MAX_NSLEN+1];
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
+    char nspace[PMIX_MAX_NSLEN + 1];
     char *n2 = NULL;
     pmix_status_t rc, ret;
     int32_t cnt;
@@ -311,10 +380,10 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
 
     pmix_output_verbose(2, pmix_globals.debug_output,
                         "pmix:client recv callback activated with %d bytes",
-                        (NULL == buf) ? -1 : (int)buf->bytes_used);
+                        (NULL == buf) ? -1 : (int) buf->bytes_used);
 
     /* init */
-    memset(nspace, 0, PMIX_MAX_NSLEN+1);
+    memset(nspace, 0, PMIX_MAX_NSLEN + 1);
 
     if (NULL == buf) {
         ret = PMIX_ERR_BAD_PARAM;
@@ -329,22 +398,19 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
 
     /* unpack the returned status */
     cnt = 1;
-    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver,
-                       buf, &ret, &cnt, PMIX_STATUS);
+    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver, buf, &ret, &cnt, PMIX_STATUS);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         ret = rc;
     }
     /* unpack the namespace */
     cnt = 1;
-    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver,
-                       buf, &n2, &cnt, PMIX_STRING);
+    PMIX_BFROPS_UNPACK(rc, pmix_client_globals.myserver, buf, &n2, &cnt, PMIX_STRING);
     if (PMIX_SUCCESS != rc && PMIX_ERR_UNPACK_READ_PAST_END_OF_BUFFER != rc) {
         PMIX_ERROR_LOG(rc);
         ret = rc;
     }
-    pmix_output_verbose(1, pmix_globals.debug_output,
-                    "pmix:client recv '%s'", n2);
+    pmix_output_verbose(1, pmix_globals.debug_output, "pmix:client recv '%s'", n2);
 
     if (NULL != n2) {
         /* protect length */
@@ -358,7 +424,7 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
         }
     }
 
-  report:
+report:
     if (NULL != cb->cbfunc.spawnfn) {
         cb->cbfunc.spawnfn(ret, nspace, cb->cbdata);
     }
@@ -367,7 +433,7 @@ static void wait_cbfunc(struct pmix_peer_t *pr,
 
 static void spawn_cbfunc(pmix_status_t status, char nspace[], void *cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
 
     PMIX_ACQUIRE_OBJECT(cb);
     cb->status = status;
