@@ -6,6 +6,7 @@
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
  * Copyright (c) 2019      Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -14,51 +15,49 @@
  */
 #include "src/include/pmix_config.h"
 
-#include "src/include/pmix_stdint.h"
 #include "src/include/pmix_socket_errno.h"
+#include "src/include/pmix_stdint.h"
 
 #include "include/pmix.h"
 #include "include/pmix_common.h"
 #include "include/pmix_server.h"
 
+#include "src/common/pmix_attributes.h"
+#include "src/mca/bfrops/bfrops.h"
+#include "src/mca/pstrg/pstrg.h"
+#include "src/mca/ptl/base/base.h"
 #include "src/threads/threads.h"
 #include "src/util/argv.h"
 #include "src/util/error.h"
 #include "src/util/name_fns.h"
 #include "src/util/output.h"
-#include "src/mca/bfrops/bfrops.h"
-#include "src/mca/ptl/base/base.h"
-#include "src/common/pmix_attributes.h"
 
 #include "src/client/pmix_client_ops.h"
-#include "src/server/pmix_server_ops.h"
 #include "src/include/pmix_globals.h"
+#include "src/server/pmix_server_ops.h"
 
 static void relcbfunc(void *cbdata)
 {
-    pmix_shift_caddy_t *cd = (pmix_shift_caddy_t*)cbdata;
+    pmix_shift_caddy_t *cd = (pmix_shift_caddy_t *) cbdata;
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:query release callback");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix:query release callback");
 
     if (NULL != cd->info) {
         PMIX_INFO_FREE(cd->info, cd->ninfo);
     }
     PMIX_RELEASE(cd);
 }
-static void query_cbfunc(struct pmix_peer_t *peer,
-                         pmix_ptl_hdr_t *hdr,
-                         pmix_buffer_t *buf, void *cbdata)
+static void query_cbfunc(struct pmix_peer_t *peer, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+                         void *cbdata)
 {
-    pmix_query_caddy_t *cd = (pmix_query_caddy_t*)cbdata;
+    pmix_query_caddy_t *cd = (pmix_query_caddy_t *) cbdata;
     pmix_status_t rc;
     pmix_shift_caddy_t *results;
     int cnt;
     size_t n;
     pmix_kval_t *kv;
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:query cback from server");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix:query cback from server");
 
     results = PMIX_NEW(pmix_shift_caddy_t);
 
@@ -92,23 +91,21 @@ static void query_cbfunc(struct pmix_peer_t *peer,
             goto complete;
         }
         /* locally cache the results */
-        for (n=0; n < results->ninfo; n++) {
+        for (n = 0; n < results->ninfo; n++) {
             kv = PMIX_NEW(pmix_kval_t);
             kv->key = strdup(results->info[n].key);
             PMIX_VALUE_CREATE(kv->value, 1);
-            PMIX_BFROPS_VALUE_XFER(rc, pmix_globals.mypeer,
-                                   kv->value, &results->info[n].value);
+            PMIX_BFROPS_VALUE_XFER(rc, pmix_globals.mypeer, kv->value, &results->info[n].value);
 
-            PMIX_GDS_STORE_KV(rc, pmix_globals.mypeer,
-                              &pmix_globals.myid, PMIX_INTERNAL,
-                              kv);
-            PMIX_RELEASE(kv);  // maintain accounting
+            PMIX_GDS_STORE_KV(rc, pmix_globals.mypeer, &pmix_globals.myid, PMIX_INTERNAL, kv);
+            PMIX_RELEASE(kv); // maintain accounting
         }
     }
 
-  complete:
+complete:
     pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:query cback from server releasing with status %s", PMIx_Error_string(results->status));
+                        "pmix:query cback from server releasing with status %s",
+                        PMIx_Error_string(results->status));
     /* release the caller */
     if (NULL != cd->cbfunc) {
         cd->cbfunc(results->status, results->info, results->ninfo, cd->cbdata, relcbfunc, results);
@@ -116,17 +113,17 @@ static void query_cbfunc(struct pmix_peer_t *peer,
     PMIX_RELEASE(cd);
 }
 
-static void qinfocb(pmix_status_t status, pmix_info_t info[], size_t ninfo,
-                    void *cbdata, pmix_release_cbfunc_t release_fn, void *release_cbdata)
+static void qinfocb(pmix_status_t status, pmix_info_t info[], size_t ninfo, void *cbdata,
+                    pmix_release_cbfunc_t release_fn, void *release_cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
     size_t n;
 
     cb->status = status;
     if (NULL != info) {
         cb->ninfo = ninfo;
         PMIX_INFO_CREATE(cb->info, cb->ninfo);
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             PMIX_INFO_XFER(&cb->info[n], &info[n]);
         }
     }
@@ -146,18 +143,14 @@ static pmix_status_t request_help(pmix_query_t queries[], size_t nqueries,
 
     /* if we are the server, then we just issue the query and
      * return the response */
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) &&
-        !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) && !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
         if (NULL == pmix_host_server.query) {
             /* nothing we can do */
             return PMIX_ERR_NOT_SUPPORTED;
         }
-        pmix_output_verbose(2, pmix_globals.debug_output,
-                            "pmix:query handed to RM");
-        rc = pmix_host_server.query(&pmix_globals.myid,
-                                    queries, nqueries,
-                                    cbfunc, cbdata);
+        pmix_output_verbose(2, pmix_globals.debug_output, "pmix:query handed to RM");
+        rc = pmix_host_server.query(&pmix_globals.myid, queries, nqueries, cbfunc, cbdata);
         return rc;
     }
 
@@ -173,24 +166,21 @@ static pmix_status_t request_help(pmix_query_t queries[], size_t nqueries,
     cd->cbfunc = cbfunc;
     cd->cbdata = cbdata;
     msg = PMIX_NEW(pmix_buffer_t);
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &cmd, 1, PMIX_COMMAND);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &cmd, 1, PMIX_COMMAND);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cd);
         return rc;
     }
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &nqueries, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &nqueries, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cd);
         return rc;
     }
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, queries, nqueries, PMIX_QUERY);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, queries, nqueries, PMIX_QUERY);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -198,20 +188,69 @@ static pmix_status_t request_help(pmix_query_t queries[], size_t nqueries,
         return rc;
     }
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:query sending to server");
-    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver,
-                       msg, query_cbfunc, (void*)cd);
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix:query sending to server");
+    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver, msg, query_cbfunc, (void *) cd);
     if (PMIX_SUCCESS != rc) {
         PMIX_RELEASE(cd);
     }
     return rc;
+}
 
+static void _local_relcb(void *cbdata)
+{
+    pmix_query_caddy_t *cd = (pmix_query_caddy_t *) cbdata;
+
+    if (NULL != cd->info) {
+        PMIX_INFO_FREE(cd->info, cd->ninfo);
+    }
+    PMIX_RELEASE(cd);
+}
+
+static void nxtcbfunc(pmix_status_t status, pmix_list_t *results, void *cbdata)
+{
+    pmix_query_caddy_t *cd = (pmix_query_caddy_t *) cbdata;
+    size_t n;
+    pmix_kval_t *kv, *kvnxt;
+    pmix_status_t rc;
+
+    /* if they return success, then all queries were locally
+     * resolved, so construct the results for return */
+    if (PMIX_SUCCESS == status) {
+        cd->status = status;
+        cd->ninfo = pmix_list_get_size(results);
+        PMIX_INFO_CREATE(cd->info, cd->ninfo);
+        n = 0;
+        PMIX_LIST_FOREACH_SAFE (kv, kvnxt, results, pmix_kval_t) {
+            PMIX_LOAD_KEY(cd->info[n].key, kv->key);
+            rc = pmix_value_xfer(&cd->info[n].value, kv->value);
+            if (PMIX_SUCCESS != rc) {
+                cd->status = rc;
+                PMIX_INFO_FREE(cd->info, cd->ninfo);
+                break;
+            }
+            ++n;
+        }
+
+        if (NULL != cd->cbfunc) {
+            cd->cbfunc(cd->status, cd->info, cd->ninfo, cd->cbdata, _local_relcb, cd);
+        }
+    } else {
+        /* need to ask our host */
+        rc = request_help(cd->queries, cd->nqueries, cd->cbfunc, cd->cbdata);
+        if (PMIX_SUCCESS != rc) {
+            /* we have to return the error to the caller */
+            if (NULL != cd->cbfunc) {
+                cd->cbfunc(rc, NULL, 0, cd->cbdata, NULL, NULL);
+            }
+        }
+        PMIX_RELEASE(cd);
+        return;
+    }
 }
 
 static void localquery(int sd, short args, void *cbdata)
 {
-    pmix_query_caddy_t *cd = (pmix_query_caddy_t*)cbdata;
+    pmix_query_caddy_t *cd = (pmix_query_caddy_t *) cbdata;
     pmix_query_t *queries = cd->queries;
     size_t nqueries = cd->nqueries;
     pmix_status_t rc;
@@ -225,9 +264,9 @@ static void localquery(int sd, short args, void *cbdata)
     /* setup the list of local results */
     PMIX_CONSTRUCT(&results, pmix_list_t);
 
-    for (n=0; n < nqueries; n++) {
+    for (n = 0; n < nqueries; n++) {
         PMIX_LOAD_PROCID(&proc, NULL, PMIX_RANK_INVALID);
-        for (p=0; p < queries[n].nqual; p++) {
+        for (p = 0; p < queries[n].nqual; p++) {
             if (PMIX_CHECK_KEY(&queries[n].qualifiers[p], PMIX_PROCID)) {
                 PMIX_LOAD_NSPACE(proc.nspace, queries[n].qualifiers[p].value.data.proc->nspace);
                 proc.rank = queries[n].qualifiers[p].value.data.proc->rank;
@@ -251,8 +290,7 @@ static void localquery(int sd, short args, void *cbdata)
             cb.proc = &proc;
         } else {
             /* set the proc */
-            if (PMIX_RANK_INVALID == proc.rank &&
-                0 == strlen(proc.nspace)) {
+            if (PMIX_RANK_INVALID == proc.rank && 0 == strlen(proc.nspace)) {
                 /* use our id */
                 cb.proc = &pmix_globals.myid;
             } else {
@@ -269,7 +307,7 @@ static void localquery(int sd, short args, void *cbdata)
         }
 
         /* first see if we already have this info */
-        for (p=0; NULL != queries[n].keys[p]; p++) {
+        for (p = 0; NULL != queries[n].keys[p]; p++) {
             cb.key = queries[n].keys[p];
             PMIX_GDS_FETCH_KV(rc, pmix_globals.mypeer, &cb);
             if (PMIX_SUCCESS != rc) {
@@ -278,7 +316,7 @@ static void localquery(int sd, short args, void *cbdata)
                 goto nextstep;
             }
             /* need to retain this result */
-            PMIX_LIST_FOREACH_SAFE(kv, kvnxt, &cb.kvs, pmix_kval_t) {
+            PMIX_LIST_FOREACH_SAFE (kv, kvnxt, &cb.kvs, pmix_kval_t) {
                 pmix_list_remove_item(&cb.kvs, &kv->super);
                 pmix_list_append(&results, &kv->super);
             }
@@ -286,17 +324,51 @@ static void localquery(int sd, short args, void *cbdata)
         }
     }
 
-  nextstep:
-    /* need to ask our host */
-    rc = request_help(cd->queries, cd->nqueries, cd->cbfunc, cd->cbdata);
-    if (PMIX_SUCCESS != rc) {
-        /* we have to return the error to the caller */
-        if (NULL != cd->cbfunc) {
-            cd->cbfunc(rc, NULL, 0, cd->cbdata, NULL, NULL);
+nextstep:
+    /* pass the queries thru our active plugins with query
+     * interfaces to see if someone can resolve it */
+    rc = pmix_pstrg.query(queries, nqueries, &results, nxtcbfunc, cd);
+    if (PMIX_OPERATION_SUCCEEDED == rc) {
+        /* if we get here, then all queries were locally
+         * resolved, so construct the results for return */
+        cd->status = PMIX_SUCCESS;
+        cd->ninfo = pmix_list_get_size(&results);
+        if (0 < cd->ninfo) {
+            PMIX_INFO_CREATE(cd->info, cd->ninfo);
+            n = 0;
+            PMIX_LIST_FOREACH_SAFE (kv, kvnxt, &results, pmix_kval_t) {
+                PMIX_LOAD_KEY(cd->info[n].key, kv->key);
+                rc = pmix_value_xfer(&cd->info[n].value, kv->value);
+                if (PMIX_SUCCESS != rc) {
+                    cd->status = rc;
+                    PMIX_INFO_FREE(cd->info, cd->ninfo);
+                    break;
+                }
+                ++n;
+            }
         }
+        /* done with the list of results */
+        PMIX_LIST_DESTRUCT(&results);
+
+        if (NULL != cd->cbfunc) {
+            cd->cbfunc(cd->status, cd->info, cd->ninfo, cd->cbdata, _local_relcb, cd);
+        }
+    } else if (PMIX_SUCCESS != rc) {
+        /* need to ask our host */
+        rc = request_help(cd->queries, cd->nqueries, cd->cbfunc, cd->cbdata);
+        if (PMIX_SUCCESS != rc) {
+            /* we have to return the error to the caller */
+            if (NULL != cd->cbfunc) {
+                cd->cbfunc(rc, NULL, 0, cd->cbdata, NULL, NULL);
+            }
+        }
+        PMIX_RELEASE(cd);
+        return;
     }
-    PMIX_RELEASE(cd);
-    return;
+
+    /* get here if the query returned PMIX_SUCCESS, which means
+     * that the query is being processed and will call the cbfunc
+     * when complete */
 }
 
 PMIX_EXPORT pmix_status_t PMIx_Query_info(pmix_query_t queries[], size_t nqueries,
@@ -313,15 +385,14 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info(pmix_query_t queries[], size_t nquerie
     }
     PMIX_RELEASE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "%s pmix:query", PMIX_NAME_PRINT(&pmix_globals.myid));
+    pmix_output_verbose(2, pmix_globals.debug_output, "%s pmix:query",
+                        PMIX_NAME_PRINT(&pmix_globals.myid));
 
     /* create a callback object as we need to pass it to the
      * recv routine so we know which callback to use when
      * the return message is recvd */
     PMIX_CONSTRUCT(&cb, pmix_cb_t);
-    if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(queries, nqueries,
-                                                 qinfocb, &cb))) {
+    if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(queries, nqueries, qinfocb, &cb))) {
         PMIX_DESTRUCT(&cb);
         return rc;
     }
@@ -337,8 +408,7 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info(pmix_query_t queries[], size_t nquerie
     }
     PMIX_DESTRUCT(&cb);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:job_ctrl completed");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix:job_ctrl completed");
 
     return rc;
 }
@@ -352,8 +422,7 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info_nb(pmix_query_t queries[], size_t nque
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:query non-blocking");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix:query non-blocking");
 
     if (pmix_globals.init_cntr <= 0) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
@@ -367,7 +436,7 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info_nb(pmix_query_t queries[], size_t nque
 
     /* do a quick check of the qualifiers arrays to ensure
      * the nqual field has been set */
-    for (n=0; n < nqueries; n++) {
+    for (n = 0; n < nqueries; n++) {
         if (NULL != queries[n].qualifiers && 0 == queries[n].nqual) {
             /* look for the info marked as "end" */
             p = 0;
@@ -389,7 +458,7 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info_nb(pmix_query_t queries[], size_t nque
      * did would be sent to the host. However, for now we simply
      * assume that any requirement to refresh will force all to
      * do so */
-    for (n=0; n < nqueries; n++) {
+    for (n = 0; n < nqueries; n++) {
         /* check for requests to report supported attributes */
         if (0 == strcmp(queries[n].keys[0], PMIX_QUERY_ATTRIBUTE_SUPPORT)) {
             cd = PMIX_NEW(pmix_query_caddy_t);
@@ -417,7 +486,7 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info_nb(pmix_query_t queries[], size_t nque
              * was accepted for processing */
             return PMIX_SUCCESS;
         }
-        for (p=0; p < queries[n].nqual; p++) {
+        for (p = 0; p < queries[n].nqual; p++) {
             if (PMIX_CHECK_KEY(&queries[n].qualifiers[p], PMIX_QUERY_REFRESH_CACHE)) {
                 if (PMIX_INFO_TRUE(&queries[n].qualifiers[p])) {
                     /* need to refresh the cache from our host */
@@ -443,13 +512,10 @@ PMIX_EXPORT pmix_status_t PMIx_Query_info_nb(pmix_query_t queries[], size_t nque
     return PMIX_SUCCESS;
 }
 
-static void acb(pmix_status_t status,
-                pmix_info_t *info, size_t ninfo,
-                void *cbdata,
-                pmix_release_cbfunc_t release_fn,
-                void *release_cbdata)
+static void acb(pmix_status_t status, pmix_info_t *info, size_t ninfo, void *cbdata,
+                pmix_release_cbfunc_t release_fn, void *release_cbdata)
 {
-    pmix_cb_t *cb = (pmix_cb_t*)cbdata;
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
     size_t n;
 
     cb->status = status;
@@ -460,12 +526,12 @@ static void acb(pmix_status_t status,
             goto done;
         }
         cb->ninfo = ninfo;
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             PMIX_INFO_XFER(&cb->info[n], &info[n]);
         }
     }
 
-  done:
+done:
     if (NULL != release_fn) {
         release_fn(release_cbdata);
     }
@@ -487,8 +553,8 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request(pmix_alloc_directive_t directi
     }
     PMIX_RELEASE_THREAD(&pmix_global_lock);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "%s pmix:allocate", PMIX_NAME_PRINT(&pmix_globals.myid));
+    pmix_output_verbose(2, pmix_globals.debug_output, "%s pmix:allocate",
+                        PMIX_NAME_PRINT(&pmix_globals.myid));
 
     /* set the default response */
     *results = NULL;
@@ -498,8 +564,7 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request(pmix_alloc_directive_t directi
      * recv routine so we know which callback to use when
      * the return message is recvd */
     PMIX_CONSTRUCT(&cb, pmix_cb_t);
-    if (PMIX_SUCCESS != (rc = PMIx_Allocation_request_nb(directive, info, ninfo,
-                                                         acb, &cb))) {
+    if (PMIX_SUCCESS != (rc = PMIx_Allocation_request_nb(directive, info, ninfo, acb, &cb))) {
         PMIX_DESTRUCT(&cb);
         return rc;
     }
@@ -516,8 +581,7 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request(pmix_alloc_directive_t directi
     }
     PMIX_DESTRUCT(&cb);
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix:allocate completed");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix:allocate completed");
 
     return rc;
 }
@@ -531,8 +595,7 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request_nb(pmix_alloc_directive_t dire
     pmix_status_t rc;
     pmix_query_caddy_t *cb;
 
-    pmix_output_verbose(2, pmix_globals.debug_output,
-                        "pmix: allocate called");
+    pmix_output_verbose(2, pmix_globals.debug_output, "pmix: allocate called");
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
@@ -543,19 +606,14 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request_nb(pmix_alloc_directive_t dire
 
     /* if we are the server, then we just issue the request and
      * return the response */
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) &&
-        !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) && !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
         if (NULL == pmix_host_server.allocate) {
             /* nothing we can do */
             return PMIX_ERR_NOT_SUPPORTED;
         }
-        pmix_output_verbose(2, pmix_globals.debug_output,
-                            "pmix:allocate handed to RM");
-        rc = pmix_host_server.allocate(&pmix_globals.myid,
-                                       directive,
-                                       info, ninfo,
-                                       cbfunc, cbdata);
+        pmix_output_verbose(2, pmix_globals.debug_output, "pmix:allocate handed to RM");
+        rc = pmix_host_server.allocate(&pmix_globals.myid, directive, info, ninfo, cbfunc, cbdata);
         return rc;
     }
 
@@ -570,8 +628,7 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request_nb(pmix_alloc_directive_t dire
 
     msg = PMIX_NEW(pmix_buffer_t);
     /* pack the cmd */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &cmd, 1, PMIX_COMMAND);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &cmd, 1, PMIX_COMMAND);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -579,8 +636,7 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request_nb(pmix_alloc_directive_t dire
     }
 
     /* pack the directive */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &directive, 1, PMIX_ALLOC_DIRECTIVE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &directive, 1, PMIX_ALLOC_DIRECTIVE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
@@ -588,16 +644,14 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request_nb(pmix_alloc_directive_t dire
     }
 
     /* pack the info */
-    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &ninfo, 1, PMIX_SIZE);
+    PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, &ninfo, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return rc;
     }
     if (0 < ninfo) {
-        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, info, ninfo, PMIX_INFO);
+        PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver, msg, info, ninfo, PMIX_INFO);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -613,8 +667,7 @@ PMIX_EXPORT pmix_status_t PMIx_Allocation_request_nb(pmix_alloc_directive_t dire
     cb->cbdata = cbdata;
 
     /* push the message into our event base to send to the server */
-    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver,
-                       msg, query_cbfunc, (void*)cb);
+    PMIX_PTL_SEND_RECV(rc, pmix_client_globals.myserver, msg, query_cbfunc, (void *) cb);
     if (PMIX_SUCCESS != rc) {
         PMIX_RELEASE(msg);
         PMIX_RELEASE(cb);
