@@ -12,6 +12,7 @@
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2019      Mellanox Technologies, Inc.
  *                         All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -21,41 +22,35 @@
 
 #include "src/include/pmix_config.h"
 
-
 #include <stdio.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 
-#include "src/util/argv.h"
-#include "src/util/error.h"
 #include "src/include/pmix_globals.h"
 #include "src/mca/preg/preg.h"
+#include "src/util/argv.h"
+#include "src/util/error.h"
 
 #include "src/mca/bfrops/base/base.h"
 
 /* define two public functions */
-PMIX_EXPORT void pmix_value_load(pmix_value_t *v, const void *data,
-                                 pmix_data_type_t type)
+PMIX_EXPORT void pmix_value_load(pmix_value_t *v, const void *data, pmix_data_type_t type)
 {
     pmix_bfrops_base_value_load(v, data, type);
 }
 
-PMIX_EXPORT pmix_status_t pmix_value_unload(pmix_value_t *kv,
-                                            void **data,
-                                            size_t *sz)
+PMIX_EXPORT pmix_status_t pmix_value_unload(pmix_value_t *kv, void **data, size_t *sz)
 {
     return pmix_bfrops_base_value_unload(kv, data, sz);
 }
 
-PMIX_EXPORT pmix_status_t pmix_value_xfer(pmix_value_t *dest,
-                                          const pmix_value_t *src)
+PMIX_EXPORT pmix_status_t pmix_value_xfer(pmix_value_t *dest, const pmix_value_t *src)
 {
     return pmix_bfrops_base_value_xfer(dest, src);
 }
 
-void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
-                                 pmix_data_type_t type)
+void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data, pmix_data_type_t type)
 {
     pmix_byte_object_t *bo;
     pmix_proc_info_t *pi;
@@ -69,16 +64,23 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
     pmix_geometry_t *geometry;
     pmix_endpoint_t *endpoint;
     pmix_device_distance_t *devdist;
+    pmix_data_buffer_t *dbuf;
+    pmix_nspace_t *nspace;
+    pmix_proc_stats_t *pstats;
+    pmix_disk_stats_t *dkstats;
+    pmix_net_stats_t *netstats;
+    pmix_node_stats_t *ndstats;
 
     v->type = type;
     if (NULL == data) {
         /* just set the fields to zero */
         memset(&v->data, 0, sizeof(v->data));
         if (PMIX_BOOL == type) {
-          v->data.flag = true; // existence of the attribute indicates true unless specified different
+            v->data.flag
+                = true; // existence of the attribute indicates true unless specified different
         }
     } else {
-        switch(type) {
+        switch (type) {
         case PMIX_UNDEF:
             break;
         case PMIX_BOOL:
@@ -144,6 +146,11 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
         case PMIX_PROC_RANK:
             memcpy(&(v->data.rank), data, sizeof(pmix_rank_t));
             break;
+        case PMIX_PROC_NSPACE:
+            nspace = (pmix_nspace_t *) data;
+            v->data.nspace = (pmix_nspace_t *) malloc(sizeof(pmix_nspace_t));
+            PMIX_LOAD_NSPACE(*(v->data.nspace), *nspace);
+            break;
         case PMIX_PROC:
             PMIX_PROC_CREATE(v->data.proc, 1);
             if (NULL == v->data.proc) {
@@ -155,8 +162,8 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
         case PMIX_BYTE_OBJECT:
         case PMIX_COMPRESSED_STRING:
         case PMIX_COMPRESSED_BYTE_OBJECT:
-            bo = (pmix_byte_object_t*)data;
-            v->data.bo.bytes = (char*)malloc(bo->size);
+            bo = (pmix_byte_object_t *) data;
+            v->data.bo.bytes = (char *) malloc(bo->size);
             if (NULL == v->data.bo.bytes) {
                 PMIX_ERROR_LOG(PMIX_ERR_NOMEM);
                 return;
@@ -182,7 +189,7 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
                 PMIX_ERROR_LOG(PMIX_ERR_NOMEM);
                 return;
             }
-            pi = (pmix_proc_info_t*)data;
+            pi = (pmix_proc_info_t *) data;
             memcpy(&(v->data.pinfo->proc), &pi->proc, sizeof(pmix_proc_t));
             if (NULL != pi->hostname) {
                 v->data.pinfo->hostname = strdup(pi->hostname);
@@ -194,20 +201,20 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
             memcpy(&(v->data.pinfo->exit_code), &pi->exit_code, sizeof(int));
             break;
         case PMIX_DATA_ARRAY:
-            darray = (pmix_data_array_t*)data;
+            darray = (pmix_data_array_t *) data;
             rc = pmix_bfrops_base_copy_darray(&v->data.darray, darray, PMIX_DATA_ARRAY);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
             }
             break;
         case PMIX_POINTER:
-            v->data.ptr = (void*)data;
+            v->data.ptr = (void *) data;
             break;
         case PMIX_ALLOC_DIRECTIVE:
             memcpy(&(v->data.adir), data, sizeof(pmix_alloc_directive_t));
             break;
         case PMIX_ENVAR:
-            envar = (pmix_envar_t*)data;
+            envar = (pmix_envar_t *) data;
             if (NULL != envar->envar) {
                 v->data.envar.envar = strdup(envar->envar);
             }
@@ -217,7 +224,7 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
             v->data.envar.separator = envar->separator;
             break;
         case PMIX_COORD:
-            coord = (pmix_coord_t*)data;
+            coord = (pmix_coord_t *) data;
             rc = pmix_bfrops_base_copy_coord(&v->data.coord, coord, PMIX_COORD);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
@@ -230,7 +237,7 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
             memcpy(&(v->data.jstate), data, sizeof(pmix_job_state_t));
             break;
         case PMIX_TOPO:
-            topo = (pmix_topology_t*)data;
+            topo = (pmix_topology_t *) data;
             rc = pmix_bfrops_base_copy_topology(&v->data.topo, topo, PMIX_TOPO);
             if (PMIX_ERR_INIT == rc || PMIX_ERR_NOT_SUPPORTED == rc) {
                 /* we are not initialized yet, so just copy the pointer */
@@ -239,7 +246,7 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
             }
             break;
         case PMIX_PROC_CPUSET:
-            cpuset = (pmix_cpuset_t*)data;
+            cpuset = (pmix_cpuset_t *) data;
             rc = pmix_bfrops_base_copy_cpuset(&v->data.cpuset, cpuset, PMIX_PROC_CPUSET);
             if (PMIX_ERR_INIT == rc || PMIX_ERR_NOT_SUPPORTED == rc) {
                 /* we are not initialized yet, so just copy the pointer */
@@ -251,7 +258,7 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
             memcpy(&(v->data.locality), data, sizeof(pmix_locality_t));
             break;
         case PMIX_GEOMETRY:
-            geometry = (pmix_geometry_t*)data;
+            geometry = (pmix_geometry_t *) data;
             rc = pmix_bfrops_base_copy_geometry(&v->data.geometry, geometry, PMIX_GEOMETRY);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
@@ -261,33 +268,71 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
             memcpy(&(v->data.devtype), data, sizeof(pmix_device_type_t));
             break;
         case PMIX_DEVICE_DIST:
-            devdist = (pmix_device_distance_t*)data;
+            devdist = (pmix_device_distance_t *) data;
             rc = pmix_bfrops_base_copy_devdist(&v->data.devdist, devdist, PMIX_DEVICE_DIST);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
             }
             break;
         case PMIX_ENDPOINT:
-            endpoint = (pmix_endpoint_t*)data;
+            endpoint = (pmix_endpoint_t *) data;
             rc = pmix_bfrops_base_copy_endpoint(&v->data.endpoint, endpoint, PMIX_ENDPOINT);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
             }
             break;
         case PMIX_REGATTR:
-            regattr = (pmix_regattr_t*)data;
-            rc = pmix_bfrops_base_copy_regattr((pmix_regattr_t**)&v->data.ptr, regattr, PMIX_REGATTR);
+            regattr = (pmix_regattr_t *) data;
+            rc = pmix_bfrops_base_copy_regattr((pmix_regattr_t **) &v->data.ptr, regattr,
+                                               PMIX_REGATTR);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
             }
             break;
         case PMIX_REGEX:
             /* load it into the byte object */
-            rc = pmix_preg.copy(&v->data.bo.bytes, &v->data.bo.size, (char*)data);
+            rc = pmix_preg.copy(&v->data.bo.bytes, &v->data.bo.size, (char *) data);
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
             }
             break;
+        case PMIX_DATA_BUFFER:
+            dbuf = (pmix_data_buffer_t *) data;
+            PMIX_DATA_BUFFER_CREATE(v->data.dbuf);
+            rc = PMIx_Data_copy_payload(v->data.dbuf, dbuf);
+            if (PMIX_SUCCESS != rc) {
+                PMIX_ERROR_LOG(rc);
+            }
+            break;
+        case PMIX_PROC_STATS:
+            pstats = (pmix_proc_stats_t *) data;
+            rc = pmix_bfrops_base_copy_pstats(&v->data.pstats, pstats, PMIX_PROC_STATS);
+            if (PMIX_SUCCESS != rc) {
+                PMIX_ERROR_LOG(rc);
+            }
+            break;
+        case PMIX_DISK_STATS:
+            dkstats = (pmix_disk_stats_t *) data;
+            rc = pmix_bfrops_base_copy_dkstats(&v->data.dkstats, dkstats, PMIX_DISK_STATS);
+            if (PMIX_SUCCESS != rc) {
+                PMIX_ERROR_LOG(rc);
+            }
+            break;
+        case PMIX_NET_STATS:
+            netstats = (pmix_net_stats_t *) data;
+            rc = pmix_bfrops_base_copy_netstats(&v->data.netstats, netstats, PMIX_NET_STATS);
+            if (PMIX_SUCCESS != rc) {
+                PMIX_ERROR_LOG(rc);
+            }
+            break;
+        case PMIX_NODE_STATS:
+            ndstats = (pmix_node_stats_t *) data;
+            rc = pmix_bfrops_base_copy_ndstats(&v->data.ndstats, ndstats, PMIX_NODE_STATS);
+            if (PMIX_SUCCESS != rc) {
+                PMIX_ERROR_LOG(rc);
+            }
+            break;
+
         default:
             /* silence warnings */
             break;
@@ -296,9 +341,7 @@ void pmix_bfrops_base_value_load(pmix_value_t *v, const void *data,
     return;
 }
 
-pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
-                                            void **data,
-                                            size_t *sz)
+pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv, void **data, size_t *sz)
 {
     pmix_status_t rc;
     pmix_envar_t *envar;
@@ -306,11 +349,11 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
     pmix_regattr_t *regattr, *r;
 
     rc = PMIX_SUCCESS;
-    if (NULL == data ||
-       (NULL == *data && PMIX_STRING != kv->type && PMIX_BYTE_OBJECT != kv->type)) {
+    if (NULL == data
+        || (NULL == *data && PMIX_STRING != kv->type && PMIX_BYTE_OBJECT != kv->type)) {
         rc = PMIX_ERR_BAD_PARAM;
     } else {
-        switch(kv->type) {
+        switch (kv->type) {
         case PMIX_UNDEF:
             rc = PMIX_ERR_UNKNOWN_DATA_TYPE;
             break;
@@ -400,8 +443,15 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             memcpy(*data, &(kv->data.rank), sizeof(pmix_rank_t));
             *sz = sizeof(pmix_rank_t);
             break;
+        case PMIX_PROC_NSPACE:
+            rc = pmix_bfrops_base_copy_nspace((pmix_nspace_t **) data, kv->data.nspace,
+                                              PMIX_PROC_NSPACE);
+            if (PMIX_SUCCESS == rc) {
+                *sz = sizeof(pmix_nspace_t);
+            }
+            break;
         case PMIX_PROC:
-            rc = pmix_bfrops_base_copy_proc((pmix_proc_t**)data, kv->data.proc, PMIX_PROC);
+            rc = pmix_bfrops_base_copy_proc((pmix_proc_t **) data, kv->data.proc, PMIX_PROC);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_proc_t);
             }
@@ -434,21 +484,22 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             *sz = sizeof(pmix_proc_state_t);
             break;
         case PMIX_PROC_INFO:
-            rc = pmix_bfrops_base_copy_pinfo((pmix_proc_info_t**)data, kv->data.pinfo, PMIX_PROC_INFO);
+            rc = pmix_bfrops_base_copy_pinfo((pmix_proc_info_t **) data, kv->data.pinfo,
+                                             PMIX_PROC_INFO);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_proc_info_t);
             }
             break;
         case PMIX_DATA_ARRAY:
-            darray = (pmix_data_array_t**)data;
+            darray = (pmix_data_array_t **) data;
             rc = pmix_bfrops_base_copy_darray(darray, kv->data.darray, PMIX_DATA_ARRAY);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_data_array_t);
             }
             break;
         case PMIX_POINTER:
-            *data = (void*)kv->data.ptr;
-            *sz = sizeof(void*);
+            *data = (void *) kv->data.ptr;
+            *sz = sizeof(void *);
             break;
         case PMIX_ALLOC_DIRECTIVE:
             memcpy(*data, &(kv->data.adir), sizeof(pmix_alloc_directive_t));
@@ -470,7 +521,7 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             *sz = sizeof(pmix_envar_t);
             break;
         case PMIX_COORD:
-            rc = pmix_bfrops_base_copy_coord((pmix_coord_t**)data, kv->data.coord, PMIX_COORD);
+            rc = pmix_bfrops_base_copy_coord((pmix_coord_t **) data, kv->data.coord, PMIX_COORD);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_coord_t);
             }
@@ -484,7 +535,8 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             *sz = sizeof(pmix_job_state_t);
             break;
         case PMIX_TOPO:
-            rc = pmix_bfrops_base_copy_topology((pmix_topology_t**)data, kv->data.topo, PMIX_TOPO);
+            rc = pmix_bfrops_base_copy_topology((pmix_topology_t **) data, kv->data.topo,
+                                                PMIX_TOPO);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_topology_t);
             } else if (PMIX_ERR_INIT == rc || PMIX_ERR_NOT_SUPPORTED == rc) {
@@ -495,7 +547,8 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             }
             break;
         case PMIX_PROC_CPUSET:
-            rc = pmix_bfrops_base_copy_cpuset((pmix_cpuset_t**)data, kv->data.cpuset, PMIX_PROC_CPUSET);
+            rc = pmix_bfrops_base_copy_cpuset((pmix_cpuset_t **) data, kv->data.cpuset,
+                                              PMIX_PROC_CPUSET);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_cpuset_t);
             } else if (PMIX_ERR_INIT == rc || PMIX_ERR_NOT_SUPPORTED == rc) {
@@ -510,7 +563,8 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             *sz = sizeof(pmix_locality_t);
             break;
         case PMIX_GEOMETRY:
-            rc = pmix_bfrops_base_copy_geometry((pmix_geometry_t**)data, kv->data.geometry, PMIX_GEOMETRY);
+            rc = pmix_bfrops_base_copy_geometry((pmix_geometry_t **) data, kv->data.geometry,
+                                                PMIX_GEOMETRY);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_geometry_t);
             }
@@ -520,13 +574,15 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             *sz = sizeof(pmix_device_type_t);
             break;
         case PMIX_DEVICE_DIST:
-            rc = pmix_bfrops_base_copy_devdist((pmix_device_distance_t**)data, kv->data.devdist, PMIX_DEVICE_DIST);
+            rc = pmix_bfrops_base_copy_devdist((pmix_device_distance_t **) data, kv->data.devdist,
+                                               PMIX_DEVICE_DIST);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_device_distance_t);
             }
             break;
         case PMIX_ENDPOINT:
-            rc = pmix_bfrops_base_copy_endpoint((pmix_endpoint_t**)data, kv->data.endpoint, PMIX_ENDPOINT);
+            rc = pmix_bfrops_base_copy_endpoint((pmix_endpoint_t **) data, kv->data.endpoint,
+                                                PMIX_ENDPOINT);
             if (PMIX_SUCCESS == rc) {
                 *sz = sizeof(pmix_endpoint_t);
             }
@@ -536,7 +592,7 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
             if (NULL == regattr) {
                 return PMIX_ERR_NOMEM;
             }
-            r = (pmix_regattr_t*)kv->data.ptr;
+            r = (pmix_regattr_t *) kv->data.ptr;
             if (NULL != r->name) {
                 regattr->name = strdup(r->name);
             }
@@ -555,6 +611,41 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
                 *sz = 0;
             }
             break;
+        case PMIX_DATA_BUFFER:
+            rc = pmix_bfrops_base_copy_dbuf((pmix_data_buffer_t **) data, kv->data.dbuf,
+                                            PMIX_DATA_BUFFER);
+            if (PMIX_SUCCESS == rc) {
+                *sz = sizeof(pmix_data_buffer_t);
+            }
+            break;
+        case PMIX_PROC_STATS:
+            rc = pmix_bfrops_base_copy_pstats((pmix_proc_stats_t **) data, kv->data.pstats,
+                                              PMIX_PROC_STATS);
+            if (PMIX_SUCCESS == rc) {
+                *sz = sizeof(pmix_proc_stats_t);
+            }
+            break;
+        case PMIX_DISK_STATS:
+            rc = pmix_bfrops_base_copy_dkstats((pmix_disk_stats_t **) data, kv->data.dkstats,
+                                               PMIX_DISK_STATS);
+            if (PMIX_SUCCESS == rc) {
+                *sz = sizeof(pmix_disk_stats_t);
+            }
+            break;
+        case PMIX_NET_STATS:
+            rc = pmix_bfrops_base_copy_netstats((pmix_net_stats_t **) data, kv->data.netstats,
+                                                PMIX_NET_STATS);
+            if (PMIX_SUCCESS == rc) {
+                *sz = sizeof(pmix_net_stats_t);
+            }
+            break;
+        case PMIX_NODE_STATS:
+            rc = pmix_bfrops_base_copy_ndstats((pmix_node_stats_t **) data, kv->data.ndstats,
+                                               PMIX_NODE_STATS);
+            if (PMIX_SUCCESS == rc) {
+                *sz = sizeof(pmix_node_stats_t);
+            }
+            break;
         default:
             /* silence warnings */
             rc = PMIX_ERROR;
@@ -565,8 +656,7 @@ pmix_status_t pmix_bfrops_base_value_unload(pmix_value_t *kv,
 }
 
 /* compare function for pmix_value_t */
-pmix_value_cmp_t pmix_bfrops_base_value_cmp(pmix_value_t *p,
-                                            pmix_value_t *p1)
+pmix_value_cmp_t pmix_bfrops_base_value_cmp(pmix_value_t *p, pmix_value_t *p1)
 {
     pmix_value_cmp_t rc = PMIX_VALUE1_GREATER;
     int ret;
@@ -576,162 +666,158 @@ pmix_value_cmp_t pmix_bfrops_base_value_cmp(pmix_value_t *p,
     }
 
     switch (p->type) {
-        case PMIX_UNDEF:
+    case PMIX_UNDEF:
+        rc = PMIX_EQUAL;
+        break;
+    case PMIX_BOOL:
+        if (p->data.flag == p1->data.flag) {
             rc = PMIX_EQUAL;
-            break;
-        case PMIX_BOOL:
-            if (p->data.flag == p1->data.flag) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_BYTE:
-            if (p->data.byte == p1->data.byte) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_SIZE:
-            if (p->data.size == p1->data.size) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_INT:
-            if (p->data.integer == p1->data.integer) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_INT8:
-            if (p->data.int8 == p1->data.int8) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_INT16:
-            if (p->data.int16 == p1->data.int16) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_INT32:
-            if (p->data.int32 == p1->data.int32) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_INT64:
-            if (p->data.int64 == p1->data.int64) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_UINT:
-            if (p->data.uint == p1->data.uint) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_UINT8:
-            if (p->data.uint8 == p1->data.int8) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_UINT16:
-            if (p->data.uint16 == p1->data.uint16) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_UINT32:
-            if (p->data.uint32 == p1->data.uint32) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_UINT64:
-            if (p->data.uint64 == p1->data.uint64) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_STRING:
-            if (0 == strcmp(p->data.string, p1->data.string)) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_COMPRESSED_STRING:
-            if (p->data.bo.size > p1->data.bo.size) {
-                return PMIX_VALUE2_GREATER;
-            } else {
+        }
+        break;
+    case PMIX_BYTE:
+        if (p->data.byte == p1->data.byte) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_SIZE:
+        if (p->data.size == p1->data.size) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_INT:
+        if (p->data.integer == p1->data.integer) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_INT8:
+        if (p->data.int8 == p1->data.int8) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_INT16:
+        if (p->data.int16 == p1->data.int16) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_INT32:
+        if (p->data.int32 == p1->data.int32) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_INT64:
+        if (p->data.int64 == p1->data.int64) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_UINT:
+        if (p->data.uint == p1->data.uint) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_UINT8:
+        if (p->data.uint8 == p1->data.int8) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_UINT16:
+        if (p->data.uint16 == p1->data.uint16) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_UINT32:
+        if (p->data.uint32 == p1->data.uint32) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_UINT64:
+        if (p->data.uint64 == p1->data.uint64) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_STRING:
+        if (0 == strcmp(p->data.string, p1->data.string)) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_COMPRESSED_STRING:
+        if (p->data.bo.size > p1->data.bo.size) {
+            return PMIX_VALUE2_GREATER;
+        } else {
+            return PMIX_VALUE1_GREATER;
+        }
+    case PMIX_STATUS:
+        if (p->data.status == p1->data.status) {
+            rc = PMIX_EQUAL;
+        }
+        break;
+    case PMIX_ENVAR:
+        if (NULL != p->data.envar.envar) {
+            if (NULL == p1->data.envar.envar) {
                 return PMIX_VALUE1_GREATER;
             }
-            break;
-        case PMIX_STATUS:
-            if (p->data.status == p1->data.status) {
-                rc = PMIX_EQUAL;
-            }
-            break;
-        case PMIX_ENVAR:
-            if (NULL != p->data.envar.envar) {
-                if (NULL == p1->data.envar.envar) {
-                    return PMIX_VALUE1_GREATER;
-                }
-                ret = strcmp(p->data.envar.envar, p1->data.envar.envar);
-                if (ret < 0) {
-                    return PMIX_VALUE2_GREATER;
-                } else if (0 < ret) {
-                    return PMIX_VALUE1_GREATER;
-                }
-            } else if (NULL != p1->data.envar.envar) {
-                /* we know value1->envar had to be NULL */
-                return PMIX_VALUE2_GREATER;
-            }
-
-            /* if both are NULL or are equal, then check value */
-            if (NULL != p->data.envar.value) {
-                if (NULL == p1->data.envar.value) {
-                    return PMIX_VALUE1_GREATER;
-                }
-                ret = strcmp(p->data.envar.value, p1->data.envar.value);
-                if (ret < 0) {
-                    return PMIX_VALUE2_GREATER;
-                } else if (0 < ret) {
-                    return PMIX_VALUE1_GREATER;
-                }
-            } else if (NULL != p1->data.envar.value) {
-                /* we know value1->value had to be NULL */
-                return PMIX_VALUE2_GREATER;
-            }
-
-            /* finally, check separator */
-            if (p->data.envar.separator < p1->data.envar.separator) {
-                return PMIX_VALUE2_GREATER;
-            }
-            if (p1->data.envar.separator < p->data.envar.separator) {
-                return PMIX_VALUE1_GREATER;
-            }
-            rc = PMIX_EQUAL;
-            break;
-        case PMIX_COORD:
-            ret = memcmp(p->data.coord, p1->data.coord, sizeof(pmix_coord_t));
-            if (0 > ret) {
+            ret = strcmp(p->data.envar.envar, p1->data.envar.envar);
+            if (ret < 0) {
                 return PMIX_VALUE2_GREATER;
             } else if (0 < ret) {
                 return PMIX_VALUE1_GREATER;
-            } else {
-                return PMIX_EQUAL;
             }
-            break;
-        case PMIX_REGATTR:
-            ret = memcmp(p->data.ptr, p1->data.ptr, sizeof(pmix_regattr_t));
-            if (0 > ret) {
+        } else if (NULL != p1->data.envar.envar) {
+            /* we know value1->envar had to be NULL */
+            return PMIX_VALUE2_GREATER;
+        }
+
+        /* if both are NULL or are equal, then check value */
+        if (NULL != p->data.envar.value) {
+            if (NULL == p1->data.envar.value) {
+                return PMIX_VALUE1_GREATER;
+            }
+            ret = strcmp(p->data.envar.value, p1->data.envar.value);
+            if (ret < 0) {
                 return PMIX_VALUE2_GREATER;
             } else if (0 < ret) {
                 return PMIX_VALUE1_GREATER;
-            } else {
-                return PMIX_EQUAL;
             }
-            break;
+        } else if (NULL != p1->data.envar.value) {
+            /* we know value1->value had to be NULL */
+            return PMIX_VALUE2_GREATER;
+        }
 
-        default:
-            pmix_output(0, "COMPARE-PMIX-VALUE: UNSUPPORTED TYPE %d", (int)p->type);
+        /* finally, check separator */
+        if (p->data.envar.separator < p1->data.envar.separator) {
+            return PMIX_VALUE2_GREATER;
+        }
+        if (p1->data.envar.separator < p->data.envar.separator) {
+            return PMIX_VALUE1_GREATER;
+        }
+        rc = PMIX_EQUAL;
+        break;
+    case PMIX_COORD:
+        ret = memcmp(p->data.coord, p1->data.coord, sizeof(pmix_coord_t));
+        if (0 > ret) {
+            return PMIX_VALUE2_GREATER;
+        } else if (0 < ret) {
+            return PMIX_VALUE1_GREATER;
+        } else {
+            return PMIX_EQUAL;
+        }
+    case PMIX_REGATTR:
+        ret = memcmp(p->data.ptr, p1->data.ptr, sizeof(pmix_regattr_t));
+        if (0 > ret) {
+            return PMIX_VALUE2_GREATER;
+        } else if (0 < ret) {
+            return PMIX_VALUE1_GREATER;
+        } else {
+            return PMIX_EQUAL;
+        }
+
+    default:
+        pmix_output(0, "COMPARE-PMIX-VALUE: UNSUPPORTED TYPE %d", (int) p->type);
     }
     return rc;
 }
 
 /* Xfer FUNCTIONS FOR GENERIC PMIX TYPES */
-pmix_status_t pmix_bfrops_base_value_xfer(pmix_value_t *p,
-                                          const pmix_value_t *src)
+pmix_status_t pmix_bfrops_base_value_xfer(pmix_value_t *p, const pmix_value_t *src)
 {
     pmix_status_t rc;
 
@@ -739,7 +825,7 @@ pmix_status_t pmix_bfrops_base_value_xfer(pmix_value_t *p,
     p->type = src->type;
     switch (src->type) {
     case PMIX_UNDEF:
-    break;
+        break;
     case PMIX_BOOL:
         p->data.flag = src->data.flag;
         break;
@@ -815,6 +901,8 @@ pmix_status_t pmix_bfrops_base_value_xfer(pmix_value_t *p,
     case PMIX_PROC_RANK:
         memcpy(&p->data.rank, &src->data.rank, sizeof(pmix_rank_t));
         break;
+    case PMIX_PROC_NSPACE:
+        return pmix_bfrops_base_copy_nspace(&p->data.nspace, src->data.nspace, PMIX_PROC_NSPACE);
     case PMIX_PROC:
         PMIX_PROC_CREATE(p->data.proc, 1);
         if (NULL == p->data.proc) {
@@ -905,26 +993,39 @@ pmix_status_t pmix_bfrops_base_value_xfer(pmix_value_t *p,
     case PMIX_ENDPOINT:
         return pmix_bfrops_base_copy_endpoint(&p->data.endpoint, src->data.endpoint, PMIX_ENDPOINT);
     case PMIX_REGATTR:
-        return pmix_bfrops_base_copy_regattr((pmix_regattr_t**)&p->data.ptr, src->data.ptr, PMIX_REGATTR);
+        return pmix_bfrops_base_copy_regattr((pmix_regattr_t **) &p->data.ptr, src->data.ptr,
+                                             PMIX_REGATTR);
+    case PMIX_DATA_BUFFER:
+        return pmix_bfrops_base_copy_dbuf(&p->data.dbuf, src->data.dbuf, PMIX_DATA_BUFFER);
+    case PMIX_PROC_STATS:
+        return pmix_bfrops_base_copy_pstats(&p->data.pstats, src->data.pstats, PMIX_PROC_STATS);
+    case PMIX_DISK_STATS:
+        return pmix_bfrops_base_copy_dkstats(&p->data.dkstats, src->data.dkstats, PMIX_DISK_STATS);
+    case PMIX_NET_STATS:
+        return pmix_bfrops_base_copy_netstats(&p->data.netstats, src->data.netstats,
+                                              PMIX_NET_STATS);
+    case PMIX_NODE_STATS:
+        return pmix_bfrops_base_copy_ndstats(&p->data.ndstats, src->data.ndstats, PMIX_NODE_STATS);
     default:
-        pmix_output(0, "PMIX-XFER-VALUE: UNSUPPORTED TYPE %d", (int)src->type);
+        pmix_output(0, "PMIX-XFER-VALUE: UNSUPPORTED TYPE %d", (int) src->type);
         return PMIX_ERROR;
     }
     return PMIX_SUCCESS;
 }
 
-
 /**
  * Internal function that resizes (expands) an inuse buffer if
  * necessary.
  */
-char* pmix_bfrop_buffer_extend(pmix_buffer_t *buffer, size_t bytes_to_add)
+char *pmix_bfrop_buffer_extend(pmix_buffer_t *buffer, size_t bytes_to_add)
 {
     size_t required, to_alloc;
     size_t pack_offset, unpack_offset;
 
     /* Check to see if we have enough space already */
-
+    if (0 == bytes_to_add) {
+        return buffer->pack_ptr;
+    }
 
     if ((buffer->bytes_allocated - buffer->bytes_used) >= bytes_to_add) {
         return buffer->pack_ptr;
@@ -933,7 +1034,8 @@ char* pmix_bfrop_buffer_extend(pmix_buffer_t *buffer, size_t bytes_to_add)
     required = buffer->bytes_used + bytes_to_add;
     if (required >= pmix_bfrops_globals.threshold_size) {
         to_alloc = ((required + pmix_bfrops_globals.threshold_size - 1)
-                    / pmix_bfrops_globals.threshold_size) * pmix_bfrops_globals.threshold_size;
+                    / pmix_bfrops_globals.threshold_size)
+                   * pmix_bfrops_globals.threshold_size;
     } else {
         to_alloc = buffer->bytes_allocated;
         if (0 == to_alloc) {
@@ -945,24 +1047,23 @@ char* pmix_bfrop_buffer_extend(pmix_buffer_t *buffer, size_t bytes_to_add)
     }
 
     if (NULL != buffer->base_ptr) {
-        pack_offset = ((char*) buffer->pack_ptr) - ((char*) buffer->base_ptr);
-        unpack_offset = ((char*) buffer->unpack_ptr) -
-            ((char*) buffer->base_ptr);
-        buffer->base_ptr = (char*)realloc(buffer->base_ptr, to_alloc);
+        pack_offset = ((char *) buffer->pack_ptr) - ((char *) buffer->base_ptr);
+        unpack_offset = ((char *) buffer->unpack_ptr) - ((char *) buffer->base_ptr);
+        buffer->base_ptr = (char *) realloc(buffer->base_ptr, to_alloc);
         memset(buffer->base_ptr + pack_offset, 0, to_alloc - buffer->bytes_allocated);
     } else {
         pack_offset = 0;
         unpack_offset = 0;
         buffer->bytes_used = 0;
-        buffer->base_ptr = (char*)malloc(to_alloc);
+        buffer->base_ptr = (char *) malloc(to_alloc);
         memset(buffer->base_ptr, 0, to_alloc);
     }
 
     if (NULL == buffer->base_ptr) {
         return NULL;
     }
-    buffer->pack_ptr = ((char*) buffer->base_ptr) + pack_offset;
-    buffer->unpack_ptr = ((char*) buffer->base_ptr) + unpack_offset;
+    buffer->pack_ptr = ((char *) buffer->base_ptr) + pack_offset;
+    buffer->unpack_ptr = ((char *) buffer->base_ptr) + unpack_offset;
     buffer->bytes_allocated = to_alloc;
 
     /* All done */
@@ -993,8 +1094,8 @@ bool pmix_bfrop_too_small(pmix_buffer_t *buffer, size_t bytes_reqd)
     return false;
 }
 
-pmix_status_t pmix_bfrop_store_data_type(pmix_pointer_array_t *regtypes,
-                                         pmix_buffer_t *buffer, pmix_data_type_t type)
+pmix_status_t pmix_bfrop_store_data_type(pmix_pointer_array_t *regtypes, pmix_buffer_t *buffer,
+                                         pmix_data_type_t type)
 {
     pmix_status_t ret;
 
@@ -1002,8 +1103,8 @@ pmix_status_t pmix_bfrop_store_data_type(pmix_pointer_array_t *regtypes,
     return ret;
 }
 
-pmix_status_t pmix_bfrop_get_data_type(pmix_pointer_array_t *regtypes,
-                                       pmix_buffer_t *buffer, pmix_data_type_t *type)
+pmix_status_t pmix_bfrop_get_data_type(pmix_pointer_array_t *regtypes, pmix_buffer_t *buffer,
+                                       pmix_data_type_t *type)
 {
     pmix_status_t ret;
     int32_t m = 1;
@@ -1012,20 +1113,19 @@ pmix_status_t pmix_bfrop_get_data_type(pmix_pointer_array_t *regtypes,
     return ret;
 }
 
-const char* pmix_bfrops_base_data_type_string(pmix_pointer_array_t *regtypes,
-                                              pmix_data_type_t type)
+const char *pmix_bfrops_base_data_type_string(pmix_pointer_array_t *regtypes, pmix_data_type_t type)
 {
     pmix_bfrop_type_info_t *info;
 
     /* Lookup the object for this type and call it */
-    if (NULL == (info = (pmix_bfrop_type_info_t*)pmix_pointer_array_get_item(regtypes, type))) {
+    if (NULL == (info = (pmix_bfrop_type_info_t *) pmix_pointer_array_get_item(regtypes, type))) {
         return NULL;
     }
 
     return info->odti_name;
 }
 
-PMIX_EXPORT void* pmix_info_list_start(void)
+PMIX_EXPORT void *pmix_info_list_start(void)
 {
     pmix_list_t *p;
 
@@ -1033,12 +1133,10 @@ PMIX_EXPORT void* pmix_info_list_start(void)
     return p;
 }
 
-PMIX_EXPORT pmix_status_t pmix_info_list_add(void *ptr,
-                                             pmix_key_t key,
-                                             void *value,
+PMIX_EXPORT pmix_status_t pmix_info_list_add(void *ptr, const char *key, void *value,
                                              pmix_data_type_t type)
 {
-    pmix_list_t *p = (pmix_list_t*)ptr;
+    pmix_list_t *p = (pmix_list_t *) ptr;
     pmix_infolist_t *iptr;
 
     iptr = PMIX_NEW(pmix_infolist_t);
@@ -1050,10 +1148,9 @@ PMIX_EXPORT pmix_status_t pmix_info_list_add(void *ptr,
     return PMIX_SUCCESS;
 }
 
-PMIX_EXPORT pmix_status_t pmix_info_list_xfer(void *ptr,
-                                              const pmix_info_t *info)
+PMIX_EXPORT pmix_status_t pmix_info_list_xfer(void *ptr, const pmix_info_t *info)
 {
-    pmix_list_t *p = (pmix_list_t*)ptr;
+    pmix_list_t *p = (pmix_list_t *) ptr;
     pmix_infolist_t *iptr;
 
     iptr = PMIX_NEW(pmix_infolist_t);
@@ -1067,7 +1164,7 @@ PMIX_EXPORT pmix_status_t pmix_info_list_xfer(void *ptr,
 
 PMIX_EXPORT pmix_status_t pmix_info_list_convert(void *ptr, pmix_data_array_t *par)
 {
-    pmix_list_t *p = (pmix_list_t*)ptr;
+    pmix_list_t *p = (pmix_list_t *) ptr;
     size_t n;
     pmix_infolist_t *iptr;
     pmix_info_t *array;
@@ -1086,11 +1183,11 @@ PMIX_EXPORT pmix_status_t pmix_info_list_convert(void *ptr, pmix_data_array_t *p
     }
     par->type = PMIX_INFO;
     par->size = n;
-    array = (pmix_info_t*)par->array;
+    array = (pmix_info_t *) par->array;
 
     /* transfer the elements across */
-    n=0;
-    PMIX_LIST_FOREACH(iptr, p, pmix_infolist_t) {
+    n = 0;
+    PMIX_LIST_FOREACH (iptr, p, pmix_infolist_t) {
         PMIX_INFO_XFER(&array[n], &iptr->info);
         ++n;
     }
@@ -1100,6 +1197,6 @@ PMIX_EXPORT pmix_status_t pmix_info_list_convert(void *ptr, pmix_data_array_t *p
 
 PMIX_EXPORT void pmix_info_list_release(void *ptr)
 {
-    pmix_list_t *p = (pmix_list_t*)ptr;
+    pmix_list_t *p = (pmix_list_t *) ptr;
     PMIX_LIST_RELEASE(p);
 }
