@@ -14,6 +14,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015-2020 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -28,15 +29,15 @@
 #include "include/pmix_common.h"
 
 #ifdef HAVE_STRING_H
-#include <string.h>
+#    include <string.h>
 #endif
 
-#include "src/mca/mca.h"
-#include "src/mca/base/base.h"
-#include "src/mca/base/pmix_mca_base_var.h"
-#include "src/mca/base/pmix_mca_base_framework.h"
 #include "src/class/pmix_list.h"
+#include "src/mca/base/base.h"
+#include "src/mca/base/pmix_mca_base_framework.h"
+#include "src/mca/base/pmix_mca_base_var.h"
 #include "src/mca/bfrops/base/base.h"
+#include "src/mca/mca.h"
 
 /*
  * The following file was created by configure.  It contains extern
@@ -47,15 +48,14 @@
 #include "src/mca/bfrops/base/static-components.h"
 
 /* Instantiate the global vars */
-pmix_bfrops_globals_t pmix_bfrops_globals = {
-    .actives = PMIX_LIST_STATIC_INIT,
-    .initialized = false,
-    .initial_size = 0,
-    .threshold_size = 0,
+pmix_bfrops_globals_t pmix_bfrops_globals = {.actives = PMIX_LIST_STATIC_INIT,
+                                             .initialized = false,
+                                             .initial_size = 0,
+                                             .threshold_size = 0,
 #if PMIX_ENABLE_DEBUG
-    .default_type = PMIX_BFROP_BUFFER_FULLY_DESC
+                                             .default_type = PMIX_BFROP_BUFFER_FULLY_DESC
 #else
-    .default_type = PMIX_BFROP_BUFFER_NON_DESC
+                                             .default_type = PMIX_BFROP_BUFFER_NON_DESC
 #endif
 };
 int pmix_bfrops_base_output = 0;
@@ -64,23 +64,21 @@ static int pmix_bfrop_register(pmix_mca_base_register_flag_t flags)
 {
     if (PMIX_MCA_BASE_REGISTER_DEFAULT == flags) {
         /* do something to silence warning */
-        int count=0;
+        int count = 0;
         ++count;
     }
     pmix_bfrops_globals.initial_size = PMIX_BFROP_DEFAULT_INITIAL_SIZE;
-    pmix_mca_base_var_register("pmix", "bfrops", "base", "initial_size",
-                               "Initial size of a buffer",
-                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, 0,
-                               PMIX_INFO_LVL_2,
-                               PMIX_MCA_BASE_VAR_SCOPE_READONLY,
+    pmix_mca_base_var_register("pmix", "bfrops", "base", "initial_size", "Initial size of a buffer",
+                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
+                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY,
                                &pmix_bfrops_globals.initial_size);
 
     pmix_bfrops_globals.threshold_size = PMIX_BFROP_DEFAULT_THRESHOLD_SIZE;
     pmix_mca_base_var_register("pmix", "bfrops", "base", "threshold_size",
-                               "Size at which we switch from extending a buffer by doubling to extending by a smaller value",
-                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, 0,
-                               PMIX_INFO_LVL_2,
-                               PMIX_MCA_BASE_VAR_SCOPE_READONLY,
+                               "Size at which we switch from extending a buffer by doubling to "
+                               "extending by a smaller value",
+                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
+                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY,
                                &pmix_bfrops_globals.threshold_size);
 
 #if PMIX_ENABLE_DEBUG
@@ -88,11 +86,9 @@ static int pmix_bfrop_register(pmix_mca_base_register_flag_t flags)
 #else
     pmix_bfrops_globals.default_type = PMIX_BFROP_BUFFER_NON_DESC;
 #endif
-    pmix_mca_base_var_register("pmix", "bfrops", "base", "default_type",
-                               "Default type for buffers",
-                               PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                               PMIX_INFO_LVL_2,
-                               PMIX_MCA_BASE_VAR_SCOPE_READONLY,
+    pmix_mca_base_var_register("pmix", "bfrops", "base", "default_type", "Default type for buffers",
+                               PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
+                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY,
                                &pmix_bfrops_globals.default_type);
     return PMIX_SUCCESS;
 }
@@ -125,9 +121,10 @@ static pmix_status_t pmix_bfrop_open(pmix_mca_base_open_flag_t flags)
     return rc;
 }
 
-PMIX_MCA_BASE_FRAMEWORK_DECLARE(pmix, bfrops, "PMIx Buffer Operations",
-                                pmix_bfrop_register, pmix_bfrop_open, pmix_bfrop_close,
-                                mca_bfrops_base_static_components, 0);
+PMIX_MCA_BASE_FRAMEWORK_DECLARE(pmix, bfrops, "PMIx Buffer Operations", pmix_bfrop_register,
+                                pmix_bfrop_open, pmix_bfrop_close,
+                                mca_bfrops_base_static_components,
+                                PMIX_MCA_BASE_FRAMEWORK_FLAG_DEFAULT);
 
 static void moddes(pmix_bfrops_base_active_module_t *p)
 {
@@ -135,15 +132,13 @@ static void moddes(pmix_bfrops_base_active_module_t *p)
         p->module->finalize();
     }
 }
-PMIX_CLASS_INSTANCE(pmix_bfrops_base_active_module_t,
-                    pmix_list_item_t,
-                    NULL, moddes);
+PMIX_CLASS_INSTANCE(pmix_bfrops_base_active_module_t, pmix_list_item_t, NULL, moddes);
 
 /**
  * Object constructors, destructors, and instantiations
  */
 /** Value **/
-static void pmix_buffer_construct (pmix_buffer_t* buffer)
+static void pmix_buffer_construct(pmix_buffer_t *buffer)
 {
     /** set the default buffer type */
     buffer->type = PMIX_BFROP_BUFFER_UNDEF;
@@ -153,18 +148,14 @@ static void pmix_buffer_construct (pmix_buffer_t* buffer)
     buffer->bytes_allocated = buffer->bytes_used = 0;
 }
 
-static void pmix_buffer_destruct (pmix_buffer_t* buffer)
+static void pmix_buffer_destruct(pmix_buffer_t *buffer)
 {
     if (NULL != buffer->base_ptr) {
-        free (buffer->base_ptr);
+        free(buffer->base_ptr);
     }
 }
 
-PMIX_CLASS_INSTANCE(pmix_buffer_t,
-                   pmix_object_t,
-                   pmix_buffer_construct,
-                   pmix_buffer_destruct);
-
+PMIX_CLASS_INSTANCE(pmix_buffer_t, pmix_object_t, pmix_buffer_construct, pmix_buffer_destruct);
 
 static void pmix_bfrop_type_info_construct(pmix_bfrop_type_info_t *obj)
 {
@@ -182,9 +173,8 @@ static void pmix_bfrop_type_info_destruct(pmix_bfrop_type_info_t *obj)
     }
 }
 
-PMIX_CLASS_INSTANCE(pmix_bfrop_type_info_t, pmix_object_t,
-                   pmix_bfrop_type_info_construct,
-                   pmix_bfrop_type_info_destruct);
+PMIX_CLASS_INSTANCE(pmix_bfrop_type_info_t, pmix_object_t, pmix_bfrop_type_info_construct,
+                    pmix_bfrop_type_info_destruct);
 
 static void kvcon(pmix_kval_t *k)
 {
@@ -200,6 +190,4 @@ static void kvdes(pmix_kval_t *k)
         PMIX_VALUE_RELEASE(k->value);
     }
 }
-PMIX_CLASS_INSTANCE(pmix_kval_t,
-                   pmix_list_item_t,
-                   kvcon, kvdes);
+PMIX_CLASS_INSTANCE(pmix_kval_t, pmix_list_item_t, kvcon, kvdes);
