@@ -9,10 +9,11 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2014-2018 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -20,15 +21,14 @@
  * $HEADER$
  */
 
-#include <src/include/pmix_config.h>
-
+#include "src/include/pmix_config.h"
 
+#include "bfrop_v12.h"
+#include "internal.h"
+#include "src/mca/bfrops/base/base.h"
 #include "src/util/argv.h"
 #include "src/util/error.h"
 #include "src/util/output.h"
-#include "src/mca/bfrops/base/base.h"
-#include "bfrop_v12.h"
-#include "internal.h"
 
 pmix_status_t pmix12_bfrop_copy(void **dest, void *src, pmix_data_type_t type)
 {
@@ -44,9 +44,11 @@ pmix_status_t pmix12_bfrop_copy(void **dest, void *src, pmix_data_type_t type)
         return PMIX_ERR_BAD_PARAM;
     }
 
-   /* Lookup the copy function for this type and call it */
+    /* Lookup the copy function for this type and call it */
 
-    if (NULL == (info = (pmix_bfrop_type_info_t*)pmix_pointer_array_get_item(&mca_bfrops_v12_component.types, type))) {
+    if (NULL
+        == (info = (pmix_bfrop_type_info_t *)
+                pmix_pointer_array_get_item(&mca_bfrops_v12_component.types, type))) {
         PMIX_ERROR_LOG(PMIX_ERR_UNKNOWN_DATA_TYPE);
         return PMIX_ERR_UNKNOWN_DATA_TYPE;
     }
@@ -59,27 +61,26 @@ pmix_status_t pmix12_bfrop_copy_payload(pmix_buffer_t *dest, pmix_buffer_t *src)
     size_t to_copy = 0;
     char *ptr;
     /* deal with buffer type */
-    if( NULL == dest->base_ptr ){
+    if (NULL == dest->base_ptr) {
         /* destination buffer is empty - derive src buffer type */
         dest->type = src->type;
-    } else if( dest->type != src->type ){
+    } else if (dest->type != src->type) {
         /* buffer types mismatch */
         PMIX_ERROR_LOG(PMIX_ERR_BAD_PARAM);
         return PMIX_ERR_BAD_PARAM;
     }
 
     to_copy = src->pack_ptr - src->unpack_ptr;
-    if( NULL == (ptr = pmix_bfrop_buffer_extend(dest, to_copy)) ){
+    if (NULL == (ptr = pmix_bfrop_buffer_extend(dest, to_copy))) {
         PMIX_ERROR_LOG(PMIX_ERR_OUT_OF_RESOURCE);
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
-    memcpy(ptr,src->unpack_ptr, to_copy);
+    memcpy(ptr, src->unpack_ptr, to_copy);
     dest->bytes_used += to_copy;
     dest->pack_ptr += to_copy;
     return PMIX_SUCCESS;
 }
 
-
 /*
  * STANDARD COPY FUNCTION - WORKS FOR EVERYTHING NON-STRUCTURED
  */
@@ -88,7 +89,7 @@ pmix_status_t pmix12_bfrop_std_copy(void **dest, void *src, pmix_data_type_t typ
     size_t datasize;
     uint8_t *val = NULL;
 
-    switch(type) {
+    switch (type) {
     case PMIX_BOOL:
         datasize = sizeof(bool);
         break;
@@ -143,7 +144,7 @@ pmix_status_t pmix12_bfrop_std_copy(void **dest, void *src, pmix_data_type_t typ
         return PMIX_ERR_UNKNOWN_DATA_TYPE;
     }
 
-    val = (uint8_t*)malloc(datasize);
+    val = (uint8_t *) malloc(datasize);
     if (NULL == val) {
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
@@ -161,7 +162,7 @@ pmix_status_t pmix12_bfrop_std_copy(void **dest, void *src, pmix_data_type_t typ
  */
 pmix_status_t pmix12_bfrop_copy_string(char **dest, char *src, pmix_data_type_t type)
 {
-    if (NULL == src) {  /* got zero-length string/NULL pointer - store NULL */
+    if (NULL == src) { /* got zero-length string/NULL pointer - store NULL */
         *dest = NULL;
     } else {
         *dest = strdup(src);
@@ -174,50 +175,50 @@ pmix_value_cmp_t pmix12_bfrop_value_cmp(pmix_value_t *p, pmix_value_t *p1)
 {
     bool rc = false;
     switch (p->type) {
-        case PMIX_BOOL:
-            rc = (p->data.flag == p1->data.flag);
-            break;
-        case PMIX_BYTE:
-            rc = (p->data.byte == p1->data.byte);
-            break;
-        case PMIX_SIZE:
-            rc = (p->data.size == p1->data.size);
-            break;
-        case PMIX_INT:
-            rc = (p->data.integer == p1->data.integer);
-            break;
-        case PMIX_INT8:
-            rc = (p->data.int8 == p1->data.int8);
-            break;
-        case PMIX_INT16:
-            rc = (p->data.int16 == p1->data.int16);
-            break;
-        case PMIX_INT32:
-            rc = (p->data.int32 == p1->data.int32);
-            break;
-        case PMIX_INT64:
-            rc = (p->data.int64 == p1->data.int64);
-            break;
-        case PMIX_UINT:
-            rc = (p->data.uint == p1->data.uint);
-            break;
-        case PMIX_UINT8:
-            rc = (p->data.uint8 == p1->data.int8);
-            break;
-        case PMIX_UINT16:
-            rc = (p->data.uint16 == p1->data.uint16);
-            break;
-        case PMIX_UINT32:
-            rc = (p->data.uint32 == p1->data.uint32);
-            break;
-        case PMIX_UINT64:
-            rc = (p->data.uint64 == p1->data.uint64);
-            break;
-        case PMIX_STRING:
-            rc = strcmp(p->data.string, p1->data.string);
-            break;
-        default:
-            pmix_output(0, "COMPARE-PMIX-VALUE: UNSUPPORTED TYPE %d", (int)p->type);
+    case PMIX_BOOL:
+        rc = (p->data.flag == p1->data.flag);
+        break;
+    case PMIX_BYTE:
+        rc = (p->data.byte == p1->data.byte);
+        break;
+    case PMIX_SIZE:
+        rc = (p->data.size == p1->data.size);
+        break;
+    case PMIX_INT:
+        rc = (p->data.integer == p1->data.integer);
+        break;
+    case PMIX_INT8:
+        rc = (p->data.int8 == p1->data.int8);
+        break;
+    case PMIX_INT16:
+        rc = (p->data.int16 == p1->data.int16);
+        break;
+    case PMIX_INT32:
+        rc = (p->data.int32 == p1->data.int32);
+        break;
+    case PMIX_INT64:
+        rc = (p->data.int64 == p1->data.int64);
+        break;
+    case PMIX_UINT:
+        rc = (p->data.uint == p1->data.uint);
+        break;
+    case PMIX_UINT8:
+        rc = (p->data.uint8 == p1->data.int8);
+        break;
+    case PMIX_UINT16:
+        rc = (p->data.uint16 == p1->data.uint16);
+        break;
+    case PMIX_UINT32:
+        rc = (p->data.uint32 == p1->data.uint32);
+        break;
+    case PMIX_UINT64:
+        rc = (p->data.uint64 == p1->data.uint64);
+        break;
+    case PMIX_STRING:
+        rc = strcmp(p->data.string, p1->data.string);
+        break;
+    default:
+        pmix_output(0, "COMPARE-PMIX-VALUE: UNSUPPORTED TYPE %d", (int) p->type);
     }
     if (rc) {
         return PMIX_EQUAL;
@@ -310,20 +311,19 @@ pmix_status_t pmix12_bfrop_value_xfer(pmix_value_t *p, const pmix_value_t *src)
         }
         break;
     default:
-        pmix_output(0, "COPY-PMIX-VALUE: UNSUPPORTED TYPE %d", (int)src->type);
+        pmix_output(0, "COPY-PMIX-VALUE: UNSUPPORTED TYPE %d", (int) src->type);
         return PMIX_ERROR;
     }
     return PMIX_SUCCESS;
 }
 
 /* PMIX_VALUE */
-pmix_status_t pmix12_bfrop_copy_value(pmix_value_t **dest, pmix_value_t *src,
-                                     pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_value(pmix_value_t **dest, pmix_value_t *src, pmix_data_type_t type)
 {
     pmix_value_t *p;
 
     /* create the new object */
-    *dest = (pmix_value_t*)malloc(sizeof(pmix_value_t));
+    *dest = (pmix_value_t *) malloc(sizeof(pmix_value_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
@@ -335,43 +335,39 @@ pmix_status_t pmix12_bfrop_copy_value(pmix_value_t **dest, pmix_value_t *src,
     return pmix_value_xfer(p, src);
 }
 
-pmix_status_t pmix12_bfrop_copy_info(pmix_info_t **dest, pmix_info_t *src,
-                                    pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_info(pmix_info_t **dest, pmix_info_t *src, pmix_data_type_t type)
 {
-    *dest = (pmix_info_t*)malloc(sizeof(pmix_info_t));
+    *dest = (pmix_info_t *) malloc(sizeof(pmix_info_t));
     pmix_strncpy((*dest)->key, src->key, PMIX_MAX_KEYLEN);
     return pmix_value_xfer(&(*dest)->value, &src->value);
 }
 
-pmix_status_t pmix12_bfrop_copy_buf(pmix_buffer_t **dest, pmix_buffer_t *src,
-                                   pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_buf(pmix_buffer_t **dest, pmix_buffer_t *src, pmix_data_type_t type)
 {
     *dest = PMIX_NEW(pmix_buffer_t);
     pmix_bfrops_base_copy_payload(*dest, src);
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_app(pmix_app_t **dest, pmix_app_t *src,
-                                   pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_app(pmix_app_t **dest, pmix_app_t *src, pmix_data_type_t type)
 {
     size_t j;
 
-    *dest = (pmix_app_t*)malloc(sizeof(pmix_app_t));
+    *dest = (pmix_app_t *) malloc(sizeof(pmix_app_t));
     (*dest)->cmd = strdup(src->cmd);
     (*dest)->argv = pmix_argv_copy(src->argv);
     (*dest)->env = pmix_argv_copy(src->env);
     (*dest)->maxprocs = src->maxprocs;
     (*dest)->ninfo = src->ninfo;
-    (*dest)->info = (pmix_info_t*)malloc(src->ninfo * sizeof(pmix_info_t));
-    for (j=0; j < src->ninfo; j++) {
+    (*dest)->info = (pmix_info_t *) malloc(src->ninfo * sizeof(pmix_info_t));
+    for (j = 0; j < src->ninfo; j++) {
         pmix_strncpy((*dest)->info[j].key, src->info[j].key, PMIX_MAX_KEYLEN);
         pmix_value_xfer(&(*dest)->info[j].value, &src->info[j].value);
     }
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_kval(pmix_kval_t **dest, pmix_kval_t *src,
-                                    pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_kval(pmix_kval_t **dest, pmix_kval_t *src, pmix_data_type_t type)
 {
     pmix_kval_t *p;
 
@@ -388,25 +384,23 @@ pmix_status_t pmix12_bfrop_copy_kval(pmix_kval_t **dest, pmix_kval_t *src,
     return pmix_value_xfer(p->value, src->value);
 }
 
-pmix_status_t pmix12_bfrop_copy_array(pmix_info_array_t **dest,
-                                     pmix_info_array_t *src,
-                                     pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_array(pmix_info_array_t **dest, pmix_info_array_t *src,
+                                      pmix_data_type_t type)
 {
     pmix_info_t *d1, *s1;
 
-    *dest = (pmix_info_array_t*)malloc(sizeof(pmix_info_array_t));
+    *dest = (pmix_info_array_t *) malloc(sizeof(pmix_info_array_t));
     (*dest)->size = src->size;
-    (*dest)->array = (pmix_info_t*)malloc(src->size * sizeof(pmix_info_t));
-    d1 = (pmix_info_t*)(*dest)->array;
-    s1 = (pmix_info_t*)src->array;
+    (*dest)->array = (pmix_info_t *) malloc(src->size * sizeof(pmix_info_t));
+    d1 = (pmix_info_t *) (*dest)->array;
+    s1 = (pmix_info_t *) src->array;
     memcpy(d1, s1, src->size * sizeof(pmix_info_t));
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_proc(pmix_proc_t **dest, pmix_proc_t *src,
-                                    pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_proc(pmix_proc_t **dest, pmix_proc_t *src, pmix_data_type_t type)
 {
-    *dest = (pmix_proc_t*)malloc(sizeof(pmix_proc_t));
+    *dest = (pmix_proc_t *) malloc(sizeof(pmix_proc_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
@@ -415,18 +409,17 @@ pmix_status_t pmix12_bfrop_copy_proc(pmix_proc_t **dest, pmix_proc_t *src,
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_modex(pmix_modex_data_t **dest,
-                                     pmix_modex_data_t *src,
-                                     pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_modex(pmix_modex_data_t **dest, pmix_modex_data_t *src,
+                                      pmix_data_type_t type)
 {
-    *dest = (pmix_modex_data_t*)malloc(sizeof(pmix_modex_data_t));
+    *dest = (pmix_modex_data_t *) malloc(sizeof(pmix_modex_data_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
     (*dest)->blob = NULL;
     (*dest)->size = 0;
     if (NULL != src->blob) {
-        (*dest)->blob = (uint8_t*)malloc(src->size * sizeof(uint8_t));
+        (*dest)->blob = (uint8_t *) malloc(src->size * sizeof(uint8_t));
         if (NULL == (*dest)->blob) {
             return PMIX_ERR_OUT_OF_RESOURCE;
         }
@@ -436,11 +429,10 @@ pmix_status_t pmix12_bfrop_copy_modex(pmix_modex_data_t **dest,
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_persist(pmix_persistence_t **dest,
-                                       pmix_persistence_t *src,
-                                       pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_persist(pmix_persistence_t **dest, pmix_persistence_t *src,
+                                        pmix_data_type_t type)
 {
-    *dest = (pmix_persistence_t*)malloc(sizeof(pmix_persistence_t));
+    *dest = (pmix_persistence_t *) malloc(sizeof(pmix_persistence_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
@@ -448,25 +440,22 @@ pmix_status_t pmix12_bfrop_copy_persist(pmix_persistence_t **dest,
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_bo(pmix_byte_object_t **dest,
-                                  pmix_byte_object_t *src,
-                                  pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_bo(pmix_byte_object_t **dest, pmix_byte_object_t *src,
+                                   pmix_data_type_t type)
 {
-    *dest = (pmix_byte_object_t*)malloc(sizeof(pmix_byte_object_t));
+    *dest = (pmix_byte_object_t *) malloc(sizeof(pmix_byte_object_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
-    (*dest)->bytes = (char*)malloc(src->size);
+    (*dest)->bytes = (char *) malloc(src->size);
     memcpy((*dest)->bytes, src->bytes, src->size);
     (*dest)->size = src->size;
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix12_bfrop_copy_pdata(pmix_pdata_t **dest,
-                                     pmix_pdata_t *src,
-                                     pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_pdata(pmix_pdata_t **dest, pmix_pdata_t *src, pmix_data_type_t type)
 {
-    *dest = (pmix_pdata_t*)malloc(sizeof(pmix_pdata_t));
+    *dest = (pmix_pdata_t *) malloc(sizeof(pmix_pdata_t));
     pmix_strncpy((*dest)->proc.nspace, src->proc.nspace, PMIX_MAX_NSLEN);
     (*dest)->proc.rank = src->proc.rank;
     pmix_strncpy((*dest)->key, src->key, PMIX_MAX_KEYLEN);
@@ -474,19 +463,18 @@ pmix_status_t pmix12_bfrop_copy_pdata(pmix_pdata_t **dest,
 }
 
 pmix_status_t pmix12_bfrop_copy_darray(pmix_pdata_t **dest, pmix_data_array_t *src,
-                                      pmix_data_type_t type)
+                                       pmix_data_type_t type)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_copy_proc_info(pmix_pdata_t **dest, pmix_proc_info_t *src,
-                                      pmix_data_type_t type)
+                                          pmix_data_type_t type)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix12_bfrop_copy_query(pmix_pdata_t **dest, pmix_query_t *src,
-                                      pmix_data_type_t type)
+pmix_status_t pmix12_bfrop_copy_query(pmix_pdata_t **dest, pmix_query_t *src, pmix_data_type_t type)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
