@@ -21,6 +21,7 @@
  * Copyright (c) 2017      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -72,53 +73,53 @@
 #include "pmix.h"
 #include "src/include/types.h"
 
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 #include <errno.h>
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#    include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
+#    include <sys/wait.h>
 #endif
 #include <signal.h>
 #ifdef HAVE_FCNTL_H
-#include <fcntl.h>
+#    include <fcntl.h>
 #endif
 #ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
+#    include <sys/time.h>
 #endif
 #ifdef HAVE_SYS_PARAM_H
-#include <sys/param.h>
+#    include <sys/param.h>
 #endif
 #ifdef HAVE_NETDB_H
-#include <netdb.h>
+#    include <netdb.h>
 #endif
 #include <stdlib.h>
 #ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif  /* HAVE_SYS_STAT_H */
+#    include <sys/stat.h>
+#endif /* HAVE_SYS_STAT_H */
 #include <stdarg.h>
 #ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
+#    include <sys/select.h>
 #endif
 #ifdef HAVE_DIRENT_H
-#include <dirent.h>
+#    include <dirent.h>
 #endif
 #include <ctype.h>
 
 #include "src/class/pmix_pointer_array.h"
+#include "src/util/error.h"
+#include "src/util/fd.h"
 #include "src/util/pmix_environ.h"
 #include "src/util/show_help.h"
-#include "src/util/fd.h"
-#include "src/util/error.h"
 
 #include "src/include/pmix_globals.h"
-#include "src/util/name_fns.h"
 #include "src/threads/threads.h"
+#include "src/util/name_fns.h"
 
 #include "src/mca/pfexec/base/base.h"
 #include "src/mca/pfexec/linux/pfexec_linux.h"
@@ -126,9 +127,8 @@
 /*
  * Module functions (function pointers used in a struct)
  */
-static pmix_status_t spawn_job(const pmix_info_t job_info[], size_t ninfo,
-                               const pmix_app_t apps[], size_t napps,
-                               pmix_spawn_cbfunc_t cbfunc, void *cbdata);
+static pmix_status_t spawn_job(const pmix_info_t job_info[], size_t ninfo, const pmix_app_t apps[],
+                               size_t napps, pmix_spawn_cbfunc_t cbfunc, void *cbdata);
 static pmix_status_t kill_proc(pmix_proc_t *proc);
 static pmix_status_t signal_proc(pmix_proc_t *proc, int32_t signal);
 
@@ -136,13 +136,11 @@ static pmix_status_t signal_proc(pmix_proc_t *proc, int32_t signal);
  * Explicitly declared functions so that we can get the noreturn
  * attribute registered with the compiler.
  */
-static void send_error_show_help(int fd, int exit_status,
-                                 const char *file, const char *topic, ...)
-    __pmix_attribute_noreturn__;
-
-static void do_child(pmix_app_t *cd, char **env, pmix_pfexec_child_t *child, int write_fd)
-    __pmix_attribute_noreturn__;
+static void send_error_show_help(int fd, int exit_status, const char *file, const char *topic,
+                                 ...) __pmix_attribute_noreturn__;
 
+static void do_child(pmix_app_t *cd, char **env, pmix_pfexec_child_t *child,
+                     int write_fd) __pmix_attribute_noreturn__;
 
 /*
  * Module
@@ -153,7 +151,6 @@ pmix_pfexec_base_module_t pmix_pfexec_linux_module = {
     .signal_proc = signal_proc,
 };
 
-
 /* deliver a signal to a specified pid. */
 static pmix_status_t sigproc(pid_t pd, int signum)
 {
@@ -180,13 +177,13 @@ static pmix_status_t sigproc(pid_t pd, int signum)
         if (ESRCH != errno) {
             PMIX_OUTPUT_VERBOSE((2, pmix_pfexec_base_framework.framework_output,
                                  "%s pfexec:linux:SENT SIGNAL %d TO PID %d GOT ERRNO %d",
-                                 PMIX_NAME_PRINT(&pmix_globals.myid), signum, (int)pid, errno));
+                                 PMIX_NAME_PRINT(&pmix_globals.myid), signum, (int) pid, errno));
             return errno;
         }
     }
     PMIX_OUTPUT_VERBOSE((2, pmix_pfexec_base_framework.framework_output,
                          "%s pfexec:linux:SENT SIGNAL %d TO PID %d SUCCESS",
-                         PMIX_NAME_PRINT(&pmix_globals.myid), signum, (int)pid));
+                         PMIX_NAME_PRINT(&pmix_globals.myid), signum, (int) pid));
     return 0;
 }
 
@@ -230,7 +227,7 @@ static void set_handler_linux(int sig)
     act.sa_flags = 0;
     sigemptyset(&act.sa_mask);
 
-    sigaction(sig, &act, (struct sigaction *)0);
+    sigaction(sig, &act, (struct sigaction *) 0);
 }
 
 /*
@@ -265,29 +262,26 @@ static int write_help_msg(int fd, pmix_pfexec_pipe_err_msg_t *msg, const char *f
     if (PMIX_SUCCESS != (ret = pmix_fd_write(fd, sizeof(*msg), msg))) {
         goto out;
     }
-    if (msg->file_str_len > 0 &&
-        PMIX_SUCCESS != (ret = pmix_fd_write(fd, msg->file_str_len, file))) {
+    if (msg->file_str_len > 0
+        && PMIX_SUCCESS != (ret = pmix_fd_write(fd, msg->file_str_len, file))) {
         goto out;
     }
-    if (msg->topic_str_len > 0 &&
-        PMIX_SUCCESS != (ret = pmix_fd_write(fd, msg->topic_str_len, topic))) {
+    if (msg->topic_str_len > 0
+        && PMIX_SUCCESS != (ret = pmix_fd_write(fd, msg->topic_str_len, topic))) {
         goto out;
     }
-    if (msg->msg_str_len > 0 &&
-        PMIX_SUCCESS != (ret = pmix_fd_write(fd, msg->msg_str_len, str))) {
+    if (msg->msg_str_len > 0 && PMIX_SUCCESS != (ret = pmix_fd_write(fd, msg->msg_str_len, str))) {
         goto out;
     }
 
- out:
+out:
     free(str);
     return ret;
 }
 
-
 /* Called from the child to send an error message up the pipe to the
    waiting parent. */
-static void send_error_show_help(int fd, int exit_status,
-                                 const char *file, const char *topic, ...)
+static void send_error_show_help(int fd, int exit_status, const char *file, const char *topic, ...)
 {
     va_list ap;
     pmix_pfexec_pipe_err_msg_t msg;
@@ -305,7 +299,8 @@ static void send_error_show_help(int fd, int exit_status,
 
 /* close all open file descriptors w/ exception of stdin/stdout/stderr
    the pipe up to the parent, and the keepalive pipe. */
-static int close_open_file_descriptors(int write_fd, int keepalive) {
+static int close_open_file_descriptors(int write_fd, int keepalive)
+{
     DIR *dir = opendir("/proc/self/fd");
     if (NULL == dir) {
         return PMIX_ERR_FILE_OPEN_FAILURE;
@@ -315,11 +310,10 @@ static int close_open_file_descriptors(int write_fd, int keepalive) {
     /* grab the fd of the opendir above so we don't close in the
      * middle of the scan. */
     int dir_scan_fd = dirfd(dir);
-    if(dir_scan_fd < 0 ) {
+    if (dir_scan_fd < 0) {
         return PMIX_ERR_FILE_OPEN_FAILURE;
     }
 
-
     while (NULL != (files = readdir(dir))) {
         if (!isdigit(files->d_name[0])) {
             continue;
@@ -329,10 +323,7 @@ static int close_open_file_descriptors(int write_fd, int keepalive) {
             closedir(dir);
             return PMIX_ERR_TYPE_MISMATCH;
         }
-        if (fd >=3 &&
-            fd != write_fd &&
-	        fd != dir_scan_fd &&
-            fd != keepalive) {
+        if (fd >= 3 && fd != write_fd && fd != dir_scan_fd && fd != keepalive) {
             close(fd);
         }
     }
@@ -340,8 +331,7 @@ static int close_open_file_descriptors(int write_fd, int keepalive) {
     return PMIX_SUCCESS;
 }
 
-static void do_child(pmix_app_t *app, char **env,
-                     pmix_pfexec_child_t *child, int write_fd)
+static void do_child(pmix_app_t *app, char **env, pmix_pfexec_child_t *child, int write_fd)
 {
     int i, errval;
     sigset_t sigs;
@@ -372,9 +362,7 @@ static void do_child(pmix_app_t *app, char **env,
     */
     if (PMIX_SUCCESS != (i = pmix_pfexec_base_setup_child(child))) {
         PMIX_ERROR_LOG(i);
-        send_error_show_help(write_fd, 1,
-                             "help-pfexec-linux.txt",
-                             "iof setup failed",
+        send_error_show_help(write_fd, 1, "help-pfexec-linux.txt", "iof setup failed",
                              pmix_globals.hostname, app->cmd);
         /* Does not return */
     }
@@ -384,7 +372,7 @@ static void do_child(pmix_app_t *app, char **env,
        the parent. */
     if (PMIX_SUCCESS != close_open_file_descriptors(write_fd, child->keepalive[1])) {
         // close *all* file descriptors -- slow
-        for(fd=3; fd<fdmax; fd++) {
+        for (fd = 3; fd < fdmax; fd++) {
             if (fd != write_fd && fd != child->keepalive[1]) {
                 close(fd);
             }
@@ -414,12 +402,8 @@ static void do_child(pmix_app_t *app, char **env,
     /* take us to the correct wdir */
     if (NULL != app->cwd) {
         if (0 != chdir(app->cwd)) {
-            send_error_show_help(write_fd, 1,
-                                 "help-pfexec-linux.txt",
-                                 "wdir-not-found",
-                                 "pmixd",
-                                 app->cwd,
-                                 pmix_globals.hostname);
+            send_error_show_help(write_fd, 1, "help-pfexec-linux.txt", "wdir-not-found", "pmixd",
+                                 app->cwd, pmix_globals.hostname);
             /* Does not return */
         }
     }
@@ -428,13 +412,11 @@ static void do_child(pmix_app_t *app, char **env,
     execve(app->cmd, app->argv, env);
     errval = errno;
     getcwd(dir, sizeof(dir));
-    send_error_show_help(write_fd, 1,
-                         "help-pfexec-linux.txt", "execve error",
+    send_error_show_help(write_fd, 1, "help-pfexec-linux.txt", "execve error",
                          pmix_globals.hostname, dir, app->cmd, strerror(errval));
     /* Does not return */
 }
 
-
 static pmix_status_t do_parent(pmix_app_t *app, pmix_pfexec_child_t *child, int read_fd)
 {
     pmix_status_t rc;
@@ -473,10 +455,8 @@ static pmix_status_t do_parent(pmix_app_t *app, pmix_pfexec_child_t *child, int
         if (msg.file_str_len > 0) {
             rc = pmix_fd_read(read_fd, msg.file_str_len, file);
             if (PMIX_SUCCESS != rc) {
-                pmix_show_help("help-pfexec-linux.txt", "syscall fail",
-                               true,
-                               pmix_globals.hostname, app->cmd,
-                               "pmix_fd_read", __FILE__, __LINE__);
+                pmix_show_help("help-pfexec-linux.txt", "syscall fail", true, pmix_globals.hostname,
+                               app->cmd, "pmix_fd_read", __FILE__, __LINE__);
                 return rc;
             }
             file[msg.file_str_len] = '\0';
@@ -484,10 +464,8 @@ static pmix_status_t do_parent(pmix_app_t *app, pmix_pfexec_child_t *child, int
         if (msg.topic_str_len > 0) {
             rc = pmix_fd_read(read_fd, msg.topic_str_len, topic);
             if (PMIX_SUCCESS != rc) {
-                pmix_show_help("help-pfexec-linux.txt", "syscall fail",
-                               true,
-                               pmix_globals.hostname, app->cmd,
-                               "pmix_fd_read", __FILE__, __LINE__);
+                pmix_show_help("help-pfexec-linux.txt", "syscall fail", true, pmix_globals.hostname,
+                               app->cmd, "pmix_fd_read", __FILE__, __LINE__);
                 return rc;
             }
             topic[msg.topic_str_len] = '\0';
@@ -495,18 +473,14 @@ static pmix_status_t do_parent(pmix_app_t *app, pmix_pfexec_child_t *child, int
         if (msg.msg_str_len > 0) {
             str = calloc(1, msg.msg_str_len + 1);
             if (NULL == str) {
-                pmix_show_help("help-pfexec-linux.txt", "syscall fail",
-                               true,
-                               pmix_globals.hostname, app->cmd,
-                               "calloc", __FILE__, __LINE__);
+                pmix_show_help("help-pfexec-linux.txt", "syscall fail", true, pmix_globals.hostname,
+                               app->cmd, "calloc", __FILE__, __LINE__);
                 return PMIX_ERR_NOMEM;
             }
             rc = pmix_fd_read(read_fd, msg.msg_str_len, str);
             if (PMIX_SUCCESS != rc) {
-                pmix_show_help("help-pfexec-linux.txt", "syscall fail",
-                               true,
-                               pmix_globals.hostname, app->cmd,
-                               "pmix_fd_read", __FILE__, __LINE__);
+                pmix_show_help("help-pfexec-linux.txt", "syscall fail", true, pmix_globals.hostname,
+                               app->cmd, "pmix_fd_read", __FILE__, __LINE__);
                 free(str);
                 return rc;
             }
@@ -545,7 +519,6 @@ static pmix_status_t do_parent(pmix_app_t *app, pmix_pfexec_child_t *child, int
     return PMIX_SUCCESS;
 }
 
-
 /**
  *  Fork/exec the specified processes
  */
@@ -590,18 +563,15 @@ static int fork_proc(pmix_app_t *app, pmix_pfexec_child_t *child, char **env)
     return do_parent(app, child, p[0]);
 }
 
-
 /**
  * Launch all processes allocated to the current node.
  */
 
-static pmix_status_t spawn_job(const pmix_info_t job_info[], size_t ninfo,
-                               const pmix_app_t apps[], size_t napps,
-                               pmix_spawn_cbfunc_t cbfunc, void *cbdata)
+static pmix_status_t spawn_job(const pmix_info_t job_info[], size_t ninfo, const pmix_app_t apps[],
+                               size_t napps, pmix_spawn_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_output_verbose(5, pmix_pfexec_base_framework.framework_output,
-                        "%s pfexec:linux spawning child job",
-                        PMIX_NAME_PRINT(&pmix_globals.myid));
+                        "%s pfexec:linux spawning child job", PMIX_NAME_PRINT(&pmix_globals.myid));
 
     PMIX_PFEXEC_SPAWN(job_info, ninfo, apps, napps, fork_proc, cbfunc, cbdata);
 
