@@ -6,6 +6,7 @@
  * Copyright (c) 2018      Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -17,19 +18,19 @@
 
 #include <string.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#    include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
+#    include <sys/stat.h>
 #endif
 #ifdef HAVE_FCNTL_H
-#include <fcntl.h>
+#    include <fcntl.h>
 #endif
 #ifdef HAVE_SYS_UTSNAME_H
-#include <sys/utsname.h>
+#    include <sys/utsname.h>
 #endif
 #include <time.h>
 
@@ -37,9 +38,8 @@
 #include "src/include/pmix_globals.h"
 
 #include "src/class/pmix_list.h"
-#include "src/util/error.h"
 #include "src/mca/ploc/base/base.h"
-
+#include "src/util/error.h"
 
 pmix_status_t pmix_ploc_base_setup_topology(pmix_info_t *info, size_t ninfo)
 {
@@ -50,17 +50,16 @@ pmix_status_t pmix_ploc_base_setup_topology(pmix_info_t *info, size_t ninfo)
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:setup_topology called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:setup_topology called");
 
     /* if we are not a server, then this is an error */
-    if (!PMIX_PROC_IS_SERVER(&pmix_globals.mypeer->proc_type) &&
-        !PMIX_PROC_IS_LAUNCHER(&pmix_globals.mypeer->proc_type)) {
+    if (!PMIX_PROC_IS_SERVER(&pmix_globals.mypeer->proc_type)
+        && !PMIX_PROC_IS_LAUNCHER(&pmix_globals.mypeer->proc_type)) {
         return PMIX_ERR_NOT_SUPPORTED;
     }
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->setup_topology) {
             rc = active->module->setup_topology(info, ninfo);
             if (PMIX_SUCCESS == rc) {
@@ -85,11 +84,10 @@ pmix_status_t pmix_ploc_base_load_topology(pmix_topology_t *topo)
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:load_topology called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:load_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->load_topology) {
             rc = active->module->load_topology(topo);
             if (PMIX_SUCCESS == rc) {
@@ -119,7 +117,7 @@ pmix_status_t pmix_ploc_base_generate_cpuset_string(const pmix_cpuset_t *cpuset,
                         "ploc:generate_cpuset_string called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->get_cpuset) {
             rc = active->module->generate_cpuset_string(cpuset, cpuset_string);
             if (PMIX_SUCCESS == rc) {
@@ -135,8 +133,7 @@ pmix_status_t pmix_ploc_base_generate_cpuset_string(const pmix_cpuset_t *cpuset,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_parse_cpuset_string(const char *cpuset_string,
-                                                 pmix_cpuset_t *cpuset)
+pmix_status_t pmix_ploc_base_parse_cpuset_string(const char *cpuset_string, pmix_cpuset_t *cpuset)
 {
     pmix_ploc_base_active_module_t *active;
     pmix_status_t rc;
@@ -145,11 +142,10 @@ pmix_status_t pmix_ploc_base_parse_cpuset_string(const char *cpuset_string,
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:get_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:get_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->parse_cpuset_string) {
             rc = active->module->parse_cpuset_string(cpuset_string, cpuset);
             if (PMIX_SUCCESS == rc) {
@@ -165,8 +161,7 @@ pmix_status_t pmix_ploc_base_parse_cpuset_string(const char *cpuset_string,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_generate_locality_string(const pmix_cpuset_t *cpuset,
-                                                      char **locality)
+pmix_status_t pmix_ploc_base_generate_locality_string(const pmix_cpuset_t *cpuset, char **locality)
 {
     pmix_ploc_base_active_module_t *active;
     pmix_status_t rc;
@@ -179,13 +174,13 @@ pmix_status_t pmix_ploc_base_generate_locality_string(const pmix_cpuset_t *cpuse
                         "ploc:generate_locality_string called");
 
     /* if we are not a server, then this is an error */
-    if (!PMIX_PROC_IS_SERVER(&pmix_globals.mypeer->proc_type) &&
-        !PMIX_PROC_IS_LAUNCHER(&pmix_globals.mypeer->proc_type)) {
+    if (!PMIX_PROC_IS_SERVER(&pmix_globals.mypeer->proc_type)
+        && !PMIX_PROC_IS_LAUNCHER(&pmix_globals.mypeer->proc_type)) {
         return PMIX_ERR_NOT_SUPPORTED;
     }
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->generate_locality_string) {
             rc = active->module->generate_locality_string(cpuset, locality);
             if (PMIX_SUCCESS == rc) {
@@ -201,8 +196,7 @@ pmix_status_t pmix_ploc_base_generate_locality_string(const pmix_cpuset_t *cpuse
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_get_relative_locality(const char *loc1,
-                                                   const char *loc2,
+pmix_status_t pmix_ploc_base_get_relative_locality(const char *loc1, const char *loc2,
                                                    pmix_locality_t *locality)
 {
     pmix_ploc_base_active_module_t *active;
@@ -216,7 +210,7 @@ pmix_status_t pmix_ploc_base_get_relative_locality(const char *loc1,
                         "ploc:get_relative_locality called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->get_relative_locality) {
             rc = active->module->get_relative_locality(loc1, loc2, locality);
             if (PMIX_SUCCESS == rc) {
@@ -232,8 +226,7 @@ pmix_status_t pmix_ploc_base_get_relative_locality(const char *loc1,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_get_cpuset(pmix_cpuset_t *cpuset,
-                                        pmix_bind_envelope_t ref)
+pmix_status_t pmix_ploc_base_get_cpuset(pmix_cpuset_t *cpuset, pmix_bind_envelope_t ref)
 {
     pmix_ploc_base_active_module_t *active;
     pmix_status_t rc;
@@ -242,11 +235,10 @@ pmix_status_t pmix_ploc_base_get_cpuset(pmix_cpuset_t *cpuset,
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:get_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:get_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->get_cpuset) {
             rc = active->module->get_cpuset(cpuset, ref);
             if (PMIX_SUCCESS == rc) {
@@ -262,11 +254,9 @@ pmix_status_t pmix_ploc_base_get_cpuset(pmix_cpuset_t *cpuset,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_compute_distances(pmix_topology_t *topo,
-                                               pmix_cpuset_t *cpuset,
+pmix_status_t pmix_ploc_base_compute_distances(pmix_topology_t *topo, pmix_cpuset_t *cpuset,
                                                pmix_info_t info[], size_t ninfo,
-                                               pmix_device_distance_t **dist,
-                                               size_t *ndist)
+                                               pmix_device_distance_t **dist, size_t *ndist)
 {
     pmix_ploc_base_active_module_t *active;
     pmix_status_t rc;
@@ -279,7 +269,7 @@ pmix_status_t pmix_ploc_base_compute_distances(pmix_topology_t *topo,
                         "ploc:compute_distances called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->compute_distances) {
             rc = active->module->compute_distances(topo, cpuset, info, ninfo, dist, ndist);
             if (PMIX_SUCCESS == rc) {
@@ -299,8 +289,7 @@ pmix_status_t pmix_ploc_base_compute_distances(pmix_topology_t *topo,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_pack_cpuset(pmix_buffer_t *buf,
-                                         pmix_cpuset_t *src,
+pmix_status_t pmix_ploc_base_pack_cpuset(pmix_buffer_t *buf, pmix_cpuset_t *src,
                                          pmix_pointer_array_t *regtypes)
 {
     pmix_ploc_base_active_module_t *active;
@@ -310,11 +299,10 @@ pmix_status_t pmix_ploc_base_pack_cpuset(pmix_buffer_t *buf,
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:pack_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:pack_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->pack_cpuset) {
             rc = active->module->pack_cpuset(buf, src, regtypes);
             if (PMIX_SUCCESS == rc) {
@@ -330,8 +318,7 @@ pmix_status_t pmix_ploc_base_pack_cpuset(pmix_buffer_t *buf,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_unpack_cpuset(pmix_buffer_t *buf,
-                                           pmix_cpuset_t *dest,
+pmix_status_t pmix_ploc_base_unpack_cpuset(pmix_buffer_t *buf, pmix_cpuset_t *dest,
                                            pmix_pointer_array_t *regtypes)
 {
     pmix_ploc_base_active_module_t *active;
@@ -341,11 +328,10 @@ pmix_status_t pmix_ploc_base_unpack_cpuset(pmix_buffer_t *buf,
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:unpack_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:unpack_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->unpack_cpuset) {
             rc = active->module->unpack_cpuset(buf, dest, regtypes);
             if (PMIX_SUCCESS == rc) {
@@ -370,11 +356,10 @@ pmix_status_t pmix_ploc_base_copy_cpuset(pmix_cpuset_t *dest, pmix_cpuset_t *src
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:copy_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:copy_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->copy_cpuset) {
             rc = active->module->copy_cpuset(dest, src);
             if (PMIX_SUCCESS == rc) {
@@ -390,7 +375,7 @@ pmix_status_t pmix_ploc_base_copy_cpuset(pmix_cpuset_t *dest, pmix_cpuset_t *src
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-char* pmix_ploc_base_print_cpuset(pmix_cpuset_t *src)
+char *pmix_ploc_base_print_cpuset(pmix_cpuset_t *src)
 {
     pmix_ploc_base_active_module_t *active;
     char *string;
@@ -399,11 +384,10 @@ char* pmix_ploc_base_print_cpuset(pmix_cpuset_t *src)
         return NULL;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:print_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:print_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->print_cpuset) {
             string = active->module->print_cpuset(src);
             if (NULL != string) {
@@ -428,7 +412,7 @@ void pmix_ploc_base_destruct_cpuset(pmix_cpuset_t *cpuset)
                         "ploc:destruct_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->destruct_cpuset) {
             rc = active->module->destruct_cpuset(cpuset);
             if (PMIX_SUCCESS == rc) {
@@ -447,11 +431,10 @@ void pmix_ploc_base_release_cpuset(pmix_cpuset_t *ptr, size_t sz)
         return;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:release_cpuset called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:release_cpuset called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->release_cpuset) {
             rc = active->module->release_cpuset(ptr, sz);
             if (PMIX_SUCCESS == rc) {
@@ -461,8 +444,7 @@ void pmix_ploc_base_release_cpuset(pmix_cpuset_t *ptr, size_t sz)
     }
 }
 
-pmix_status_t pmix_ploc_base_pack_topology(pmix_buffer_t *buf,
-                                           pmix_topology_t *src,
+pmix_status_t pmix_ploc_base_pack_topology(pmix_buffer_t *buf, pmix_topology_t *src,
                                            pmix_pointer_array_t *regtypes)
 {
     pmix_ploc_base_active_module_t *active;
@@ -472,11 +454,10 @@ pmix_status_t pmix_ploc_base_pack_topology(pmix_buffer_t *buf,
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:pack_topology called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:pack_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->pack_topology) {
             rc = active->module->pack_topology(buf, src, regtypes);
             if (PMIX_SUCCESS == rc) {
@@ -492,8 +473,7 @@ pmix_status_t pmix_ploc_base_pack_topology(pmix_buffer_t *buf,
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-pmix_status_t pmix_ploc_base_unpack_topology(pmix_buffer_t *buf,
-                                             pmix_topology_t *dest,
+pmix_status_t pmix_ploc_base_unpack_topology(pmix_buffer_t *buf, pmix_topology_t *dest,
                                              pmix_pointer_array_t *regtypes)
 {
     pmix_ploc_base_active_module_t *active;
@@ -507,7 +487,7 @@ pmix_status_t pmix_ploc_base_unpack_topology(pmix_buffer_t *buf,
                         "ploc:unpack_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->unpack_topology) {
             rc = active->module->unpack_topology(buf, dest, regtypes);
             if (PMIX_SUCCESS == rc) {
@@ -532,11 +512,10 @@ pmix_status_t pmix_ploc_base_copy_topology(pmix_topology_t *dest, pmix_topology_
         return PMIX_ERR_INIT;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:copy_topology called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:copy_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->copy_topology) {
             rc = active->module->copy_topology(dest, src);
             if (PMIX_SUCCESS == rc) {
@@ -552,7 +531,7 @@ pmix_status_t pmix_ploc_base_copy_topology(pmix_topology_t *dest, pmix_topology_
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-char* pmix_ploc_base_print_topology(pmix_topology_t *src)
+char *pmix_ploc_base_print_topology(pmix_topology_t *src)
 {
     pmix_ploc_base_active_module_t *active;
     char *string;
@@ -561,11 +540,10 @@ char* pmix_ploc_base_print_topology(pmix_topology_t *src)
         return NULL;
     }
 
-    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output,
-                        "ploc:print_topology called");
+    pmix_output_verbose(2, pmix_ploc_base_framework.framework_output, "ploc:print_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->print_topology) {
             string = active->module->print_topology(src);
             if (NULL != string) {
@@ -590,7 +568,7 @@ void pmix_ploc_base_destruct_topology(pmix_topology_t *ptr)
                         "ploc:destruct_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->destruct_topology) {
             rc = active->module->destruct_topology(ptr);
             if (PMIX_SUCCESS == rc) {
@@ -613,7 +591,7 @@ void pmix_ploc_base_release_topology(pmix_topology_t *ptr, size_t sz)
                         "ploc:release_topology called");
 
     /* process the request */
-    PMIX_LIST_FOREACH(active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
+    PMIX_LIST_FOREACH (active, &pmix_ploc_globals.actives, pmix_ploc_base_active_module_t) {
         if (NULL != active->module->release_topology) {
             rc = active->module->release_topology(ptr, sz);
             if (PMIX_SUCCESS == rc) {
