@@ -1,24 +1,23 @@
 /* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
 /*
- * Copyright (c) 2018      Intel, Inc.  All rights reserved.
+ * Copyright (c) 2018-2020 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
  *
  * $HEADER$
-*/
+ */
 
 /*
  * includes
  */
 #include "pmix_config.h"
-#include "pmix_common.h"
+#include "include/pmix_common.h"
 
 #include "plog_default.h"
 
-
-static pmix_status_t component_query(pmix_mca_base_module_t **module,
-                                     int *priority);
+static pmix_status_t component_query(pmix_mca_base_module_t **module, int *priority);
 
 /*
  * Struct of function pointers that need to be initialized
@@ -38,10 +37,9 @@ pmix_plog_base_component_t mca_plog_default_component = {
     },
 };
 
-static pmix_status_t component_query(pmix_mca_base_module_t **module,
-                                     int *priority)
+static pmix_status_t component_query(pmix_mca_base_module_t **module, int *priority)
 {
     *priority = 1;
-    *module = (pmix_mca_base_module_t *)&pmix_plog_default_module;
+    *module = (pmix_mca_base_module_t *) &pmix_plog_default_module;
     return PMIX_SUCCESS;
 }
