@@ -1,12 +1,13 @@
 /* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
 /*
  * Copyright (c) 2018-2020 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
  *
  * $HEADER$
-*/
+ */
 
 /*
  * includes
@@ -15,15 +16,13 @@
 #include "include/pmix_common.h"
 
 #ifdef HAVE_SYSLOG_H
-#include <syslog.h>
+#    include <syslog.h>
 #endif
 
-#include "src/util/show_help.h"
 #include "plog_syslog.h"
+#include "src/util/show_help.h"
 
-
-static pmix_status_t component_query(pmix_mca_base_module_t **module,
-                                     int *priority);
+static pmix_status_t component_query(pmix_mca_base_module_t **module, int *priority);
 static pmix_status_t syslog_register(void);
 
 /*
@@ -57,19 +56,19 @@ static pmix_status_t syslog_register(void)
 {
     pmix_status_t rc = PMIX_SUCCESS;
 
-    (void) pmix_mca_base_component_var_register(&mca_plog_syslog_component.super.base, "console",
-                                           "Write directly to system console if there is an error while sending to system logger",
-                                           PMIX_MCA_BASE_VAR_TYPE_BOOL, NULL, 0, 0,
-                                           PMIX_INFO_LVL_2,
-                                           PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                           &mca_plog_syslog_component.console);
+    (void) pmix_mca_base_component_var_register(
+        &mca_plog_syslog_component.super.base, "console",
+        "Write directly to system console if there is an error while sending to system logger",
+        PMIX_MCA_BASE_VAR_TYPE_BOOL, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
+        PMIX_MCA_BASE_VAR_SCOPE_READONLY, &mca_plog_syslog_component.console);
 
+    level = "info";
     (void) pmix_mca_base_component_var_register(&mca_plog_syslog_component.super.base, "level",
-                                           "Default syslog logging level (err, alert, crit, emerg, warning, notice, info[default], or debug)",
-                                           PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, 0,
-                                           PMIX_INFO_LVL_2,
-                                           PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                           &level);
+                                                "Default syslog logging level (err, alert, crit, "
+                                                "emerg, warning, notice, info[default], or debug)",
+                                                PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0,
+                                                PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
+                                                PMIX_MCA_BASE_VAR_SCOPE_READONLY, &level);
     if (0 == strncasecmp(level, "err", 3)) {
         mca_plog_syslog_component.level = LOG_ERR;
     } else if (0 == strcasecmp(level, "alert")) {
@@ -91,13 +90,13 @@ static pmix_status_t syslog_register(void)
         rc = PMIX_ERR_NOT_SUPPORTED;
     }
 
-    (void) pmix_mca_base_component_var_register(&mca_plog_syslog_component.super.base, "facility",
-                                           "Specify what type of program is logging the message "
-                                           "(only \"auth\", \"priv\", \"daemon\", and \"user\" are supported)",
-                                           PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, 0,
-                                           PMIX_INFO_LVL_2,
-                                           PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                           &facility);
+    facility = "user";
+    (void) pmix_mca_base_component_var_register(
+        &mca_plog_syslog_component.super.base, "facility",
+        "Specify what type of program is logging the message "
+        "(only \"auth\", \"priv\", \"daemon\", and \"user\" are supported)",
+        PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
+        PMIX_MCA_BASE_VAR_SCOPE_READONLY, &facility);
     if (0 == strncasecmp(facility, "auth", 4)) {
         mca_plog_syslog_component.facility = LOG_AUTH;
     } else if (0 == strncasecmp(facility, "priv", 4)) {
@@ -114,11 +113,9 @@ static pmix_status_t syslog_register(void)
     return rc;
 }
 
-
-static pmix_status_t component_query(pmix_mca_base_module_t **module,
-                                     int *priority)
+static pmix_status_t component_query(pmix_mca_base_module_t **module, int *priority)
 {
     *priority = 10;
-    *module = (pmix_mca_base_module_t *)&pmix_plog_syslog_module;
+    *module = (pmix_mca_base_module_t *) &pmix_plog_syslog_module;
     return PMIX_SUCCESS;
 }
