@@ -1,6 +1,7 @@
 /*
- * Copyright (c) 2015-2019 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -11,8 +12,7 @@
 #ifndef PMIX_PNET_OPA_H
 #define PMIX_PNET_OPA_H
 
-#include <src/include/pmix_config.h>
-
+#include "src/include/pmix_config.h"
 
 #include "src/mca/pnet/pnet.h"
 
@@ -24,6 +24,7 @@ typedef struct {
     char *excparms;
     char **include;
     char **exclude;
+    int radix;
 } pmix_pnet_opa_component_t;
 
 /* the component must be visible data for the linker to find it */
@@ -31,10 +32,10 @@ PMIX_EXPORT extern pmix_pnet_opa_component_t mca_pnet_opa_component;
 extern pmix_pnet_module_t pmix_opa_module;
 
 /* define a key for any blob we need to send in a launch msg */
-#define PMIX_PNET_OPA_BLOB  "pmix.pnet.opa.blob"
+#define PMIX_PNET_OPA_BLOB "pmix.pnet.opa.blob"
 
 /* define an inventory key */
-#define PMIX_OPA_INVENTORY_KEY  "pmix.opa.inventory"
+#define PMIX_OPA_INVENTORY_KEY "pmix.opa.inventory"
 
 END_C_DECLS
 
