@@ -14,6 +14,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015-2020 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -28,29 +29,29 @@
 #include "include/pmix_common.h"
 
 #ifdef HAVE_STRING_H
-#include <string.h>
+#    include <string.h>
 #endif
 #ifdef HAVE_FCNTL_H
-#include <fcntl.h>
+#    include <fcntl.h>
 #endif
 #ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
+#    include <sys/stat.h>
 #endif
 
-#include "src/mca/mca.h"
-#include "src/mca/base/base.h"
-#include "src/mca/base/pmix_mca_base_var.h"
-#include "src/mca/base/pmix_mca_base_framework.h"
 #include "src/class/pmix_list.h"
 #include "src/client/pmix_client_ops.h"
+#include "src/mca/base/base.h"
+#include "src/mca/base/pmix_mca_base_framework.h"
+#include "src/mca/base/pmix_mca_base_var.h"
+#include "src/mca/mca.h"
 #include "src/server/pmix_server_ops.h"
 #include "src/util/error.h"
 #include "src/util/os_dirpath.h"
 #include "src/util/pmix_environ.h"
 #include "src/util/show_help.h"
 
-#include "src/mca/ptl/ptl_types.h"
 #include "src/mca/ptl/base/base.h"
+#include "src/mca/ptl/ptl_types.h"
 
 /*
  * The following file was created by configure.  It contains extern
@@ -60,7 +61,7 @@
 
 #include "src/mca/ptl/base/static-components.h"
 
-#define PMIX_MAX_MSG_SIZE   16
+#define PMIX_MAX_MSG_SIZE 16
 
 /* Instantiate the global vars */
 pmix_ptl_base_t pmix_ptl_base = {0};
@@ -73,115 +74,111 @@ static int pmix_ptl_register(pmix_mca_base_register_flag_t flags)
 {
     int idx;
 
-    (void)flags;
+    (void) flags;
     pmix_mca_base_var_register("pmix", "ptl", "base", "max_msg_size",
                                "Max size (in Mbytes) of a client/server msg",
-                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, 0,
-                               PMIX_INFO_LVL_2,
-                               PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                               &max_msg_size);
+                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
+                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY, &max_msg_size);
     pmix_ptl_base.max_msg_size = max_msg_size * 1024 * 1024;
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "if_include",
-                                     "Comma-delimited list of devices and/or CIDR notation of TCP networks "
-                                     "(e.g., \"eth0,192.168.0.0/16\").  Mutually exclusive with ptl_tcp_if_exclude.",
-                                     PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, 0,
-                                     PMIX_INFO_LVL_2,
-                                     PMIX_MCA_BASE_VAR_SCOPE_LOCAL,
-                                     &pmix_ptl_base.if_include);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "if_include", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register(
+        "pmix", "ptl", "base", "if_include",
+        "Comma-delimited list of devices and/or CIDR notation of TCP networks "
+        "(e.g., \"eth0,192.168.0.0/16\").  Mutually exclusive with ptl_tcp_if_exclude.",
+        PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
+        PMIX_MCA_BASE_VAR_SCOPE_LOCAL, &pmix_ptl_base.if_include);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "if_include",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "if_exclude",
-                                     "Comma-delimited list of devices and/or CIDR notation of TCP networks to NOT use "
-                                     "-- all devices not matching these specifications will be used (e.g., \"eth0,192.168.0.0/16\"). "
-                                     "If set to a non-default value, it is mutually exclusive with ptl_tcp_if_include.",
-                                     PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, 0,
-                                     PMIX_INFO_LVL_2,
-                                     PMIX_MCA_BASE_VAR_SCOPE_LOCAL,
-                                     &pmix_ptl_base.if_exclude);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "if_exclude", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register(
+        "pmix", "ptl", "base", "if_exclude",
+        "Comma-delimited list of devices and/or CIDR notation of TCP networks to NOT use "
+        "-- all devices not matching these specifications will be used (e.g., "
+        "\"eth0,192.168.0.0/16\"). "
+        "If set to a non-default value, it is mutually exclusive with ptl_tcp_if_include.",
+        PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
+        PMIX_MCA_BASE_VAR_SCOPE_LOCAL, &pmix_ptl_base.if_exclude);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "if_exclude",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
     /* if_include and if_exclude need to be mutually exclusive */
-    if (NULL != pmix_ptl_base.if_include &&
-        NULL != pmix_ptl_base.if_exclude) {
-        pmix_show_help("help-ptl-base.txt", "include-exclude", true,
-                       pmix_ptl_base.if_include,
+    if (NULL != pmix_ptl_base.if_include && NULL != pmix_ptl_base.if_exclude) {
+        pmix_show_help("help-ptl-base.txt", "include-exclude", true, pmix_ptl_base.if_include,
                        pmix_ptl_base.if_exclude);
         return PMIX_ERR_NOT_AVAILABLE;
     }
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "ipv4_port",
-                                     "IPv4 port to be used",
-                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
-                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                     &pmix_ptl_base.ipv4_port);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "ipv4_port", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "ipv4_port", "IPv4 port to be used",
+                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0,
+                                     PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
+                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY, &pmix_ptl_base.ipv4_port);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "ipv4_port",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "ipv6_port",
-                                     "IPv6 port to be used",
-                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
-                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                     &pmix_ptl_base.ipv6_port);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "ipv6_port", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "ipv6_port", "IPv6 port to be used",
+                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0,
+                                     PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
+                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY, &pmix_ptl_base.ipv6_port);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "ipv6_port",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
     idx = pmix_mca_base_var_register("pmix", "ptl", "base", "disable_ipv4_family",
-                                     "Disable the IPv4 interfaces",
-                                     PMIX_MCA_BASE_VAR_TYPE_BOOL, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
+                                     "Disable the IPv4 interfaces", PMIX_MCA_BASE_VAR_TYPE_BOOL,
+                                     NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
                                      PMIX_MCA_BASE_VAR_SCOPE_READONLY,
                                      &pmix_ptl_base.disable_ipv4_family);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "disable_ipv4_family", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "disable_ipv4_family",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
+    pmix_ptl_base.disable_ipv6_family = true;
     idx = pmix_mca_base_var_register("pmix", "ptl", "base", "disable_ipv6_family",
-                                     "Disable the IPv6 interfaces",
-                                     PMIX_MCA_BASE_VAR_TYPE_BOOL, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
+                                     "Disable the IPv6 interfaces (default:disabled)",
+                                     PMIX_MCA_BASE_VAR_TYPE_BOOL, NULL, 0,
+                                     PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
                                      PMIX_MCA_BASE_VAR_SCOPE_READONLY,
                                      &pmix_ptl_base.disable_ipv6_family);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "disable_ipv6_family", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "disable_ipv6_family",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "connection_wait_time",
-                                     "Number of seconds to wait for the server connection file to appear",
-                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
-                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                     &pmix_ptl_base.wait_to_connect);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "connection_wait_time", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register(
+        "pmix", "ptl", "base", "connection_wait_time",
+        "Number of seconds to wait for the server connection file to appear",
+        PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
+        PMIX_MCA_BASE_VAR_SCOPE_READONLY, &pmix_ptl_base.wait_to_connect);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "connection_wait_time",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "max_retries",
-                                     "Number of times to look for the connection file before quitting",
-                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
-                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                     &pmix_ptl_base.max_retries);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "max_retries", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register(
+        "pmix", "ptl", "base", "max_retries",
+        "Number of times to look for the connection file before quitting",
+        PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
+        PMIX_MCA_BASE_VAR_SCOPE_READONLY, &pmix_ptl_base.max_retries);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "max_retries",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "handshake_wait_time",
-                                     "Number of seconds to wait for the server reply to the handshake request",
-                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
-                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                     &pmix_ptl_base.handshake_wait_time);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "handshake_wait_time", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register(
+        "pmix", "ptl", "base", "handshake_wait_time",
+        "Number of seconds to wait for the server reply to the handshake request",
+        PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
+        PMIX_MCA_BASE_VAR_SCOPE_READONLY, &pmix_ptl_base.handshake_wait_time);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "handshake_wait_time",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
-    idx = pmix_mca_base_var_register("pmix", "ptl", "base", "handshake_max_retries",
-                                     "Number of times to retry the handshake request before giving up",
-                                     PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, 0,
-                                     PMIX_INFO_LVL_4,
-                                     PMIX_MCA_BASE_VAR_SCOPE_READONLY,
-                                     &pmix_ptl_base.handshake_max_retries);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "handshake_max_retries", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
+    idx = pmix_mca_base_var_register(
+        "pmix", "ptl", "base", "handshake_max_retries",
+        "Number of times to retry the handshake request before giving up",
+        PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_4,
+        PMIX_MCA_BASE_VAR_SCOPE_READONLY, &pmix_ptl_base.handshake_max_retries);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "handshake_max_retries",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
     idx = pmix_mca_base_var_register("pmix", "ptl", "base", "report_uri",
                                      "Output URI [- => stdout, + => stderr, or filename]",
-                                     PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, 0,
-                                     PMIX_INFO_LVL_2,
-                                     PMIX_MCA_BASE_VAR_SCOPE_LOCAL,
-                                     &pmix_ptl_base.report_uri);
-    (void)pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "report_uri", PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
-
+                                     PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0,
+                                     PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
+                                     PMIX_MCA_BASE_VAR_SCOPE_LOCAL, &pmix_ptl_base.report_uri);
+    (void) pmix_mca_base_var_register_synonym(idx, "pmix", "ptl", "tcp", "report_uri",
+                                              PMIX_MCA_BASE_VAR_SYN_FLAG_DEPRECATED);
 
     return PMIX_SUCCESS;
 }
@@ -253,15 +250,13 @@ static pmix_status_t pmix_ptl_close(void)
     if (NULL != pmix_ptl_base.session_tmpdir) {
         /* if I created the session tmpdir, then remove it if empty */
         if (pmix_ptl_base.created_session_tmpdir) {
-            pmix_os_dirpath_destroy(pmix_ptl_base.session_tmpdir,
-                                    true, NULL);
+            pmix_os_dirpath_destroy(pmix_ptl_base.session_tmpdir, true, NULL);
         }
         free(pmix_ptl_base.session_tmpdir);
     }
     if (NULL != pmix_ptl_base.system_tmpdir) {
         if (pmix_ptl_base.created_system_tmpdir) {
-            pmix_os_dirpath_destroy(pmix_ptl_base.system_tmpdir,
-                                    true, NULL);
+            pmix_os_dirpath_destroy(pmix_ptl_base.system_tmpdir, true, NULL);
         }
         free(pmix_ptl_base.system_tmpdir);
     }
@@ -284,8 +279,7 @@ static pmix_status_t pmix_ptl_open(pmix_mca_base_open_flag_t flags)
 
     /* check for environ-based directives
      * on system tmpdir to use */
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) ||
-        PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) || PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
         pmix_ptl_base.session_tmpdir = strdup(pmix_server_globals.tmpdir);
     } else {
         if (NULL != (tdir = getenv("PMIX_SERVER_TMPDIR"))) {
@@ -295,8 +289,7 @@ static pmix_status_t pmix_ptl_open(pmix_mca_base_open_flag_t flags)
         }
     }
 
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) ||
-        PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) || PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
         pmix_ptl_base.system_tmpdir = strdup(pmix_server_globals.system_tmpdir);
     } else {
         if (NULL != (tdir = getenv("PMIX_SYSTEM_TMPDIR"))) {
@@ -306,14 +299,12 @@ static pmix_status_t pmix_ptl_open(pmix_mca_base_open_flag_t flags)
         }
     }
 
-    if (NULL != pmix_ptl_base.report_uri &&
-        0 != strcmp(pmix_ptl_base.report_uri, "-") &&
-        0 != strcmp(pmix_ptl_base.report_uri, "+")) {
+    if (NULL != pmix_ptl_base.report_uri && 0 != strcmp(pmix_ptl_base.report_uri, "-")
+        && 0 != strcmp(pmix_ptl_base.report_uri, "+")) {
         pmix_ptl_base.urifile = strdup(pmix_ptl_base.report_uri);
     }
 
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) ||
-        PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) || PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
         if (NULL != (tdir = getenv("PMIX_LAUNCHER_RENDEZVOUS_FILE"))) {
             pmix_ptl_base.rendezvous_filename = strdup(tdir);
         }
@@ -325,9 +316,9 @@ static pmix_status_t pmix_ptl_open(pmix_mca_base_open_flag_t flags)
     return rc;
 }
 
-PMIX_MCA_BASE_FRAMEWORK_DECLARE(pmix, ptl, "PMIx Transfer Layer",
-                                pmix_ptl_register, pmix_ptl_open, pmix_ptl_close,
-                                mca_ptl_base_static_components, 0);
+PMIX_MCA_BASE_FRAMEWORK_DECLARE(pmix, ptl, "PMIx Transfer Layer", pmix_ptl_register, pmix_ptl_open,
+                                pmix_ptl_close, mca_ptl_base_static_components,
+                                PMIX_MCA_BASE_FRAMEWORK_FLAG_DEFAULT);
 
 /***   INSTANTIATE INTERNAL CLASSES   ***/
 static void scon(pmix_ptl_send_t *p)
@@ -346,9 +337,7 @@ static void sdes(pmix_ptl_send_t *p)
         PMIX_RELEASE(p->data);
     }
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_send_t,
-                                pmix_list_item_t,
-                                scon, sdes);
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_send_t, pmix_list_item_t, scon, sdes);
 
 static void rcon(pmix_ptl_recv_t *p)
 {
@@ -367,9 +356,7 @@ static void rdes(pmix_ptl_recv_t *p)
         PMIX_RELEASE(p->peer);
     }
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_recv_t,
-                                pmix_list_item_t,
-                                rcon, rdes);
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_recv_t, pmix_list_item_t, rcon, rdes);
 
 static void prcon(pmix_ptl_posted_recv_t *p)
 {
@@ -377,10 +364,7 @@ static void prcon(pmix_ptl_posted_recv_t *p)
     p->cbfunc = NULL;
     p->cbdata = NULL;
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_posted_recv_t,
-                                pmix_list_item_t,
-                                prcon, NULL);
-
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_posted_recv_t, pmix_list_item_t, prcon, NULL);
 
 static void srcon(pmix_ptl_sr_t *p)
 {
@@ -395,9 +379,7 @@ static void srdes(pmix_ptl_sr_t *p)
         PMIX_RELEASE(p->peer);
     }
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_sr_t,
-                                pmix_object_t,
-                                srcon, srdes);
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_sr_t, pmix_object_t, srcon, srdes);
 
 static void pccon(pmix_pending_connection_t *p)
 {
@@ -438,9 +420,7 @@ static void pcdes(pmix_pending_connection_t *p)
         free(p->cred);
     }
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_pending_connection_t,
-                                pmix_object_t,
-                                pccon, pcdes);
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_pending_connection_t, pmix_object_t, pccon, pcdes);
 
 static void lcon(pmix_listener_t *p)
 {
@@ -463,9 +443,7 @@ static void ldes(pmix_listener_t *p)
         free(p->uri);
     }
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_listener_t,
-                                pmix_list_item_t,
-                                lcon, ldes);
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_listener_t, pmix_list_item_t, lcon, ldes);
 
 static void qcon(pmix_ptl_queue_t *p)
 {
@@ -479,6 +457,26 @@ static void qdes(pmix_ptl_queue_t *p)
         PMIX_RELEASE(p->peer);
     }
 }
-PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_queue_t,
-                                pmix_object_t,
-                                qcon, qdes);
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_ptl_queue_t, pmix_object_t, qcon, qdes);
+
+static void ccon(pmix_connection_t *p)
+{
+    p->sd = -1;
+    p->nspace = NULL;
+    p->rank = PMIX_RANK_INVALID;
+    p->uri = NULL;
+    p->version = NULL;
+}
+static void dcon(pmix_connection_t *p)
+{
+    if (NULL != p->nspace) {
+        free(p->nspace);
+    }
+    if (NULL != p->uri) {
+        free(p->uri);
+    }
+    if (NULL != p->version) {
+        free(p->version);
+    }
+}
+PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_connection_t, pmix_list_item_t, ccon, dcon);
