@@ -18,6 +18,7 @@
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -30,19 +31,15 @@
 #include "src/include/pmix_config.h"
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 
 #include "src/include/pmix_globals.h"
-#include "src/util/net.h"
-#include "src/util/name_fns.h"
-#include "src/util/output.h"
-#include "src/util/show_help.h"
 #include "src/mca/base/base.h"
 #include "src/mca/base/pmix_mca_base_var.h"
 #include "src/mca/bfrops/base/base.h"
-#include "src/mca/pcompress/base/base.h"
 #include "src/mca/gds/base/base.h"
+#include "src/mca/pcompress/base/base.h"
 #include "src/mca/pif/base/base.h"
 #include "src/mca/pinstalldirs/base/base.h"
 #include "src/mca/ploc/base/base.h"
@@ -51,7 +48,12 @@
 #include "src/mca/preg/base/base.h"
 #include "src/mca/psec/base/base.h"
 #include "src/mca/psquash/base/base.h"
+#include "src/mca/pstrg/base/base.h"
 #include "src/mca/ptl/base/base.h"
+#include "src/util/name_fns.h"
+#include "src/util/net.h"
+#include "src/util/output.h"
+#include "src/util/show_help.h"
 
 #include "src/client/pmix_client_ops.h"
 #include "src/common/pmix_attributes.h"
@@ -60,8 +62,8 @@
 #include "src/util/error.h"
 #include "src/util/keyval_parse.h"
 
-#include "src/runtime/pmix_rte.h"
 #include "src/runtime/pmix_progress_threads.h"
+#include "src/runtime/pmix_rte.h"
 
 const char pmix_version_string[] = PMIX_IDENT_STRING;
 
@@ -73,62 +75,54 @@ PMIX_EXPORT bool pmix_init_called = false;
  * Initialize only those entries that are not covered
  * by MCA params or are complex structures initialized
  * below */
-PMIX_EXPORT pmix_globals_t pmix_globals = {
-    .init_cntr = 0,
-    .mypeer = NULL,
-    .hostname = NULL,
-    .nodeid = UINT32_MAX,
-    .pindex = 0,
-    .evbase = NULL,
-    .debug_output = -1,
-    .connected = false,
-    .commits_pending = false,
-    .mygds = NULL,
-    .pushstdin = false,
-    .topology = {NULL, NULL},
-    .external_topology = false,
-    .external_progress = false
-};
+PMIX_EXPORT pmix_globals_t pmix_globals = {.init_cntr = 0,
+                                           .mypeer = NULL,
+                                           .hostname = NULL,
+                                           .nodeid = UINT32_MAX,
+                                           .pindex = 0,
+                                           .evbase = NULL,
+                                           .debug_output = -1,
+                                           .connected = false,
+                                           .commits_pending = false,
+                                           .pushstdin = false,
+                                           .topology = {NULL, NULL},
+                                           .external_topology = false,
+                                           .external_progress = false};
 
-
-static void _notification_eviction_cbfunc(struct pmix_hotel_t *hotel,
-                                          int room_num,
-                                          void *occupant)
+static void _notification_eviction_cbfunc(struct pmix_hotel_t *hotel, int room_num, void *occupant)
 {
-    pmix_notify_caddy_t *cache = (pmix_notify_caddy_t*)occupant;
+    pmix_notify_caddy_t *cache = (pmix_notify_caddy_t *) occupant;
     PMIX_RELEASE(cache);
 }
 
-
-int pmix_rte_init(uint32_t type,
-                  pmix_info_t info[], size_t ninfo,
-                  pmix_ptl_cbfunc_t cbfunc)
+int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfunc_t cbfunc)
 {
     int ret, debug_level;
     char *error = NULL, *evar;
     size_t n, m;
     char hostname[PMIX_MAXHOSTNAMELEN] = {0};
-    char *gds = NULL;
     pmix_info_t *iptr;
     size_t minfo;
     bool keepfqdn = false;
 
-    if( ++pmix_initialized != 1 ) {
-        if( pmix_initialized < 1 ) {
+    if (++pmix_initialized != 1) {
+        if (pmix_initialized < 1) {
             return PMIX_ERROR;
         }
         return PMIX_SUCCESS;
     }
 
-    #if PMIX_NO_LIB_DESTRUCTOR
-        if (pmix_init_called) {
-            /* can't use show_help here */
-            fprintf (stderr, "pmix_init: attempted to initialize after finalize without compiler "
-                     "support for either __attribute__(destructor) or linker support for -fini -- process "
-                     "will likely abort\n");
-            return PMIX_ERR_NOT_SUPPORTED;
-        }
-    #endif
+#if PMIX_NO_LIB_DESTRUCTOR
+    if (pmix_init_called) {
+        /* can't use show_help here */
+        fprintf(
+            stderr,
+            "pmix_init: attempted to initialize after finalize without compiler "
+            "support for either __attribute__(destructor) or linker support for -fini -- process "
+            "will likely abort\n");
+        return PMIX_ERR_NOT_SUPPORTED;
+    }
+#endif
 
     pmix_init_called = true;
 
@@ -138,13 +132,19 @@ int pmix_rte_init(uint32_t type,
     }
 
     /* initialize install dirs code */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, ret);
         return ret;
     }
     if (PMIX_SUCCESS != (ret = pmix_pinstall_dirs_base_init(info, ninfo))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, ret);
         return ret;
     }
@@ -188,17 +188,23 @@ int pmix_rte_init(uint32_t type,
 
     /* setup the globals structure */
     pmix_globals.pid = getpid();
-    memset(&pmix_globals.myid.nspace, 0, PMIX_MAX_NSLEN+1);
-    pmix_globals.myid.rank = PMIX_RANK_INVALID;
+    PMIX_LOAD_PROCID(&pmix_globals.myid, NULL, PMIX_RANK_INVALID);
+
+    pmix_globals.myidval.type = PMIX_PROC;
+    pmix_globals.myidval.data.proc = (pmix_proc_t *) malloc(sizeof(pmix_proc_t));
+    PMIX_LOAD_PROCID(pmix_globals.myidval.data.proc, NULL, PMIX_RANK_INVALID);
+
+    pmix_globals.myrankval.type = PMIX_PROC_RANK;
+    pmix_globals.myrankval.data.rank = PMIX_RANK_INVALID;
+
     PMIX_CONSTRUCT(&pmix_globals.events, pmix_events_t);
     pmix_globals.event_window.tv_sec = pmix_event_caching_window;
     pmix_globals.event_window.tv_usec = 0;
     PMIX_CONSTRUCT(&pmix_globals.cached_events, pmix_list_t);
     /* construct the global notification ring buffer */
     PMIX_CONSTRUCT(&pmix_globals.notifications, pmix_hotel_t);
-    ret = pmix_hotel_init(&pmix_globals.notifications, pmix_globals.max_events,
-                          pmix_globals.evbase, pmix_globals.event_eviction_time,
-                          _notification_eviction_cbfunc);
+    ret = pmix_hotel_init(&pmix_globals.notifications, pmix_globals.max_events, pmix_globals.evbase,
+                          pmix_globals.event_eviction_time, _notification_eviction_cbfunc);
     PMIX_CONSTRUCT(&pmix_globals.nspaces, pmix_list_t);
     /* need to hold off checking the hotel init return code
      * until after we construct all the globals so they can
@@ -213,14 +219,14 @@ int pmix_rte_init(uint32_t type,
     pmix_pointer_array_init(&pmix_globals.iof_requests, 128, INT_MAX, 128);
     /* setup the stdin forwarding target list */
     PMIX_CONSTRUCT(&pmix_globals.stdin_targets, pmix_list_t);
+    memset(&pmix_globals.iof_flags, 0, sizeof(pmix_iof_flags_t));
 
     /* Setup client verbosities as all procs are allowed to
      * access client APIs */
     if (0 < pmix_client_globals.get_verbose) {
         /* set default output */
         pmix_client_globals.get_output = pmix_output_open(NULL);
-        pmix_output_set_verbosity(pmix_client_globals.get_output,
-                                  pmix_client_globals.get_verbose);
+        pmix_output_set_verbosity(pmix_client_globals.get_output, pmix_client_globals.get_verbose);
     }
     if (0 < pmix_client_globals.connect_verbose) {
         /* set default output */
@@ -237,8 +243,7 @@ int pmix_rte_init(uint32_t type,
     if (0 < pmix_client_globals.pub_verbose) {
         /* set default output */
         pmix_client_globals.pub_output = pmix_output_open(NULL);
-        pmix_output_set_verbosity(pmix_client_globals.pub_output,
-                                  pmix_client_globals.pub_verbose);
+        pmix_output_set_verbosity(pmix_client_globals.pub_output, pmix_client_globals.pub_verbose);
     }
     if (0 < pmix_client_globals.spawn_verbose) {
         /* set default output */
@@ -255,8 +260,7 @@ int pmix_rte_init(uint32_t type,
     if (0 < pmix_client_globals.iof_verbose) {
         /* set default output */
         pmix_client_globals.iof_output = pmix_output_open(NULL);
-        pmix_output_set_verbosity(pmix_client_globals.iof_output,
-                                  pmix_client_globals.iof_verbose);
+        pmix_output_set_verbosity(pmix_client_globals.iof_output, pmix_client_globals.iof_verbose);
     }
 
     /* get our effective id's */
@@ -290,7 +294,7 @@ int pmix_rte_init(uint32_t type,
 
     /* scan incoming info for directives */
     if (NULL != info) {
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             if (PMIX_CHECK_KEY(&info[n], PMIX_HOSTNAME)) {
                 if (NULL != pmix_globals.hostname) {
                     free(pmix_globals.hostname);
@@ -301,13 +305,11 @@ int pmix_rte_init(uint32_t type,
                 if (PMIX_SUCCESS != ret) {
                     goto return_error;
                 }
-            } else if (PMIX_CHECK_KEY(&info[n], PMIX_GDS_MODULE)) {
-                gds = info[n].value.data.string;
             } else if (PMIX_CHECK_KEY(&info[n], PMIX_NODE_INFO_ARRAY)) {
                 /* contains info about our node */
-                iptr = (pmix_info_t*)info[n].value.data.darray->array;
+                iptr = (pmix_info_t *) info[n].value.data.darray->array;
                 minfo = info[n].value.data.darray->size;
-                for (m=0; m < minfo; m++) {
+                for (m = 0; m < minfo; m++) {
                     if (PMIX_CHECK_KEY(&iptr[m], PMIX_HOSTNAME)) {
                         if (NULL != pmix_globals.hostname) {
                             free(pmix_globals.hostname);
@@ -324,33 +326,42 @@ int pmix_rte_init(uint32_t type,
                 pmix_globals.external_progress = PMIX_INFO_TRUE(&info[n]);
             } else if (PMIX_CHECK_KEY(&info[n], PMIX_HOSTNAME_KEEP_FQDN)) {
                 keepfqdn = PMIX_INFO_TRUE(&info[n]);
+            } else {
+                pmix_iof_check_flags(&info[n], &pmix_globals.iof_flags);
             }
         }
     }
 
-    /* if we were given a hostname in our environment, use it */
-    if (NULL != (evar = getenv("PMIX_HOSTNAME"))) {
-        pmix_globals.hostname = strdup(evar);
-    } else {
-        gethostname(hostname, PMIX_MAXHOSTNAMELEN-1);
-        /* strip the FQDN unless told to keep it */
-        if (!keepfqdn && !pmix_net_isaddr(hostname) &&
-            NULL != (evar = strchr(hostname, '.'))) {
-            *evar = '\0';
+    /* the passed-in hostname trumps all, so don't overwrite it
+     * if we were given one */
+    if (NULL == pmix_globals.hostname) {
+        /* if we were given a hostname in our environment, use it */
+        if (NULL != (evar = getenv("PMIX_HOSTNAME"))) {
+            pmix_globals.hostname = strdup(evar);
+        } else {
+            /* if we weren't previously given a hostname, then
+             * use the OS one */
+            gethostname(hostname, PMIX_MAXHOSTNAMELEN - 1);
+            /* strip the FQDN unless told to keep it */
+            if (!keepfqdn && !pmix_net_isaddr(hostname) && NULL != (evar = strchr(hostname, '.'))) {
+                *evar = '\0';
+            }
+            pmix_globals.hostname = strdup(hostname);
         }
-        pmix_globals.hostname = strdup(hostname);
     }
 
     /* the choice of modules to use when communicating with a peer
      * will be done by the individual init functions and at the
      * time of connection to that peer */
 
-    if( PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_psquash_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_psquash_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_psquash_base_open";
         goto return_error;
     }
 
-    if( PMIX_SUCCESS != (ret = pmix_psquash_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_psquash_base_select())) {
         error = "pmix_psquash_base_select";
         goto return_error;
     }
@@ -362,31 +373,37 @@ int pmix_rte_init(uint32_t type,
     }
 
     /* open the bfrops and select the active plugins */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_bfrops_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_bfrops_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_bfrops_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_bfrop_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_bfrop_base_select())) {
         error = "pmix_bfrops_base_select";
         goto return_error;
     }
 
     /* open and select the compress framework */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_pcompress_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_pcompress_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_pcompress_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_compress_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_compress_base_select())) {
         error = "pmix_pcompress_base_select";
         goto return_error;
     }
 
     /* open the ptl and select the active plugins */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_ptl_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_ptl_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_ptl_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_ptl_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_ptl_base_select())) {
         error = "pmix_ptl_base_select";
         goto return_error;
     }
@@ -401,7 +418,9 @@ int pmix_rte_init(uint32_t type,
         /* convert to an MCA param, but don't overwrite something already there */
         pmix_setenv("PMIX_MCA_psec", evar, false, &environ);
     }
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_psec_base_framework, 0))) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_psec_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_psec_base_open";
         goto return_error;
     }
@@ -411,57 +430,73 @@ int pmix_rte_init(uint32_t type,
     }
 
     /* open the gds and select the active plugins */
-    if (NULL != gds) {
-        pmix_setenv("PMIX_MCA_gds", gds, true, &environ);
-    } else if (NULL != (evar = getenv("PMIX_GDS_MODULE"))) {
-        /* convert to an MCA param, but don't overwrite something already there */
-        pmix_setenv("PMIX_MCA_gds", evar, false, &environ);
-    }
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_gds_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_gds_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_gds_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_gds_base_select(info, ninfo)) ) {
+    if (PMIX_SUCCESS != (ret = pmix_gds_base_select(info, ninfo))) {
         error = "pmix_gds_base_select";
         goto return_error;
     }
 
     /* initialize pif framework */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_pif_base_framework, 0))) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_pif_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_pif_base_open";
         return ret;
     }
 
     /* open the preg and select the active plugins - must come after pcompress! */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_preg_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_preg_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_preg_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_preg_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_preg_base_select())) {
         error = "pmix_preg_base_select";
         goto return_error;
     }
 
     /* open the plog and select the active plugins */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_plog_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_plog_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_plog_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_plog_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_plog_base_select())) {
         error = "pmix_plog_base_select";
         goto return_error;
     }
 
     /* open the ploc and select the active plugins */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_ploc_base_framework, 0)) ) {
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_ploc_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
         error = "pmix_ploc_base_open";
         goto return_error;
     }
-    if (PMIX_SUCCESS != (ret = pmix_ploc_base_select()) ) {
+    if (PMIX_SUCCESS != (ret = pmix_ploc_base_select())) {
         error = "pmix_ploc_base_select";
         goto return_error;
     }
 
+    /* open the pstrg framework */
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_pstrg_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
+        error = "pmix_strg_base_open";
+        goto return_error;
+    }
+    if (PMIX_SUCCESS != (ret = pmix_pstrg_base_select())) {
+        error = "pmix_pstrg_base_select";
+        goto return_error;
+    }
+
     /* initialize the attribute support system */
     pmix_init_registered_attrs();
 
@@ -473,11 +508,10 @@ int pmix_rte_init(uint32_t type,
 
     return PMIX_SUCCESS;
 
-  return_error:
+return_error:
     if (PMIX_ERR_SILENT != ret) {
-        pmix_show_help( "help-pmix-runtime.txt",
-                        "pmix_init:startup:internal-failure", true,
-                        error, ret );
+        pmix_show_help("help-pmix-runtime.txt", "pmix_init:startup:internal-failure", true, error,
+                       ret);
     }
     return ret;
 }
