@@ -5,6 +5,7 @@
  *                         and Technology (RIST).  All rights reserved.
  * Copyright (c) 2019      Mellanox Technologies, Inc.
  *                         All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -15,18 +16,18 @@
 #include "src/include/pmix_config.h"
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
-#include <string.h>
 #include <pthread.h>
+#include <string.h>
 #include PMIX_EVENT_HEADER
 
 #include "src/class/pmix_list.h"
+#include "src/include/pmix_globals.h"
+#include "src/runtime/pmix_progress_threads.h"
 #include "src/threads/threads.h"
 #include "src/util/error.h"
 #include "src/util/fd.h"
-#include "src/include/pmix_globals.h"
-#include "src/runtime/pmix_progress_threads.h"
 
 /* create a tracking object for progress threads */
 typedef struct {
@@ -57,7 +58,7 @@ typedef struct {
 
 static void tracker_constructor(pmix_progress_tracker_t *p)
 {
-    p->refcount = 1;  // start at one since someone created it
+    p->refcount = 1; // start at one since someone created it
     p->name = NULL;
     p->ev_base = NULL;
     p->ev_active = false;
@@ -87,29 +88,19 @@ static void tracker_destructor(pmix_progress_tracker_t *p)
 #endif
 }
 
-static PMIX_CLASS_INSTANCE(pmix_progress_tracker_t,
-                          pmix_list_item_t,
-                          tracker_constructor,
-                          tracker_destructor);
+static PMIX_CLASS_INSTANCE(pmix_progress_tracker_t, pmix_list_item_t, tracker_constructor,
+                           tracker_destructor);
 
 /* LOCAL VARIABLES */
 static bool inited = false;
 static pmix_list_t tracking;
-static struct timeval long_timeout = {
-    .tv_sec = 3600,
-    .tv_usec = 0
-};
+static struct timeval long_timeout = {.tv_sec = 3600, .tv_usec = 0};
 static const char *shared_thread_name = "PMIX-wide async progress thread";
 static pmix_progress_tracker_t *shared_thread_tracker = NULL;
 
-
 #if PMIX_HAVE_LIBEV
 
-typedef enum {
-    PMIX_EVENT_ACTIVE,
-    PMIX_EVENT_ADD,
-    PMIX_EVENT_DEL
-} pmix_event_type_t;
+typedef enum { PMIX_EVENT_ACTIVE, PMIX_EVENT_ADD, PMIX_EVENT_DEL } pmix_event_type_t;
 
 typedef struct {
     pmix_list_item_t super;
@@ -120,37 +111,36 @@ typedef struct {
     pmix_event_type_t type;
 } pmix_event_caddy_t;
 
-static PMIX_CLASS_INSTANCE(pmix_event_caddy_t,
-                           pmix_list_item_t,
-                           NULL, NULL);
+static PMIX_CLASS_INSTANCE(pmix_event_caddy_t, pmix_list_item_t, NULL, NULL);
 
-static pmix_progress_tracker_t* pmix_progress_tracker_get_by_base(struct event_base *);
+static pmix_progress_tracker_t *pmix_progress_tracker_get_by_base(struct event_base *);
 
-static void pmix_libev_ev_async_cb (EV_P_ ev_async *w, int revents)
+static void pmix_libev_ev_async_cb(EV_P_ ev_async *w, int revents)
 {
-    pmix_progress_tracker_t *trk = pmix_progress_tracker_get_by_base((struct event_base *)EV_A);
+    pmix_progress_tracker_t *trk = pmix_progress_tracker_get_by_base((struct event_base *) EV_A);
     assert(NULL != trk);
-    pthread_mutex_lock (&trk->mutex);
+    pthread_mutex_lock(&trk->mutex);
     pmix_event_caddy_t *cd, *next;
-    PMIX_LIST_FOREACH_SAFE(cd, next, &trk->list, pmix_event_caddy_t) {
+    PMIX_LIST_FOREACH_SAFE (cd, next, &trk->list, pmix_event_caddy_t) {
         switch (cd->type) {
-            case PMIX_EVENT_ADD:
-                (void)event_add(cd->ev, cd->tv);
-                break;
-            case PMIX_EVENT_DEL:
-                (void)event_del(cd->ev);
-                break;
-            case PMIX_EVENT_ACTIVE:
-                (void)event_active(cd->ev, cd->res, cd->ncalls);
-                break;
+        case PMIX_EVENT_ADD:
+            (void) event_add(cd->ev, cd->tv);
+            break;
+        case PMIX_EVENT_DEL:
+            (void) event_del(cd->ev);
+            break;
+        case PMIX_EVENT_ACTIVE:
+            (void) event_active(cd->ev, cd->res, cd->ncalls);
+            break;
         }
         pmix_list_remove_item(&trk->list, &cd->super);
         PMIX_RELEASE(cd);
     }
-    pthread_mutex_unlock (&trk->mutex);
+    pthread_mutex_unlock(&trk->mutex);
 }
 
-int pmix_event_add(struct event *ev, struct timeval *tv) {
+int pmix_event_add(struct event *ev, struct timeval *tv)
+{
     int res;
     pmix_progress_tracker_t *trk = pmix_progress_tracker_get_by_base(ev->ev_base);
     if ((NULL != trk) && !pthread_equal(pthread_self(), trk->engine.t_handle)) {
@@ -160,7 +150,7 @@ int pmix_event_add(struct event *ev, struct timeval *tv) {
         cd->tv = tv;
         pthread_mutex_lock(&trk->mutex);
         pmix_list_append(&trk->list, &cd->super);
-        ev_async_send ((struct ev_loop *)trk->ev_base, &trk->async);
+        ev_async_send((struct ev_loop *) trk->ev_base, &trk->async);
         pthread_mutex_unlock(&trk->mutex);
         res = PMIX_SUCCESS;
     } else {
@@ -169,7 +159,8 @@ int pmix_event_add(struct event *ev, struct timeval *tv) {
     return res;
 }
 
-int pmix_event_del(struct event *ev) {
+int pmix_event_del(struct event *ev)
+{
     int res;
     pmix_progress_tracker_t *trk = pmix_progress_tracker_get_by_base(ev->ev_base);
     if ((NULL != trk) && !pthread_equal(pthread_self(), trk->engine.t_handle)) {
@@ -178,7 +169,7 @@ int pmix_event_del(struct event *ev) {
         cd->ev = ev;
         pthread_mutex_lock(&trk->mutex);
         pmix_list_append(&trk->list, &cd->super);
-        ev_async_send ((struct ev_loop *)trk->ev_base, &trk->async);
+        ev_async_send((struct ev_loop *) trk->ev_base, &trk->async);
         pthread_mutex_unlock(&trk->mutex);
         res = PMIX_SUCCESS;
     } else {
@@ -187,7 +178,8 @@ int pmix_event_del(struct event *ev) {
     return res;
 }
 
-void pmix_event_active (struct event *ev, int res, short ncalls) {
+void pmix_event_active(struct event *ev, int res, short ncalls)
+{
     pmix_progress_tracker_t *trk = pmix_progress_tracker_get_by_base(ev->ev_base);
     if ((NULL != trk) && !pthread_equal(pthread_self(), trk->engine.t_handle)) {
         pmix_event_caddy_t *cd = PMIX_NEW(pmix_event_caddy_t);
@@ -197,17 +189,18 @@ void pmix_event_active (struct event *ev, int res, short ncalls) {
         cd->ncalls = ncalls;
         pthread_mutex_lock(&trk->mutex);
         pmix_list_append(&trk->list, &cd->super);
-        ev_async_send ((struct ev_loop *)trk->ev_base, &trk->async);
+        ev_async_send((struct ev_loop *) trk->ev_base, &trk->async);
         pthread_mutex_unlock(&trk->mutex);
     } else {
         event_active(ev, res, ncalls);
     }
 }
 
-void pmix_event_base_loopexit (pmix_event_base_t *ev_base) {
+void pmix_event_base_loopexit(pmix_event_base_t *ev_base)
+{
     pmix_progress_tracker_t *trk = pmix_progress_tracker_get_by_base(ev_base);
     assert(NULL != trk);
-    ev_async_send ((struct ev_loop *)trk->ev_base, &trk->async);
+    ev_async_send((struct ev_loop *) trk->ev_base, &trk->async);
 }
 #endif
 
@@ -217,7 +210,7 @@ void pmix_event_base_loopexit (pmix_event_base_t *ev_base) {
  */
 static void dummy_timeout_cb(int fd, short args, void *cbdata)
 {
-    pmix_progress_tracker_t *trk = (pmix_progress_tracker_t*)cbdata;
+    pmix_progress_tracker_t *trk = (pmix_progress_tracker_t *) cbdata;
 
     pmix_event_add(&trk->block, &long_timeout);
 }
@@ -225,10 +218,10 @@ static void dummy_timeout_cb(int fd, short args, void *cbdata)
 /*
  * Main for the progress thread
  */
-static void* progress_engine(pmix_object_t *obj)
+static void *progress_engine(pmix_object_t *obj)
 {
-    pmix_thread_t *t = (pmix_thread_t*)obj;
-    pmix_progress_tracker_t *trk = (pmix_progress_tracker_t*)t->t_arg;
+    pmix_thread_t *t = (pmix_thread_t *) obj;
+    pmix_progress_tracker_t *trk = (pmix_progress_tracker_t *) t->t_arg;
 
     while (trk->ev_active) {
         pmix_event_loop(trk->ev_base, PMIX_EVLOOP_ONCE);
@@ -269,7 +262,6 @@ static int start_progress_engine(pmix_progress_tracker_t *trk)
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
     }
-
     return rc;
 }
 
@@ -287,7 +279,7 @@ pmix_event_base_t *pmix_progress_thread_init(const char *name)
     }
 
     /* check if we already have this thread */
-    PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
+    PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
         if (0 == strcmp(name, trk->name)) {
             /* we do, so up the refcount on it */
             ++trk->refcount;
@@ -317,13 +309,12 @@ pmix_event_base_t *pmix_progress_thread_init(const char *name)
 
     /* add an event to the new event base (if there are no events,
        pmix_event_loop() will return immediately) */
-    pmix_event_assign(&trk->block, trk->ev_base, -1, PMIX_EV_PERSIST,
-                   dummy_timeout_cb, trk);
+    pmix_event_assign(&trk->block, trk->ev_base, -1, PMIX_EV_PERSIST, dummy_timeout_cb, trk);
     pmix_event_add(&trk->block, &long_timeout);
 
 #if PMIX_HAVE_LIBEV
-    ev_async_init (&trk->async, pmix_libev_ev_async_cb);
-    ev_async_start((struct ev_loop *)trk->ev_base, &trk->async);
+    ev_async_init(&trk->async, pmix_libev_ev_async_cb);
+    ev_async_start((struct ev_loop *) trk->ev_base, &trk->async);
 #endif
 
     /* construct the thread object */
@@ -356,7 +347,7 @@ pmix_status_t pmix_progress_thread_start(const char *name)
     }
 
     /* find the specified engine */
-    PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
+    PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
         if (0 == strcmp(name, trk->name)) {
             /* If the progress thread is active, ignore the request */
             if (trk->ev_active) {
@@ -373,7 +364,6 @@ pmix_status_t pmix_progress_thread_start(const char *name)
     return PMIX_ERR_NOT_FOUND;
 }
 
-
 pmix_status_t pmix_progress_thread_stop(const char *name)
 {
     pmix_progress_tracker_t *trk;
@@ -391,7 +381,7 @@ pmix_status_t pmix_progress_thread_stop(const char *name)
     }
 
     /* find the specified engine */
-    PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
+    PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
         if (0 == strcmp(name, trk->name)) {
             /* decrement the refcount */
             --trk->refcount;
@@ -431,7 +421,7 @@ pmix_status_t pmix_progress_thread_finalize(const char *name)
     }
 
     /* find the specified engine */
-    PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
+    PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
         if (0 == strcmp(name, trk->name)) {
             /* If the refcount is still above 0, we're done here */
             if (trk->refcount > 0) {
@@ -467,7 +457,7 @@ pmix_status_t pmix_progress_thread_pause(const char *name)
     }
 
     /* find the specified engine */
-    PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
+    PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
         if (0 == strcmp(name, trk->name)) {
             if (trk->ev_active) {
                 stop_progress_engine(trk);
@@ -481,12 +471,13 @@ pmix_status_t pmix_progress_thread_pause(const char *name)
 }
 
 #if PMIX_HAVE_LIBEV
-static pmix_progress_tracker_t* pmix_progress_tracker_get_by_base(pmix_event_base_t *base) {
+static pmix_progress_tracker_t *pmix_progress_tracker_get_by_base(pmix_event_base_t *base)
+{
     pmix_progress_tracker_t *trk;
 
-    if (inited)  {
-        PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
-            if(trk->ev_base == base) {
+    if (inited) {
+        PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
+            if (trk->ev_base == base) {
                 return trk;
             }
         }
@@ -512,7 +503,7 @@ pmix_status_t pmix_progress_thread_resume(const char *name)
     }
 
     /* find the specified engine */
-    PMIX_LIST_FOREACH(trk, &tracking, pmix_progress_tracker_t) {
+    PMIX_LIST_FOREACH (trk, &tracking, pmix_progress_tracker_t) {
         if (0 == strcmp(name, trk->name)) {
             if (trk->ev_active) {
                 return PMIX_ERR_RESOURCE_BUSY;
