@@ -15,6 +15,7 @@
  * Copyright (c) 2011      Oak Ridge National Labs.  All rights reserved.
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Mellanox Technologies, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -26,21 +27,21 @@
 #include "pmix_config.h"
 #include "include/pmix_common.h"
 
+#include <pthread.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <time.h>
-#include <pthread.h>
+#include <unistd.h>
 
 #include "include/pmix_tool.h"
 #include "src/common/pmix_attributes.h"
 #include "src/mca/base/base.h"
 #include "src/mca/pinstalldirs/base/base.h"
+#include "src/runtime/pmix_rte.h"
 #include "src/threads/threads.h"
 #include "src/util/cmd_line.h"
 #include "src/util/keyval_parse.h"
 #include "src/util/show_help.h"
-#include "src/runtime/pmix_rte.h"
 
 typedef struct {
     pmix_lock_t lock;
@@ -58,7 +59,6 @@ typedef struct {
     size_t ninfo;
 } myquery_data_t;
 
-
 /* this is a callback function for the PMIx_Query
  * API. The query will callback with a status indicating
  * if the request could be fully satisfied, partially
@@ -71,13 +71,10 @@ typedef struct {
  * Once we have dealt with the returned data, we must
  * call the release_fn so that the PMIx library can
  * cleanup */
-static void cbfunc(pmix_status_t status,
-                   pmix_info_t *info, size_t ninfo,
-                   void *cbdata,
-                   pmix_release_cbfunc_t release_fn,
-                   void *release_cbdata)
+static void querycbfunc(pmix_status_t status, pmix_info_t *info, size_t ninfo, void *cbdata,
+                        pmix_release_cbfunc_t release_fn, void *release_cbdata)
 {
-    myquery_data_t *mq = (myquery_data_t*)cbdata;
+    myquery_data_t *mq = (myquery_data_t *) cbdata;
     size_t n;
 
     mq->status = status;
@@ -87,7 +84,7 @@ static void cbfunc(pmix_status_t status,
     if (0 < ninfo) {
         PMIX_INFO_CREATE(mq->info, ninfo);
         mq->ninfo = ninfo;
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             PMIX_INFO_XFER(&mq->info[n], &info[n]);
         }
     }
@@ -106,13 +103,10 @@ static void cbfunc(pmix_status_t status,
  * when registering for general events - i.e.,, the default
  * handler. We don't technically need to register one, but it
  * is usually good practice to catch any events that occur */
-static void notification_fn(size_t evhdlr_registration_id,
-                            pmix_status_t status,
-                            const pmix_proc_t *source,
-                            pmix_info_t info[], size_t ninfo,
+static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
+                            const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                             pmix_info_t results[], size_t nresults,
-                            pmix_event_notification_cbfunc_fn_t cbfunc,
-                            void *cbdata)
+                            pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
     /* this example doesn't do anything with default events */
     if (NULL != cbfunc) {
@@ -127,15 +121,13 @@ static void notification_fn(size_t evhdlr_registration_id,
  * to the registered event. The index is used later on to deregister
  * an event handler - if we don't explicitly deregister it, then the
  * PMIx server will do so when it see us exit */
-static void evhandler_reg_callbk(pmix_status_t status,
-                                 size_t evhandler_ref,
-                                 void *cbdata)
+static void evhandler_reg_callbk(pmix_status_t status, size_t evhandler_ref, void *cbdata)
 {
-    mylock_t *lock = (mylock_t*)cbdata;
+    mylock_t *lock = (mylock_t *) cbdata;
 
     if (PMIX_SUCCESS != status) {
         fprintf(stderr, "Client %s:%d EVENT HANDLER REGISTRATION FAILED WITH STATUS %d, ref=%lu\n",
-                   myproc.nspace, myproc.rank, status, (unsigned long)evhandler_ref);
+                myproc.nspace, myproc.rank, status, (unsigned long) evhandler_ref);
     }
     lock->status = status;
     PMIX_WAKEUP_THREAD(&lock->lock);
@@ -165,104 +157,55 @@ typedef struct {
 pmix_pattrs_globals_t pmix_pattrs_globals = {0};
 
 pmix_cmd_line_init_t cmd_line_opts[] = {
-    { NULL,
-      'h', NULL, "help",
-      0,
-      &pmix_pattrs_globals.help, PMIX_CMD_LINE_TYPE_BOOL,
-      "This help message" },
+    {NULL, 'h', NULL, "help", 0, &pmix_pattrs_globals.help, PMIX_CMD_LINE_TYPE_BOOL,
+     "This help message"},
 
-    { NULL,
-      'v', NULL, "verbose",
-      0,
-      &pmix_pattrs_globals.verbose, PMIX_CMD_LINE_TYPE_BOOL,
-      "Be Verbose" },
+    {NULL, 'v', NULL, "verbose", 0, &pmix_pattrs_globals.verbose, PMIX_CMD_LINE_TYPE_BOOL,
+     "Be Verbose"},
 
-    { NULL,
-      'p', NULL, "pid",
-      1,
-      &pmix_pattrs_globals.pid, PMIX_CMD_LINE_TYPE_INT,
-      "Specify server pid to connect to" },
+    {NULL, 'p', NULL, "pid", 1, &pmix_pattrs_globals.pid, PMIX_CMD_LINE_TYPE_INT,
+     "Specify server pid to connect to"},
 
-    { NULL,
-      'n', NULL, "nspace",
-      1,
-      &pmix_pattrs_globals.nspace, PMIX_CMD_LINE_TYPE_STRING,
-      "Specify server nspace to connect to" },
+    {NULL, 'n', NULL, "nspace", 1, &pmix_pattrs_globals.nspace, PMIX_CMD_LINE_TYPE_STRING,
+     "Specify server nspace to connect to"},
 
-    { NULL,
-      '\0', NULL, "uri",
-      1,
-      &pmix_pattrs_globals.uri, PMIX_CMD_LINE_TYPE_STRING,
-      "Specify URI of server to connect to" },
+    {NULL, '\0', NULL, "uri", 1, &pmix_pattrs_globals.uri, PMIX_CMD_LINE_TYPE_STRING,
+     "Specify URI of server to connect to"},
 
-    { NULL,
-      '\0', NULL, "system-server-first",
-      0,
-      &pmix_pattrs_globals.sysfirst, PMIX_CMD_LINE_TYPE_BOOL,
-      "Look for the system server first" },
+    {NULL, '\0', NULL, "system-server-first", 0, &pmix_pattrs_globals.sysfirst,
+     PMIX_CMD_LINE_TYPE_BOOL, "Look for the system server first"},
 
-    { NULL,
-      '\0', NULL, "system-server",
-      0,
-      &pmix_pattrs_globals.system, PMIX_CMD_LINE_TYPE_BOOL,
-      "Specifically connect to the system server" },
+    {NULL, '\0', NULL, "system-server", 0, &pmix_pattrs_globals.system, PMIX_CMD_LINE_TYPE_BOOL,
+     "Specifically connect to the system server"},
 
-    { NULL,
-      'c', NULL, "client",
-      1,
-      &pmix_pattrs_globals.client, PMIX_CMD_LINE_TYPE_STRING,
-      "Comma-delimited list of client function whose attributes are to be printed (function or all)" },
+    {NULL, 'c', NULL, "client", 1, &pmix_pattrs_globals.client, PMIX_CMD_LINE_TYPE_STRING,
+     "Comma-delimited list of client function whose attributes are to be printed (function or "
+     "all)"},
 
-    { NULL,
-      's', NULL, "server",
-      1,
-      &pmix_pattrs_globals.server, PMIX_CMD_LINE_TYPE_STRING,
-      "Comma-delimited list of server function whose attributes are to be printed (function or all)" },
+    {NULL, 's', NULL, "server", 1, &pmix_pattrs_globals.server, PMIX_CMD_LINE_TYPE_STRING,
+     "Comma-delimited list of server function whose attributes are to be printed (function or "
+     "all)"},
 
-    { NULL,
-      't', NULL, "tool",
-      1,
-      &pmix_pattrs_globals.tool, PMIX_CMD_LINE_TYPE_STRING,
-      "Comma-delimited list of tool function whose attributes are to be printed (function or all)" },
+    {NULL, 't', NULL, "tool", 1, &pmix_pattrs_globals.tool, PMIX_CMD_LINE_TYPE_STRING,
+     "Comma-delimited list of tool function whose attributes are to be printed (function or all)"},
 
-    { NULL,
-      'h', NULL, "host",
-      1,
-      &pmix_pattrs_globals.host, PMIX_CMD_LINE_TYPE_STRING,
-      "Comma-delimited list of host function whose attributes are to be printed (function or all)" },
+    {NULL, 'h', NULL, "host", 1, &pmix_pattrs_globals.host, PMIX_CMD_LINE_TYPE_STRING,
+     "Comma-delimited list of host function whose attributes are to be printed (function or all)"},
 
-    { NULL,
-      '\0', NULL, "client-fns",
-      0,
-      &pmix_pattrs_globals.clientfns, PMIX_CMD_LINE_TYPE_BOOL,
-      "List the functions supported in this client library" },
+    {NULL, '\0', NULL, "client-fns", 0, &pmix_pattrs_globals.clientfns, PMIX_CMD_LINE_TYPE_BOOL,
+     "List the functions supported in this client library"},
 
-    { NULL,
-      '\0', NULL, "server-fns",
-      0,
-      &pmix_pattrs_globals.serverfns, PMIX_CMD_LINE_TYPE_BOOL,
-      "List the functions supported in this server library" },
+    {NULL, '\0', NULL, "server-fns", 0, &pmix_pattrs_globals.serverfns, PMIX_CMD_LINE_TYPE_BOOL,
+     "List the functions supported in this server library"},
 
-    { NULL,
-      '\0', NULL, "tool-fns",
-      0,
-      &pmix_pattrs_globals.toolfns, PMIX_CMD_LINE_TYPE_BOOL,
-      "List the functions supported in this tool library" },
-
-    { NULL,
-      '\0', NULL, "host-fns",
-      0,
-      &pmix_pattrs_globals.hostfns, PMIX_CMD_LINE_TYPE_BOOL,
-      "List the functions supported by this host environment" },
+    {NULL, '\0', NULL, "tool-fns", 0, &pmix_pattrs_globals.toolfns, PMIX_CMD_LINE_TYPE_BOOL,
+     "List the functions supported in this tool library"},
 
+    {NULL, '\0', NULL, "host-fns", 0, &pmix_pattrs_globals.hostfns, PMIX_CMD_LINE_TYPE_BOOL,
+     "List the functions supported by this host environment"},
 
     /* End of list */
-    { NULL,
-      '\0', NULL, NULL,
-      0,
-      NULL, PMIX_CMD_LINE_TYPE_NULL,
-      NULL }
-};
+    {NULL, '\0', NULL, NULL, 0, NULL, PMIX_CMD_LINE_TYPE_NULL, NULL}};
 
 int main(int argc, char **argv)
 {
@@ -287,13 +230,19 @@ int main(int argc, char **argv)
     }
 
     /* initialize install dirs code */
-    if (PMIX_SUCCESS != (rc = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+    if (PMIX_SUCCESS
+        != (rc = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework,
+                                              PMIX_MCA_BASE_OPEN_DEFAULT))) {
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, rc);
         return rc;
     }
     if (PMIX_SUCCESS != (rc = pmix_pinstall_dirs_base_init(NULL, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, rc);
         return rc;
     }
@@ -326,8 +275,7 @@ int main(int argc, char **argv)
 
     if (PMIX_SUCCESS != rc) {
         if (PMIX_ERR_SILENT != rc) {
-            fprintf(stderr, "%s: command line error (%s)\n", argv[0],
-                    PMIx_Error_string(rc));
+            fprintf(stderr, "%s: command line error (%s)\n", argv[0], PMIx_Error_string(rc));
         }
         return rc;
     }
@@ -335,8 +283,7 @@ int main(int argc, char **argv)
     if (pmix_pattrs_globals.help) {
         char *str, *args = NULL;
         args = pmix_cmd_line_get_usage_msg(&cmd_line);
-        str = pmix_show_help_string("help-pattrs.txt", "usage", true,
-                                    args);
+        str = pmix_show_help_string("help-pattrs.txt", "usage", true, args);
         if (NULL != str) {
             printf("%s", str);
             free(str);
@@ -347,8 +294,10 @@ int main(int argc, char **argv)
     }
 
     /* cannot list functions and get attributes at same time */
-    if ((pmix_pattrs_globals.clientfns || pmix_pattrs_globals.serverfns || pmix_pattrs_globals.toolfns || pmix_pattrs_globals.hostfns)
-        && (pmix_pattrs_globals.client || pmix_pattrs_globals.server || pmix_pattrs_globals.tool || NULL != pmix_pattrs_globals.host)) {
+    if ((pmix_pattrs_globals.clientfns || pmix_pattrs_globals.serverfns
+         || pmix_pattrs_globals.toolfns || pmix_pattrs_globals.hostfns)
+        && (pmix_pattrs_globals.client || pmix_pattrs_globals.server || pmix_pattrs_globals.tool
+            || NULL != pmix_pattrs_globals.host)) {
         fprintf(stderr, "Cannot request both a list of functions and attributes at same time\n");
         exit(1);
     }
@@ -356,8 +305,9 @@ int main(int argc, char **argv)
     /* if they are asking for client, server, or tool attrs, then
      * we don't need to connect to anyone - just register the
      * attrs and report */
-    if (pmix_pattrs_globals.clientfns || pmix_pattrs_globals.serverfns || pmix_pattrs_globals.toolfns ||
-        pmix_pattrs_globals.client || pmix_pattrs_globals.server || pmix_pattrs_globals.tool) {
+    if (pmix_pattrs_globals.clientfns || pmix_pattrs_globals.serverfns
+        || pmix_pattrs_globals.toolfns || pmix_pattrs_globals.client || pmix_pattrs_globals.server
+        || pmix_pattrs_globals.tool) {
         PMIX_INFO_CREATE(info, 1);
         PMIX_INFO_LOAD(&info[0], PMIX_TOOL_DO_NOT_CONNECT, NULL, PMIX_BOOL);
         rc = PMIx_tool_init(&myproc, info, 1);
@@ -385,7 +335,7 @@ int main(int argc, char **argv)
             fns = pmix_attributes_print_attr(PMIX_TOOL_ATTRIBUTES, pmix_pattrs_globals.tool);
         }
         if (NULL != fns) {
-            for (n=0; NULL != fns[n]; n++) {
+            for (n = 0; NULL != fns[n]; n++) {
                 fprintf(stderr, "%s\n", fns[n]);
             }
         }
@@ -396,8 +346,7 @@ int main(int argc, char **argv)
     if (!pmix_pattrs_globals.hostfns && NULL == pmix_pattrs_globals.host) {
         char *str, *args = NULL;
         args = pmix_cmd_line_get_usage_msg(&cmd_line);
-        str = pmix_show_help_string("help-pattrs.txt", "usage", true,
-                                    args);
+        str = pmix_show_help_string("help-pattrs.txt", "usage", true, args);
         if (NULL != str) {
             printf("%s", str);
             free(str);
@@ -434,8 +383,8 @@ int main(int argc, char **argv)
 
     /* register a default event handler */
     PMIX_CONSTRUCT_LOCK(&mylock.lock);
-    PMIx_Register_event_handler(NULL, 0, NULL, 0,
-                                notification_fn, evhandler_reg_callbk, (void*)&mylock);
+    PMIx_Register_event_handler(NULL, 0, NULL, 0, notification_fn, evhandler_reg_callbk,
+                                (void *) &mylock);
     PMIX_WAIT_THREAD(&mylock.lock);
     if (PMIX_SUCCESS != mylock.status) {
         fprintf(stderr, "PMIx_Register_event_handler returned bad status: %d\n", mylock.status);
@@ -452,10 +401,11 @@ int main(int argc, char **argv)
     if (pmix_pattrs_globals.hostfns) {
         PMIX_INFO_LOAD(&query.qualifiers[0], PMIX_HOST_FUNCTIONS, NULL, PMIX_BOOL);
     } else {
-        PMIX_INFO_LOAD(&query.qualifiers[0], PMIX_HOST_ATTRIBUTES, pmix_pattrs_globals.host, PMIX_STRING);
+        PMIX_INFO_LOAD(&query.qualifiers[0], PMIX_HOST_ATTRIBUTES, pmix_pattrs_globals.host,
+                       PMIX_STRING);
     }
     PMIX_CONSTRUCT_LOCK(&mq.lock);
-    rc = PMIx_Query_info_nb(&query, 1, cbfunc,(void*)&mq);
+    rc = PMIx_Query_info_nb(&query, 1, querycbfunc, (void *) &mq);
     if (PMIX_SUCCESS != rc) {
         fprintf(stderr, "PMIx_Query_info failed: %d\n", rc);
         goto done;
@@ -467,27 +417,28 @@ int main(int argc, char **argv)
         rc = mq.status;
     } else {
         /* print out the returned value(s) */
-        for (n=0; n < mq.ninfo; n++) {
+        for (n = 0; n < mq.ninfo; n++) {
             if (PMIX_CHECK_KEY(&mq.info[n], PMIX_HOST_FUNCTIONS)) {
                 fns = pmix_argv_split(mq.info[n].value.data.string, ',');
                 fprintf(stderr, "HOST SUPPORTED FUNCTIONS:\n");
-                for (m=0; NULL != fns[m]; m++) {
+                for (m = 0; NULL != fns[m]; m++) {
                     fprintf(stderr, "\t%s\n", fns[m]);
                 }
                 pmix_argv_free(fns);
             } else {
                 pmix_attributes_print_headers(&ans, PMIX_HOST_ATTRIBUTES);
                 if (PMIX_DATA_ARRAY == mq.info[n].value.type) {
-                    info = (pmix_info_t*)mq.info[n].value.data.darray->array;
-                    for (m=0; m < mq.info[n].value.data.darray->size; m++) {
-                        reg = (pmix_regattr_t*)info[m].value.data.darray->array;
-                        pmix_attributes_print_attrs(&ans, info[m].key, reg, info[0].value.data.darray->size);
+                    info = (pmix_info_t *) mq.info[n].value.data.darray->array;
+                    for (m = 0; m < mq.info[n].value.data.darray->size; m++) {
+                        reg = (pmix_regattr_t *) info[m].value.data.darray->array;
+                        pmix_attributes_print_attrs(&ans, info[m].key, reg,
+                                                    info[0].value.data.darray->size);
                     }
                 } else {
-                    reg = (pmix_regattr_t*)mq.info[n].value.data.ptr;
+                    reg = (pmix_regattr_t *) mq.info[n].value.data.ptr;
                     pmix_attributes_print_attrs(&ans, mq.info[n].key, reg, 1);
                 }
-                for (m=0; NULL != ans[m]; m++) {
+                for (m = 0; NULL != ans[m]; m++) {
                     fprintf(stderr, "%s\n", ans[m]);
                 }
                 pmix_argv_free(ans);
@@ -496,8 +447,8 @@ int main(int argc, char **argv)
         }
     }
 
-  done:
+done:
     PMIx_tool_finalize();
 
-    return(rc);
+    return (rc);
 }
