@@ -16,6 +16,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -25,33 +26,32 @@
 
 #include "pmix_config.h"
 
+#include <ctype.h>
 #include <stdio.h>
 #include <string.h>
-#include <ctype.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 #ifdef HAVE_NETDB_H
-#include <netdb.h>
+#    include <netdb.h>
 #endif
 #ifdef HAVE_SYS_PARAM_H
-#include <sys/param.h>
+#    include <sys/param.h>
 #endif
 #include <errno.h>
 #include <signal.h>
 
-#include "src/mca/pinstalldirs/base/base.h"
 #include "src/class/pmix_object.h"
 #include "src/class/pmix_pointer_array.h"
+#include "src/mca/base/base.h"
+#include "src/mca/pinstalldirs/base/base.h"
+#include "src/runtime/pmix_rte.h"
 #include "src/util/argv.h"
 #include "src/util/cmd_line.h"
 #include "src/util/error.h"
-#include "src/util/error.h"
 #include "src/util/keyval_parse.h"
 #include "src/util/output.h"
 #include "src/util/show_help.h"
-#include "src/mca/base/base.h"
-#include "src/runtime/pmix_rte.h"
 
 #include "pinfo.h"
 #include "support.h"
@@ -61,6 +61,8 @@
  */
 
 pmix_cmd_line_t *pmix_info_cmd_line = NULL;
+pmix_pointer_array_t pmix_component_map = {{0}};
+pmix_pointer_array_t mca_types = {{0}};
 
 const char *pmix_info_type_base = "base";
 
@@ -70,8 +72,6 @@ int main(int argc, char *argv[])
     bool acted = false;
     bool want_all = false;
     int i;
-    pmix_pointer_array_t mca_types;
-    pmix_pointer_array_t component_map;
     pmix_info_component_map_t *map;
 
     /* protect against problems if someone passes us thru a pipe
@@ -84,13 +84,19 @@ int main(int argc, char *argv[])
     }
 
     /* initialize install dirs code */
-    if (PMIX_SUCCESS != (ret = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+    if (PMIX_SUCCESS
+        != (ret = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework,
+                                               PMIX_MCA_BASE_OPEN_DEFAULT))) {
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, ret);
         return ret;
     }
     if (PMIX_SUCCESS != (ret = pmix_pinstall_dirs_base_init(NULL, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, ret);
         return ret;
     }
@@ -119,35 +125,33 @@ int main(int argc, char *argv[])
     pmix_info_cmd_line = PMIX_NEW(pmix_cmd_line_t);
     if (NULL == pmix_info_cmd_line) {
         ret = errno;
-        pmix_show_help("help-pmix-info.txt", "lib-call-fail", true,
-                       "pmix_cmd_line_create", __FILE__, __LINE__, NULL);
+        pmix_show_help("help-pmix-info.txt", "lib-call-fail", true, "pmix_cmd_line_create",
+                       __FILE__, __LINE__, NULL);
         exit(ret);
     }
 
-    if (PMIX_SUCCESS != (ret = pmix_info_init(argc, argv, pmix_info_cmd_line))) {
+    if (PMIX_SUCCESS != (ret = pmix_info_init(argc, argv))) {
         return ret;
     }
 
     /* setup the mca_types array */
     PMIX_CONSTRUCT(&mca_types, pmix_pointer_array_t);
     pmix_pointer_array_init(&mca_types, 256, INT_MAX, 128);
-    pmix_info_register_types(&mca_types);
+    pmix_info_register_types();
 
     /* init the component map */
-    PMIX_CONSTRUCT(&component_map, pmix_pointer_array_t);
-    pmix_pointer_array_init(&component_map, 64, INT_MAX, 32);
+    PMIX_CONSTRUCT(&pmix_component_map, pmix_pointer_array_t);
+    pmix_pointer_array_init(&pmix_component_map, 64, INT_MAX, 32);
 
     /* Register PMIx's params */
-    if (PMIX_SUCCESS != (ret = pmix_info_register_framework_params(&component_map))) {
+    if (PMIX_SUCCESS != (ret = pmix_info_register_framework_params())) {
         if (PMIX_ERR_BAD_PARAM == ret) {
             /* output what we got */
-            pmix_info_do_params(true, pmix_cmd_line_is_taken(pmix_info_cmd_line, "internal"),
-                                &mca_types, &component_map, NULL);
+            pmix_info_do_params(true, pmix_cmd_line_is_taken(pmix_info_cmd_line, "internal"));
         }
         exit(1);
     }
 
-
     /* Execute the desired action(s) */
     want_all = pmix_cmd_line_is_taken(pmix_info_cmd_line, "all");
     if (want_all) {
@@ -155,7 +159,7 @@ int main(int argc, char *argv[])
         pmix_info_show_pmix_version(pmix_info_ver_full);
     }
     if (want_all || pmix_cmd_line_is_taken(pmix_info_cmd_line, "path")) {
-        pmix_info_do_path(want_all, pmix_info_cmd_line);
+        pmix_info_do_path(want_all);
         acted = true;
     }
     if (want_all || pmix_cmd_line_is_taken(pmix_info_cmd_line, "arch")) {
@@ -170,14 +174,13 @@ int main(int argc, char *argv[])
         pmix_info_do_config(true);
         acted = true;
     }
-    if (want_all || pmix_cmd_line_is_taken(pmix_info_cmd_line, "param") ||
-        pmix_cmd_line_is_taken(pmix_info_cmd_line, "params")) {
-        pmix_info_do_params(want_all, pmix_cmd_line_is_taken(pmix_info_cmd_line, "internal"),
-                            &mca_types, &component_map, pmix_info_cmd_line);
+    if (want_all || pmix_cmd_line_is_taken(pmix_info_cmd_line, "param")
+        || pmix_cmd_line_is_taken(pmix_info_cmd_line, "params")) {
+        pmix_info_do_params(want_all, pmix_cmd_line_is_taken(pmix_info_cmd_line, "internal"));
         acted = true;
     }
     if (pmix_cmd_line_is_taken(pmix_info_cmd_line, "type")) {
-        pmix_info_do_type(pmix_info_cmd_line);
+        pmix_info_do_type();
         acted = true;
     }
 
@@ -190,22 +193,22 @@ int main(int argc, char *argv[])
         pmix_info_do_arch();
         pmix_info_do_hostname();
         pmix_info_do_config(false);
-        pmix_info_show_component_version(&mca_types, &component_map, pmix_info_type_all,
-                                         pmix_info_component_all, pmix_info_ver_full,
-                                         pmix_info_ver_all);
+        pmix_info_show_component_version(pmix_info_type_all, pmix_info_component_all,
+                                         pmix_info_ver_full, pmix_info_ver_all);
     }
 
-
     /* All done */
     pmix_info_close_components();
     PMIX_RELEASE(pmix_info_cmd_line);
     PMIX_DESTRUCT(&mca_types);
-    for (i=0; i < component_map.size; i++) {
-        if (NULL != (map = (pmix_info_component_map_t*)pmix_pointer_array_get_item(&component_map, i))) {
+    for (i = 0; i < pmix_component_map.size; i++) {
+        if (NULL
+            != (map = (pmix_info_component_map_t *) pmix_pointer_array_get_item(&pmix_component_map,
+                                                                                i))) {
             PMIX_RELEASE(map);
         }
     }
-    PMIX_DESTRUCT(&component_map);
+    PMIX_DESTRUCT(&pmix_component_map);
 
     pmix_info_finalize();
 
