@@ -18,6 +18,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -34,26 +35,29 @@
 #include "pmix_config.h"
 #include "include/pmix_common.h"
 
-#include <stdio.h>
 #include <errno.h>
+#include <stdio.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif  /* HAVE_UNISTD_H */
+#    include <unistd.h>
+#endif /* HAVE_UNISTD_H */
 #include <stdlib.h>
 #ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif  /* HAVE_SYS_STAT_H */
+#    include <sys/stat.h>
+#endif /* HAVE_SYS_STAT_H */
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif  /* HAVE_SYS_TYPES_H */
+#    include <sys/types.h>
+#endif /* HAVE_SYS_TYPES_H */
 #ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif  /* HAVE_SYS_WAIT_H */
+#    include <sys/wait.h>
+#endif /* HAVE_SYS_WAIT_H */
 #include <string.h>
 #ifdef HAVE_DIRENT_H
-#include <dirent.h>
-#endif  /* HAVE_DIRENT_H */
+#    include <dirent.h>
+#endif /* HAVE_DIRENT_H */
 
+#include "src/mca/base/base.h"
+#include "src/mca/pinstalldirs/base/base.h"
+#include "src/runtime/pmix_rte.h"
 #include "src/threads/threads.h"
 #include "src/util/basename.h"
 #include "src/util/cmd_line.h"
@@ -61,13 +65,10 @@
 #include "src/util/output.h"
 #include "src/util/pmix_environ.h"
 #include "src/util/show_help.h"
-#include "src/mca/base/base.h"
-#include "src/mca/pinstalldirs/base/base.h"
-#include "src/runtime/pmix_rte.h"
 
-#include "src/include/pmix_globals.h"
-#include "include/pmix_tool.h"
 #include "include/pmix.h"
+#include "include/pmix_tool.h"
+#include "src/include/pmix_globals.h"
 
 typedef struct {
     pmix_lock_t lock;
@@ -117,44 +118,24 @@ typedef struct {
 
 pmix_ps_globals_t pmix_ps_globals = {0};
 
-pmix_cmd_line_init_t cmd_line_opts[] = {
-    { NULL,
-      'h', NULL, "help",
-      0,
-      &pmix_ps_globals.help, PMIX_CMD_LINE_TYPE_BOOL,
-      "This help message" },
+pmix_cmd_line_init_t cmd_line_opts[]
+    = {{NULL, 'h', NULL, "help", 0, &pmix_ps_globals.help, PMIX_CMD_LINE_TYPE_BOOL,
+        "This help message"},
 
-    { NULL,
-      '\0', NULL, "parseable",
-      0,
-      &pmix_ps_globals.parseable, PMIX_CMD_LINE_TYPE_BOOL,
-      "Provide parseable output" },
+       {NULL, '\0', NULL, "parseable", 0, &pmix_ps_globals.parseable, PMIX_CMD_LINE_TYPE_BOOL,
+        "Provide parseable output"},
 
-    { NULL,
-      '\0', NULL, "nspace",
-      0,
-     &pmix_ps_globals.nspace, PMIX_CMD_LINE_TYPE_STRING,
-      "Nspace of job whose status is being requested" },
+       {NULL, '\0', NULL, "nspace", 0, &pmix_ps_globals.nspace, PMIX_CMD_LINE_TYPE_STRING,
+        "Nspace of job whose status is being requested"},
 
-    { NULL,
-      'p', NULL, "pid",
-      1,
-      &pmix_ps_globals.pid, PMIX_CMD_LINE_TYPE_INT,
-      "Specify pid of starter to be contacted (default is to system server" },
+       {NULL, 'p', NULL, "pid", 1, &pmix_ps_globals.pid, PMIX_CMD_LINE_TYPE_INT,
+        "Specify pid of launcher to be contacted (default is to system server"},
 
-    { NULL,
-      'n', NULL, "nodes",
-      0,
-      &pmix_ps_globals.nodes, PMIX_CMD_LINE_TYPE_BOOL,
-      "Display Node Information" },
+       {NULL, 'n', NULL, "nodes", 0, &pmix_ps_globals.nodes, PMIX_CMD_LINE_TYPE_BOOL,
+        "Display Node Information"},
 
-    /* End of list */
-    { NULL,
-      '\0', NULL, NULL,
-      0,
-      NULL, PMIX_CMD_LINE_TYPE_NULL,
-      NULL }
-};
+       /* End of list */
+       {NULL, '\0', NULL, NULL, 0, NULL, PMIX_CMD_LINE_TYPE_NULL, NULL}};
 
 /* this is a callback function for the PMIx_Query
  * API. The query will callback with a status indicating
@@ -168,13 +149,10 @@ pmix_cmd_line_init_t cmd_line_opts[] = {
  * Once we have dealt with the returned data, we must
  * call the release_fn so that the PMIx library can
  * cleanup */
-static void cbfunc(pmix_status_t status,
-                   pmix_info_t *info, size_t ninfo,
-                   void *cbdata,
-                   pmix_release_cbfunc_t release_fn,
-                   void *release_cbdata)
+static void querycbfunc(pmix_status_t status, pmix_info_t *info, size_t ninfo, void *cbdata,
+                        pmix_release_cbfunc_t release_fn, void *release_cbdata)
 {
-    myquery_data_t *mq = (myquery_data_t*)cbdata;
+    myquery_data_t *mq = (myquery_data_t *) cbdata;
     size_t n;
 
     /* save the returned info - the PMIx library "owns" it
@@ -183,7 +161,7 @@ static void cbfunc(pmix_status_t status,
     if (0 < ninfo) {
         PMIX_INFO_CREATE(mq->info, ninfo);
         mq->ninfo = ninfo;
-        for (n=0; n < ninfo; n++) {
+        for (n = 0; n < ninfo; n++) {
             fprintf(stderr, "Transferring %s\n", info[n].key);
             PMIX_INFO_XFER(&mq->info[n], &info[n]);
         }
@@ -202,13 +180,10 @@ static void cbfunc(pmix_status_t status,
 /* this is the event notification function we pass down below
  * when registering for general events - i.e.,, the default
  * handler. */
-static void notification_fn(size_t evhdlr_registration_id,
-                            pmix_status_t status,
-                            const pmix_proc_t *source,
-                            pmix_info_t info[], size_t ninfo,
+static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
+                            const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                             pmix_info_t results[], size_t nresults,
-                            pmix_event_notification_cbfunc_fn_t cbfunc,
-                            void *cbdata)
+                            pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
     /* this example doesn't do anything with default events */
     if (NULL != cbfunc) {
@@ -223,22 +198,19 @@ static void notification_fn(size_t evhdlr_registration_id,
  * to the registered event. The index is used later on to deregister
  * an event handler - if we don't explicitly deregister it, then the
  * PMIx server will do so when it see us exit */
-static void evhandler_reg_callbk(pmix_status_t status,
-                                 size_t evhandler_ref,
-                                 void *cbdata)
+static void evhandler_reg_callbk(pmix_status_t status, size_t evhandler_ref, void *cbdata)
 {
-    mylock_t *lock = (mylock_t*)cbdata;
+    mylock_t *lock = (mylock_t *) cbdata;
 
     if (PMIX_SUCCESS != status) {
         fprintf(stderr, "Client %s:%d EVENT HANDLER REGISTRATION FAILED WITH STATUS %d, ref=%lu\n",
-                   myproc.nspace, myproc.rank, status, (unsigned long)evhandler_ref);
+                myproc.nspace, myproc.rank, status, (unsigned long) evhandler_ref);
     }
     lock->status = status;
     PMIX_WAKEUP_THREAD(&lock->lock);
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
     pmix_status_t rc = PMIX_SUCCESS;
     pmix_info_t *info;
@@ -258,13 +230,19 @@ main(int argc, char *argv[])
     }
 
     /* initialize install dirs code */
-    if (PMIX_SUCCESS != (rc = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+    if (PMIX_SUCCESS
+        != (rc = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework,
+                                              PMIX_MCA_BASE_OPEN_DEFAULT))) {
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, rc);
         return rc;
     }
     if (PMIX_SUCCESS != (rc = pmix_pinstall_dirs_base_init(NULL, 0))) {
-        fprintf(stderr, "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, returned %d instead of PMIX_SUCCESS)\n",
+        fprintf(stderr,
+                "pmix_pinstalldirs_base_init() failed -- process will likely abort (%s:%d, "
+                "returned %d instead of PMIX_SUCCESS)\n",
                 __FILE__, __LINE__, rc);
         return rc;
     }
@@ -299,8 +277,7 @@ main(int argc, char *argv[])
 
     if (PMIX_SUCCESS != rc) {
         if (PMIX_ERR_SILENT != rc) {
-            fprintf(stderr, "%s: command line error (%s)\n", argv[0],
-                    PMIx_Error_string(rc));
+            fprintf(stderr, "%s: command line error (%s)\n", argv[0], PMIx_Error_string(rc));
         }
         return rc;
     }
@@ -308,8 +285,7 @@ main(int argc, char *argv[])
     if (pmix_ps_globals.help) {
         char *str, *args = NULL;
         args = pmix_cmd_line_get_usage_msg(&cmd_line);
-        str = pmix_show_help_string("help-pps.txt", "usage", true,
-                                    args);
+        str = pmix_show_help_string("help-pps.txt", "usage", true, args);
         if (NULL != str) {
             printf("%s", str);
             free(str);
@@ -334,8 +310,8 @@ main(int argc, char *argv[])
 
     /* register a default event handler */
     PMIX_CONSTRUCT_LOCK(&mylock.lock);
-    PMIx_Register_event_handler(NULL, 0, NULL, 0,
-                                notification_fn, evhandler_reg_callbk, (void*)&mylock);
+    PMIx_Register_event_handler(NULL, 0, NULL, 0, notification_fn, evhandler_reg_callbk,
+                                (void *) &mylock);
     PMIX_WAIT_THREAD(&mylock.lock);
     PMIX_DESTRUCT_LOCK(&mylock.lock);
 
@@ -353,7 +329,7 @@ main(int argc, char *argv[])
     myquery_data.ninfo = 0;
     /* execute the query */
     fprintf(stderr, "pps: querying nspaces\n");
-    if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(query, nq, cbfunc, (void*)&myquery_data))) {
+    if (PMIX_SUCCESS != (rc = PMIx_Query_info_nb(query, nq, querycbfunc, (void *) &myquery_data))) {
         fprintf(stderr, "PMIx_Query_info failed: %d\n", rc);
         goto done;
     }
@@ -364,7 +340,8 @@ main(int argc, char *argv[])
      * a comma-delimited list of nspaces */
     if (1 != myquery_data.ninfo) {
         /* this is an error */
-        fprintf(stderr, "PMIx Query returned an incorrect number of results: %lu\n", myquery_data.ninfo);
+        fprintf(stderr, "PMIx Query returned an incorrect number of results: %lu\n",
+                myquery_data.ninfo);
         PMIX_INFO_FREE(myquery_data.info, myquery_data.ninfo);
         goto done;
     }
@@ -374,7 +351,7 @@ main(int argc, char *argv[])
     /***************
      * Cleanup
      ***************/
-  done:
+done:
     PMIx_tool_finalize();
 
     return rc;
