@@ -6,12 +6,13 @@
  *                         reserved.
  * Copyright (c) 2011-2014 Los Alamos National Security, LLC.  All rights
  *                         reserved.
- * Copyright (c) 2014-2018 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015-2018 Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2016      Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -20,16 +21,16 @@
  *
  */
 
-#include <src/include/pmix_config.h>
+#include "src/include/pmix_config.h"
 
-#include <src/include/pmix_stdint.h>
-#include <src/include/hash_string.h>
+#include "src/include/hash_string.h"
+#include "src/include/pmix_stdint.h"
 
 #include <string.h>
 
-#include "src/include/pmix_globals.h"
 #include "src/class/pmix_hash_table.h"
 #include "src/class/pmix_pointer_array.h"
+#include "src/include/pmix_globals.h"
 #include "src/mca/bfrops/bfrops.h"
 #include "src/util/error.h"
 #include "src/util/output.h"
@@ -56,31 +57,25 @@ static void pddes(pmix_proc_data_t *p)
 {
     PMIX_LIST_DESTRUCT(&p->data);
 }
-static PMIX_CLASS_INSTANCE(pmix_proc_data_t,
-                           pmix_list_item_t,
-                           pdcon, pddes);
+static PMIX_CLASS_INSTANCE(pmix_proc_data_t, pmix_list_item_t, pdcon, pddes);
 
-static pmix_kval_t* lookup_keyval(pmix_list_t *data,
-                                  const char *key);
-static pmix_proc_data_t* lookup_proc(pmix_hash_table_t *jtable,
-                                     uint64_t id, bool create);
+static pmix_kval_t *lookup_keyval(pmix_list_t *data, const char *key);
+static pmix_proc_data_t *lookup_proc(pmix_hash_table_t *jtable, uint64_t id, bool create);
 
-pmix_status_t pmix_hash_store(pmix_hash_table_t *table,
-                              pmix_rank_t rank, pmix_kval_t *kin)
+pmix_status_t pmix_hash_store(pmix_hash_table_t *table, pmix_rank_t rank, pmix_kval_t *kin)
 {
     pmix_proc_data_t *proc_data;
     uint64_t id;
     pmix_kval_t *hv;
 
-    pmix_output_verbose(10, pmix_globals.debug_output,
-                        "HASH:STORE rank %d key %s",
-                        rank, (NULL == kin) ? "NULL KVAL" : kin->key);
+    pmix_output_verbose(10, pmix_globals.debug_output, "HASH:STORE rank %d key %s", rank,
+                        (NULL == kin) ? "NULL KVAL" : kin->key);
 
     if (NULL == kin) {
         return PMIX_ERR_BAD_PARAM;
     }
 
-    id = (uint64_t)rank;
+    id = (uint64_t) rank;
 
     /* lookup the proc data object for this proc - create
      * it if we don't already have it */
@@ -102,8 +97,8 @@ pmix_status_t pmix_hash_store(pmix_hash_table_t *table,
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
-                              const char *key, pmix_value_t **kvs)
+pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank, const char *key,
+                              pmix_value_t **kvs)
 {
     pmix_status_t rc = PMIX_SUCCESS;
     pmix_proc_data_t *proc_data;
@@ -114,11 +109,10 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
     size_t ninfo, n;
     pmix_value_t *val;
 
-    pmix_output_verbose(10, pmix_globals.debug_output,
-                        "HASH:FETCH rank %d key %s",
-                        rank, (NULL == key) ? "NULL" : key);
+    pmix_output_verbose(10, pmix_globals.debug_output, "HASH:FETCH rank %d key %s", rank,
+                        (NULL == key) ? "NULL" : key);
 
-    id = (uint64_t)rank;
+    id = (uint64_t) rank;
 
     /* - PMIX_RANK_UNDEF should return following statuses
      *     PMIX_ERR_PROC_ENTRY_NOT_FOUND | PMIX_SUCCESS
@@ -126,12 +120,12 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
      *     PMIX_ERR_PROC_ENTRY_NOT_FOUND | PMIX_ERR_NOT_FOUND | PMIX_SUCCESS
      * special logic is basing on these statuses on a client and a server */
     if (PMIX_RANK_UNDEF == rank) {
-        rc = pmix_hash_table_get_first_key_uint64(table, &id,
-                (void**)&proc_data, (void**)&node);
+        rc = pmix_hash_table_get_first_key_uint64(table, &id, (void **) &proc_data,
+                                                  (void **) &node);
         if (PMIX_SUCCESS != rc) {
             pmix_output_verbose(10, pmix_globals.debug_output,
-                                "HASH:FETCH proc data for rank %d not found",
-                                rank);
+                                "HASH:FETCH[%s:%d] proc data for rank %d not found", __func__,
+                                __LINE__, rank);
             return PMIX_ERR_PROC_ENTRY_NOT_FOUND;
         }
     }
@@ -140,8 +134,8 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
         proc_data = lookup_proc(table, id, false);
         if (NULL == proc_data) {
             pmix_output_verbose(10, pmix_globals.debug_output,
-                                "HASH:FETCH proc data for rank %d not found",
-                                rank);
+                                "HASH:FETCH[%s:%d] proc data for rank %d not found", __func__,
+                                __LINE__, rank);
             return PMIX_ERR_PROC_ENTRY_NOT_FOUND;
         }
 
@@ -150,12 +144,12 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
         if (NULL == key) {
             /* we will return the data as an array of pmix_info_t
              * in the kvs pmix_value_t */
-            val = (pmix_value_t*)malloc(sizeof(pmix_value_t));
+            val = (pmix_value_t *) malloc(sizeof(pmix_value_t));
             if (NULL == val) {
                 return PMIX_ERR_NOMEM;
             }
             val->type = PMIX_DATA_ARRAY;
-            val->data.darray = (pmix_data_array_t*)malloc(sizeof(pmix_data_array_t));
+            val->data.darray = (pmix_data_array_t *) malloc(sizeof(pmix_data_array_t));
             if (NULL == val->data.darray) {
                 PMIX_VALUE_RELEASE(val);
                 return PMIX_ERR_NOMEM;
@@ -170,8 +164,8 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
                 return PMIX_ERR_NOMEM;
             }
             /* copy the list elements */
-            n=0;
-            PMIX_LIST_FOREACH(hv, &proc_data->data, pmix_kval_t) {
+            n = 0;
+            PMIX_LIST_FOREACH (hv, &proc_data->data, pmix_kval_t) {
                 pmix_strncpy(info[n].key, hv->key, PMIX_MAX_KEYLEN);
                 pmix_value_xfer(&info[n].value, hv->value);
                 ++n;
@@ -185,8 +179,7 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
             hv = lookup_keyval(&proc_data->data, key);
             if (NULL != hv) {
                 /* create the copy */
-                PMIX_BFROPS_COPY(rc, pmix_globals.mypeer,
-                                 (void**)kvs, hv->value, PMIX_VALUE);
+                PMIX_BFROPS_COPY(rc, pmix_globals.mypeer, (void **) kvs, hv->value, PMIX_VALUE);
                 if (PMIX_SUCCESS != rc) {
                     PMIX_ERROR_LOG(rc);
                     return rc;
@@ -199,11 +192,12 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
             }
         }
 
-        rc = pmix_hash_table_get_next_key_uint64(table, &id,
-                (void**)&proc_data, node, (void**)&node);
+        rc = pmix_hash_table_get_next_key_uint64(table, &id, (void **) &proc_data, node,
+                                                 (void **) &node);
         if (PMIX_SUCCESS != rc) {
             pmix_output_verbose(10, pmix_globals.debug_output,
-                                "HASH:FETCH data for key %s not found", key);
+                                "%s:%d HASH:FETCH data for key %s not found", __func__, __LINE__,
+                                key);
             return PMIX_ERR_PROC_ENTRY_NOT_FOUND;
         }
     }
@@ -211,8 +205,8 @@ pmix_status_t pmix_hash_fetch(pmix_hash_table_t *table, pmix_rank_t rank,
     return rc;
 }
 
-pmix_status_t pmix_hash_fetch_by_key(pmix_hash_table_t *table, const char *key,
-                                     pmix_rank_t *rank, pmix_value_t **kvs, void **last)
+pmix_status_t pmix_hash_fetch_by_key(pmix_hash_table_t *table, const char *key, pmix_rank_t *rank,
+                                     pmix_value_t **kvs, void **last)
 {
     pmix_status_t rc = PMIX_SUCCESS;
     pmix_proc_data_t *proc_data;
@@ -230,22 +224,20 @@ pmix_status_t pmix_hash_fetch_by_key(pmix_hash_table_t *table, const char *key,
     }
 
     if (key) {
-        rc = pmix_hash_table_get_first_key_uint64(table, &id,
-                (void**)&proc_data, (void**)&node);
+        rc = pmix_hash_table_get_first_key_uint64(table, &id, (void **) &proc_data,
+                                                  (void **) &node);
         key_r = key;
     } else {
-        rc = pmix_hash_table_get_next_key_uint64(table, &id,
-                (void**)&proc_data, node, (void**)&node);
+        rc = pmix_hash_table_get_next_key_uint64(table, &id, (void **) &proc_data, node,
+                                                 (void **) &node);
     }
 
-    pmix_output_verbose(10, pmix_globals.debug_output,
-                        "HASH:FETCH BY KEY rank %d key %s",
-                        (int)id, key_r);
+    pmix_output_verbose(10, pmix_globals.debug_output, "HASH:FETCH BY KEY rank %d key %s", (int) id,
+                        key_r);
 
     if (PMIX_SUCCESS != rc) {
         pmix_output_verbose(10, pmix_globals.debug_output,
-                            "HASH:FETCH proc data for key %s not found",
-                            key_r);
+                            "HASH:FETCH proc data for key %s not found", key_r);
         return PMIX_ERR_PROC_ENTRY_NOT_FOUND;
     }
 
@@ -253,8 +245,7 @@ pmix_status_t pmix_hash_fetch_by_key(pmix_hash_table_t *table, const char *key,
     hv = lookup_keyval(&proc_data->data, key_r);
     if (hv) {
         /* create the copy */
-        PMIX_BFROPS_COPY(rc, pmix_globals.mypeer,
-                         (void**)kvs, hv->value, PMIX_VALUE);
+        PMIX_BFROPS_COPY(rc, pmix_globals.mypeer, (void **) kvs, hv->value, PMIX_VALUE);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             return rc;
@@ -263,14 +254,13 @@ pmix_status_t pmix_hash_fetch_by_key(pmix_hash_table_t *table, const char *key,
         return PMIX_ERR_NOT_FOUND;
     }
 
-    *rank = (int)id;
+    *rank = (int) id;
     *last = node;
 
     return PMIX_SUCCESS;
 }
 
-pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table,
-                                    pmix_rank_t rank, const char *key)
+pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table, pmix_rank_t rank, const char *key)
 {
     pmix_status_t rc = PMIX_SUCCESS;
     pmix_proc_data_t *proc_data;
@@ -278,19 +268,19 @@ pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table,
     uint64_t id;
     char *node;
 
-    id = (uint64_t)rank;
+    id = (uint64_t) rank;
 
     /* if the rank is wildcard, we want to apply this to
      * all rank entries */
     if (PMIX_RANK_WILDCARD == rank) {
-        rc = pmix_hash_table_get_first_key_uint64(table, &id,
-                (void**)&proc_data, (void**)&node);
+        rc = pmix_hash_table_get_first_key_uint64(table, &id, (void **) &proc_data,
+                                                  (void **) &node);
         while (PMIX_SUCCESS == rc) {
             if (NULL != proc_data) {
                 if (NULL == key) {
                     PMIX_RELEASE(proc_data);
                 } else {
-                    PMIX_LIST_FOREACH(kv, &proc_data->data, pmix_kval_t) {
+                    PMIX_LIST_FOREACH (kv, &proc_data->data, pmix_kval_t) {
                         if (0 == strcmp(key, kv->key)) {
                             pmix_list_remove_item(&proc_data->data, &kv->super);
                             PMIX_RELEASE(kv);
@@ -299,8 +289,8 @@ pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table,
                     }
                 }
             }
-            rc = pmix_hash_table_get_next_key_uint64(table, &id,
-                    (void**)&proc_data, node, (void**)&node);
+            rc = pmix_hash_table_get_next_key_uint64(table, &id, (void **) &proc_data, node,
+                                                     (void **) &node);
         }
         return PMIX_SUCCESS;
     }
@@ -313,7 +303,7 @@ pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table,
 
     /* if key is NULL, remove all data for this proc */
     if (NULL == key) {
-        while (NULL != (kv = (pmix_kval_t*)pmix_list_remove_first(&proc_data->data))) {
+        while (NULL != (kv = (pmix_kval_t *) pmix_list_remove_first(&proc_data->data))) {
             PMIX_RELEASE(kv);
         }
         /* remove the proc_data object itself from the jtable */
@@ -324,7 +314,7 @@ pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table,
     }
 
     /* remove this item */
-    PMIX_LIST_FOREACH(kv, &proc_data->data, pmix_kval_t) {
+    PMIX_LIST_FOREACH (kv, &proc_data->data, pmix_kval_t) {
         if (0 == strcmp(key, kv->key)) {
             pmix_list_remove_item(&proc_data->data, &kv->super);
             PMIX_RELEASE(kv);
@@ -338,12 +328,11 @@ pmix_status_t pmix_hash_remove_data(pmix_hash_table_t *table,
 /**
  * Find data for a given key in a given pmix_list_t.
  */
-static pmix_kval_t* lookup_keyval(pmix_list_t *data,
-                                  const char *key)
+static pmix_kval_t *lookup_keyval(pmix_list_t *data, const char *key)
 {
     pmix_kval_t *kv;
 
-    PMIX_LIST_FOREACH(kv, data, pmix_kval_t) {
+    PMIX_LIST_FOREACH (kv, data, pmix_kval_t) {
         if (0 == strcmp(key, kv->key)) {
             return kv;
         }
@@ -351,17 +340,15 @@ static pmix_kval_t* lookup_keyval(pmix_list_t *data,
     return NULL;
 }
 
-
 /**
  * Find proc_data_t container associated with given
  * pmix_identifier_t.
  */
-static pmix_proc_data_t* lookup_proc(pmix_hash_table_t *jtable,
-                                     uint64_t id, bool create)
+static pmix_proc_data_t *lookup_proc(pmix_hash_table_t *jtable, uint64_t id, bool create)
 {
     pmix_proc_data_t *proc_data = NULL;
 
-    pmix_hash_table_get_value_uint64(jtable, id, (void**)&proc_data);
+    pmix_hash_table_get_value_uint64(jtable, id, (void **) &proc_data);
     if (NULL == proc_data && create) {
         /* The proc clearly exists, so create a data structure for it */
         proc_data = PMIX_NEW(pmix_proc_data_t);
