@@ -17,6 +17,7 @@
  * Copyright (c) 2015-2016 Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2016-2020 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -29,66 +30,66 @@
 
 #include <string.h>
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#    include <unistd.h>
 #endif
 #include <errno.h>
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#    include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
+#    include <sys/socket.h>
 #endif
 #ifdef HAVE_SYS_SOCKIO_H
-#include <sys/sockio.h>
+#    include <sys/sockio.h>
 #endif
 #ifdef HAVE_SYS_IOCTL_H
-#include <sys/ioctl.h>
+#    include <sys/ioctl.h>
 #endif
 #ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
+#    include <netinet/in.h>
 #endif
 #ifdef HAVE_ARPA_INET_H
-#include <arpa/inet.h>
+#    include <arpa/inet.h>
 #endif
 #ifdef HAVE_NET_IF_H
-#include <net/if.h>
+#    include <net/if.h>
 #endif
 #ifdef HAVE_NETDB_H
-#include <netdb.h>
+#    include <netdb.h>
 #endif
 #ifdef HAVE_IFADDRS_H
-#include <ifaddrs.h>
+#    include <ifaddrs.h>
 #endif
 #include <ctype.h>
 
 #include "src/class/pmix_list.h"
+#include "src/util/argv.h"
 #include "src/util/error.h"
-#include "src/util/pif.h"
 #include "src/util/net.h"
 #include "src/util/output.h"
-#include "src/util/argv.h"
+#include "src/util/pif.h"
 #include "src/util/show_help.h"
 
 #include "src/mca/pif/base/base.h"
 
 #ifdef HAVE_STRUCT_SOCKADDR_IN
 
-#ifndef MIN
-#  define MIN(a,b)                ((a) < (b) ? (a) : (b))
-#endif
+#    ifndef MIN
+#        define MIN(a, b) ((a) < (b) ? (a) : (b))
+#    endif
 
 /*
  *  Look for interface by name and returns its address
  *  as a dotted decimal formatted string.
  */
 
-int pmix_ifnametoaddr(const char* if_name, struct sockaddr* addr, int length)
+int pmix_ifnametoaddr(const char *if_name, struct sockaddr *addr, int length)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (strcmp(intf->if_name, if_name) == 0) {
             memcpy(addr, &intf->if_addr, length);
             return PMIX_SUCCESS;
@@ -97,19 +98,18 @@ int pmix_ifnametoaddr(const char* if_name, struct sockaddr* addr, int length)
     return PMIX_ERROR;
 }
 
-
 /*
  *  Look for interface by name and returns its
  *  corresponding pmix_list index.
  */
 
-int pmix_ifnametoindex(const char* if_name)
+int pmix_ifnametoindex(const char *if_name)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (strcmp(intf->if_name, if_name) == 0) {
             return intf->if_index;
         }
@@ -117,19 +117,18 @@ int pmix_ifnametoindex(const char* if_name)
     return -1;
 }
 
-
 /*
  *  Look for interface by name and returns its
  *  corresponding kernel index.
  */
 
-int16_t pmix_ifnametokindex(const char* if_name)
+int16_t pmix_ifnametokindex(const char *if_name)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (strcmp(intf->if_name, if_name) == 0) {
             return intf->if_kernel_index;
         }
@@ -137,7 +136,6 @@ int16_t pmix_ifnametokindex(const char* if_name)
     return -1;
 }
 
-
 /*
  *  Look for interface by pmix_list index and returns its
  *  corresponding kernel index.
@@ -145,11 +143,11 @@ int16_t pmix_ifnametokindex(const char* if_name)
 
 int pmix_ifindextokindex(int if_index)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (if_index == intf->if_index) {
             return intf->if_kernel_index;
         }
@@ -157,15 +155,14 @@ int pmix_ifindextokindex(int if_index)
     return -1;
 }
 
-
 /*
  *  Attempt to resolve the adddress (given as either IPv4/IPv6 string
  *  or hostname) and lookup corresponding interface.
  */
 
-int pmix_ifaddrtoname(const char* if_addr, char* if_name, int length)
+int pmix_ifaddrtoname(const char *if_addr, char *if_name, int length)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
     int error;
     struct addrinfo hints, *res = NULL, *r;
 
@@ -184,41 +181,40 @@ int pmix_ifaddrtoname(const char* if_addr, char* if_name, int length)
 
     if (error) {
         if (NULL != res) {
-            freeaddrinfo (res);
+            freeaddrinfo(res);
         }
         return PMIX_ERR_NOT_FOUND;
     }
 
     for (r = res; r != NULL; r = r->ai_next) {
-        for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-            intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-            intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+        for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+             intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+             intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
 
             if (AF_INET == r->ai_family) {
                 struct sockaddr_in ipv4;
                 struct sockaddr_in *inaddr;
 
-                inaddr = (struct sockaddr_in*) &intf->if_addr;
-                memcpy (&ipv4, r->ai_addr, r->ai_addrlen);
+                inaddr = (struct sockaddr_in *) &intf->if_addr;
+                memcpy(&ipv4, r->ai_addr, r->ai_addrlen);
 
                 if (inaddr->sin_addr.s_addr == ipv4.sin_addr.s_addr) {
-                    pmix_strncpy(if_name, intf->if_name, length-1);
-                    freeaddrinfo (res);
+                    pmix_strncpy(if_name, intf->if_name, length - 1);
+                    freeaddrinfo(res);
                     return PMIX_SUCCESS;
                 }
-            }
-            else {
-                if (IN6_ARE_ADDR_EQUAL(&((struct sockaddr_in6*) &intf->if_addr)->sin6_addr,
-                    &((struct sockaddr_in6*) r->ai_addr)->sin6_addr)) {
-                    pmix_strncpy(if_name, intf->if_name, length-1);
-                    freeaddrinfo (res);
+            } else {
+                if (IN6_ARE_ADDR_EQUAL(&((struct sockaddr_in6 *) &intf->if_addr)->sin6_addr,
+                                       &((struct sockaddr_in6 *) r->ai_addr)->sin6_addr)) {
+                    pmix_strncpy(if_name, intf->if_name, length - 1);
+                    freeaddrinfo(res);
                     return PMIX_SUCCESS;
                 }
             }
         }
     }
     if (NULL != res) {
-        freeaddrinfo (res);
+        freeaddrinfo(res);
     }
 
     /* if we get here, it wasn't found */
@@ -230,9 +226,9 @@ int pmix_ifaddrtoname(const char* if_addr, char* if_name, int length)
  *  or hostname) and return the kernel index of the interface
  *  on the same network as the specified address
  */
-int16_t pmix_ifaddrtokindex(const char* if_addr)
+int16_t pmix_ifaddrtokindex(const char *if_addr)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
     int error;
     struct addrinfo hints, *res = NULL, *r;
     int if_kernel_index;
@@ -245,43 +241,46 @@ int16_t pmix_ifaddrtokindex(const char* if_addr)
 
     if (error) {
         if (NULL != res) {
-            freeaddrinfo (res);
+            freeaddrinfo(res);
         }
         return PMIX_ERR_NOT_FOUND;
     }
 
     for (r = res; r != NULL; r = r->ai_next) {
-        PMIX_LIST_FOREACH(intf, &pmix_if_list, pmix_pif_t) {
+        PMIX_LIST_FOREACH (intf, &pmix_if_list, pmix_pif_t) {
             if (AF_INET == r->ai_family && AF_INET == intf->af_family) {
                 struct sockaddr_in ipv4, intv4;
                 memset(&ipv4, 0, sizeof(struct sockaddr_in));
-                len = (r->ai_addrlen < sizeof(struct sockaddr_in)) ? r->ai_addrlen : sizeof(struct sockaddr_in);
+                len = (r->ai_addrlen < sizeof(struct sockaddr_in)) ? r->ai_addrlen
+                                                                   : sizeof(struct sockaddr_in);
                 memcpy(&ipv4, r->ai_addr, len);
                 memset(&intv4, 0, sizeof(struct sockaddr_in));
                 memcpy(&intv4, &intf->if_addr, sizeof(struct sockaddr_in));
-                if (pmix_net_samenetwork((struct sockaddr*)&ipv4, (struct sockaddr*)&intv4, intf->if_mask)) {
+                if (pmix_net_samenetwork((struct sockaddr *) &ipv4, (struct sockaddr *) &intv4,
+                                         intf->if_mask)) {
                     if_kernel_index = intf->if_kernel_index;
-                    freeaddrinfo (res);
+                    freeaddrinfo(res);
                     return if_kernel_index;
                 }
             } else if (AF_INET6 == r->ai_family && AF_INET6 == intf->af_family) {
                 struct sockaddr_in6 ipv6, intv6;
                 memset(&ipv6, 0, sizeof(struct sockaddr));
-                len = (r->ai_addrlen < sizeof(struct sockaddr_in6)) ? r->ai_addrlen : sizeof(struct sockaddr_in6);
+                len = (r->ai_addrlen < sizeof(struct sockaddr_in6)) ? r->ai_addrlen
+                                                                    : sizeof(struct sockaddr_in6);
                 memcpy(&ipv6, r->ai_addr, len);
                 memset(&intv6, 0, sizeof(struct sockaddr));
                 memcpy(&intv6, &intf->if_addr, sizeof(struct sockaddr_in6));
-                if (pmix_net_samenetwork((struct sockaddr*)&intv6,
-                                         (struct sockaddr*)&ipv6, intf->if_mask)) {
+                if (pmix_net_samenetwork((struct sockaddr *) &intv6, (struct sockaddr *) &ipv6,
+                                         intf->if_mask)) {
                     if_kernel_index = intf->if_kernel_index;
-                    freeaddrinfo (res);
+                    freeaddrinfo(res);
                     return if_kernel_index;
                 }
             }
         }
     }
     if (NULL != res) {
-        freeaddrinfo (res);
+        freeaddrinfo(res);
     }
     return PMIX_ERR_NOT_FOUND;
 }
@@ -295,7 +294,6 @@ int pmix_ifcount(void)
     return pmix_list_get_size(&pmix_if_list);
 }
 
-
 /*
  *  Return the pmix_list interface index for the first
  *  interface in our list.
@@ -305,13 +303,12 @@ int pmix_ifbegin(void)
 {
     pmix_pif_t *intf;
 
-    intf = (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
+    intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
     if (NULL != intf)
         return intf->if_index;
     return (-1);
 }
 
-
 /*
  *  Located the current position in the list by if_index and
  *  return the interface index of the next element in our list
@@ -322,78 +319,75 @@ int pmix_ifnext(int if_index)
 {
     pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
             do {
-                pmix_pif_t* if_next = (pmix_pif_t*)pmix_list_get_next(intf);
-                pmix_pif_t* if_end =  (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
+                pmix_pif_t *if_next = (pmix_pif_t *) pmix_list_get_next(intf);
+                pmix_pif_t *if_end = (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
                 if (if_next == if_end) {
                     return -1;
                 }
                 intf = if_next;
-            } while(intf->if_index == if_index);
+            } while (intf->if_index == if_index);
             return intf->if_index;
         }
     }
     return (-1);
 }
 
-
 /*
  *  Lookup the interface by pmix_list index and return the
  *  primary address assigned to the interface.
  */
 
-int pmix_ifindextoaddr(int if_index, struct sockaddr* if_addr, unsigned int length)
+int pmix_ifindextoaddr(int if_index, struct sockaddr *if_addr, unsigned int length)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-         intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-         intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
-            memcpy(if_addr, &intf->if_addr, MIN(length, sizeof (intf->if_addr)));
+            memcpy(if_addr, &intf->if_addr, MIN(length, sizeof(intf->if_addr)));
             return PMIX_SUCCESS;
         }
     }
     return PMIX_ERROR;
 }
 
-
 /*
  *  Lookup the interface by pmix_list kindex and return the
  *  primary address assigned to the interface.
  */
-int pmix_ifkindextoaddr(int if_kindex, struct sockaddr* if_addr, unsigned int length)
+int pmix_ifkindextoaddr(int if_kindex, struct sockaddr *if_addr, unsigned int length)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-         intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-         intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_kernel_index == if_kindex) {
-            memcpy(if_addr, &intf->if_addr, MIN(length, sizeof (intf->if_addr)));
+            memcpy(if_addr, &intf->if_addr, MIN(length, sizeof(intf->if_addr)));
             return PMIX_SUCCESS;
         }
     }
     return PMIX_ERROR;
 }
 
-
 /*
  *  Lookup the interface by pmix_list index and return the
  *  network mask assigned to the interface.
  */
 
-int pmix_ifindextomask(int if_index, uint32_t* if_mask, int length)
+int pmix_ifindextomask(int if_index, uint32_t *if_mask, int length)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
             memcpy(if_mask, &intf->if_mask, length);
             return PMIX_SUCCESS;
@@ -409,11 +403,11 @@ int pmix_ifindextomask(int if_index, uint32_t* if_mask, int length)
 
 int pmix_ifindextomac(int if_index, uint8_t mac[6])
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf = (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf = (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
             memcpy(mac, &intf->if_mac, 6);
             return PMIX_SUCCESS;
@@ -429,11 +423,11 @@ int pmix_ifindextomac(int if_index, uint8_t mac[6])
 
 int pmix_ifindextomtu(int if_index, int *mtu)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf = (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf = (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
             *mtu = intf->ifmtu;
             return PMIX_SUCCESS;
@@ -447,13 +441,13 @@ int pmix_ifindextomtu(int if_index, int *mtu)
  *  flags assigned to the interface.
  */
 
-int pmix_ifindextoflags(int if_index, uint32_t* if_flags)
+int pmix_ifindextoflags(int if_index, uint32_t *if_flags)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
             memcpy(if_flags, &intf->if_flags, sizeof(uint32_t));
             return PMIX_SUCCESS;
@@ -462,53 +456,48 @@ int pmix_ifindextoflags(int if_index, uint32_t* if_flags)
     return PMIX_ERROR;
 }
 
-
-
 /*
  *  Lookup the interface by pmix_list index and return
  *  the associated name.
  */
 
-int pmix_ifindextoname(int if_index, char* if_name, int length)
+int pmix_ifindextoname(int if_index, char *if_name, int length)
 {
     pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
-            pmix_strncpy(if_name, intf->if_name, length-1);
+            pmix_strncpy(if_name, intf->if_name, length - 1);
             return PMIX_SUCCESS;
         }
     }
     return PMIX_ERROR;
 }
 
-
 /*
  *  Lookup the interface by kernel index and return
  *  the associated name.
  */
 
-int pmix_ifkindextoname(int if_kindex, char* if_name, int length)
+int pmix_ifkindextoname(int if_kindex, char *if_name, int length)
 {
     pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_kernel_index == if_kindex) {
-            pmix_strncpy(if_name, intf->if_name, length-1);
+            pmix_strncpy(if_name, intf->if_name, length - 1);
             return PMIX_SUCCESS;
         }
     }
     return PMIX_ERROR;
 }
 
-
-#define ADDRLEN 100
-bool
-pmix_ifislocal(const char *hostname)
+#    define ADDRLEN 100
+bool pmix_ifislocal(const char *hostname)
 {
     char addrname[NI_MAXHOST]; /* should be larger than ADDRLEN, but I think
                                   they really mean IFNAMESIZE */
@@ -520,16 +509,16 @@ pmix_ifislocal(const char *hostname)
     return false;
 }
 
-static int parse_ipv4_dots(const char *addr, uint32_t* net, int* dots)
+static int parse_ipv4_dots(const char *addr, uint32_t *net, int *dots)
 {
     const char *start = addr, *end;
-    uint32_t n[]={0,0,0,0};
+    uint32_t n[] = {0, 0, 0, 0};
     int i;
 
     /* now assemble the address */
-    for( i = 0; i < 4; i++ ) {
-        n[i] = strtoul(start, (char**)&end, 10);
-        if( end == start ) {
+    for (i = 0; i < 4; i++) {
+        n[i] = strtoul(start, (char **) &end, 10);
+        if (end == start) {
             /* this is not an error, but indicates that
              * we were given a partial address - e.g.,
              * 192.168 - usually indicating an IP range
@@ -538,20 +527,20 @@ static int parse_ipv4_dots(const char *addr, uint32_t* net, int* dots)
             break;
         }
         /* did we read something sensible? */
-        if( n[i] > 255 ) {
+        if (n[i] > 255) {
             return PMIX_ERR_FABRIC_NOT_PARSEABLE;
         }
         /* skip all the . */
-        for( start = end; '\0' != *start; start++ )
-            if( '.' != *start ) break;
+        for (start = end; '\0' != *start; start++)
+            if ('.' != *start)
+                break;
     }
     *dots = i;
     *net = PMIX_PIF_ASSEMBLE_FABRIC(n[0], n[1], n[2], n[3]);
     return PMIX_SUCCESS;
 }
 
-int
-pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
+int pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
 {
     int pval, dots, rc = PMIX_SUCCESS;
     const char *ptr;
@@ -563,7 +552,7 @@ pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
 
         /* if entry includes mask, split that off */
         if (NULL != (ptr = strchr(inaddr, '/'))) {
-            ptr = ptr + 1;  /* skip the / */
+            ptr = ptr + 1; /* skip the / */
             /* is the mask a tuple? */
             if (NULL != strchr(ptr, '.')) {
                 /* yes - extract mask from it */
@@ -581,7 +570,7 @@ pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
             }
         } else {
             /* use the number of dots to determine it */
-            for (ptr = inaddr, pval = 0; '\0'!= *ptr; ptr++) {
+            for (ptr = inaddr, pval = 0; '\0' != *ptr; ptr++) {
                 if ('.' == *ptr) {
                     pval++;
                 }
@@ -592,11 +581,11 @@ pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
              */
             if (3 == pval) {
                 *mask = 0xFFFFFFFF;
-            } else if (2 == pval) {         /* 2 dots */
+            } else if (2 == pval) { /* 2 dots */
                 *mask = 0xFFFFFF00;
-            } else if (1 == pval) {  /* 1 dot */
+            } else if (1 == pval) { /* 1 dot */
                 *mask = 0xFFFF0000;
-            } else if (0 == pval) {  /* no dots */
+            } else if (0 == pval) { /* no dots */
                 *mask = 0xFF000000;
             } else {
                 pmix_output(0, "pmix_iftupletoaddr: unknown mask");
@@ -620,11 +609,11 @@ pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
 
 bool pmix_ifisloopback(int if_index)
 {
-    pmix_pif_t* intf;
+    pmix_pif_t *intf;
 
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
+    for (intf = (pmix_pif_t *) pmix_list_get_first(&pmix_if_list);
+         intf != (pmix_pif_t *) pmix_list_get_end(&pmix_if_list);
+         intf = (pmix_pif_t *) pmix_list_get_next(intf)) {
         if (intf->if_index == if_index) {
             if ((intf->if_flags & IFF_LOOPBACK) != 0) {
                 return true;
@@ -648,17 +637,18 @@ int pmix_ifmatches(int kidx, char **nets)
     uint32_t addr, netaddr, netmask;
 
     /* get the address info for the given network in case we need it */
-    if (PMIX_SUCCESS != (rc = pmix_ifkindextoaddr(kidx, (struct sockaddr*)&inaddr, sizeof(inaddr)))) {
+    if (PMIX_SUCCESS
+        != (rc = pmix_ifkindextoaddr(kidx, (struct sockaddr *) &inaddr, sizeof(inaddr)))) {
         return rc;
     }
     addr = ntohl(inaddr.sin_addr.s_addr);
 
-    for (i=0; NULL != nets[i]; i++) {
+    for (i = 0; NULL != nets[i]; i++) {
         /* if the specified interface contains letters in it, then it
          * was given as an interface name and not an IP tuple
          */
         named_if = false;
-        for (j=0; j < strlen(nets[i]); j++) {
+        for (j = 0; j < strlen(nets[i]); j++) {
             if (isalpha(nets[i][j]) && '.' != nets[i][j]) {
                 named_if = true;
                 break;
@@ -685,123 +675,77 @@ int pmix_ifmatches(int kidx, char **nets)
     return PMIX_ERR_NOT_FOUND;
 }
 
-void pmix_ifgetaliases(char ***aliases)
-{
-    pmix_pif_t* intf;
-    char ipv4[INET_ADDRSTRLEN];
-    struct sockaddr_in *addr;
-    char ipv6[INET6_ADDRSTRLEN];
-    struct sockaddr_in6 *addr6;
-
-    /* set default answer */
-    *aliases = NULL;
-
-    for (intf =  (pmix_pif_t*)pmix_list_get_first(&pmix_if_list);
-        intf != (pmix_pif_t*)pmix_list_get_end(&pmix_if_list);
-        intf =  (pmix_pif_t*)pmix_list_get_next(intf)) {
-        addr = (struct sockaddr_in*) &intf->if_addr;
-        /* ignore purely loopback interfaces */
-        if ((intf->if_flags & IFF_LOOPBACK) != 0) {
-            continue;
-        }
-        if (addr->sin_family == AF_INET) {
-            inet_ntop(AF_INET, &(addr->sin_addr.s_addr), ipv4, INET_ADDRSTRLEN);
-            pmix_argv_append_nosize(aliases, ipv4);
-        } else {
-            addr6 = (struct sockaddr_in6*) &intf->if_addr;
-            inet_ntop(AF_INET6, &(addr6->sin6_addr), ipv6, INET6_ADDRSTRLEN);
-            pmix_argv_append_nosize(aliases, ipv6);
-        }
-    }
-}
-
 #else /* HAVE_STRUCT_SOCKADDR_IN */
 
 /* if we don't have struct sockaddr_in, we don't have traditional
    ethernet devices.  Just make everything a no-op error call */
 
-int
-pmix_ifnametoaddr(const char* if_name,
-                  struct sockaddr* if_addr, int size)
+int pmix_ifnametoaddr(const char *if_name, struct sockaddr *if_addr, int size)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifaddrtoname(const char* if_addr,
-                  char* if_name, int size)
+int pmix_ifaddrtoname(const char *if_addr, char *if_name, int size)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifnametoindex(const char* if_name)
+int pmix_ifnametoindex(const char *if_name)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int16_t
-pmix_ifnametokindex(const char* if_name)
+int16_t pmix_ifnametokindex(const char *if_name)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifindextokindex(int if_index)
+int pmix_ifindextokindex(int if_index)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifcount(void)
+int pmix_ifcount(void)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifbegin(void)
+int pmix_ifbegin(void)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifnext(int if_index)
+int pmix_ifnext(int if_index)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifindextoname(int if_index, char* if_name, int length)
+int pmix_ifindextoname(int if_index, char *if_name, int length)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifkindextoname(int kif_index, char* if_name, int length)
+int pmix_ifkindextoname(int kif_index, char *if_name, int length)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifindextoaddr(int if_index, struct sockaddr* if_addr, unsigned int length)
+int pmix_ifindextoaddr(int if_index, struct sockaddr *if_addr, unsigned int length)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-int
-pmix_ifindextomask(int if_index, uint32_t* if_addr, int length)
+int pmix_ifindextomask(int if_index, uint32_t *if_addr, int length)
 {
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-bool
-pmix_ifislocal(const char *hostname)
+bool pmix_ifislocal(const char *hostname)
 {
     return false;
 }
 
-int
-pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
+int pmix_iftupletoaddr(const char *inaddr, uint32_t *net, uint32_t *mask)
 {
     return 0;
 }
@@ -811,10 +755,4 @@ int pmix_ifmatches(int idx, char **nets)
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
-void pmix_ifgetaliases(char ***aliases)
-{
-    /* set default answer */
-    *aliases = NULL;
-}
-
 #endif /* HAVE_STRUCT_SOCKADDR_IN */
