@@ -15,6 +15,7 @@
  * Copyright (c) 2011      Oak Ridge National Labs.  All rights reserved.
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Mellanox Technologies, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -28,8 +29,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <time.h>
+#include <unistd.h>
 
 #include "src/class/pmix_object.h"
 #include "src/util/output.h"
@@ -49,39 +50,36 @@ int main(int argc, char **argv)
 
     /* init us */
     if (PMIX_SUCCESS != (rc = PMIx_Init(&myproc, NULL, 0))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Init failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Init failed: %s", myproc.nspace, myproc.rank,
+                    PMIx_Error_string(rc));
         exit(rc);
     }
     pmix_output(0, "GWClient ns %s rank %d: Running", myproc.nspace, myproc.rank);
 
     /* look for network data */
     memset(&proc, 0, sizeof(pmix_proc_t));
-    (void)strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+    (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
     proc.rank = PMIX_RANK_WILDCARD;
 
-    if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, "my.net.key", NULL, 0, &val)) ||
-        PMIX_DATA_ARRAY != val->type ||
-        NULL == val->data.darray ||
-        NULL == val->data.darray->array) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get my.net.key failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+    if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, "my.net.key", NULL, 0, &val))
+        || PMIX_DATA_ARRAY != val->type || NULL == val->data.darray
+        || NULL == val->data.darray->array) {
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get my.net.key failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
     /* the returned value has all the network allocation info in a
      * pmix_data_array_t */
-    info = (pmix_info_t*)val->data.darray->array;
+    info = (pmix_info_t *) val->data.darray->array;
     ninfo = val->data.darray->size;
-    pmix_output(0, "Client ns %s rank %d: got network assignment:",
-                myproc.nspace, myproc.rank);
-    for (n=0; n < ninfo; n++) {
+    pmix_output(0, "Client ns %s rank %d: got network assignment:", myproc.nspace, myproc.rank);
+    for (n = 0; n < ninfo; n++) {
         if (PMIX_STRING == info[n].value.type) {
-            pmix_output(0, "\tKey: %s Value: %s",
-                        info[n].key, info[n].value.data.string);
+            pmix_output(0, "\tKey: %s Value: %s", info[n].key, info[n].value.data.string);
         } else if (PMIX_BYTE_OBJECT == info[n].value.type) {
             memcpy(seckey, info[n].value.data.bo.bytes, info[n].value.data.bo.size);
-            pmix_output(0, "\tKey: %s sec key: %ld.%ld",
-                        info[n].key, (long int)seckey[0], (long int)seckey[1]);
+            pmix_output(0, "\tKey: %s sec key: %ld.%ld", info[n].key, (long int) seckey[0],
+                        (long int) seckey[1]);
         }
     }
     PMIX_VALUE_RELEASE(val);
@@ -89,11 +87,12 @@ int main(int argc, char **argv)
     /* finalize us */
     pmix_output(0, "Client ns %s rank %d: Finalizing", myproc.nspace, myproc.rank);
     if (PMIX_SUCCESS != (rc = PMIx_Finalize(NULL, 0))) {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n",
-                myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
     } else {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n", myproc.nspace, myproc.rank);
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n",
+                myproc.nspace, myproc.rank);
     }
     fflush(stderr);
-    return(rc);
+    return (rc);
 }
