@@ -17,6 +17,7 @@
  * Copyright (c) 2015      Mellanox Technologies, Inc.  All rights reserved.
  * Copyright (c) 2019      Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -30,28 +31,26 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <time.h>
+#include <unistd.h>
 
 #include "src/class/pmix_object.h"
+#include "src/include/pmix_globals.h"
 #include "src/util/output.h"
 #include "src/util/printf.h"
-#include "src/include/pmix_globals.h"
 
 #define MAXCNT 1
 
 static volatile bool completed = false;
 static pmix_proc_t myproc;
 
-static void notification_fn(size_t evhdlr_registration_id,
-                            pmix_status_t status,
-                            const pmix_proc_t *source,
-                            pmix_info_t info[], size_t ninfo,
+static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
+                            const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                             pmix_info_t results[], size_t nresults,
-                            pmix_event_notification_cbfunc_fn_t cbfunc,
-                            void *cbdata)
+                            pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
-    pmix_output(0, "Client %s:%d NOTIFIED with status %s", myproc.nspace, myproc.rank, PMIx_Error_string(status));
+    pmix_output(0, "Client %s:%d NOTIFIED with status %s", myproc.nspace, myproc.rank,
+                PMIx_Error_string(status));
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, NULL, 0, NULL, NULL, cbdata);
     }
@@ -60,7 +59,7 @@ static void notification_fn(size_t evhdlr_registration_id,
 
 static void opcbfunc(pmix_status_t status, void *cbdata)
 {
-    volatile bool *active = (volatile bool*)cbdata;
+    volatile bool *active = (volatile bool *) cbdata;
     *active = false;
 }
 
@@ -71,24 +70,20 @@ static void opcbfunc(pmix_status_t status, void *cbdata)
  * to declare a use-specific notification callback point. In this case,
  * we are asking to know whenever a model is declared as a means
  * of testing server self-notification */
-static void model_callback(size_t evhdlr_registration_id,
-                           pmix_status_t status,
-                           const pmix_proc_t *source,
-                           pmix_info_t info[], size_t ninfo,
+static void model_callback(size_t evhdlr_registration_id, pmix_status_t status,
+                           const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                            pmix_info_t results[], size_t nresults,
-                           pmix_event_notification_cbfunc_fn_t cbfunc,
-                           void *cbdata)
+                           pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
     size_t n;
 
     /* just let us know it was received */
-    fprintf(stderr, "%s:%d Model event handler called with status %d(%s)\n",
-            myproc.nspace, myproc.rank, status, PMIx_Error_string(status));
-    for (n=0; n < ninfo; n++) {
+    fprintf(stderr, "%s:%d Model event handler called with status %d(%s)\n", myproc.nspace,
+            myproc.rank, status, PMIx_Error_string(status));
+    for (n = 0; n < ninfo; n++) {
         if (PMIX_STRING == info[n].value.type) {
-            fprintf(stderr, "%s:%d\t%s:\t%s\n",
-                    myproc.nspace, myproc.rank,
-                    info[n].key, info[n].value.data.string);
+            fprintf(stderr, "%s:%d\t%s:\t%s\n", myproc.nspace, myproc.rank, info[n].key,
+                    info[n].value.data.string);
         }
     }
 
@@ -117,6 +112,7 @@ int main(int argc, char **argv)
     char **peers;
     bool all_local, local;
     pmix_rank_t *locals = NULL;
+    pmix_topology_t topo;
 
     if (1 < argc) {
         if (0 == strcmp("-abort", argv[1])) {
@@ -129,18 +125,19 @@ int main(int argc, char **argv)
     PMIX_INFO_LOAD(&iptr[0], PMIX_PROGRAMMING_MODEL, "TEST", PMIX_STRING);
     PMIX_INFO_LOAD(&iptr[1], PMIX_MODEL_LIBRARY_NAME, "PMIX", PMIX_STRING);
     if (PMIX_SUCCESS != (rc = PMIx_Init(&myproc, iptr, 2))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Init failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Init failed: %s", myproc.nspace, myproc.rank,
+                    PMIx_Error_string(rc));
         exit(rc);
     }
     PMIX_INFO_FREE(iptr, 2);
-    pmix_output(0, "Client ns %s rank %d: Running on node %s", myproc.nspace, myproc.rank, pmix_globals.hostname);
+    pmix_output(0, "Client ns %s rank %d: Running on node %s", myproc.nspace, myproc.rank,
+                pmix_globals.hostname);
 
     /* test something */
     PMIX_LOAD_PROCID(&proc, myproc.nspace, PMIX_RANK_WILDCARD);
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_JOB_SIZE, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get job size failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get job size failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
     nprocs = val->data.uint32;
@@ -149,56 +146,74 @@ int main(int argc, char **argv)
 
     /* test something */
     if (PMIX_SUCCESS != (rc = PMIx_Get(&myproc, PMIX_SERVER_URI, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get server URI failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get server URI failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
     pmix_output(0, "CLIENT SERVER URI: %s", val->data.string);
     PMIX_VALUE_RELEASE(val);
 
     if (PMIX_SUCCESS != (rc = PMIx_Get(&myproc, PMIX_LOCAL_RANK, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get LOCAL RANK failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get LOCAL RANK failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
     pmix_output(0, "CLIENT LOCAL RANK: %u", val->data.uint16);
     PMIX_VALUE_RELEASE(val);
 
     if (PMIX_SUCCESS != (rc = PMIx_Get(&myproc, PMIX_HOSTNAME, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get HOSTNAME failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get HOSTNAME failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
     pmix_output(0, "CLIENT HOSTNAME: %s", val->data.string);
     PMIX_VALUE_RELEASE(val);
 
+    /* check if a security credential was given */
+    if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_CREDENTIAL, NULL, 0, &val))) {
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get CREDENTIAL failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
+    } else {
+        pmix_output(0, "CREDENTIAL: %s", val->data.string);
+        PMIX_VALUE_RELEASE(val);
+    }
+
+    /* get our topology */
+    PMIX_TOPOLOGY_CONSTRUCT(&topo);
+    rc = PMIx_Load_topology(&topo);
+    if (PMIX_SUCCESS != rc) {
+        pmix_output(0, "Client ns %s rank %d: Failed to load topology: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
+        exit(rc);
+    }
+    pmix_output(0, "Client ns %s rank %d: Topology source: %s", myproc.nspace, myproc.rank,
+                topo.source);
+
     /* register a handler specifically for when models declare */
     ninfo = 1;
     PMIX_INFO_CREATE(iptr, ninfo);
     PMIX_INFO_LOAD(&iptr[0], PMIX_EVENT_HDLR_NAME, "SIMPCLIENT-MODEL", PMIX_STRING);
     code = PMIX_MODEL_DECLARED;
-    PMIx_Register_event_handler(&code, 1, iptr, ninfo,
-                                model_callback, NULL, NULL);
+    PMIx_Register_event_handler(&code, 1, iptr, ninfo, model_callback, NULL, NULL);
     PMIX_INFO_FREE(iptr, ninfo);
 
     /* register our errhandler */
-    PMIx_Register_event_handler(NULL, 0, NULL, 0,
-                                notification_fn, NULL, NULL);
+    PMIx_Register_event_handler(NULL, 0, NULL, 0, notification_fn, NULL, NULL);
 
     /* put a few values */
-    (void)asprintf(&tmp, "%s-%d-internal", myproc.nspace, myproc.rank);
+    (void) asprintf(&tmp, "%s-%d-internal", myproc.nspace, myproc.rank);
     value.type = PMIX_UINT32;
     value.data.uint32 = 1234;
     if (PMIX_SUCCESS != (rc = PMIx_Store_internal(&myproc, tmp, &value))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Store_internal failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Store_internal failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
 
     /* get a list of our local peers */
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_LOCAL_PEERS, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get local peers failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get local peers failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         exit(rc);
     }
     /* split the returned string to get the rank of each local peer */
@@ -209,60 +224,60 @@ int main(int argc, char **argv)
         all_local = true;
     } else {
         all_local = false;
-        locals = (pmix_rank_t*)malloc(pmix_argv_count(peers) * sizeof(pmix_rank_t));
-        for (cnt=0; NULL != peers[cnt]; cnt++) {
+        locals = (pmix_rank_t *) malloc(pmix_argv_count(peers) * sizeof(pmix_rank_t));
+        for (cnt = 0; NULL != peers[cnt]; cnt++) {
             locals[cnt] = strtoul(peers[cnt], NULL, 10);
         }
     }
     pmix_argv_free(peers);
 
-    for (cnt=0; cnt < MAXCNT; cnt++) {
+    for (cnt = 0; cnt < MAXCNT; cnt++) {
         pmix_output(0, "Client %s:%d executing loop %d", myproc.nspace, myproc.rank, cnt);
-        (void)asprintf(&tmp, "%s-%d-local-%d", myproc.nspace, myproc.rank, cnt);
+        (void) asprintf(&tmp, "%s-%d-local-%d", myproc.nspace, myproc.rank, cnt);
         value.type = PMIX_UINT64;
         value.data.uint64 = 1234;
         if (PMIX_SUCCESS != (rc = PMIx_Put(PMIX_LOCAL, tmp, &value))) {
-            pmix_output(0, "Client ns %s rank %d: PMIx_Put internal failed: %s",
-                        myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d: PMIx_Put internal failed: %s", myproc.nspace,
+                        myproc.rank, PMIx_Error_string(rc));
             exit(rc);
         }
 
-        (void)asprintf(&tmp, "%s-%d-remote-%d", myproc.nspace, myproc.rank, cnt);
+        (void) asprintf(&tmp, "%s-%d-remote-%d", myproc.nspace, myproc.rank, cnt);
         value.type = PMIX_STRING;
         value.data.string = "1234";
         if (PMIX_SUCCESS != (rc = PMIx_Put(PMIX_REMOTE, tmp, &value))) {
-            pmix_output(0, "Client ns %s rank %d: PMIx_Put internal failed: %s",
-                        myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d: PMIx_Put internal failed: %s", myproc.nspace,
+                        myproc.rank, PMIx_Error_string(rc));
             exit(rc);
         }
 
         if (PMIX_SUCCESS != (rc = PMIx_Commit())) {
-            pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Commit failed: %s",
-                        myproc.nspace, myproc.rank, cnt, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Commit failed: %s", myproc.nspace,
+                        myproc.rank, cnt, PMIx_Error_string(rc));
             exit(rc);
         }
 
         /* call fence to ensure the data is received */
         PMIX_PROC_CONSTRUCT(&proc);
-        (void)strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+        (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
         proc.rank = PMIX_RANK_WILDCARD;
         if (PMIX_SUCCESS != (rc = PMIx_Fence(&proc, 1, NULL, 0))) {
-            pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Fence failed: %s",
-                        myproc.nspace, myproc.rank, cnt, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Fence failed: %s", myproc.nspace,
+                        myproc.rank, cnt, PMIx_Error_string(rc));
             exit(rc);
         }
 
         /* check the returned data */
-        (void)strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
-        for (j=0; j <= cnt; j++) {
-            for (n=0; n < nprocs; n++) {
+        (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+        for (j = 0; j <= cnt; j++) {
+            for (n = 0; n < nprocs; n++) {
                 proc.rank = n;
                 if (all_local) {
                     local = true;
                 } else {
                     local = false;
                     /* see if this proc is local to us */
-                    for (k=0; k < nlocal; k++) {
+                    for (k = 0; k < nlocal; k++) {
                         if (proc.rank == locals[k]) {
                             local = true;
                             break;
@@ -270,43 +285,52 @@ int main(int argc, char **argv)
                     }
                 }
                 if (local) {
-                    (void)asprintf(&tmp, "%s-%d-local-%d", myproc.nspace, n, j);
+                    (void) asprintf(&tmp, "%s-%d-local-%d", myproc.nspace, n, j);
                     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, tmp, NULL, 0, &val))) {
                         pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s failed: %s",
                                     myproc.nspace, myproc.rank, j, tmp, PMIx_Error_string(rc));
                         continue;
                     }
                     if (NULL == val) {
-                        pmix_output(0, "Client ns %s rank %d: NULL value returned",
-                                    myproc.nspace, myproc.rank);
+                        pmix_output(0, "Client ns %s rank %d: NULL value returned", myproc.nspace,
+                                    myproc.rank);
                         exit(1);
                     }
                     if (PMIX_UINT64 != val->type) {
-                        pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned wrong type: %d", myproc.nspace, myproc.rank, j, tmp, val->type);
+                        pmix_output(
+                            0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned wrong type: %d",
+                            myproc.nspace, myproc.rank, j, tmp, val->type);
                         PMIX_VALUE_RELEASE(val);
                         free(tmp);
                         exit(1);
                     }
                     if (1234 != val->data.uint64) {
-                        pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned wrong value: %d", myproc.nspace, myproc.rank, j, tmp, (int)val->data.uint64);
+                        pmix_output(
+                            0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned wrong value: %d",
+                            myproc.nspace, myproc.rank, j, tmp, (int) val->data.uint64);
                         PMIX_VALUE_RELEASE(val);
                         free(tmp);
                         exit(1);
                     }
-                    pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned correct", myproc.nspace, myproc.rank, j, tmp);
+                    pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned correct",
+                                myproc.nspace, myproc.rank, j, tmp);
                     PMIX_VALUE_RELEASE(val);
                     free(tmp);
 
                     /* now check that we don't get data for a remote proc - note that we
                      * always can get our own remote data as we published it */
                     if (proc.rank != myproc.rank) {
-                        (void)asprintf(&tmp, "%s-%d-remote-%d", proc.nspace, n, j);
+                        (void) asprintf(&tmp, "%s-%d-remote-%d", proc.nspace, n, j);
                         if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, tmp, NULL, 0, &val))) {
                             /* this data should _not_ be found as we are on the same node
                              * and the data was "put" with a PMIX_REMOTE scope */
-                            pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned correct", myproc.nspace, myproc.rank, j, tmp);
+                            pmix_output(0,
+                                        "Client ns %s rank %d cnt %d: PMIx_Get %s returned correct",
+                                        myproc.nspace, myproc.rank, j, tmp);
                         } else {
-                            pmix_output(0, "ERROR: Client ns %s rank %d cnt %d: PMIx_Get %s returned remote data for a local proc",
+                            pmix_output(0,
+                                        "ERROR: Client ns %s rank %d cnt %d: PMIx_Get %s returned "
+                                        "remote data for a local proc",
                                         myproc.nspace, myproc.rank, j, tmp);
                             exit(1);
                         }
@@ -317,12 +341,14 @@ int main(int argc, char **argv)
                     }
                 } else {
                     val = NULL;
-                    (void)asprintf(&tmp, "%s-%d-remote-%d", proc.nspace, n, j);
+                    (void) asprintf(&tmp, "%s-%d-remote-%d", proc.nspace, n, j);
                     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, tmp, NULL, 0, &val))) {
-                        pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned correct", myproc.nspace, myproc.rank, j, tmp);
-                    } else {
-                        pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s failed for remote proc",
+                        pmix_output(0, "Client ns %s rank %d cnt %d: PMIx_Get %s returned correct",
                                     myproc.nspace, myproc.rank, j, tmp);
+                    } else {
+                        pmix_output(
+                            0, "Client ns %s rank %d cnt %d: PMIx_Get %s failed for remote proc",
+                            myproc.nspace, myproc.rank, j, tmp);
                         exit(1);
                     }
                     if (NULL != val) {
@@ -335,16 +361,18 @@ int main(int argc, char **argv)
     }
 
     /* now get the data blob for myself */
-    pmix_output(0, "Client ns %s rank %d testing internal modex blob",
-                myproc.nspace, myproc.rank);
+    pmix_output(0, "Client ns %s rank %d testing internal modex blob", myproc.nspace, myproc.rank);
     if (PMIX_SUCCESS == (rc = PMIx_Get(&myproc, NULL, NULL, 0, &val))) {
         if (PMIX_DATA_ARRAY != val->type) {
-            pmix_output(0, "Client ns %s rank %d did not return an array for its internal modex blob",
+            pmix_output(0,
+                        "Client ns %s rank %d did not return an array for its internal modex blob",
                         myproc.nspace, myproc.rank);
             PMIX_VALUE_RELEASE(val);
             exit(1);
         } else if (PMIX_INFO != val->data.darray->type) {
-            pmix_output(0, "Client ns %s rank %d returned an internal modex array of type %s instead of PMIX_INFO",
+            pmix_output(0,
+                        "Client ns %s rank %d returned an internal modex array of type %s instead "
+                        "of PMIX_INFO",
                         myproc.nspace, myproc.rank, PMIx_Data_type_string(val->data.darray->type));
             PMIX_VALUE_RELEASE(val);
             exit(1);
@@ -354,8 +382,8 @@ int main(int argc, char **argv)
             PMIX_VALUE_RELEASE(val);
             exit(1);
         } else {
-            pmix_info_t *iptr = (pmix_info_t*)val->data.darray->array;
-            for (n=0; n < val->data.darray->size; n++) {
+            iptr = (pmix_info_t *) val->data.darray->array;
+            for (n = 0; n < val->data.darray->size; n++) {
                 pmix_output(0, "\tKey: %s", iptr[n].key);
             }
             PMIX_VALUE_RELEASE(val);
@@ -370,10 +398,10 @@ int main(int argc, char **argv)
     PMIX_INFO_CONSTRUCT(&info);
     PMIX_INFO_LOAD(&info, PMIX_LOG_STDERR, "test log msg\n", PMIX_STRING);
     active = true;
-    rc = PMIx_Log_nb(&info, 1, NULL, 0, opcbfunc, (void*)&active);
+    rc = PMIx_Log_nb(&info, 1, NULL, 0, opcbfunc, (void *) &active);
     if (PMIX_SUCCESS != rc) {
-        pmix_output(0, "Client ns %s rank %d - log_nb returned %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d - log_nb returned %s", myproc.nspace, myproc.rank,
+                    PMIx_Error_string(rc));
         exit(rc);
     } else {
         while (active) {
@@ -387,7 +415,7 @@ int main(int argc, char **argv)
         if (0 == myproc.rank) {
             PMIx_Abort(PMIX_ERR_PROC_REQUESTED_ABORT, "CALLING ABORT", NULL, 0);
         } else {
-            while(!completed) {
+            while (!completed) {
                 usleep(10);
             }
         }
@@ -396,11 +424,12 @@ int main(int argc, char **argv)
     /* finalize us */
     pmix_output(0, "Client ns %s rank %d: Finalizing", myproc.nspace, myproc.rank);
     if (PMIX_SUCCESS != (rc = PMIx_Finalize(NULL, 0))) {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n",
-                myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
     } else {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n", myproc.nspace, myproc.rank);
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n",
+                myproc.nspace, myproc.rank);
     }
     fflush(stderr);
-    return(rc);
+    return (rc);
 }
