@@ -15,6 +15,7 @@
  * Copyright (c) 2011      Oak Ridge National Labs.  All rights reserved.
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Mellanox Technologies, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -28,8 +29,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <time.h>
+#include <unistd.h>
 
 #include "src/class/pmix_object.h"
 #include "src/util/output.h"
@@ -40,33 +41,28 @@
 static volatile bool completed = false;
 static pmix_proc_t myproc;
 
-static void notification_fn(size_t evhdlr_registration_id,
-                            pmix_status_t status,
-                            const pmix_proc_t *source,
-                            pmix_info_t info[], size_t ninfo,
+static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
+                            const pmix_proc_t *source, pmix_info_t info[], size_t ninfo,
                             pmix_info_t results[], size_t nresults,
-                            pmix_event_notification_cbfunc_fn_t cbfunc,
-                            void *cbdata)
+                            pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
-    pmix_output(0, "Client %s:%d NOTIFIED with status %s", myproc.nspace, myproc.rank, PMIx_Error_string(status));
+    pmix_output(0, "Client %s:%d NOTIFIED with status %s", myproc.nspace, myproc.rank,
+                PMIx_Error_string(status));
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, NULL, 0, NULL, NULL, cbdata);
     }
     completed = true;
 }
 
-static void errhandler_reg_callbk(pmix_status_t status,
-                                  size_t errhandler_ref,
-                                  void *cbdata)
+static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, void *cbdata)
 {
-    volatile bool *active = (volatile bool*)cbdata;
+    volatile bool *active = (volatile bool *) cbdata;
 
     pmix_output(0, "Client: ERRHANDLER REGISTRATION CALLBACK CALLED WITH STATUS %d, ref=%lu",
-                status, (unsigned long)errhandler_ref);
+                status, (unsigned long) errhandler_ref);
     *active = false;
 }
 
-
 int main(int argc, char **argv)
 {
     int rc;
@@ -79,36 +75,36 @@ int main(int argc, char **argv)
 
     /* init us */
     if (PMIX_SUCCESS != (rc = PMIx_Init(&myproc, NULL, 0))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Init failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Init failed: %s", myproc.nspace, myproc.rank,
+                    PMIx_Error_string(rc));
         exit(rc);
     }
     pmix_output(0, "Client ns %s rank %d: Running", myproc.nspace, myproc.rank);
 
     /* test something */
-    (void)strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+    (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
     proc.rank = PMIX_RANK_WILDCARD;
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_JOB_SIZE, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get failed: %s", myproc.nspace, myproc.rank,
+                    PMIx_Error_string(rc));
         exit(rc);
     }
     PMIX_VALUE_RELEASE(val);
 
     /* register our errhandler */
     active = true;
-    PMIx_Register_event_handler(NULL, 0, NULL, 0,
-                                notification_fn, errhandler_reg_callbk, (void*)&active);
+    PMIx_Register_event_handler(NULL, 0, NULL, 0, notification_fn, errhandler_reg_callbk,
+                                (void *) &active);
     while (active) {
         usleep(10);
     }
 
     /* get our job size */
-    (void)strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+    (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
     proc.rank = PMIX_RANK_WILDCARD;
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_JOB_SIZE, NULL, 0, &val))) {
-        pmix_output(0, "Client ns %s rank %d: PMIx_Get job size failed: %s",
-                    myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        pmix_output(0, "Client ns %s rank %d: PMIx_Get job size failed: %s", myproc.nspace,
+                    myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     nprocs = val->data.uint32;
@@ -121,12 +117,12 @@ int main(int argc, char **argv)
         n = 1;
         PMIX_INFO_LOAD(&info, PMIX_TIMEOUT, &n, PMIX_UINT32);
         PMIX_PROC_CONSTRUCT(&proc);
-        (void)strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+        (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
         proc.rank = PMIX_RANK_WILDCARD;
         pmix_output(0, "TEST FENCE TIMEOUT");
         if (PMIX_ERR_TIMEOUT != (rc = PMIx_Fence(&proc, 1, &info, 1))) {
-            pmix_output(0, "Client ns %s rank %d: PMIx_Fence did not timeout: %s",
-                        myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d: PMIx_Fence did not timeout: %s", myproc.nspace,
+                        myproc.rank, PMIx_Error_string(rc));
             goto done;
         }
         pmix_output(0, "FENCE TIMEOUT SUCCEEDED");
@@ -134,8 +130,8 @@ int main(int argc, char **argv)
         /* check timeout on connect */
         pmix_output(0, "TEST CONNECT TIMEOUT");
         if (PMIX_ERR_TIMEOUT != (rc = PMIx_Connect(&proc, 1, &info, 1))) {
-            pmix_output(0, "Client ns %s rank %d: PMIx_Connect did not timeout: %s",
-                        myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d: PMIx_Connect did not timeout: %s", myproc.nspace,
+                        myproc.rank, PMIx_Error_string(rc));
             goto done;
         }
         pmix_output(0, "CONNECT TIMEOUT SUCCEEDED");
@@ -144,8 +140,8 @@ int main(int argc, char **argv)
         proc.rank = 1;
         pmix_output(0, "TEST GET TIMEOUT");
         if (PMIX_ERR_TIMEOUT == (rc = PMIx_Get(&proc, "1234", &info, 1, &val))) {
-            pmix_output(0, "Client ns %s rank %d: PMIx_Get did not timeout: %s",
-                        myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+            pmix_output(0, "Client ns %s rank %d: PMIx_Get did not timeout: %s", myproc.nspace,
+                        myproc.rank, PMIx_Error_string(rc));
             goto done;
         }
         pmix_output(0, "GET TIMEOUT SUCCEEDED");
@@ -154,15 +150,16 @@ int main(int argc, char **argv)
         sleep(5);
     }
 
- done:
+done:
     /* finalize us */
     pmix_output(0, "Client ns %s rank %d: Finalizing", myproc.nspace, myproc.rank);
     if (PMIX_SUCCESS != (rc = PMIx_Finalize(NULL, 0))) {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n",
-                myproc.nspace, myproc.rank, PMIx_Error_string(rc));
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
     } else {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n", myproc.nspace, myproc.rank);
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n",
+                myproc.nspace, myproc.rank);
     }
     fflush(stderr);
-    return(rc);
+    return (rc);
 }
