@@ -4,6 +4,7 @@
  *                         All rights reserved.
  * Copyright (c) 2015-2018 Mellanox Technologies, Inc.
  *                         All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -16,21 +17,19 @@
 #include "include/pmix_common.h"
 
 #include "test_common.h"
+#include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
-#include <ctype.h>
 
 int pmix_test_verbose = 0;
-test_params params;
-
 FILE *file;
 
 #define OUTPUT_MAX 1024
-char *pmix_test_output_prepare(const char *fmt, ... )
+char *pmix_test_output_prepare(const char *fmt, ...)
 {
     static char output[OUTPUT_MAX];
     va_list args;
-    va_start( args, fmt );
+    va_start(args, fmt);
     memset(output, 0, sizeof(output));
     vsnprintf(output, OUTPUT_MAX - 1, fmt, args);
     va_end(args);
@@ -43,12 +42,12 @@ void parse_cmd(int argc, char **argv, test_params *params)
 
     /* set output to stderr by default */
     file = stdout;
-    if( params->nspace != NULL ) {
+    if (params->nspace != NULL) {
         params->nspace = NULL;
     }
 
     /* parse user options */
-    for (i=1; i < argc; i++) {
+    for (i = 1; i < argc; i++) {
         if (0 == strcmp(argv[i], "--n") || 0 == strcmp(argv[i], "-n")) {
             i++;
             if (NULL != argv[i]) {
@@ -67,29 +66,41 @@ void parse_cmd(int argc, char **argv, test_params *params)
             fprintf(stderr, "\t-v       verbose output\n");
             fprintf(stderr, "\t-t <>    set timeout\n");
             fprintf(stderr, "\t-o out   redirect clients logs to file out.<rank>\n");
-            fprintf(stderr, "\t--early-fail    force client process with rank 0 to fail before PMIX_Init.\n");
-            fprintf(stderr, "\t--ns-dist n1:n2:n3   register n namespaces (3 in this example) each with ni ranks (n1, n2 or n3).\n");
-            fprintf(stderr, "\t--fence \"[<data_exchange><blocking> | ns0:ranks;ns1:ranks...][...]\"  specify fences in different configurations.\n");
-            fprintf(stderr, "\t--use-same-keys relative to the --fence option: put the same keys in the interim between multiple fences.\n");
+            fprintf(
+                stderr,
+                "\t--early-fail    force client process with rank 0 to fail before PMIX_Init.\n");
+            fprintf(stderr, "\t--ns-dist n1:n2:n3   register n namespaces (3 in this example) each "
+                            "with ni ranks (n1, n2 or n3).\n");
+            fprintf(stderr,
+                    "\t--fence \"[<data_exchange><blocking> | ns0:ranks;ns1:ranks...][...]\"  "
+                    "specify fences in different configurations.\n");
+            fprintf(stderr, "\t--use-same-keys relative to the --fence option: put the same keys "
+                            "in the interim between multiple fences.\n");
             fprintf(stderr, "\t--job-fence  test fence inside its own namespace.\n");
-            fprintf(stderr, "\t-c       relative to the --job-fence option: fence[_nb] callback shall include all collected data\n");
-            fprintf(stderr, "\t-nb      relative to the --job-fence option: use non-blocking fence\n");
-            fprintf(stderr, "\t--noise \"[ns0:ranks;ns1:ranks...]\"  add system noise to specified processes.\n");
+            fprintf(stderr, "\t-c       relative to the --job-fence option: fence[_nb] callback "
+                            "shall include all collected data\n");
+            fprintf(stderr,
+                    "\t-nb      relative to the --job-fence option: use non-blocking fence\n");
+            fprintf(stderr, "\t--noise \"[ns0:ranks;ns1:ranks...]\"  add system noise to specified "
+                            "processes.\n");
             fprintf(stderr, "\t--test-publish     test publish/lookup/unpublish api.\n");
             fprintf(stderr, "\t--test-spawn       test spawn api.\n");
             fprintf(stderr, "\t--test-connect     test connect/disconnect api.\n");
             fprintf(stderr, "\t--test-resolve-peers    test resolve_peers api.\n");
             fprintf(stderr, "\t--test-error test error handling api.\n");
-            fprintf(stderr, "\t--test-replace N:k0,k1,...,k(N-1)   test key replace for N keys, k0,k1,k(N-1) - key indexes to replace  \n");
-            fprintf(stderr, "\t--test-internal N  test store internal key, N - number of internal keys\n");
-            fprintf(stderr, "\t--gds <external gds name>           set GDS module \"--gds hash|ds12\", default is hash\n");
+            fprintf(stderr, "\t--test-replace N:k0,k1,...,k(N-1)   test key replace for N keys, "
+                            "k0,k1,k(N-1) - key indexes to replace  \n");
+            fprintf(stderr,
+                    "\t--test-internal N  test store internal key, N - number of internal keys\n");
+            fprintf(stderr, "\t--gds <external gds name>           set GDS module \"--gds "
+                            "hash|ds12\", default is hash\n");
             exit(0);
         } else if (0 == strcmp(argv[i], "--exec") || 0 == strcmp(argv[i], "-e")) {
             i++;
             if (NULL != argv[i]) {
                 params->binary = strdup(argv[i]);
             }
-        } else if (0 == strcmp(argv[i], "--nservers") || 0 == strcmp(argv[i], "-s")){
+        } else if (0 == strcmp(argv[i], "--nservers") || 0 == strcmp(argv[i], "-s")) {
             i++;
             if (NULL != argv[i]) {
                 params->nservers = atoi(argv[i]);
@@ -98,23 +109,23 @@ void parse_cmd(int argc, char **argv, test_params *params)
                 fprintf(stderr, "Only support up to 2 servers\n");
                 exit(1);
             }
-        } else if( 0 == strcmp(argv[i], "--verbose") || 0 == strcmp(argv[i],"-v") ){
+        } else if (0 == strcmp(argv[i], "--verbose") || 0 == strcmp(argv[i], "-v")) {
             TEST_VERBOSE_ON();
             params->verbose = 1;
         } else if (0 == strcmp(argv[i], "--timeout") || 0 == strcmp(argv[i], "-t")) {
             i++;
             if (NULL != argv[i]) {
                 params->timeout = atoi(argv[i]);
-                if( params->timeout == 0 ){
+                if (params->timeout == 0) {
                     params->timeout = TEST_DEFAULT_TIMEOUT;
                 }
             }
-        } else if( 0 == strcmp(argv[i], "-o")) {
+        } else if (0 == strcmp(argv[i], "-o")) {
             i++;
             if (NULL != argv[i]) {
                 params->prefix = strdup(argv[i]);
             }
-        } else if( 0 == strcmp(argv[i], "-s")) {
+        } else if (0 == strcmp(argv[i], "-s")) {
             i++;
             if (NULL != argv[i]) {
                 params->nspace = strdup(argv[i]);
@@ -124,7 +135,7 @@ void parse_cmd(int argc, char **argv, test_params *params)
             if (NULL != argv[i]) {
                 params->rank = strtol(argv[i], NULL, 10);
             }
-        } else if( 0 == strcmp(argv[i], "--early-fail") ){
+        } else if (0 == strcmp(argv[i], "--early-fail")) {
             params->early_fail = 1;
         } else if (0 == strcmp(argv[i], "--fence")) {
             i++;
@@ -174,35 +185,36 @@ void parse_cmd(int argc, char **argv, test_params *params)
             if (NULL != argv[i]) {
                 params->base_rank = strtol(argv[i], NULL, 10);
             }
-        } else if( 0 == strcmp(argv[i], "--test-publish") ){
+        } else if (0 == strcmp(argv[i], "--test-publish")) {
             params->test_publish = 1;
-        } else if( 0 == strcmp(argv[i], "--test-spawn") ){
+        } else if (0 == strcmp(argv[i], "--test-spawn")) {
             params->test_spawn = 1;
-        } else if( 0 == strcmp(argv[i], "--test-connect") ){
+        } else if (0 == strcmp(argv[i], "--test-connect")) {
             params->test_connect = 1;
-        } else if( 0 == strcmp(argv[i], "--test-resolve-peers") ){
+        } else if (0 == strcmp(argv[i], "--test-resolve-peers")) {
             params->test_resolve_peers = 1;
-        } else if( 0 == strcmp(argv[i], "--test-error") ){
+        } else if (0 == strcmp(argv[i], "--test-error")) {
             params->test_error = 1;
-        } else if(0 == strcmp(argv[i], "--test-replace") ) {
+        } else if (0 == strcmp(argv[i], "--test-replace")) {
             i++;
             if (NULL != argv[i] && (*argv[i] != '-')) {
                 params->key_replace = strdup(argv[i]);
                 if (0 != parse_replace(params->key_replace, 0, NULL)) {
-                    fprintf(stderr, "Incorrect --test-replace option format: %s\n", params->key_replace);
+                    fprintf(stderr, "Incorrect --test-replace option format: %s\n",
+                            params->key_replace);
                     exit(1);
                 }
             } else {
                 params->key_replace = strdup(TEST_REPLACE_DEFAULT);
             }
-        } else if(0 == strcmp(argv[i], "--test-internal")) {
+        } else if (0 == strcmp(argv[i], "--test-internal")) {
             i++;
             if ((NULL != argv[i]) && (*argv[i] != '-')) {
                 params->test_internal = strtol(argv[i], NULL, 10);
             } else {
                 params->test_internal = 1;
             }
-        } else if(0 == strcmp(argv[i], "--gds") ) {
+        } else if (0 == strcmp(argv[i], "--gds")) {
             i++;
             params->gds_mode = strdup(argv[i]);
         }
@@ -240,33 +252,34 @@ void parse_cmd(int argc, char **argv, test_params *params)
         }
     }
 
-    if( params->collect_bad ){
+    if (params->collect_bad) {
         params->collect = params->rank % 2;
     }
 
     // Fix rank if running under SLURM
-    if( PMIX_RANK_UNDEF == params->rank ){
+    if (PMIX_RANK_UNDEF == params->rank) {
         char *ranklist = getenv("SLURM_GTIDS");
         char *rankno = getenv("SLURM_LOCALID");
-        if( NULL != ranklist && NULL != rankno ){
-            char **argv = pmix_argv_split(ranklist, ',');
-            int count = pmix_argv_count(argv);
+        if (NULL != ranklist && NULL != rankno) {
+            char **myargv = pmix_argv_split(ranklist, ',');
+            int count = pmix_argv_count(myargv);
             int rankidx = strtoul(rankno, NULL, 10);
-            if( rankidx >= count ){
-                fprintf(stderr, "It feels like we are running under SLURM:\n\t"
+            if (rankidx >= count) {
+                fprintf(stderr,
+                        "It feels like we are running under SLURM:\n\t"
                         "SLURM_GTIDS=%s, SLURM_LOCALID=%s\nbut env vars are conflicting\n",
                         ranklist, rankno);
                 exit(1);
             }
-            params->rank = strtoul(argv[rankidx], NULL, 10);
-            pmix_argv_free(argv);
+            params->rank = strtoul(myargv[rankidx], NULL, 10);
+            pmix_argv_free(myargv);
         }
     }
 
     // Fix namespace if running under SLURM
-    if( NULL == params->nspace ){
+    if (NULL == params->nspace) {
         char *nspace = getenv("PMIX_NAMESPACE");
-        if( NULL != nspace ){
+        if (NULL != nspace) {
             params->nspace = strdup(nspace);
         }
     }
@@ -284,17 +297,11 @@ static void fdes(fence_desc_t *p)
     PMIX_LIST_RELEASE(p->participants);
 }
 
-PMIX_CLASS_INSTANCE(fence_desc_t,
-                    pmix_list_item_t,
-                    fcon, fdes);
+PMIX_CLASS_INSTANCE(fence_desc_t, pmix_list_item_t, fcon, fdes);
 
-PMIX_CLASS_INSTANCE(participant_t,
-                    pmix_list_item_t,
-                    NULL, NULL);
+PMIX_CLASS_INSTANCE(participant_t, pmix_list_item_t, NULL, NULL);
 
-PMIX_CLASS_INSTANCE(key_replace_t,
-                    pmix_list_item_t,
-                    NULL, NULL);
+PMIX_CLASS_INSTANCE(key_replace_t, pmix_list_item_t, NULL, NULL);
 
 static int ns_id = -1;
 static fence_desc_t *fdesc = NULL;
@@ -303,15 +310,16 @@ pmix_list_t test_fences;
 pmix_list_t *noise_range = NULL;
 pmix_list_t key_replace;
 
-#define CHECK_STRTOL_VAL(val, str, store) do {                  \
-    if (0 == val) {                                             \
-        if (0 != strncmp(str, "0", 1)) {                         \
-            if (!store) {                                       \
-                return 1;                                       \
-            }                                                   \
-        }                                                       \
-    }                                                           \
-} while (0)
+#define CHECK_STRTOL_VAL(val, str, store)    \
+    do {                                     \
+        if (0 == val) {                      \
+            if (0 != strncmp(str, "0", 1)) { \
+                if (!store) {                \
+                    return 1;                \
+                }                            \
+            }                                \
+        }                                    \
+    } while (0)
 
 static int parse_token(char *str, int step, int store)
 {
@@ -346,7 +354,7 @@ static int parse_token(char *str, int step, int store)
                 }
                 str++;
             }
-            if (0 < parse_token(pch+1, 1, store)) {
+            if (0 < parse_token(pch + 1, 1, store)) {
                 if (!store) {
                     return 1;
                 }
@@ -374,7 +382,7 @@ static int parse_token(char *str, int step, int store)
                     return 1;
                 }
             }
-            pch = strtok (NULL, ";");
+            pch = strtok(NULL, ";");
         }
         break;
     case 2:
@@ -385,7 +393,7 @@ static int parse_token(char *str, int step, int store)
             while (' ' == *str) {
                 str++;
             }
-            ns_id = (int)(strtol(str, NULL, 10));
+            ns_id = (int) (strtol(str, NULL, 10));
             CHECK_STRTOL_VAL(ns_id, str, store);
             if (0 < parse_token(pch, 3, store)) {
                 if (!store) {
@@ -406,7 +414,7 @@ static int parse_token(char *str, int step, int store)
             /* all ranks from namespace participate */
             if (store && NULL != participants) {
                 proc = PMIX_NEW(participant_t);
-                (void)snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
+                (void) snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
                 proc->proc.rank = PMIX_RANK_WILDCARD;
                 pmix_list_append(participants, &proc->super);
             }
@@ -415,31 +423,33 @@ static int parse_token(char *str, int step, int store)
             if (',' == *str && 0 != count) {
                 *str = '\0';
                 if (-1 != remember) {
-                    rank = (int)(strtol(str-count, NULL, 10));
-                    CHECK_STRTOL_VAL(rank, str-count, store);
+                    rank = (int) (strtol(str - count, NULL, 10));
+                    CHECK_STRTOL_VAL(rank, str - count, store);
                     for (i = remember; i < rank; i++) {
                         if (store && NULL != participants) {
                             proc = PMIX_NEW(participant_t);
-                            (void)snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
+                            (void) snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d",
+                                            TEST_NAMESPACE, ns_id);
                             proc->proc.rank = i;
                             pmix_list_append(participants, &proc->super);
                         }
                     }
                     remember = -1;
                 }
-                rank = (int)(strtol(str-count, NULL, 10));
-                CHECK_STRTOL_VAL(rank, str-count, store);
+                rank = (int) (strtol(str - count, NULL, 10));
+                CHECK_STRTOL_VAL(rank, str - count, store);
                 if (store && NULL != participants) {
                     proc = PMIX_NEW(participant_t);
-                    (void)snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
+                    (void) snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE,
+                                    ns_id);
                     proc->proc.rank = rank;
                     pmix_list_append(participants, &proc->super);
                 }
                 count = -1;
             } else if ('-' == *str && 0 != count) {
                 *str = '\0';
-                remember = (int)(strtol(str-count, NULL, 10));
-                CHECK_STRTOL_VAL(remember, str-count, store);
+                remember = (int) (strtol(str - count, NULL, 10));
+                CHECK_STRTOL_VAL(remember, str - count, store);
                 count = -1;
             }
             str++;
@@ -447,23 +457,24 @@ static int parse_token(char *str, int step, int store)
         }
         if (0 != count) {
             if (-1 != remember) {
-                rank = (int)(strtol(str-count, NULL, 10));
-                CHECK_STRTOL_VAL(rank, str-count, store);
+                rank = (int) (strtol(str - count, NULL, 10));
+                CHECK_STRTOL_VAL(rank, str - count, store);
                 for (i = remember; i < rank; i++) {
                     if (store && NULL != participants) {
                         proc = PMIX_NEW(participant_t);
-                        (void)snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
+                        (void) snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE,
+                                        ns_id);
                         proc->proc.rank = i;
                         pmix_list_append(participants, &proc->super);
                     }
                 }
                 remember = -1;
             }
-            rank = (int)(strtol(str-count, NULL, 10));
-            CHECK_STRTOL_VAL(rank, str-count, store);
+            rank = (int) (strtol(str - count, NULL, 10));
+            CHECK_STRTOL_VAL(rank, str - count, store);
             if (store && NULL != participants) {
                 proc = PMIX_NEW(participant_t);
-                (void)snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
+                (void) snprintf(proc->proc.nspace, PMIX_MAX_NSLEN, "%s-%d", TEST_NAMESPACE, ns_id);
                 proc->proc.rank = rank;
                 pmix_list_append(participants, &proc->super);
             }
@@ -480,7 +491,7 @@ int parse_fence(char *fence_param, int store)
 {
     int ret = 0;
     char *tmp = strdup(fence_param);
-    char * pch, *ech;
+    char *pch, *ech;
 
     pch = strchr(tmp, '[');
     while (NULL != pch) {
@@ -504,7 +515,7 @@ int parse_noise(char *noise_param, int store)
 {
     int ret = 0;
     char *tmp = strdup(noise_param);
-    char * pch, *ech;
+    char *pch, *ech;
 
     pch = strchr(tmp, '[');
     if (NULL != pch) {
@@ -533,20 +544,20 @@ static int is_digit(const char *str)
 
     while (0 != *str) {
         if (!isdigit(*str)) {
-        return 0;
-        }
-        else {
+            return 0;
+        } else {
             str++;
         }
     }
     return 1;
 }
 
-int parse_replace(char *replace_param, int store, int *key_num) {
+int parse_replace(char *replace_param, int store, int *key_num)
+{
     int ret = 0;
     char *tmp = strdup(replace_param);
     char tmp_str[32];
-    char * pch, *ech;
+    char *pch, *ech;
     key_replace_t *item;
     int cnt = 0;
 
@@ -563,7 +574,7 @@ int parse_replace(char *replace_param, int store, int *key_num) {
         *key_num = cnt;
     }
 
-    while(NULL != pch) {
+    while (NULL != pch) {
         pch++;
         ech = strchr(pch, ',');
         if (strlen(pch) > 0) {
@@ -601,7 +612,7 @@ int get_total_ns_number(test_params params)
         char *pch = tmp;
         while (NULL != pch) {
             num++;
-            pch = strtok((1 == num ) ? tmp : NULL, ":");
+            pch = strtok((1 == num) ? tmp : NULL, ":");
         }
         num--;
         free(tmp);
@@ -609,7 +620,8 @@ int get_total_ns_number(test_params params)
     return num;
 }
 
-int get_all_ranks_from_namespace(test_params params, char *nspace, pmix_proc_t **ranks, size_t *nranks)
+int get_all_ranks_from_namespace(test_params params, char *nspace, pmix_proc_t **ranks,
+                                 size_t *nranks)
 {
     size_t num_ranks = 0;
     int num = -1;
@@ -617,27 +629,27 @@ int get_all_ranks_from_namespace(test_params params, char *nspace, pmix_proc_t *
     if (NULL == params.ns_dist) {
         *nranks = params.ns_size;
         PMIX_PROC_CREATE(*ranks, params.ns_size);
-        for (j = 0; j < (size_t)params.ns_size; j++) {
-            (void)strncpy((*ranks)[j].nspace, nspace, PMIX_MAX_NSLEN);
+        for (j = 0; j < (size_t) params.ns_size; j++) {
+            (void) strncpy((*ranks)[j].nspace, nspace, PMIX_MAX_NSLEN);
             (*ranks)[j].rank = j;
         }
     } else {
         char *tmp = strdup(params.ns_dist);
         char *pch = tmp;
-        int ns_id = (int)strtol(nspace + strlen(TEST_NAMESPACE) + 1, NULL, 10);
-        while (NULL != pch && num != ns_id) {
-            pch = strtok((-1 == num ) ? tmp : NULL, ":");
+        int myns_id = (int) strtol(nspace + strlen(TEST_NAMESPACE) + 1, NULL, 10);
+        while (NULL != pch && num != myns_id) {
+            pch = strtok((-1 == num) ? tmp : NULL, ":");
             if (NULL == pch) {
                 break;
             }
             num++;
-            num_ranks = (size_t)strtol(pch, NULL, 10);
+            num_ranks = (size_t) strtol(pch, NULL, 10);
         }
-        if (num == ns_id && 0 != num_ranks) {
+        if (num == myns_id && 0 != num_ranks) {
             *nranks = num_ranks;
             PMIX_PROC_CREATE(*ranks, num_ranks);
             for (j = 0; j < num_ranks; j++) {
-                (void)strncpy((*ranks)[j].nspace, nspace, PMIX_MAX_NSLEN);
+                (void) strncpy((*ranks)[j].nspace, nspace, PMIX_MAX_NSLEN);
                 (*ranks)[j].rank = j;
             }
         } else {
