@@ -2,6 +2,7 @@
  * Copyright (c) 2017      Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2019      Intel, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -14,13 +15,13 @@
 
 static void release_cb(pmix_status_t status, void *cbdata)
 {
-    int *ptr = (int*)cbdata;
+    int *ptr = (int *) cbdata;
     *ptr = 0;
 }
 
 static void get_cb(pmix_status_t status, pmix_value_t *kv, void *cbdata)
 {
-    get_cbdata *cb = (get_cbdata*)cbdata;
+    get_cbdata *cb = (get_cbdata *) cbdata;
     if (PMIX_SUCCESS == status) {
         pmix_value_xfer(cb->kv, kv);
     }
@@ -28,17 +29,19 @@ static void get_cb(pmix_status_t status, pmix_value_t *kv, void *cbdata)
     cb->status = status;
 }
 
-static int key_is_replace(int key_idx) {
+static int key_is_replace(int key_idx)
+{
     key_replace_t *item;
 
-    PMIX_LIST_FOREACH(item, &key_replace, key_replace_t) {
+    PMIX_LIST_FOREACH (item, &key_replace, key_replace_t) {
         if (item->key_idx == key_idx)
             return 1;
     }
     return 0;
 }
 
-int test_replace(char *my_nspace, pmix_rank_t my_rank, test_params params) {
+int test_replace(char *my_nspace, pmix_rank_t my_rank, test_params params)
+{
     int key_idx = 0;
     int key_cnt = 0;
     char sval[PMIX_MAX_NSLEN];
@@ -62,7 +65,7 @@ int test_replace(char *my_nspace, pmix_rank_t my_rank, test_params params) {
     }
 
     PMIX_PROC_CONSTRUCT(&proc);
-    (void)strncpy(proc.nspace, my_nspace, PMIX_MAX_NSLEN);
+    (void) strncpy(proc.nspace, my_nspace, PMIX_MAX_NSLEN);
     proc.rank = PMIX_RANK_WILDCARD;
 
     /* Submit the data */
@@ -81,7 +84,7 @@ int test_replace(char *my_nspace, pmix_rank_t my_rank, test_params params) {
         exit(rc);
     }
 
-    PMIX_LIST_FOREACH(item, &key_replace, key_replace_t) {
+    PMIX_LIST_FOREACH (item, &key_replace, key_replace_t) {
         memset(sval, 0, PMIX_MAX_NSLEN);
         sprintf(sval, "test_replace:%s:%d:%d: replaced key", my_nspace, my_rank, item->key_idx);
 
@@ -94,7 +97,6 @@ int test_replace(char *my_nspace, pmix_rank_t my_rank, test_params params) {
         }
     }
 
-
     /* Submit the data */
     if (PMIX_SUCCESS != (rc = PMIx_Commit())) {
         TEST_ERROR(("%s:%d: PMIx_Commit failed: %d", my_nspace, my_rank, rc));
@@ -120,7 +122,6 @@ int test_replace(char *my_nspace, pmix_rank_t my_rank, test_params params) {
             sprintf(sval, "test_replace:%s:%d:%d", my_nspace, my_rank, key_idx);
         }
 
-
         GET(string, sval, my_nspace, my_rank, 0, key_idx, 1, 1, 0);
         if (PMIX_SUCCESS != rc) {
             TEST_ERROR(("%s:%d: PMIx_Get of remote key on local proc", my_nspace, my_rank));
